!*****************************************************************************

!  MPFUN-Fort: A thread-safe arbitrary precision computation package
!  Global data definition module (module MPFUNA)

!  Revision date:  4 May 2018

!  AUTHOR:
!     David H. Bailey
!     Lawrence Berkeley National Lab (retired) and University of California, Davis
!     Email: dhbailey@lbl.gov

!  COPYRIGHT AND DISCLAIMER:
!    All software in this package (c) 2017 David H. Bailey.
!    By downloading or using this software you agree to the copyright, disclaimer
!    and license agreement in the accompanying file DISCLAIMER.txt.

!  PURPOSE OF PACKAGE:
!    This package permits one to perform floating-point computations (real and
!    complex) to arbitrarily high numeric precision, by making only relatively
!    minor changes to existing Fortran-90 programs.  All basic arithmetic
!    operations and transcendental functions are supported, together with several
!    special functions.

!    In addition to fast execution times, one key feature of this package is a
!    100% THREAD-SAFE design, which means that user-level applications can be
!    easily converted for parallel execution, say using a threaded parallel
!    environment such as OpenMP.  There are NO global shared variables (except
!    static compile-time data), and NO initialization is necessary unless
!    extremely high precision (> 19,500 digits) is required.

!  DOCUMENTATION:
!    A detailed description of this package, and instructions for compiling
!    and testing this program on various specific systems are included in the
!    README file accompanying this package, and, in more detail, in the
!    following technical paper:
   
!    David H. Bailey, "MPFUN2015: A thread-safe arbitrary precision package," 
!    available at http://www.davidhbailey.com/dhbpapers/mpfun2015.pdf.

!  DESCRIPTION OF THIS MODULE (MPFUNA):
!    This module contains some global parameter definitions, including data
!    statements for log(2), pi and FFT data.  See documentation for details.

module mpfuna
implicit none

!----------------------------------------------------------------------------

!   Integer constants:

!   Name     Default   Description
!   mpndpw       14    Largest n such that 10^n <= mpbdx (see below).
!   mpldb         6    Logical device number for output of error messages.
!   mpnbt        48    Number of significant bits in one mantissa word.
!   mpnpr         7    Limit on summation loop to prevent overflow of exact value.
!                        See usage in mpmul and mpdiv of module MPFUNB.
!   mpnstr     2048    Maximum length of certain input character strings.
!                        See usage in mpinp of module MPFUNC.
!   mpoutl       80    Length of output lines.  See usage in mpout of MPFUNC.
!   mprknd        8    Kind parameter for double precision.

!   Double precision constants:

!   Name     Default   Description
!   mpbdx      2^48    2^mpnbt, the radix for MP numbers.
!   mpbx2      2^96    Square of radix.
!   mpb13x     2^13    Constant for checking the 40-bit restriction.
!                        See usage in mpdmc40, mpmuld40 and mpdivd40 of MPFUNB.
!   mpdpw  Log10(2^48) DP approximation to number of digits per mantissa word.
!   mpexpmx   2^31/48  Largest permissible exponent, corresponding to a maximum
!                        binary exponent of 2^31, or, in other words, a maximum
!                        MP value of 2^(2^31) or approximately 10^646456993.
!   mprdx   2^(-48)    Reciprocal of radix.
!   mprx2   2^(-96)    Reciprocal of square of radix.
!   mpb24x     2^24    Square root of radix.
!   mpr24x  2^(-24)    Reciprocal of square root of radix.

integer, public:: mpndpw, mpldb, mpnbt, mpnpr, mpnstr, mpoutl, mprknd
parameter (mpndpw = 14, mpldb = 6, mpnbt = 48, mpnpr = 7, mpnstr = 2048, &
  mpoutl = 80, mprknd = 8)
real (mprknd), public:: mpbdx, mpbx2, mpdpw, mpexpmx, mprdx, mprx2, mpb24x, &
  mpr24x, mpb13x
parameter (mpbdx = 2.d0 ** mpnbt, mpbx2 = mpbdx**2, mpdpw = 14.449439791871d0, &
  mpexpmx = 2.d0**31 / 48.d0, mprdx = 0.5d0 ** mpnbt, mprx2 = mprdx**2, &
  mpb24x = 2.d0 ** 24, mpr24x = 0.5d0 ** 24, mpb13x = 2.d0 ** 13)

!  These are for debug and timing (for internal use only):

integer mpdeb(10)
real (mprknd) mptm(10), mpffterr
data mpffterr / 0.d0/

!  This data is for the extra-high precision routines.

!  The following data arrays contain the values of log(2), pi and 1/sqrt(2) to
!  over 19,500-digit precision (by default), as well as the FFT data needed for
!  this level of precision.  If more than this level are needed, subroutine
!  mpinifft (in module MPFUNB) must be called to initialize FFT data, and and
!  subroutine mpinitran (in module MPFUND) must be called to initialize data
!  for transcendental functions.  Alternatively, if you are using the
!  high-level interface in module MPFUNF, calling mpinit will do both tasks.
!  The arrays below have sufficient space to support precision levels up to
!  1.2 million decimal digits, which is the current limit of the FFT-based
!  arithmetic facilities.

!  ALL lines from this point on, except for the "end module" statement at the end,
!  are generated by the compcon.f90 program, available from the author.

integer, public:: mplconx
integer, private:: i 
parameter (mplconx =    100000)
real (mprknd), public:: mplog2con(0:mplconx-1), mppicon(0:mplconx-1)
integer, public:: mpnrow, mpnsp1, mpnsp2
parameter (mpnrow = 16, mpnsp1 = 2, mpnsp2 = 9)
integer, public:: mplfftx
parameter (mplfftx = 2100000)
complex (mprknd), public:: mpuu1(mplfftx), mpuu2(mplfftx)

data (mplog2con(i), i =     0,   199) / &
             1366.d0,             1360.d0,             1360.d0,               -1.d0, &
  195103586505167.d0,  133778733511576.d0,    4342055649523.d0,   73832410428973.d0, &
  151788831083434.d0,  275066478163488.d0,  120858980406677.d0,   91239248173840.d0, &
  260784747036984.d0,   36576601520937.d0,   19145758686870.d0,  222196413425861.d0, &
   29462839243132.d0,   62116936195011.d0,  194847100839279.d0,  176937458202443.d0, &
  126231365393765.d0,   80036545668797.d0,   61779653191007.d0,  177601983341474.d0, &
  239889354657599.d0,  235046513723921.d0,  276372481138957.d0,   53844124193186.d0, &
  262055775829022.d0,  274970201433054.d0,   21993245513542.d0,    8202775793893.d0, &
  221293478851705.d0,  225622362967653.d0,  162260933430298.d0,   33036113938781.d0, &
   41122620716388.d0,  179458407169930.d0,  103442383243085.d0,  200116971403939.d0, &
   13503550461749.d0,   14485135643001.d0,  195581999689265.d0,   66913113762993.d0, &
    8312697199405.d0,  196930144613656.d0,   88393674083606.d0,   50249832170813.d0, &
  129298406382306.d0,  127467472860870.d0,  157876961449684.d0,  253794729298075.d0, &
   75454611747612.d0,  242505152107473.d0,   37977425808751.d0,   89575767607125.d0, &
   42375692916024.d0,  203969635810628.d0,  117770751532690.d0,   38176024875973.d0, &
   72711714752916.d0,   36322735232762.d0,  268114574063328.d0,   47419910293177.d0, &
    6327171890443.d0,  231968534127385.d0,  117600549994592.d0,  251345919089164.d0, &
   95879166082746.d0,  137461145908764.d0,  216505551482671.d0,   14168412862808.d0, &
  236816550105118.d0,  110408930706528.d0,  242229520569710.d0,   13370838472163.d0, &
  107483325387338.d0,  192127966914301.d0,  176756035750577.d0,   19498034251556.d0, &
  166218749967293.d0,  172908610003094.d0,  254404162772847.d0,  137351655277998.d0, &
  227373202119736.d0,   56751808849445.d0,   15300974014586.d0,  281421970290510.d0, &
   25695525783770.d0,  191145470290608.d0,   64088378818737.d0,  196939451606010.d0, &
  217589326149976.d0,  146099287729173.d0,   42858490642088.d0,   75453598994141.d0, &
    6782196098756.d0,  217756228858646.d0,   33137890986362.d0,   63558951255199.d0, &
   59714466148130.d0,  259690607806544.d0,  260189874223884.d0,  129602057396236.d0, &
   93780675383943.d0,   81364072854925.d0,  163759387360814.d0,  221145027180873.d0, &
  241113341817473.d0,   88091186097215.d0,  110989328717132.d0,  105768102655891.d0, &
   56960753072844.d0,  105402542294416.d0,   54244293545730.d0,   65017250905304.d0, &
   78185399338480.d0,  185311010278807.d0,  121647780274381.d0,  199890795438994.d0, &
  150450663149098.d0,   15987745561228.d0,  275595954138506.d0,   74613280387600.d0, &
  201734075227507.d0,    8574975947492.d0,  203861945667938.d0,  192437001081331.d0, &
  180116197365349.d0,  142198091147458.d0,    2499946327060.d0,  203789626324152.d0, &
  236175450875141.d0,   60477881514818.d0,  204113471347674.d0,   34660108196850.d0, &
  267012163652376.d0,   58444033376343.d0,  151682516331349.d0,   44502942647957.d0, &
  212383510363905.d0,  258022104741313.d0,   97113923347023.d0,   22699343217259.d0, &
  114384259012605.d0,  169008804431273.d0,  152595235273198.d0,  262411934499018.d0, &
  221410497646848.d0,   60447253370540.d0,   54516590975541.d0,  117830074231469.d0, &
  192884302705135.d0,  135220615201332.d0,   56445241700653.d0,  275651341129081.d0, &
  245577285652848.d0,  123567284070441.d0,  108600876545151.d0,  144056835990942.d0, &
   99579787416815.d0,  224508764742632.d0,  277738108558722.d0,   50400954115991.d0, &
  249598162021020.d0,  255655957524147.d0,  220432528939136.d0,   20788468090605.d0, &
  205576065174739.d0,  215190454199855.d0,   18736384037546.d0,  255760138991356.d0, &
   74054042203330.d0,  144653784575084.d0,   21331652561849.d0,  189392989416467.d0, &
  181113702905686.d0,  139296914589963.d0,   93563020842062.d0,  114262935873176.d0, &
  279995856049605.d0,  260862025545473.d0,  237320336013263.d0,    6968861243825.d0, &
  195088832600827.d0,  265731143245885.d0,  108839276942147.d0,  100726235149991.d0, &
   17215841433222.d0,  151755608438887.d0,  134329325683771.d0,  274982931317830.d0, &
  193630729988494.d0,   15484022489265.d0,  192820241005692.d0,  230326077282611.d0, &
  236360132321680.d0,   67558891561000.d0,   18929540980065.d0,  126675226280527.d0/
data (mplog2con(i), i =   200,   399) / &
   47717570596963.d0,    3634416518882.d0,   19342301813387.d0,  131979500830094.d0, &
  262920070466752.d0,  200016459873976.d0,   25597879146249.d0,   77573433053914.d0, &
    1197871618795.d0,   65865452238589.d0,  214661541125919.d0,  277275078097098.d0, &
  170348525947293.d0,   90316708044982.d0,  281306286489974.d0,   73422233466639.d0, &
  149694074062905.d0,  224076455111773.d0,   60954284801544.d0,  258830233352191.d0, &
  212653530404806.d0,  253442088141602.d0,  160524754787762.d0,  102983631942850.d0, &
  128865784027396.d0,  140006421278710.d0,   81405809517255.d0,   68650155993454.d0, &
   37832854915375.d0,   89617006837016.d0,  216532658252885.d0,    1311809281854.d0, &
   94033860743482.d0,    6138692405006.d0,  125076239008825.d0,  108718824777625.d0, &
   13426892044241.d0,  201973645834375.d0,   55299111000652.d0,  169091261448454.d0, &
  215290432014539.d0,   90520033094045.d0,  139620431797887.d0,   97178327364614.d0, &
  152758535081896.d0,  153416181703553.d0,  183907326261870.d0,  231333563377134.d0, &
   71797829252597.d0,    6400049087546.d0,    7980722095096.d0,   34936458916095.d0, &
  136908500935539.d0,  270108969123140.d0,   78811438881861.d0,  248976523466178.d0, &
  167499615513836.d0,   52490274718826.d0,  254154230348924.d0,   56398809248966.d0, &
  275174389317670.d0,  129855786809334.d0,  222882717723920.d0,   97005866160674.d0, &
  209525070598760.d0,  175858923182344.d0,  265424809128842.d0,  266147258658136.d0, &
   48003877572006.d0,  182835236799438.d0,   21209668104110.d0,  138178179860415.d0, &
    1705826648354.d0,   57691496570075.d0,    4529364251823.d0,  107866129522215.d0, &
  116759792583139.d0,  207995797001906.d0,  175568749075247.d0,   76559446304172.d0, &
  275210608501502.d0,   90646761164106.d0,  123875964707856.d0,   18742534070871.d0, &
  178137919836391.d0,  158814234637599.d0,  224590949519737.d0,    6046312619175.d0, &
  185827254910473.d0,  270522521289795.d0,  146281389092191.d0,   67159052024752.d0, &
  164581319964721.d0,  137450285648594.d0,  224374661514192.d0,  105873520066965.d0, &
   12656841248404.d0,  184962465753238.d0,  150431189073158.d0,  208519440279059.d0, &
  275024132828313.d0,  101515573191510.d0,  261205812397053.d0,   44048353981725.d0, &
  106081858966363.d0,   84564487661341.d0,   79680173610188.d0,  216389025269994.d0, &
  120543730777058.d0,  204574319145901.d0,   68008481428258.d0,   79161990722663.d0, &
  267319181922276.d0,  119252523306333.d0,  139146931451611.d0,  273487653308409.d0, &
  254921674365271.d0,   39038433882106.d0,    3597935490001.d0,  280297267130700.d0, &
   70529724415792.d0,  156919208299669.d0,  230493405887962.d0,   12517132321992.d0, &
  122895897937924.d0,   32317396470650.d0,  266249285370521.d0,  138021762603497.d0, &
   20632552422837.d0,  183758263374523.d0,  112921023057134.d0,   51443762300721.d0, &
   19375549422992.d0,  233362842028913.d0,  277128688998670.d0,  145973892541641.d0, &
  280191308030867.d0,  225148200551271.d0,  191364227354047.d0,  251576593672011.d0, &
  156004663785149.d0,  199013236138668.d0,   58157781452724.d0,  213986002995369.d0, &
  243664549839562.d0,   53842581741715.d0,  212775026434720.d0,  208550997664128.d0, &
  164869708165228.d0,  222683837745367.d0,  127153179914152.d0,   19204047004857.d0, &
  265743218623822.d0,  204341784042820.d0,   31301323357402.d0,    2986353706313.d0, &
  100393815303864.d0,  103961648074621.d0,  231386767083740.d0,  255869280736063.d0, &
  213588691495375.d0,  182157439097581.d0,  168858777553206.d0,  169441395612625.d0, &
   58337667456069.d0,   83690140583698.d0,   25113723323869.d0,  101537986451186.d0, &
  233094389419370.d0,  225535400301681.d0,  164143579708216.d0,  192379747049480.d0, &
  207633904876117.d0,  129586380797524.d0,  175043482756169.d0,    7716500409425.d0, &
   69212219846854.d0,  270806330151227.d0,  142415846327202.d0,  108297404459331.d0, &
   97523295692872.d0,  233176374390483.d0,  198925925097568.d0,  107753876368199.d0, &
  245137114819524.d0,  142542220326796.d0,   15493779566460.d0,   20506821940273.d0, &
   82448910622913.d0,  273781126311097.d0,  187369432029489.d0,    4228524855505.d0, &
  118744674376477.d0,  101644227031446.d0,  252499658992214.d0,     134061136051.d0, &
   81996629444444.d0,  182999151706347.d0,  258437359096080.d0,   71293889383057.d0/
data (mplog2con(i), i =   400,   599) / &
  230410814877742.d0,  170057868565236.d0,  171371622025233.d0,  134847692056066.d0, &
  151501694940484.d0,   96624837431165.d0,   53898859206901.d0,   11851673200160.d0, &
  225014554505069.d0,  211716131412437.d0,  241044453609508.d0,  186593772023827.d0, &
  260211371416707.d0,  115387932949895.d0,  197327557216792.d0,    6644283294398.d0, &
   72312279686602.d0,   28861124101221.d0,  240116388083751.d0,  165433633409441.d0, &
  276727840761073.d0,  279637835023939.d0,  278371550681685.d0,  201514043036184.d0, &
  139615938199743.d0,  157071905273047.d0,   29498863248826.d0,  222648799734689.d0, &
  213797643872281.d0,   18591672101223.d0,   30683786463517.d0,  128621771824091.d0, &
   71582186047868.d0,   21141024953751.d0,  262399375810854.d0,  153924264004070.d0, &
  250662120730107.d0,   93939684008404.d0,   48412575280487.d0,   68005114243842.d0, &
  115694613481485.d0,  214085711051187.d0,   94148898759896.d0,  194800505857973.d0, &
  210837158571303.d0,   56056257669894.d0,   51197309396874.d0,  255701216470871.d0, &
  191244025951399.d0,  119289140495714.d0,  180839070209933.d0,  224489600431629.d0, &
   99730213120109.d0,  152598355743118.d0,  104604513742500.d0,  155571924780358.d0, &
  279629163503381.d0,  234737350879168.d0,   10770321497396.d0,   89450480768584.d0, &
  111187786813935.d0,   40463254976141.d0,  156731888631217.d0,  224877865586738.d0, &
   68034045851818.d0,  210281185157174.d0,   11356595679835.d0,  235280700189728.d0, &
   34322529102390.d0,  203351633480324.d0,  242181241623623.d0,  245887163809929.d0, &
    7289878447508.d0,  170369970298469.d0,  103449600136593.d0,  240616800281724.d0, &
  204242207882229.d0,  160686015350844.d0,   47297575232836.d0,  188530013530724.d0, &
  247063001476209.d0,   38724526359348.d0,   39135831677369.d0,  137793734467805.d0, &
  265024439024810.d0,   88361666100258.d0,  179809262458869.d0,  198150566776540.d0, &
  124794331196883.d0,  219972112482677.d0,   70223633331425.d0,   84923376684871.d0, &
   38639046155066.d0,  213467993571147.d0,  197830900177348.d0,  263400902162612.d0, &
  183590302445675.d0,  185630937928191.d0,  193686678155570.d0,  106573808550422.d0, &
  247910996357089.d0,  216795898397043.d0,   22176325248376.d0,  170471668911425.d0, &
  131892859147807.d0,   96906956266928.d0,  166434476871260.d0,  157856511084937.d0, &
  142156950432370.d0,  110208140707088.d0,  242687743740218.d0,  263771378654342.d0, &
   87502737016260.d0,  124296493961079.d0,  154089783455926.d0,  174050894091736.d0, &
  166830226537139.d0,   19984683622728.d0,  153209777169061.d0,  102860355946189.d0, &
  262523732789274.d0,   15139020104995.d0,  204902555163817.d0,  109546915179702.d0, &
   41343688041445.d0,   51439613515959.d0,  230781426453475.d0,  203724520217684.d0, &
  248234460787220.d0,   56743827623138.d0,  126958875365281.d0,   36305846590841.d0, &
  146400213633706.d0,   95673234958982.d0,  220956708620069.d0,   26137721429821.d0, &
  182094762658797.d0,  216034029663403.d0,  254380123718064.d0,  234180328925157.d0, &
  177474086628432.d0,  193752330699091.d0,  273887893961070.d0,  146813939888376.d0, &
  143172322441086.d0,   44539556003888.d0,  163807636991393.d0,  201054755762119.d0, &
  175239429632248.d0,  145696636817760.d0,   74454040520063.d0,  280429078613611.d0, &
  226505524803319.d0,  278593925585612.d0,  105274723653286.d0,   95204274348992.d0, &
  104520979784490.d0,  184198080969994.d0,   74075889758111.d0,  273303688957503.d0, &
  173252775149826.d0,     858799233914.d0,  217022596041691.d0,  236686968940288.d0, &
  249539037427872.d0,   55977001987480.d0,  206266288708105.d0,  197694382419603.d0, &
  179656092929311.d0,     579225722060.d0,   87043964267037.d0,  264971709570821.d0, &
  231726321821214.d0,  132138702912395.d0,  251863994220843.d0,   91511170940456.d0, &
  232953781218497.d0,  262471205598915.d0,  109669594235372.d0,    6189908072367.d0, &
  110599166899784.d0,  200933938818554.d0,   18582511257941.d0,  179514711726577.d0, &
    6203407837472.d0,   96891387017940.d0,   27347439327089.d0,  277859498192297.d0, &
   91323024063363.d0,  137233651349827.d0,  106385672836290.d0,  121989587162756.d0, &
  189792092997659.d0,   14798801586828.d0,  106308873783277.d0,   62945161231111.d0, &
    6591952223845.d0,  193751230167055.d0,  129538237648047.d0,  148228887602016.d0/
data (mplog2con(i), i =   600,   799) / &
  136004072324168.d0,   92438179656622.d0,  145241401731107.d0,    3051676627749.d0, &
  169432440905989.d0,  157944200198412.d0,  192522121698852.d0,   83529653086879.d0, &
   52351050852786.d0,   66605402567606.d0,   55119593043629.d0,   64740644039012.d0, &
   32450678009402.d0,  274330379382847.d0,  221771824533416.d0,  171855263469350.d0, &
  205546039097717.d0,   52245572238282.d0,   80012963692205.d0,  193374799264619.d0, &
  262582960673740.d0,  131945829852888.d0,  176177949134471.d0,   22195033689854.d0, &
   53082657688351.d0,  163218548340187.d0,  220238261473582.d0,  201499807118194.d0, &
  196677934927484.d0,  175301899109228.d0,  205420950084001.d0,   65853530639324.d0, &
  190448906149347.d0,  120644581416057.d0,  206086553389361.d0,  221230296804452.d0, &
  233187641324306.d0,   27561055008612.d0,  121664062913139.d0,  149895010755713.d0, &
  157001800950839.d0,   23613064851248.d0,  165713685242443.d0,  229422429856725.d0, &
    1543684514699.d0,   27011889955256.d0,   20110491237465.d0,   32421148126105.d0, &
   60440799428305.d0,  167739242130392.d0,   74767637959584.d0,  175861839777725.d0, &
  206464500357403.d0,   21039639719672.d0,  198727132101896.d0,  153874110638546.d0, &
   39465247326401.d0,   25630195241631.d0,  216287715916127.d0,  187978948287470.d0, &
   31363056568953.d0,  254365980246506.d0,  113205752568364.d0,  113703169213286.d0, &
  177021089581251.d0,   52111438793163.d0,   40721007441772.d0,  209505245209280.d0, &
  243771449015718.d0,  171278891130996.d0,   49175264375326.d0,   23638775957155.d0, &
  173976946952342.d0,   33303008552378.d0,  273550220417749.d0,  274137849637303.d0, &
  140386519112515.d0,    9130903652366.d0,  258898017068385.d0,   16303174130415.d0, &
  244414634262605.d0,  195660808411235.d0,   39582821192189.d0,  157742701228250.d0, &
  116859866127231.d0,  107227673132936.d0,  111186957156229.d0,  129533820498373.d0, &
   76063010009853.d0,  250727598774913.d0,   64327005017493.d0,   12579182119697.d0, &
  264088297050976.d0,    3724428620639.d0,   13296247129642.d0,    4555859629815.d0, &
   17927332493138.d0,   56301990541358.d0,  188398218125487.d0,    5436555510272.d0, &
  150425299997993.d0,  268875997060783.d0,   14772297588908.d0,   87612842943612.d0, &
  123726543998107.d0,  168532969009698.d0,  216196703941688.d0,  100783496419201.d0, &
  182855124882763.d0,  265616112127378.d0,   79955932276259.d0,  185468689781840.d0, &
   40334418771488.d0,   99930641370608.d0,    2838688525953.d0,  280788521712797.d0, &
  202970341943248.d0,  160842845780768.d0,  164995583896402.d0,  257111712011824.d0, &
   16271330390919.d0,   32511527263805.d0,  221158831297283.d0,   33806710298920.d0, &
  250946605467406.d0,  136422651167831.d0,  133115977159509.d0,  278404661474537.d0, &
   56216932630957.d0,  155552177913552.d0,  218870012701380.d0,  191280168504666.d0, &
  108178540543232.d0,   98303227767928.d0,  181053727579220.d0,   77549318883347.d0, &
  183273587631130.d0,  208670025026107.d0,   49751378857213.d0,  264220163459237.d0, &
  175968859763296.d0,  222583943668733.d0,     107219476308.d0,  169861515952748.d0, &
  105558002468756.d0,   75175205370650.d0,   64907000883236.d0,   92514263600935.d0, &
   14342140417440.d0,   68082289174194.d0,    7506781596875.d0,   58702502149497.d0, &
  152424469374981.d0,    1871530797301.d0,  163816197873254.d0,   51058355969501.d0, &
  148675045366233.d0,  168793984476761.d0,  117184953706018.d0,   99293824787141.d0, &
   38740984133523.d0,   74577967426910.d0,  197765606552696.d0,  151343196124126.d0, &
  197847605585695.d0,  250379815020583.d0,   84693703438401.d0,  104392836652696.d0, &
  247350819591380.d0,  188504093259478.d0,  123570240288388.d0,  208598922785664.d0, &
   82476497063915.d0,    9889866338691.d0,  111399473505455.d0,  254432690370903.d0, &
  173575738293302.d0,  116247040897508.d0,   88016417198600.d0,  179388824371929.d0, &
    9941867792480.d0,   62307771773693.d0,  116136865147971.d0,    6732731366072.d0, &
  240166885547208.d0,   27671529713255.d0,   66348242278403.d0,   19431475665847.d0, &
  123149702148731.d0,   29691231326242.d0,    5841695992505.d0,   78871988983040.d0, &
  232890641734803.d0,  206115782613284.d0,  276427053087969.d0,   48749547571903.d0, &
  131599671576951.d0,   38277341297810.d0,  209896944546986.d0,   93705826307682.d0/
data (mplog2con(i), i =   800,   999) / &
  195793474807783.d0,  195761340541103.d0,  101254102852393.d0,  273226048604778.d0, &
   99421173516415.d0,  217164876447430.d0,  254799542850169.d0,   63776419546352.d0, &
   36066895072114.d0,  263392182250810.d0,    3025565518622.d0,  263960696603841.d0, &
   27008869657557.d0,  146958581086354.d0,   64566586690166.d0,  167764211734509.d0, &
  134237306759934.d0,   88992953130893.d0,   97456965307715.d0,   96242621953770.d0, &
   52776712568635.d0,  222806773570039.d0,  126316470223183.d0,  151309709044965.d0, &
  162152305058473.d0,  254205271289820.d0,   96807922811783.d0,  242091481973358.d0, &
   33351108622730.d0,   79650636832334.d0,   39320790206871.d0,  144787979287983.d0, &
   93533692117148.d0,   41641865231315.d0,  259276997450870.d0,  235549569915797.d0, &
  236155664269968.d0,  255041926325390.d0,  181933034888424.d0,   41034503134517.d0, &
  116743050788353.d0,  167102167708062.d0,  182082313653276.d0,  270020391852066.d0, &
  141472761810758.d0,   57323477200181.d0,  214422468031023.d0,   35443987584955.d0, &
   33069906896357.d0,  113471794134797.d0,  145604697461982.d0,  238767188840876.d0, &
  143637923038934.d0,   78515875319205.d0,  178186990407477.d0,  130711710958179.d0, &
  277311102121166.d0,   72874462168264.d0,  141526949166577.d0,   84072045215436.d0, &
  271085585358739.d0,   66005957358079.d0,   92326918362945.d0,     283328812281.d0, &
  226711811451271.d0,  189530094504126.d0,  159212688799953.d0,   98812345449679.d0, &
   78636233817987.d0,   75493541844801.d0,  178085063342101.d0,  152157638507225.d0, &
  230836301406950.d0,   31271242244299.d0,  209442073459224.d0,  141501893626205.d0, &
  233159525450668.d0,  109445467824790.d0,   85095235845442.d0,  240949781360056.d0, &
   87394644774572.d0,  187007185779642.d0,   32413551298512.d0,  115370468991076.d0, &
  196198894869763.d0,  115198530706168.d0,  209551858903758.d0,  120433948955693.d0, &
  101420793794908.d0,  115589518530921.d0,   93029517434973.d0,  254089914342791.d0, &
  149752441807333.d0,   36631151846066.d0,  263131703329213.d0,   41006912568345.d0, &
    9269377515035.d0,  188510109735537.d0,  115021374359131.d0,   36990392508687.d0, &
  271668528095271.d0,  242453982513685.d0,  159875842688570.d0,   64309341605957.d0, &
  164077661588569.d0,   13309108671365.d0,  175001613372894.d0,  126785583330244.d0, &
   23433524384892.d0,  275107686446546.d0,  197782557871845.d0,  214061837218594.d0, &
  126156598046108.d0,   27018686241866.d0,  121427676394830.d0,  202001385988389.d0, &
    4699062608999.d0,   98140202248620.d0,  207169493414035.d0,  101553674145453.d0, &
   33824324716536.d0,  104552568772465.d0,  266190812159840.d0,   84287351446124.d0, &
  195322694302702.d0,  183761891997203.d0,  118528996429553.d0,  269900868298458.d0, &
  213298020878642.d0,   78528524421873.d0,   80240538177563.d0,   25953427615860.d0, &
  235380788937767.d0,  192570047944066.d0,  157807283045511.d0,    4068981866538.d0, &
    8907475064745.d0,  241319373197806.d0,  273350915486307.d0,  133934817021413.d0, &
  164656840779985.d0,  161424742511936.d0,   45471532103282.d0,  210038336780417.d0, &
   47670251419623.d0,   14086799602094.d0,  256903337419641.d0,  165262266942297.d0, &
  242333950988296.d0,  189782000431885.d0,  177945414303986.d0,   80842781930930.d0, &
  164231862990765.d0,  273907062797477.d0,  239849291956836.d0,   53867284005157.d0, &
   35296015116898.d0,   94223969309474.d0,   49012382286059.d0,  178526174772365.d0, &
   31902421611467.d0,  111180007265454.d0,  234682577550776.d0,  268466172990030.d0, &
  192651242350769.d0,   69255076661766.d0,   47988851117212.d0,  178616626285421.d0, &
  136185197929846.d0,  249877918077345.d0,  270000309919521.d0,   69240916798233.d0, &
  183863246850943.d0,  227407506439533.d0,   59116371040868.d0,  140270613449130.d0, &
  240969019658572.d0,  249313339705313.d0,  189738292511636.d0,   47225397616956.d0, &
   74149656493350.d0,   31485101873059.d0,  128418887147825.d0,   13141767007198.d0, &
  161159463408360.d0,  141956140704906.d0,  275378384364915.d0,   93436585416233.d0, &
   94449495120331.d0,  232946354592176.d0,  280366342195430.d0,  175460997846560.d0, &
  103425820621099.d0,  172234023689801.d0,  119197898804223.d0,  123870543969748.d0, &
  224977587931488.d0,  280986393894442.d0,   85312945491244.d0,   41880582972114.d0/
data (mplog2con(i), i =  1000,  1199) / &
  166719834692845.d0,  178495379211246.d0,   91090385265466.d0,   40800725435897.d0, &
  119154938032654.d0,  269313471301386.d0,  141536841559170.d0,  247330076132078.d0, &
  148200335969451.d0,   19250496339599.d0,  155010018408613.d0,  157370986299554.d0, &
   91900459309021.d0,  190722594275419.d0,  255900344488295.d0,   55473482766731.d0, &
   80045647682255.d0,  121044956139119.d0,  127199422751069.d0,  126330667355042.d0, &
  193012369343547.d0,  148614875565433.d0,  242224297604743.d0,  109033090425170.d0, &
   65695076526608.d0,  251380611615520.d0,  197782891247620.d0,   83705224023012.d0, &
   43416732199777.d0,   94525039484688.d0,  109876466666777.d0,  263532167714528.d0, &
   27259864027241.d0,  101492416808489.d0,  245625526492122.d0,  141886419919538.d0, &
  105137023175583.d0,   35324311135020.d0,   61768789352196.d0,  197728797190064.d0, &
  277622955861000.d0,  129226118089360.d0,  277308410242938.d0,  127028990673694.d0, &
   26265941718156.d0,   82956488255395.d0,  257999362662576.d0,   67730067708843.d0, &
   45397563760447.d0,   64673654562483.d0,  131638810601088.d0,   99326882221430.d0, &
  110567372143845.d0,  225158660219543.d0,   15040782050925.d0,   18011784749004.d0, &
   49061472858790.d0,  194030729753645.d0,  184651824206692.d0,  231215480073694.d0, &
   73419833487202.d0,  140353679853941.d0,  160034011938518.d0,  181755075097430.d0, &
   27720566028803.d0,  180195451893298.d0,   39476403718892.d0,   35075895532596.d0, &
   49852957462675.d0,  252404813827448.d0,   41841576066276.d0,   70187239958453.d0, &
  209912636578837.d0,  160006163514944.d0,   36862903226980.d0,  230274833620625.d0, &
   49437778696660.d0,  168615909980332.d0,   16284724565290.d0,  153658742354859.d0, &
   70575925538568.d0,  278660779511482.d0,   28570874697568.d0,  244002666033535.d0, &
   61990110744475.d0,   73047696081250.d0,  149910319898194.d0,   45233244696203.d0, &
  188766009720589.d0,  233357536950142.d0,  230920893367432.d0,   52781013697371.d0, &
   54809554637519.d0,  170393388360719.d0,   27688331883894.d0,   47019906322495.d0, &
  139447410478434.d0,  160079226479905.d0,  131592082214023.d0,  168790218007371.d0, &
   85081063680057.d0,  260920685259063.d0,   95241489299696.d0,   48794270034510.d0, &
  200650461711090.d0,  233897404807092.d0,  259257824381247.d0,   17588370099795.d0, &
   80254586876216.d0,  240067518771106.d0,   19834396142554.d0,   57028318201992.d0, &
  135136208671313.d0,  183185679283367.d0,   76947807318735.d0,  250130684656423.d0, &
  141900668142634.d0,  281422767033645.d0,   43521187378004.d0,   51702927463694.d0, &
   66201327395128.d0,  179383527439856.d0,  179128910797215.d0,  218582749151468.d0, &
   15131538392951.d0,  161266103165609.d0,  165063898221626.d0,   45473979771279.d0, &
  117580224369398.d0,  270857582599583.d0,   41898201878403.d0,  247001702128902.d0, &
  272136316862398.d0,  222697462030598.d0,   20369923570657.d0,   14750749777773.d0, &
  157822823839815.d0,   63344535482457.d0,  182122083070311.d0,  184805317124815.d0, &
  175610276654621.d0,  128885937438810.d0,   78671277270634.d0,   41726019781907.d0, &
  154691668725950.d0,   24146332505197.d0,   77812683636011.d0,  189588459282040.d0, &
   75161068241705.d0,  208842085871610.d0,   96614885732891.d0,   39356867131667.d0, &
  153948469179812.d0,  120167836104715.d0,  180061291783787.d0,  178653537147680.d0, &
  105803920181920.d0,  253872819864271.d0,  202388080738215.d0,  101157252328640.d0, &
  177186683841365.d0,  103943139539566.d0,  204307235828068.d0,   56825811867060.d0, &
  102150773872115.d0,  178058679546431.d0,    9538690654759.d0,  234255189137201.d0, &
   77917184016557.d0,  130624682850491.d0,  137174497523946.d0,  170381253321994.d0, &
   96405400517664.d0,  113172517329220.d0,  228151894262173.d0,  275540944860387.d0, &
   70891482908216.d0,  243333325080460.d0,   12833899417286.d0,  123439520879850.d0, &
  206056868614635.d0,  233010729167073.d0,  159926730765327.d0,   78219652034625.d0, &
   63769533227598.d0,   51811356049634.d0,   10218972180589.d0,  223532567436227.d0, &
   65538657650243.d0,  120168397314582.d0,   81968086686931.d0,   68635031707224.d0, &
  125069300672612.d0,  221051297603021.d0,   84347209112934.d0,  194320182812887.d0, &
  236548216101560.d0,  210060739809593.d0,  182616332628824.d0,  176830208056941.d0/
data (mplog2con(i), i =  1200,  1365) / &
  257962208112377.d0,  221841847227500.d0,  175605889644712.d0,  235365910754710.d0, &
   53894550676333.d0,  130952690109055.d0,  159793621284027.d0,  144433250819931.d0, &
  100168642278580.d0,  128755259825569.d0,  234242901681504.d0,  212233574256013.d0, &
   82802583742124.d0,   35152326773884.d0,  156447087032835.d0,  235614066329664.d0, &
  239917264686370.d0,  180323706718221.d0,   35349575622922.d0,   60700529184750.d0, &
   70721144960403.d0,  227164782214788.d0,    4293175357312.d0,   69457381831815.d0, &
  160183605414188.d0,   80521771893208.d0,  148478617144108.d0,  261432054307377.d0, &
  137090364627560.d0,   81783333520759.d0,   87021506971727.d0,  156087619307690.d0, &
  102223868138878.d0,  218416600136766.d0,  118003682085238.d0,  172802199893976.d0, &
   60329667695640.d0,   93372180461143.d0,  213010537589539.d0,  157839820060465.d0, &
   28107661889108.d0,  169624012256913.d0,  108652753837526.d0,  100629275095442.d0, &
   44465325969887.d0,  224919807441880.d0,  122524532991229.d0,   76593209734133.d0, &
  238498219815259.d0,  104041709688302.d0,  247929077624049.d0,  211543676600549.d0, &
  274177561752011.d0,  184778801982322.d0,  194421166303430.d0,  226495997432766.d0, &
  176059350605062.d0,   34996850358300.d0,  257868640681287.d0,  217681404758299.d0, &
  259298602088149.d0,  256981101916121.d0,  187337060065093.d0,  214307770905913.d0, &
  175188002059574.d0,   89033756914915.d0,  195963775852191.d0,  206636713827921.d0, &
   19997107225269.d0,  177033734596143.d0,  208620730994525.d0,  190551497856653.d0, &
  275838344190435.d0,   98667030008419.d0,  243094529735413.d0,   15116936646847.d0, &
  171432684027626.d0,  196800526973011.d0,   86707763284171.d0,  189106077104597.d0, &
  128090430638098.d0,  142916434612959.d0,  120720142974820.d0,  206817699133869.d0, &
  157941083436537.d0,   80349227048311.d0,  190262298862224.d0,  205537896491528.d0, &
  279996825758071.d0,   48177585868729.d0,  175366477405397.d0,   85834545254716.d0, &
   91163495070959.d0,  255162326686060.d0,  168414434618762.d0,  134504744738519.d0, &
   65100542393082.d0,  225844735672407.d0,   66497832275490.d0,  238798744006118.d0, &
  178371797016599.d0,  227308724520324.d0,  133630951941831.d0,  271575310659528.d0, &
   82623618547531.d0,  129637611243515.d0,   86625938035381.d0,  159339367983205.d0, &
   75916429590586.d0,  266556358563224.d0,  237356049820651.d0,  134777520832468.d0, &
  163731223583245.d0,   14103109729464.d0,   18508810798681.d0,  157745234342115.d0, &
  259017490743306.d0,  269152906409258.d0,  124306085987923.d0,  267911797427020.d0, &
  144028784662322.d0,   89782967533566.d0,   39093231972367.d0,  244696500140285.d0, &
  241777129684435.d0,  267224564138396.d0,   36407663518230.d0,   57219901782661.d0, &
  250475113907153.d0,  250261810546155.d0,  151985810051236.d0,   29355963334804.d0, &
  122264303773584.d0,  106836684856976.d0,  267139479101077.d0,  111407330284171.d0, &
  199616964908989.d0,  240911958265745.d0,  216446298613970.d0,  132485490221102.d0, &
   99006950416098.d0,   42189720477805.d0,  216694627931887.d0,  275299537772413.d0, &
   18922357984059.d0,   32590389403003.d0,   29921508803880.d0,  212072072952283.d0, &
  214793333129405.d0,  181264524377119.d0,  191985170506645.d0,  220503061463397.d0, &
  185223048143791.d0,   75452359098730.d0,  198300390228062.d0,  200525392796179.d0, &
   27754149989446.d0,  152216085100888.d0,   53242222333168.d0,  107808555753668.d0, &
  139244811837043.d0,  128176336483743.d0,   68748105767857.d0,  139191175313584.d0, &
                0.d0,                0.d0/
data (mppicon(i), i =     0,   199) / &
             1366.d0,             1360.d0,             1360.d0,                0.d0, &
                3.d0,   39854788871587.d0,    9702651562542.d0,    3781505098761.d0, &
   61719378342352.d0,    8997865843790.d0,  119336826577382.d0,   62466330967636.d0, &
  113040131951724.d0,  211845666818428.d0,   88911183664565.d0,  199316699845142.d0, &
  235130291092251.d0,  230008579070175.d0,  199751144141531.d0,  228813841086689.d0, &
  193434223017622.d0,  205044159213868.d0,  140295721294151.d0,  197437179758593.d0, &
  267054717271062.d0,  109303173771607.d0,   86215635828387.d0,  268913229041045.d0, &
  128159451100760.d0,  124845259522581.d0,   82388131816477.d0,  213693307919408.d0, &
  234441510379539.d0,  217504393930848.d0,  147269231933720.d0,  203251692572281.d0, &
  242650086774798.d0,  119426104668190.d0,  152002501113793.d0,  208019411925167.d0, &
   52614781754464.d0,  253253383334485.d0,  188653607884898.d0,  109848423323082.d0, &
   63128145170614.d0,  198789813244225.d0,  255974167578287.d0,  136832986887150.d0, &
   22064915266602.d0,   48008160703512.d0,   54936093867542.d0,  171006591152086.d0, &
  204730020450140.d0,  134356567926933.d0,  147846658476184.d0,  117972982023359.d0, &
  255204375667091.d0,  107580505258785.d0,  186441451482208.d0,  103270344486788.d0, &
  102657931179441.d0,  242056354261861.d0,   30271525699201.d0,  232644097150829.d0, &
  123091681559097.d0,   50625928930436.d0,   35203326734410.d0,  173858587812294.d0, &
  114636819623066.d0,  113303860915155.d0,  150566157263058.d0,  237856084235791.d0, &
  183793114756003.d0,  121972967871354.d0,   65853563072592.d0,  139617216537073.d0, &
  111176196227446.d0,  113019266695747.d0,   15979642783257.d0,   76345723092356.d0, &
  182257936195262.d0,  246769323115969.d0,   35679368791199.d0,   95388717960915.d0, &
  187338793645830.d0,   30781484450459.d0,    2461952694052.d0,  228741675014927.d0, &
  258193199579291.d0,    8054989488281.d0,   30215729609176.d0,  271480033633278.d0, &
   88075660774459.d0,  166493882746048.d0,    7399182782390.d0,   71053267459676.d0, &
  174556487230563.d0,  115429119835756.d0,   92037176734443.d0,   65227340082684.d0, &
   89196189488428.d0,  224855584976734.d0,  207849554956292.d0,  244311882819087.d0, &
   44010952346547.d0,  211980935185864.d0,  127611297292089.d0,  204320114693497.d0, &
  211918423863818.d0,  235986991071276.d0,  125865755092478.d0,  276113310650021.d0, &
  257255038657272.d0,   66473592618337.d0,  117738732265160.d0,  190238373392957.d0, &
  200089593415520.d0,   91471986834944.d0,  245752095594427.d0,  222580449483399.d0, &
   94759311337947.d0,  234482279262334.d0,  281215876149958.d0,  154272363931995.d0, &
   43640018327752.d0,  248488073738480.d0,   19379177274776.d0,  278320385641212.d0, &
  199476229821275.d0,  169685106145016.d0,   76303626553788.d0,   83543951729117.d0, &
  267020881591859.d0,  108830499393252.d0,  218703746616026.d0,   59886004195454.d0, &
  174814496104372.d0,  164771492900496.d0,  160085958299249.d0,  118282688450702.d0, &
  230694232466912.d0,  156389879025269.d0,  163516115247867.d0,  266159851341960.d0, &
  202389865754652.d0,   87606035507343.d0,  214528546566545.d0,  197537385230127.d0, &
   37489663154039.d0,  257789003729666.d0,   34780202716175.d0,  199490307365036.d0, &
  268103913693849.d0,  198634987650323.d0,  247078676872065.d0,  231643303974495.d0, &
  178561127642885.d0,  162506313310490.d0,   22505203769445.d0,  131623475922772.d0, &
   73624255804879.d0,  259268637653822.d0,  151323882363859.d0,  191445990965285.d0, &
   15586980639582.d0,   37830084220856.d0,  247042834445979.d0,  263924551144803.d0, &
  159555247908522.d0,  132771457128794.d0,   91805471038370.d0,    3185687495462.d0, &
    3806995009449.d0,   19551117397619.d0,   81646041116106.d0,  135328669768529.d0, &
     354776459541.d0,  235361376648347.d0,  218683282596982.d0,  142826788620474.d0, &
  122824641210655.d0,  266730025462285.d0,  238687277507873.d0,  254785944485684.d0, &
    5698440484452.d0,   92016140462495.d0,  157921798932377.d0,  121517634112378.d0, &
  124149078108484.d0,  241295711716377.d0,   41934675420848.d0,   80985357917422.d0, &
  106345804968550.d0,  260217244838298.d0,   26385433514604.d0,  214068130552118.d0, &
    2909656402985.d0,  176304435553304.d0,   64039024892058.d0,  100341666638735.d0/
data (mppicon(i), i =   200,   399) / &
  251610357252054.d0,  177925932969960.d0,   53830119930086.d0,  264043277405405.d0, &
   35762119699238.d0,  109413918966302.d0,  224704256830271.d0,   68972607782039.d0, &
   26475980550305.d0,  114895567999648.d0,  249068233970437.d0,  187260695166471.d0, &
  145257939250780.d0,  156668678395670.d0,  266875044551223.d0,  264226590289948.d0, &
   34102073930751.d0,  191370674977973.d0,  128308482374232.d0,  241931778904465.d0, &
   21962259247094.d0,  162943668003573.d0,   78070608684417.d0,   61310035085493.d0, &
  129968310050215.d0,  186111154851792.d0,    3362637006654.d0,  180822925763128.d0, &
  226058018885167.d0,   55528485099582.d0,  197024348932920.d0,   87332674367298.d0, &
   14310663914687.d0,   49169097041047.d0,  136860583702642.d0,  207462115303066.d0, &
  130978677983248.d0,  197412502297807.d0,   69468228317727.d0,   51038994583578.d0, &
  243982588497287.d0,  134519568495624.d0,  239795483679420.d0,  256510438206586.d0, &
  259737535192570.d0,  108891436663908.d0,  215310722144327.d0,   55069416938819.d0, &
   65108025981462.d0,   20483995282021.d0,  215853523271682.d0,   21143668748767.d0, &
  273357760187989.d0,  142577744895761.d0,   28153581229809.d0,  237098425334801.d0, &
   26643177710857.d0,  266699868575729.d0,  277053823434540.d0,   33076557022947.d0, &
   76351279820721.d0,  147396265400894.d0,   46950286092060.d0,   86024017029477.d0, &
  242689709120783.d0,  141006088852070.d0,  220062016129400.d0,  171595543528981.d0, &
   16194524605048.d0,  182502762421770.d0,   50530071563943.d0,   59498907375929.d0, &
   41846298540384.d0,   90313079715603.d0,   20576847396462.d0,  258123766358972.d0, &
   76509045573763.d0,  195159955407244.d0,  280550538665455.d0,  209372586534232.d0, &
   36856870443010.d0,  262571299953455.d0,  164081355947437.d0,  100528801715489.d0, &
  200283603296624.d0,  260435130802591.d0,   23158795839536.d0,  258805025080116.d0, &
  279407654822863.d0,  199507078827120.d0,  178369280777739.d0,  223934730792652.d0, &
  148143629020327.d0,  172259808097011.d0,  145609668107951.d0,   28303579324451.d0, &
  116244990311248.d0,   70816934018090.d0,  198681724643797.d0,  211251069688660.d0, &
   12204273279129.d0,  164890664657469.d0,  138164672366746.d0,  167001976148461.d0, &
  162036607095425.d0,   15623080495078.d0,   35006514651041.d0,  132322483066869.d0, &
  145844659712611.d0,  170990231296706.d0,   77613510101739.d0,   91457844449241.d0, &
   80145930793256.d0,   97770416321734.d0,  281384751525217.d0,  262217357548874.d0, &
   22926139373539.d0,   72638048510014.d0,   21853966885558.d0,  179953424063340.d0, &
   86955820535760.d0,  219090379796330.d0,  206387763165981.d0,   72349278132254.d0, &
  133721768676807.d0,  251011971825025.d0,  108099216253426.d0,  100661790702728.d0, &
  144726469097123.d0,  139728787827147.d0,  128171613915659.d0,   95188060277083.d0, &
  210009625020573.d0,   22414116529026.d0,   15394643545386.d0,   13563337514413.d0, &
  268547716509793.d0,   56568755424659.d0,  138821234584817.d0,  118894288927966.d0, &
   60858813019232.d0,   70944045911671.d0,   55450813300868.d0,   28554295175407.d0, &
  237861225469749.d0,  186271249646860.d0,    7431803677692.d0,  140788136451652.d0, &
  134341263176836.d0,  279092998245918.d0,  174589807418323.d0,   17959553427295.d0, &
  240217041093440.d0,  217446483325246.d0,   62501390186654.d0,  265454734021950.d0, &
   37278431853898.d0,  253865302416259.d0,  191280281639528.d0,  163282861684300.d0, &
   41904190859572.d0,   71559003207170.d0,  234160492145454.d0,  233792256660488.d0, &
   40068607702122.d0,   74456826859520.d0,  107404754286126.d0,  166182036837409.d0, &
   87362848393280.d0,   85306575263413.d0,  160182700400083.d0,  112838173900732.d0, &
   10909279688581.d0,  140378553463243.d0,  146254758356915.d0,   94546075703845.d0, &
   79056050195098.d0,   44326078206724.d0,   46128119449306.d0,  256969738512604.d0, &
   22414751197440.d0,  114412570814369.d0,  156054671326882.d0,  255669429908876.d0, &
  246318437291702.d0,  187802251481911.d0,  105470680933273.d0,   70829014655230.d0, &
  173954127070649.d0,  261932198869778.d0,   86359407196919.d0,   82931931817635.d0, &
  112364580214706.d0,   64248322776411.d0,   73883776575479.d0,  222617298270986.d0, &
  269718996824983.d0,   76142634383944.d0,  163996167780922.d0,   35749387304555.d0/
data (mppicon(i), i =   400,   599) / &
  186606943638859.d0,   94181783281941.d0,  169706181437795.d0,  169195324286506.d0, &
   81734287828473.d0,  104404180832297.d0,   54412906653698.d0,    4566346137787.d0, &
   23484967693539.d0,  164656518325446.d0,  119994016928575.d0,  218869501003769.d0, &
  222025130188559.d0,   70675727670664.d0,  121045908410859.d0,  234864931631804.d0, &
  212821016130916.d0,   41212227903530.d0,  171939888425123.d0,   34511875935762.d0, &
  198745364968094.d0,  192853960674001.d0,  141928991790560.d0,   56343845223204.d0, &
   12519540177186.d0,  147002269558458.d0,   14954513173644.d0,   50177954598930.d0, &
  132240259912957.d0,  110488174389196.d0,  270412555068271.d0,  148972165055389.d0, &
  278348026514718.d0,   11301724199214.d0,  280874661670571.d0,  269350237349906.d0, &
  242307591560696.d0,  168345023077230.d0,  117706908718352.d0,  120289890871141.d0, &
  233353572837380.d0,  265158627150848.d0,  281078585167762.d0,  115517122373243.d0, &
  175903856098716.d0,  176548104362261.d0,  104057311276936.d0,   89454188723092.d0, &
  133863229347563.d0,   60718736198673.d0,   98378375946903.d0,  268479230732354.d0, &
  190936099990331.d0,   20295008942126.d0,  265104340959799.d0,  201839067203233.d0, &
  206597791638352.d0,   29047133835722.d0,  261659023490520.d0,  249459280266306.d0, &
   24571676857222.d0,  238649529521579.d0,  257467798742862.d0,  240271885319871.d0, &
  256772017538046.d0,  173432932659447.d0,  211683376659448.d0,  105567616881149.d0, &
  144340801822640.d0,  131141156001590.d0,  277955305696051.d0,  264014516039808.d0, &
   72049083047519.d0,  131530550590952.d0,  191471072723609.d0,  210385456156248.d0, &
  268899092135330.d0,  268783066843017.d0,  208642320562627.d0,  220673514714229.d0, &
  266448077117881.d0,  135150379830045.d0,  245760250220153.d0,  159839722554990.d0, &
   98466968917872.d0,  154847891540226.d0,  244421103430881.d0,  206167117664680.d0, &
  108063347747230.d0,  201756520145065.d0,  241932927044001.d0,  215720205215834.d0, &
   34093617168012.d0,   82023677238638.d0,  279345121279261.d0,   12806063628678.d0, &
  266146916397417.d0,  242682203166521.d0,    7690707455643.d0,   87744022990865.d0, &
  103361190200314.d0,  175933499903462.d0,  228868522282023.d0,  131114719101792.d0, &
   83590291916469.d0,  263983624405237.d0,  148296637110442.d0,   53723554517478.d0, &
  174646846089827.d0,   92096406274754.d0,   24415744814678.d0,  159140196314108.d0, &
  138133905153398.d0,  122071091334012.d0,    1684590955069.d0,  136968589838051.d0, &
  125754265148857.d0,   29417769587614.d0,  203396452996472.d0,    9881204938813.d0, &
  137246983131076.d0,   33332962177377.d0,  253955552908505.d0,  119095470878677.d0, &
  219796408979140.d0,   59557234531782.d0,  220142165963316.d0,  160956081661710.d0, &
  275488872333536.d0,   64019947312122.d0,  270272288683831.d0,   99802911825072.d0, &
  113929638590274.d0,  232555957754300.d0,  171243920789149.d0,  210073076225581.d0, &
   31330830173307.d0,  201812383310241.d0,  158629020742078.d0,  116782018090824.d0, &
  188221515656825.d0,  218405375468873.d0,  214165642803438.d0,   77575137121651.d0, &
   11120959049158.d0,   45327941609914.d0,   77312306783976.d0,  209314744934906.d0, &
  235228550222234.d0,  109880511994502.d0,  261833026552504.d0,   73822685799710.d0, &
    4031312482468.d0,  144862296579049.d0,  116881359181136.d0,  204940200257574.d0, &
  179193136167649.d0,   83191730204501.d0,  108756208709587.d0,  271935717654276.d0, &
  122498775124569.d0,  141719577659312.d0,  147341454206637.d0,   65141325687184.d0, &
  278565643147159.d0,   49412388225579.d0,  153182539197498.d0,    1639175803343.d0, &
   69090932501800.d0,   34768394628594.d0,  202977383462002.d0,   99544277508137.d0, &
  189605091059174.d0,   78824142138771.d0,  275547533067405.d0,   44235341232341.d0, &
  112328310992424.d0,  132349443566965.d0,  105922342293060.d0,  250496963843333.d0, &
  120759598214586.d0,    3991654434148.d0,  264697826483733.d0,   66590643230503.d0, &
   29603753756458.d0,   29959235772003.d0,   37340271372027.d0,   42730413192499.d0, &
  238768797122037.d0,    3668783041210.d0,   66774532978449.d0,  213351862414284.d0, &
   89506257408607.d0,   85659218950192.d0,  242503376525410.d0,  161769835326074.d0, &
  159167113231310.d0,   89205638461263.d0,  209124788200318.d0,  214581889091806.d0/
data (mppicon(i), i =   600,   799) / &
   91712115697280.d0,  178868343332205.d0,  195869458902525.d0,    9926229799834.d0, &
   77010445910237.d0,   97224617827360.d0,  220651189106653.d0,   30067140906194.d0, &
    1646779491259.d0,  243689641097817.d0,  280672861489732.d0,  207484733453034.d0, &
  227225150719163.d0,  155469539622716.d0,  122354266793059.d0,   92562410876610.d0, &
  130961980154736.d0,  127603705767771.d0,   21268551308913.d0,  192773120409664.d0, &
  223236540654284.d0,   58077729128725.d0,  192985256952872.d0,  164481042548408.d0, &
  175598906286152.d0,  122317372011808.d0,  188574852586827.d0,   43371250344213.d0, &
  106317210664924.d0,  205859815371845.d0,   41496372328929.d0,   89947240083250.d0, &
  221790502632137.d0,  246414227455175.d0,  230857965113795.d0,  178020669659792.d0, &
  148751164358042.d0,  229638459348234.d0,  239934107140906.d0,  218326985313785.d0, &
   54412415413071.d0,  272259482076149.d0,  205861856549375.d0,   43814129287063.d0, &
   37572741364778.d0,   17119679978388.d0,   23252867322721.d0,  227283712066216.d0, &
  110333729089745.d0,  200940168602373.d0,  116600054370405.d0,  223216501186796.d0, &
  121006787713851.d0,   84218415559288.d0,  256618375648562.d0,  247199306863520.d0, &
   57361594184222.d0,   29731714059171.d0,   57779217658144.d0,  214912426630965.d0, &
  175430549712686.d0,  252936785956835.d0,  265110703364692.d0,   33925285138018.d0, &
  133933408616047.d0,   24295311342892.d0,   31909536060101.d0,  271558477739299.d0, &
  267557776029219.d0,  162350656214732.d0,  225411375071586.d0,   99462512209430.d0, &
   60024463455180.d0,  244737480229305.d0,   81158982373403.d0,  125096661673670.d0, &
  219615409607690.d0,   76836160062450.d0,  135904738563069.d0,  108473945733925.d0, &
  210978285146870.d0,  124323885330948.d0,    2348118953852.d0,  225909309920017.d0, &
   68994727994323.d0,   62310267757895.d0,  191249427996828.d0,  271883483641775.d0, &
  177868025192544.d0,  147111191415528.d0,  155960910477744.d0,   84635190958408.d0, &
  213700442819212.d0,    1938823632619.d0,  248461992982633.d0,  182917802245897.d0, &
   40878459119263.d0,  201547266051703.d0,  248881938948067.d0,   64611120756794.d0, &
  223209987389818.d0,  121800899690447.d0,  234046940470993.d0,  268555270635252.d0, &
  255237777861360.d0,  254093644814781.d0,  167263731359074.d0,  254696555710945.d0, &
   40189015131734.d0,  216678097927244.d0,  261778312104505.d0,   36165646477742.d0, &
  158045731281951.d0,  120555945745842.d0,  205475563466362.d0,  120518538241800.d0, &
  278009629948940.d0,  193774008969389.d0,   48580379430635.d0,  222974387784140.d0, &
  125330729500561.d0,  139664329305482.d0,    9558505103666.d0,  114919542547370.d0, &
  224246542824186.d0,   49114800574035.d0,   99857755457031.d0,  218497356357300.d0, &
   62184538248358.d0,  111490471802442.d0,   74649655852289.d0,  196692598689458.d0, &
  167604935068836.d0,   34614071995410.d0,  105761506625304.d0,  216499935330405.d0, &
  281262435794314.d0,  187152414258376.d0,  221897762517175.d0,   23061425879461.d0, &
   63327692748998.d0,   42351198112489.d0,  126403978878646.d0,  134320077821211.d0, &
  236505313493385.d0,  234283302509697.d0,  234463476993754.d0,  201858887360585.d0, &
  157244767203038.d0,    4037448811671.d0,  126707224193169.d0,   53500525188612.d0, &
   74813211904314.d0,  131003887324702.d0,  271154978380942.d0,  254778767530545.d0, &
  194161679267981.d0,   89255737982528.d0,    3223505087222.d0,  214785437926120.d0, &
  237150371033319.d0,  133103522298684.d0,   29389504882607.d0,  173686715396635.d0, &
  204045330720936.d0,  260730656706545.d0,  206269472888145.d0,  181238565170397.d0, &
  250605571261705.d0,    3933903942226.d0,   67284228782620.d0,   37721462431826.d0, &
  215109696340783.d0,    5698944036255.d0,  139266760257431.d0,  131620810003724.d0, &
  207409254262053.d0,  245403752809385.d0,  226665076796811.d0,    1323186228725.d0, &
  228153471530329.d0,   24734807111698.d0,  269244395311792.d0,  223995048030043.d0, &
   24891277766049.d0,  138525562041675.d0,  224019176743890.d0,  216817948710340.d0, &
  113427174870842.d0,   96526902773373.d0,   64025689293861.d0,  201868271345026.d0, &
  101322109143278.d0,  277819391116419.d0,   64816981024003.d0,   25506757069997.d0, &
  196021871623820.d0,  124430469662900.d0,  263029075725765.d0,  217107667689462.d0/
data (mppicon(i), i =   800,   999) / &
  168565546327216.d0,   18697694688067.d0,  224211819024564.d0,   75810651220142.d0, &
  126947056819357.d0,  198698224375467.d0,   40735705101096.d0,   80674863174308.d0, &
  261195969286628.d0,  214545351432650.d0,  176693002461794.d0,   86331799629480.d0, &
    8170984472549.d0,  140986060388095.d0,  240758744617816.d0,  204399401622212.d0, &
  226622646718701.d0,   85572218649842.d0,  198463026689401.d0,   41690240952748.d0, &
   94465432302303.d0,    6614736526641.d0,  269392247636707.d0,   47871065545676.d0, &
   11651178560879.d0,   29845830643233.d0,  208968959343364.d0,  260400820499791.d0, &
  253130993133077.d0,  167239869947282.d0,  161137181050519.d0,  254246556353902.d0, &
  245600280543557.d0,   89641778990384.d0,  169262139699594.d0,  154429542850135.d0, &
   59989628155067.d0,  134524166384308.d0,  174575569140987.d0,  140835397798844.d0, &
   34391573317393.d0,  147093410437249.d0,   22504779807441.d0,  236828149205008.d0, &
   45425131298213.d0,   30451071161622.d0,  137988766368877.d0,  192541985186340.d0, &
  135390542436948.d0,  133168040933967.d0,  202100348045732.d0,   10881107899849.d0, &
  181962169864202.d0,  204123329451300.d0,   46641754372185.d0,  172460977034375.d0, &
   70674813598216.d0,  258942858900040.d0,  151090507536477.d0,   16967500726864.d0, &
  208562776105026.d0,  151178019233536.d0,   59451937755024.d0,   41992976758820.d0, &
    3686077555413.d0,  156648980211981.d0,  217705730891430.d0,   39997236950830.d0, &
  215471634636015.d0,  263158051772737.d0,  164609466638399.d0,  274411635524004.d0, &
   81899572554049.d0,  274374670481652.d0,   69436474187016.d0,   16191474998067.d0, &
  107238185154356.d0,  119120126555040.d0,  236275146196402.d0,   32640511111245.d0, &
   78028026530705.d0,   70898219734946.d0,  197100384660562.d0,  199151044037777.d0, &
   12779515864566.d0,  219467870436759.d0,  228590485999539.d0,   43563360547880.d0, &
  113272034712229.d0,   93751486205727.d0,  220847510701058.d0,  234132728144259.d0, &
  226082265324446.d0,   27887845764911.d0,  156164343363196.d0,   75321264614710.d0, &
  119433824568923.d0,   48772960117751.d0,  229860090858449.d0,  237236353712941.d0, &
  229070255132448.d0,  148984457267433.d0,    3606928171296.d0,  128892807519339.d0, &
  248476809540395.d0,   11786754512730.d0,  157361423479020.d0,  247143121646066.d0, &
   88940631268336.d0,   69372060691903.d0,  242400301471050.d0,   80044859883537.d0, &
  205838652738555.d0,  142476834492545.d0,  117717994563137.d0,  101620490844624.d0, &
   64692550749243.d0,  164845873437485.d0,  270993070753150.d0,   15505644231795.d0, &
  195898012315212.d0,   22502177670404.d0,   31379868988188.d0,  193786025622078.d0, &
  124176157221847.d0,   36629562956047.d0,  212055089539867.d0,  121335635746247.d0, &
  252290884997372.d0,  255872873176100.d0,  108707115030242.d0,  148198075021625.d0, &
   93173778130173.d0,  177892575571437.d0,  277383053890181.d0,   22961167311690.d0, &
  252501341799061.d0,   42706076469338.d0,  138171967743402.d0,  249764609211765.d0, &
  222498953474161.d0,  185784891770522.d0,   46434833548438.d0,  121163230159997.d0, &
  261935889375512.d0,   15661703857507.d0,  173046525802047.d0,  197531583990660.d0, &
  135644618950678.d0,  128887113073072.d0,  236227185334032.d0,  129977411237245.d0, &
   83954269355955.d0,   25870723579652.d0,  132845311553836.d0,   15826366780539.d0, &
   98892288683069.d0,   27275285791768.d0,  279365887522484.d0,  181979890969896.d0, &
  162584013563531.d0,   85835683940183.d0,   49253334804352.d0,    3187626467993.d0, &
   86688307604388.d0,    1833202365552.d0,  270847333609889.d0,  257270665025878.d0, &
  126102974125826.d0,   23866565611299.d0,    9401464880841.d0,   61944284733860.d0, &
  281255733743377.d0,  225377533213642.d0,   44957441053758.d0,   19039034522886.d0, &
   12784006054873.d0,   83400627555738.d0,  129146646724288.d0,  188398467505346.d0, &
  149331456092764.d0,  147060595273514.d0,  230979292283853.d0,  226997649406720.d0, &
   59522872396475.d0,   97011912630953.d0,  116663398465367.d0,  280735995190631.d0, &
  264178367627906.d0,  153768478397581.d0,    5309893290797.d0,  193544999326830.d0, &
  145171756671677.d0,   63539664081033.d0,  149627105868228.d0,  175779573207258.d0, &
   12279189022777.d0,    7460810161956.d0,  267992991561228.d0,  198595132314316.d0/
data (mppicon(i), i =  1000,  1199) / &
  166957934655835.d0,  173392615614414.d0,  211539924498829.d0,   78730151528382.d0, &
   23133380900173.d0,  125947544335679.d0,  143854526257254.d0,  210156894512478.d0, &
  169340476398947.d0,   81850046780392.d0,   56785349276852.d0,    1508845644377.d0, &
  242844381906415.d0,   21428716611262.d0,   12159364972195.d0,    1724046479777.d0, &
  254438640092461.d0,  192307967023859.d0,  147395770499882.d0,  116895193143662.d0, &
   90415705683995.d0,   72015957830220.d0,  217166376057058.d0,   66113890995569.d0, &
  192196341488752.d0,  133196475519236.d0,  128924534622079.d0,   68135187558712.d0, &
   85142544773387.d0,  207205500133060.d0,  269331927590651.d0,  162334328215096.d0, &
   37454423867484.d0,  278381369576390.d0,   27172495670054.d0,  125936999132037.d0, &
   96305793225937.d0,  242573477981968.d0,  122990509570135.d0,   29790258727535.d0, &
  137117184505151.d0,  152575378837856.d0,   10341114872586.d0,  225867635370411.d0, &
   22410145193679.d0,  210510962814486.d0,   89964588105458.d0,  239304387531104.d0, &
  232876087343176.d0,  144011099798983.d0,   90414440613353.d0,  268699190292275.d0, &
  101150205470009.d0,   59384731098639.d0,   57701237316097.d0,   73308984586947.d0, &
  209770885052601.d0,   84081101208620.d0,  128158471293278.d0,    6929439650972.d0, &
  196531741196582.d0,   55063725426547.d0,  251114090189641.d0,   30224538950933.d0, &
  262193415386980.d0,  244853355410651.d0,  155246048710899.d0,  197624961927754.d0, &
   33195326699892.d0,   19473386756676.d0,  210413002715423.d0,   89080538942011.d0, &
   47041955005472.d0,   51707955428959.d0,   32763519798068.d0,  269659711149870.d0, &
  242063429310665.d0,  255068037113875.d0,   31212561880980.d0,   87572566403146.d0, &
   13657629296216.d0,  116771319855734.d0,  272443885997057.d0,     622462788671.d0, &
  250047144547472.d0,  180139395943667.d0,  278068887222324.d0,   63618916666234.d0, &
   47104841417259.d0,  208515902967222.d0,  214488668136531.d0,  182424074214853.d0, &
   49587725166697.d0,  118590717485595.d0,  161265489918005.d0,  281263982947988.d0, &
  138793103570109.d0,   45684698293207.d0,   27743646210686.d0,  229544898192589.d0, &
  162778730408132.d0,  263181503898599.d0,   60508200041839.d0,  162685076393520.d0, &
  227620512287753.d0,  211433107067965.d0,  104204561623321.d0,   76956441186612.d0, &
  158010961222561.d0,  216596964648099.d0,   64932550026738.d0,  275458559858813.d0, &
   50705909906038.d0,   67182368743437.d0,  163709255258224.d0,  219605670630259.d0, &
   66801239693159.d0,  250610823072711.d0,   95126087777632.d0,  180859162379657.d0, &
  176347953679104.d0,  255602447502030.d0,  162506188152096.d0,  177210321080631.d0, &
   33996147409974.d0,  183479078466632.d0,   54728707574826.d0,  124376686620086.d0, &
  153947364624883.d0,  277175955942006.d0,  199769896914527.d0,  141135531373872.d0, &
  189787842973237.d0,  150745626711277.d0,  133289614592875.d0,  241007907169446.d0, &
  106046035689058.d0,  277165973602126.d0,  221690479543677.d0,  168607253057060.d0, &
  149386338115500.d0,   80713155592113.d0,   55016164717116.d0,  270914275627665.d0, &
   37990915675179.d0,  263942542583190.d0,  161134137147337.d0,  176523039480505.d0, &
  212297699398334.d0,  198506120647105.d0,  204303201681585.d0,  174651271824221.d0, &
   58458998635759.d0,   58570466638095.d0,  102180169822828.d0,   26474497765587.d0, &
  160797435956356.d0,  114183298235688.d0,  161554318202769.d0,  240546823676167.d0, &
  222204137755679.d0,   11088403063063.d0,  272648341749015.d0,  145669610613151.d0, &
   76214875201668.d0,  250420694101408.d0,  277623523852853.d0,   88169775827378.d0, &
   13183945780675.d0,   35727922599607.d0,  203150579479761.d0,   15342267304684.d0, &
  112387691269295.d0,    2320863078230.d0,  245327906183049.d0,   50738818431979.d0, &
   43921832714796.d0,    3252235369590.d0,   34898171630422.d0,  100959852034364.d0, &
  254217398299204.d0,   19260947500558.d0,  237512344315407.d0,  216997344783705.d0, &
   46815661636554.d0,  268164512791395.d0,  167780920618837.d0,  163642271192029.d0, &
  115121814842205.d0,  250293368903662.d0,   23749638283661.d0,  168877982858546.d0, &
  185570568117033.d0,  176306616160146.d0,  237574960613801.d0,  146636769355645.d0, &
  121991060927002.d0,   47622535098754.d0,   30588796397538.d0,  122325829143345.d0/
data (mppicon(i), i =  1200,  1365) / &
  125928471214348.d0,   66754624756915.d0,  276670930860193.d0,   41592492352447.d0, &
  275432275549506.d0,  178535394051556.d0,  248129650267007.d0,   36445674202595.d0, &
   24061051406781.d0,  242285738907249.d0,  265212069757331.d0,  275688317402269.d0, &
  114544620438291.d0,  153520388570900.d0,   17438392060473.d0,   86365623032354.d0, &
  159346406792449.d0,   44862173327173.d0,   33810241215454.d0,  105552060007740.d0, &
  154438341611417.d0,    2184406938700.d0,  183564416558466.d0,   10760650533923.d0, &
  207795254174433.d0,  140498789446064.d0,  256721450238454.d0,    2108727268849.d0, &
    8908230606647.d0,  240959695463323.d0,   34107617604575.d0,  105226446716600.d0, &
  116657941254940.d0,  222948952908435.d0,  104168357023017.d0,  210425463058241.d0, &
  176329880775545.d0,  185174309423207.d0,  223096107284753.d0,  134219230012285.d0, &
   55861315357521.d0,   69716841248388.d0,   81447558161020.d0,  184275455182368.d0, &
  184732313456805.d0,  258953022107697.d0,   19649078621042.d0,  209136006496869.d0, &
  122190255452485.d0,   22719167055187.d0,  257735934729583.d0,  161661420442807.d0, &
   27771387842652.d0,  142407488479533.d0,  242405028604263.d0,   67625750016963.d0, &
   49078850808195.d0,   36459538539158.d0,  206341834764048.d0,  153942098671993.d0, &
  174078924550607.d0,  275839895878248.d0,  254454004883836.d0,   87104411412068.d0, &
  167216516790234.d0,  110910870793095.d0,  181406976069396.d0,   24863514484854.d0, &
  182929492697948.d0,  242637056732673.d0,  139105956787373.d0,  228577746450057.d0, &
  227171332371274.d0,   54051461176318.d0,  271235465901151.d0,  190884631078024.d0, &
   88661382527883.d0,    7685168500018.d0,  107859904225188.d0,  255468981694109.d0, &
   99253269072493.d0,   37290794560997.d0,   50884374439127.d0,  126848231310152.d0, &
  247935598170342.d0,  271437861537392.d0,    1272844446891.d0,  183206604706068.d0, &
  192681323294678.d0,   33244498243702.d0,  275141580762805.d0,  184476464674149.d0, &
   99616483254477.d0,  263633153891481.d0,  105831802897988.d0,  263194567963521.d0, &
   38892427924518.d0,  194924368359755.d0,  202495696347819.d0,  139140587936001.d0, &
  206286621323527.d0,   24822496898831.d0,  232590236046964.d0,  260324779096401.d0, &
  224194287520505.d0,   25144984854731.d0,   56146146017300.d0,   63776086815013.d0, &
  199783814132743.d0,  134033994374355.d0,  179664295342564.d0,  261346370863982.d0, &
  176309451323721.d0,   64034989531147.d0,   57866088387943.d0,  270930740983484.d0, &
  191461083693436.d0,  258124935042874.d0,  238410464607117.d0,    5468047300161.d0, &
  261470004865531.d0,  132400947407404.d0,  189893223546904.d0,  262456358556195.d0, &
  200903619148691.d0,  271152852391521.d0,  227428498036340.d0,  205635593244889.d0, &
  130327734210094.d0,  146605108080568.d0,  278688594683846.d0,   51456712816405.d0, &
  202500407128139.d0,  277389545396841.d0,  117280822934063.d0,  218568659050002.d0, &
   43907087511055.d0,   34970078478665.d0,  217918014533593.d0,  270782223180883.d0, &
   62620279476936.d0,   56180610913140.d0,  144692003019063.d0,  193149140295619.d0, &
   52715149458973.d0,  189818726150023.d0,  200148677472689.d0,  211341471392474.d0, &
  192572558734653.d0,  273043508830500.d0,  125178921944951.d0,  170584662836717.d0, &
  146359006387172.d0,  123116950268947.d0,  256409690618445.d0,  147297898614723.d0, &
  129178866883709.d0,  113348977098387.d0,  255453464635589.d0,  182341109094986.d0, &
  266891779588647.d0,   42528865335244.d0,  121327305094822.d0,  134125885090344.d0, &
                0.d0,                0.d0/
data (mpuu1(i), i =     1,   100) / &
(  1.3000000000000000D+01,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01)/
data (mpuu1(i), i =   101,   200) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -2.4298017990326387D-01,  9.7003125319454397D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -4.2755509343028186D-01,  9.0398929312344345D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -5.1410274419322155D-01,  8.5772861000027212D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.7155895484701844D-01,  7.4095112535495899D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -8.0320753148064483D-01,  5.9569930449243347D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.5772861000027212D-01,  5.1410274419322177D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.7003125319454397D-01,  2.4298017990326404D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8917650996478101D-01,  1.4673047445536180D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.1523159058062693D-01,  7.8834642762660623D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.3499761988709738D-01,  8.4485356524970701D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  4.9289819222978415D-01,  8.7008699110871135D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.0524131400498981D-01,  9.1420975570353069D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.6671275747489842D-01,  9.6377606579543984D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.2241067519921628D-01,  9.9247953459870997D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  7.3564563599667454D-02,  9.9729045667869021D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -7.3564563599667343D-02,  9.9729045667869021D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.7096188876030124D-01,  9.8527764238894122D-01)/
data (mpuu1(i), i =   201,   300) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -2.1910124015686966D-01,  9.7570213003852857D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.5989503653498817D-01,  9.3299279883473885D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.4961132965460671D-01,  8.9322430119551521D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.7580819141784534D-01,  8.1758481315158371D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.2424708295146689D-01,  6.8954054473706705D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.8834642762660623D-01,  6.1523159058062693D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.1758481315158360D-01,  5.7580819141784545D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.7008699110871135D-01,  4.9289819222978415D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.9322430119551521D-01,  4.4961132965460687D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.1420975570353069D-01,  4.0524131400498986D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.3299279883473885D-01,  3.5989503653498833D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4952818059303667D-01,  3.1368174039889141D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7570213003852846D-01,  2.1910124015687002D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8527764238894122D-01,  1.7096188876030119D-01), &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.9247953459870997D-01,  1.2241067519921635D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9729045667869021D-01,  7.3564563599667745D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9969881869620425D-01,  2.4541228522912326D-02), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.9867446569395382D-01,  4.3861623853852766D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.7607009419540660D-01,  4.8218377207912272D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.6397285612158670D-01,  5.0353838372571758D-01)/
data (mpuu1(i), i =   301,   400) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.3822470555483797D-01,  5.4532498842204646D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.9583690460888357D-01,  6.0551104140432555D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.4913639452345937D-01,  6.6241577759017178D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.3265427167241282D-01,  6.8060099779545302D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.8060099779545313D-01,  7.3265427167241270D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.4383154288979150D-01,  7.6516726562245885D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.2485948814238645D-01,  7.8073722857209438D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.6573181078361323D-01,  8.2458930278502529D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.2458968267846895D-01,  8.5135519310526520D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.6053871095824001D-01,  8.8763962040285393D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.7131719395183760D-01,  9.2850608047321548D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.2531029216226298D-01,  9.4560732538052128D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  3.0200594931922820D-01,  9.5330604035419375D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.5486565960451463D-01,  9.6697647104485207D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.3105810828067125D-01,  9.7293995220556007D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  2.0711137619221856D-01,  9.7831737071962765D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.8303988795514103D-01,  9.8310548743121629D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.5885814333386139D-01,  9.8730141815785843D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  1.1022220729388318D-01,  9.9390697000235606D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  8.5797312344439880D-02,  9.9631261218277800D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  6.1320736302208655D-02,  9.9811811290014918D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  3.6807222941358991D-02,  9.9932238458834954D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  1.2271538285719944D-02,  9.9992470183914450D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -1.2271538285719823D-02,  9.9992470183914450D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -3.6807222941358866D-02,  9.9932238458834954D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -6.1320736302208530D-02,  9.9811811290014918D-01), &
( -7.3564563599667343D-02,  9.9729045667869021D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.1022220729388307D-01,  9.9390697000235606D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.3458070850712611D-01,  9.9090263542778001D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.5885814333386128D-01,  9.8730141815785843D-01), &
( -1.7096188876030124D-01,  9.8527764238894122D-01), ( -1.8303988795514095D-01,  9.8310548743121629D-01)/
data (mpuu1(i), i =   401,   500) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -2.0711137619221845D-01,  9.7831737071962765D-01), &
( -2.1910124015686966D-01,  9.7570213003852857D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.5486565960451452D-01,  9.6697647104485207D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -2.7851968938505295D-01,  9.6043051941556590D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.4841868024943440D-01,  9.3733901191257496D-01), &
( -3.5989503653498817D-01,  9.3299279883473885D-01), ( -3.7131719395183754D-01,  9.2850608047321559D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.1642956009763699D-01,  9.0916798309052249D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.4961132965460671D-01,  8.9322430119551521D-01), ( -4.6053871095824012D-01,  8.8763962040285393D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.2458968267846873D-01,  8.5135519310526520D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.6573181078361323D-01,  8.2458930278502529D-01), &
( -5.7580819141784534D-01,  8.1758481315158371D-01), ( -5.8579785745643886D-01,  8.1045719825259477D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -6.0551104140432543D-01,  7.9583690460888357D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -6.2485948814238623D-01,  7.8073722857209460D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.4383154288979128D-01,  7.6516726562245907D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -6.6241577759017178D-01,  7.4913639452345926D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -6.9837624940897280D-01,  7.1573082528381871D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.1573082528381859D-01,  6.9837624940897292D-01), &
( -7.2424708295146689D-01,  6.8954054473706705D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.4913639452345904D-01,  6.6241577759017201D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -7.6516726562245896D-01,  6.4383154288979139D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.8073722857209449D-01,  6.2485948814238634D-01), &
( -7.8834642762660623D-01,  6.1523159058062693D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.1045719825259466D-01,  5.8579785745643898D-01), &
( -8.1758481315158360D-01,  5.7580819141784545D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.3822470555483808D-01,  5.4532498842204635D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.5135519310526520D-01,  5.2458968267846895D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.6397285612158670D-01,  5.0353838372571758D-01), &
( -8.7008699110871135D-01,  4.9289819222978415D-01), ( -8.7607009419540649D-01,  4.8218377207912289D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -8.9322430119551521D-01,  4.4961132965460687D-01), ( -8.9867446569395393D-01,  4.3861623853852755D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.1911385169005777D-01,  3.9399204006104815D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.3299279883473885D-01,  3.5989503653498833D-01), ( -9.3733901191257485D-01,  3.4841868024943479D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4560732538052128D-01,  3.2531029216226320D-01), &
( -9.4952818059303667D-01,  3.1368174039889141D-01), ( -9.5330604035419386D-01,  3.0200594931922803D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.6043051941556579D-01,  2.7851968938505312D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.6697647104485207D-01,  2.5486565960451468D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7293995220556007D-01,  2.3105810828067130D-01), &
( -9.7570213003852846D-01,  2.1910124015687002D-01), ( -9.7831737071962754D-01,  2.0711137619221884D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8310548743121640D-01,  1.8303988795514090D-01), &
( -9.8527764238894122D-01,  1.7096188876030119D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01)/
data (mpuu1(i), i =   501,   600) / &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.9090263542778001D-01,  1.3458070850712628D-01), &
( -9.9247953459870997D-01,  1.2241067519921635D-01), ( -9.9390697000235606D-01,  1.1022220729388325D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9631261218277800D-01,  8.5797312344440158D-02), &
( -9.9729045667869021D-01,  7.3564563599667745D-02), ( -9.9811811290014918D-01,  6.1320736302208495D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9932238458834954D-01,  3.6807222941358832D-02), &
( -9.9969881869620425D-01,  2.4541228522912326D-02), ( -9.9992470183914450D-01,  1.2271538285720007D-02), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9998117528260111D-01,  6.1358846491544753D-03), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.7956976568544052D-01,  2.0110463484209190D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7433938278557586D-01,  2.2508391135979283D-01), &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7150389098625178D-01,  2.3702360599436720D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6852209427441727D-01,  2.4892760574572015D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6539444169768940D-01,  2.6079411791527551D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5870347489587160D-01,  2.8440753721127188D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.5514116830577067D-01,  2.9615088824362379D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.5143502096900834D-01,  3.0784964004153487D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4758559101774109D-01,  3.1950203081601569D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4359345816196039D-01,  3.3110630575987643D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3518350993894761D-01,  3.5416352542049034D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.3076696107898371D-01,  3.6561299780477385D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.2151403934204190D-01,  3.8834504669882625D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1667905992104270D-01,  3.9962419984564679D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0659570451491533D-01,  4.2200027079979968D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  9.0134884704602203D-01,  4.3309381885315196D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.9044872324475788D-01,  4.5508358712634384D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8479709843093779D-01,  4.6597649576796618D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7309497841829009D-01,  4.8755016014843600D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01)/
data (mpuu1(i), i =   601,   700) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.5455798836540053D-01,  5.1935599016558964D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.4812034480329723D-01,  5.2980362468629461D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.2804504525775580D-01,  5.6066157619733603D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.2110251499110465D-01,  5.7078074588696726D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.1403632970594841D-01,  5.8081395809576453D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.0684755354379933D-01,  5.9075970185887416D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.9210657730021239D-01,  6.1038280627630948D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.8455659715557524D-01,  6.2005721176328910D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.7688846567323244D-01,  6.2963823891492698D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.6910333764557970D-01,  6.3912444486377573D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.6120238548426178D-01,  6.4851440102211244D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4505778544146595D-01,  6.6699992230363747D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.3681656887736979D-01,  6.7609270357531592D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.2846439044822520D-01,  6.8508366777270036D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.2000250796138165D-01,  6.9397146088965389D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  7.1143219574521643D-01,  7.0275474445722530D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  7.0275474445722541D-01,  7.1143219574521632D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.9397146088965400D-01,  7.2000250796138165D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.8508366777270047D-01,  7.2846439044822520D-01), &
(  6.8060099779545313D-01,  7.3265427167241270D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.6699992230363758D-01,  7.4505778544146595D-01), &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.5780669329707875D-01,  7.5318679904361241D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.4851440102211255D-01,  7.6120238548426178D-01), &
(  6.4383154288979150D-01,  7.6516726562245885D-01), (  6.3912444486377584D-01,  7.6910333764557959D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.2963823891492710D-01,  7.7688846567323244D-01), &
(  6.2485948814238645D-01,  7.8073722857209438D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  6.1038280627630948D-01,  7.9210657730021228D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  6.0061647938386897D-01,  7.9953726910790501D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.7078074588696737D-01,  8.2110251499110465D-01), &
(  5.6573181078361323D-01,  8.2458930278502529D-01), (  5.6066157619733603D-01,  8.2804504525775569D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.4017147272989297D-01,  8.4155497743689833D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  5.2458968267846895D-01,  8.5135519310526520D-01), (  5.1935599016558964D-01,  8.5455798836540053D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  5.0883014254310710D-01,  8.6086693863776720D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.8755016014843611D-01,  8.7309497841828998D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.7679923006332225D-01,  8.7901222642863341D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.6597649576796613D-01,  8.8479709843093779D-01), &
(  4.6053871095824001D-01,  8.8763962040285393D-01), (  4.5508358712634384D-01,  8.9044872324475788D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.4412214457042926D-01,  8.9596624975618511D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  4.3309381885315201D-01,  9.0134884704602203D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.2200027079979979D-01,  9.0659570451491533D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  4.1084317105790391D-01,  9.1170603200542988D-01)/
data (mpuu1(i), i =   701,   800) / &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.8834504669882630D-01,  9.2151403934204190D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.7700741021641831D-01,  9.2621024213831138D-01), &
(  3.7131719395183760D-01,  9.2850608047321548D-01), (  3.6561299780477396D-01,  9.3076696107898371D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.5416352542049051D-01,  9.3518350993894750D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.4266071731199438D-01,  9.3945922360218992D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.3110630575987643D-01,  9.4359345816196039D-01), &
(  3.2531029216226298D-01,  9.4560732538052128D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  3.0784964004153498D-01,  9.5143502096900834D-01), &
(  3.0200594931922820D-01,  9.5330604035419375D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.8440753721127182D-01,  9.5870347489587160D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.7262135544994898D-01,  9.6212140426904158D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.6079411791527557D-01,  9.6539444169768940D-01), &
(  2.5486565960451463D-01,  9.6697647104485207D-01), (  2.4892760574572026D-01,  9.6852209427441727D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  2.3105810828067125D-01,  9.7293995220556007D-01), (  2.2508391135979278D-01,  9.7433938278557586D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  2.0110463484209193D-01,  9.7956976568544052D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.8303988795514103D-01,  9.8310548743121629D-01), (  1.7700422041214886D-01,  9.8421009238692903D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.6491312048997006D-01,  9.8630809724459867D-01), &
(  1.5885814333386139D-01,  9.8730141815785843D-01), (  1.5279718525844341D-01,  9.8825756773074946D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.4065823933284924D-01,  9.9005821026229712D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  1.2849811079379322D-01,  9.9170975366909953D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  1.1631863091190486D-01,  9.9321194923479450D-01), &
(  1.1022220729388318D-01,  9.9390697000235606D-01), (  1.0412163387205473D-01,  9.9456457073425542D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  9.1908956497132696D-02,  9.9576741446765982D-01), &
(  8.5797312344439880D-02,  9.9631261218277800D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  6.7443919563664106D-02,  9.9772306664419164D-01), &
(  6.1320736302208655D-02,  9.9811811290014918D-01), (  5.5195244349690031D-02,  9.9847558057329477D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  4.2938256934940959D-02,  9.9907772775264536D-01), &
(  3.6807222941358991D-02,  9.9932238458834954D-01), (  3.0674803176636584D-02,  9.9952941750109314D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  1.8406729905804820D-02,  9.9983058179582340D-01), &
(  1.2271538285719944D-02,  9.9992470183914450D-01), (  6.1358846491545160D-03,  9.9998117528260111D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -6.1358846491543929D-03,  9.9998117528260111D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -1.8406729905804695D-02,  9.9983058179582340D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -3.0674803176636459D-02,  9.9952941750109314D-01), &
( -3.6807222941358866D-02,  9.9932238458834954D-01), ( -4.2938256934940834D-02,  9.9907772775264536D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -5.5195244349689913D-02,  9.9847558057329477D-01), &
( -6.1320736302208530D-02,  9.9811811290014918D-01), ( -6.7443919563663995D-02,  9.9772306664419164D-01), &
( -7.3564563599667343D-02,  9.9729045667869021D-01), ( -7.9682437971430015D-02,  9.9682029929116567D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -9.1908956497132585D-02,  9.9576741446765982D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.1022220729388307D-01,  9.9390697000235606D-01), ( -1.1631863091190475D-01,  9.9321194923479450D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.2849811079379311D-01,  9.9170975366909953D-01), &
( -1.3458070850712611D-01,  9.9090263542778001D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.5279718525844330D-01,  9.8825756773074946D-01), &
( -1.5885814333386128D-01,  9.8730141815785843D-01), ( -1.6491312048996995D-01,  9.8630809724459867D-01), &
( -1.7096188876030124D-01,  9.8527764238894122D-01), ( -1.7700422041214875D-01,  9.8421009238692903D-01), &
( -1.8303988795514095D-01,  9.8310548743121629D-01), ( -1.8906866414980616D-01,  9.8196386910955524D-01)/
data (mpuu1(i), i =   801,   900) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -2.0110463484209182D-01,  9.7956976568544052D-01), &
( -2.0711137619221845D-01,  9.7831737071962765D-01), ( -2.1311031991609125D-01,  9.7702814265775439D-01), &
( -2.1910124015686966D-01,  9.7570213003852857D-01), ( -2.2508391135979267D-01,  9.7433938278557586D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -2.3702360599436723D-01,  9.7150389098625178D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.4892760574572015D-01,  9.6852209427441727D-01), &
( -2.5486565960451452D-01,  9.6697647104485207D-01), ( -2.6079411791527546D-01,  9.6539444169768940D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -2.7262135544994887D-01,  9.6212140426904158D-01), &
( -2.7851968938505295D-01,  9.6043051941556590D-01), ( -2.8440753721127171D-01,  9.5870347489587160D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -2.9615088824362384D-01,  9.5514116830577067D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -3.0784964004153487D-01,  9.5143502096900834D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -3.1950203081601564D-01,  9.4758559101774120D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.3110630575987632D-01,  9.4359345816196039D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.4266071731199427D-01,  9.3945922360218992D-01), &
( -3.4841868024943440D-01,  9.3733901191257496D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -3.5989503653498817D-01,  9.3299279883473885D-01), ( -3.6561299780477385D-01,  9.3076696107898371D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -3.7700741021641820D-01,  9.2621024213831138D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -3.8834504669882619D-01,  9.2151403934204201D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -3.9962419984564673D-01,  9.1667905992104270D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.1084317105790380D-01,  9.1170603200542988D-01), &
( -4.1642956009763699D-01,  9.0916798309052249D-01), ( -4.2200027079979968D-01,  9.0659570451491533D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.3309381885315196D-01,  9.0134884704602203D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -4.4412214457042914D-01,  8.9596624975618522D-01), &
( -4.4961132965460671D-01,  8.9322430119551521D-01), ( -4.5508358712634372D-01,  8.9044872324475799D-01), &
( -4.6053871095824012D-01,  8.8763962040285393D-01), ( -4.6597649576796601D-01,  8.8479709843093790D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.7679923006332198D-01,  8.7901222642863353D-01), &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -4.8755016014843572D-01,  8.7309497841829020D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.0883014254310710D-01,  8.6086693863776720D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.1935599016558964D-01,  8.5455798836540053D-01), &
( -5.2458968267846873D-01,  8.5135519310526520D-01), ( -5.2980362468629461D-01,  8.4812034480329723D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.4017147272989285D-01,  8.4155497743689844D-01), &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.6066157619733592D-01,  8.2804504525775591D-01), &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.7078074588696714D-01,  8.2110251499110476D-01), &
( -5.7580819141784534D-01,  8.1758481315158371D-01), ( -5.8081395809576430D-01,  8.1403632970594852D-01), &
( -5.8579785745643886D-01,  8.1045719825259477D-01), ( -5.9075970185887405D-01,  8.0684755354379945D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -6.0061647938386864D-01,  7.9953726910790524D-01), &
( -6.0551104140432543D-01,  7.9583690460888357D-01), ( -6.1038280627630948D-01,  7.9210657730021228D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -6.2005721176328921D-01,  7.8455659715557524D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.2963823891492698D-01,  7.7688846567323244D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.3912444486377573D-01,  7.6910333764557970D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.4851440102211244D-01,  7.6120238548426189D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -6.5780669329707853D-01,  7.5318679904361252D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.7609270357531581D-01,  7.3681656887737002D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -6.8508366777270024D-01,  7.2846439044822531D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -6.9397146088965378D-01,  7.2000250796138188D-01), &
( -6.9837624940897280D-01,  7.1573082528381871D-01), ( -7.0275474445722508D-01,  7.1143219574521677D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.1143219574521654D-01,  7.0275474445722519D-01), &
( -7.1573082528381859D-01,  6.9837624940897292D-01), ( -7.2000250796138165D-01,  6.9397146088965389D-01)/
data (mpuu1(i), i =   901,  1000) / &
( -7.2424708295146689D-01,  6.8954054473706705D-01), ( -7.2846439044822520D-01,  6.8508366777270036D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.3681656887736979D-01,  6.7609270357531592D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.4505778544146595D-01,  6.6699992230363758D-01), &
( -7.4913639452345904D-01,  6.6241577759017201D-01), ( -7.5318679904361241D-01,  6.5780669329707875D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -7.6120238548426178D-01,  6.4851440102211255D-01), &
( -7.6516726562245896D-01,  6.4383154288979139D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.7688846567323233D-01,  6.2963823891492721D-01), &
( -7.8073722857209449D-01,  6.2485948814238634D-01), ( -7.8455659715557513D-01,  6.2005721176328943D-01), &
( -7.8834642762660623D-01,  6.1523159058062693D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -7.9953726910790501D-01,  6.0061647938386886D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.0684755354379933D-01,  5.9075970185887416D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.1403632970594841D-01,  5.8081395809576453D-01), &
( -8.1758481315158360D-01,  5.7580819141784545D-01), ( -8.2110251499110465D-01,  5.7078074588696726D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.2804504525775569D-01,  5.6066157619733603D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.3486287498638001D-01,  5.5045797293660492D-01), &
( -8.3822470555483808D-01,  5.4532498842204635D-01), ( -8.4155497743689833D-01,  5.4017147272989297D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.4812034480329712D-01,  5.2980362468629483D-01), &
( -8.5135519310526520D-01,  5.2458968267846895D-01), ( -8.5455798836540042D-01,  5.1935599016558975D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.6086693863776720D-01,  5.0883014254310732D-01), &
( -8.6397285612158670D-01,  5.0353838372571758D-01), ( -8.6704624551569265D-01,  4.9822766697278176D-01), &
( -8.7008699110871135D-01,  4.9289819222978415D-01), ( -8.7309497841829020D-01,  4.8755016014843588D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -8.7901222642863353D-01,  4.7679923006332209D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.8479709843093779D-01,  4.6597649576796618D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -8.9044872324475788D-01,  4.5508358712634389D-01), &
( -8.9322430119551521D-01,  4.4961132965460687D-01), ( -8.9596624975618511D-01,  4.4412214457042931D-01), &
( -8.9867446569395393D-01,  4.3861623853852755D-01), ( -9.0134884704602192D-01,  4.3309381885315207D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.0659570451491533D-01,  4.2200027079979985D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.1170603200542977D-01,  4.1084317105790413D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.1667905992104259D-01,  3.9962419984564707D-01), &
( -9.1911385169005777D-01,  3.9399204006104815D-01), ( -9.2151403934204179D-01,  3.8834504669882658D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.2621024213831138D-01,  3.7700741021641815D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.3076696107898371D-01,  3.6561299780477380D-01), &
( -9.3299279883473885D-01,  3.5989503653498833D-01), ( -9.3518350993894761D-01,  3.5416352542049034D-01), &
( -9.3733901191257485D-01,  3.4841868024943479D-01), ( -9.3945922360218992D-01,  3.4266071731199443D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4359345816196039D-01,  3.3110630575987648D-01), &
( -9.4560732538052128D-01,  3.2531029216226320D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01), &
( -9.4952818059303667D-01,  3.1368174039889141D-01), ( -9.5143502096900834D-01,  3.0784964004153503D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.5514116830577067D-01,  2.9615088824362401D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.6043051941556579D-01,  2.7851968938505312D-01), ( -9.6212140426904158D-01,  2.7262135544994925D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.6539444169768929D-01,  2.6079411791527585D-01), &
( -9.6697647104485207D-01,  2.5486565960451468D-01), ( -9.6852209427441738D-01,  2.4892760574572009D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7150389098625178D-01,  2.3702360599436717D-01), &
( -9.7293995220556007D-01,  2.3105810828067130D-01), ( -9.7433938278557586D-01,  2.2508391135979283D-01), &
( -9.7570213003852846D-01,  2.1910124015687002D-01), ( -9.7702814265775439D-01,  2.1311031991609142D-01), &
( -9.7831737071962754D-01,  2.0711137619221884D-01), ( -9.7956976568544052D-01,  2.0110463484209198D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8196386910955524D-01,  1.8906866414980633D-01), &
( -9.8310548743121640D-01,  1.8303988795514090D-01), ( -9.8421009238692903D-01,  1.7700422041214892D-01), &
( -9.8527764238894122D-01,  1.7096188876030119D-01), ( -9.8630809724459856D-01,  1.6491312048997012D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.8825756773074946D-01,  1.5279718525844369D-01)/
data (mpuu1(i), i =  1001,  1100) / &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.9005821026229701D-01,  1.4065823933284952D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9170975366909953D-01,  1.2849811079379306D-01), &
( -9.9247953459870997D-01,  1.2241067519921635D-01), ( -9.9321194923479450D-01,  1.1631863091190471D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9456457073425542D-01,  1.0412163387205457D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9576741446765982D-01,  9.1908956497132765D-02), &
( -9.9631261218277800D-01,  8.5797312344440158D-02), ( -9.9682029929116567D-01,  7.9682437971430195D-02), &
( -9.9729045667869021D-01,  7.3564563599667745D-02), ( -9.9772306664419164D-01,  6.7443919563664176D-02), &
( -9.9811811290014918D-01,  6.1320736302208495D-02), ( -9.9847558057329477D-01,  5.5195244349690094D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9907772775264536D-01,  4.2938256934941021D-02), &
( -9.9932238458834954D-01,  3.6807222941358832D-02), ( -9.9952941750109314D-01,  3.0674803176636865D-02), &
( -9.9969881869620425D-01,  2.4541228522912326D-02), ( -9.9983058179582340D-01,  1.8406729905805101D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9998117528260111D-01,  6.1358846491547988D-03), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9999529380957619D-01,  3.0679567629659761D-03), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9995764455196390D-01,  9.2037547820598194D-03), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9988234745421256D-01,  1.5339206284988100D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9976940535121528D-01,  2.1474080275469508D-02), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9961882249517864D-01,  2.7608145778965740D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9943060455546173D-01,  3.3741171851377580D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9920475861836389D-01,  3.9872927587739811D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9894129318685687D-01,  4.6003182130914623D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9864021818026527D-01,  5.2131704680283324D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9830154493389289D-01,  5.8258264500435752D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9792528619859600D-01,  6.4382630929857465D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9751145614030345D-01,  7.0504573389613856D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9706007033948296D-01,  7.6623861392031492D-02), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9657114579055484D-01,  8.2740264549375692D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9604470090125197D-01,  8.8853552582524600D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9548075549192694D-01,  9.4963495329638992D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9487933079480562D-01,  1.0106986275482782D-01), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9424044945318790D-01,  1.0717242495680884D-01), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9356413552059530D-01,  1.1327095217756435D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9285041445986510D-01,  1.1936521481099135D-01), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.9209931314219180D-01,  1.2545498341154623D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9131085984611544D-01,  1.3154002870288312D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.9048508425645709D-01,  1.3762012158648604D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8962201746320089D-01,  1.4369503315029447D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8872169196032378D-01,  1.4976453467732151D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8778414164457218D-01,  1.5582839765426523D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8680940181418553D-01,  1.6188639378011183D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8579750916756748D-01,  1.6793829497473117D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8474850180190421D-01,  1.7398387338746382D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8366241921173025D-01,  1.8002290140569951D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8253930228744124D-01,  1.8605515166344663D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.8018213596811743D-01,  1.9809841071795356D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.7894817531906220D-01,  2.0410896609281687D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7767735782450993D-01,  2.1011183688046961D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7636973133002114D-01,  2.1610679707621952D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7502534506699412D-01,  2.2209362097320351D-01), &
(  9.7433938278557586D-01,  2.2508391135979283D-01), (  9.7364424965081198D-01,  2.2807208317088573D-01)/
data (mpuu1(i), i =  1101,  1200) / &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7222649707893627D-01,  2.3404195858354343D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.7077214072895035D-01,  2.4000302244874150D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6928123535654853D-01,  2.4595505033579459D-01), &
(  9.6852209427441727D-01,  2.4892760574572015D-01), (  9.6775383709347551D-01,  2.5189781815421697D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6619000344541250D-01,  2.5783110216215899D-01), &
(  9.6539444169768940D-01,  2.6079411791527551D-01), (  9.6458979328981276D-01,  2.6375467897483135D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.6295326687368388D-01,  2.6966832557291509D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.6128048581132064D-01,  2.7557181931095814D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5957151308198452D-01,  2.8146493792575794D-01), &
(  9.5870347489587160D-01,  2.8440753721127188D-01), (  9.5782641302753291D-01,  2.8734745954472951D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.5604525134999641D-01,  2.9321916269425863D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.5422809510910567D-01,  2.9907982630804048D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.5237501271976588D-01,  3.0492922973540237D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.5048607394948170D-01,  3.1076715274961147D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.4758559101774109D-01,  3.1950203081601569D-01), (  9.4660091308328353D-01,  3.2240767880106985D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4460483726148026D-01,  3.2820984357909250D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.4257319760144687D-01,  3.3399965144200938D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.4050607059326830D-01,  3.3977688440682685D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3840353406310806D-01,  3.4554132496398909D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3626566717027826D-01,  3.5129275608556709D-01), &
(  9.3518350993894761D-01,  3.5416352542049034D-01), (  9.3409255040425898D-01,  3.5703096123342998D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.3188426558166815D-01,  3.6275572436739723D-01), &
(  9.3076696107898371D-01,  3.6561299780477385D-01), (  9.2964089584318121D-01,  3.6846682995337232D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2736252565040111D-01,  3.7416406297145793D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.2504924078267758D-01,  3.7984720892405116D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.2270112833387863D-01,  3.8551605384391885D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  9.2031827670911059D-01,  3.9117038430225387D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1790077562139050D-01,  3.9680998741671031D-01), &
(  9.1667905992104270D-01,  3.9962419984564679D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.1296219042839821D-01,  4.0804416286497869D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.1044129225806725D-01,  4.1363831223843456D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0788611648766626D-01,  4.1921688836322391D-01), &
(  9.0659570451491533D-01,  4.2200027079979968D-01), (  9.0529675931811882D-01,  4.2477968120910881D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  9.0267331823725883D-01,  4.3032648134008261D-01), &
(  9.0134884704602203D-01,  4.3309381885315196D-01), (  9.0001589201616028D-01,  4.3585707992225547D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9732458070541832D-01,  4.4137126873171667D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.9459948563138270D-01,  4.4686884016237416D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.9184070939234272D-01,  4.5234958723377089D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.8904835585466457D-01,  4.5781330359887723D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8622253014888064D-01,  4.6325978355186015D-01), &
(  8.8479709843093779D-01,  4.6597649576796618D-01), (  8.8336333866573158D-01,  4.6868882203582796D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.8047088905216075D-01,  4.7410021465054997D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7754529020726135D-01,  4.7949375766015301D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7458665227817622D-01,  4.8486924800079106D-01), &
(  8.7309497841829009D-01,  4.8755016014843600D-01), (  8.7159508665595098D-01,  4.9022648328829116D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.6857070597134090D-01,  4.9556526182577254D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.6551362409056909D-01,  5.0088538261124071D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.6242395611104050D-01,  5.0618664534515523D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.5930181835700847D-01,  5.1146885043797030D-01)/
data (mpuu1(i), i =  1201,  1300) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.5614732837519447D-01,  5.1673179901764987D-01), &
(  8.5455798836540053D-01,  5.1935599016558964D-01), (  8.5296060493036363D-01,  5.2197529293715439D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.4974176800085255D-01,  5.2719913478190139D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.4649093877405213D-01,  5.3240312787719790D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.4320823964184544D-01,  5.3758707629564539D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  8.3989379419599952D-01,  5.4275078486451589D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3654772722351201D-01,  5.4789405917310019D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.3317016470191319D-01,  5.5301670558002747D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.2976123379452305D-01,  5.5811853122055610D-01), &
(  8.2804504525775580D-01,  5.6066157619733603D-01), (  8.2632106284566353D-01,  5.6319934401383409D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.2284978137582643D-01,  5.6825895267013149D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  8.1934752007679701D-01,  5.7329716669804220D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.1581441080673378D-01,  5.7831379641165559D-01), &
(  8.1403632970594841D-01,  5.8081395809576453D-01), (  8.1225058658520388D-01,  5.8330865293769829D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.0865618158817498D-01,  5.8828154822264522D-01), &
(  8.0684755354379933D-01,  5.9075970185887416D-01), (  8.0503133114296366D-01,  5.9323229503979980D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  8.0137617172314024D-01,  5.9816070699634238D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.9769084094339116D-01,  6.0306659854034816D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.9397547755433717D-01,  6.0794978496777363D-01), &
(  7.9210657730021239D-01,  6.1038280627630948D-01), (  7.9023022143731003D-01,  6.1281008242940971D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.8645521359908577D-01,  6.1764730793780387D-01), &
(  7.8455659715557524D-01,  6.2005721176328910D-01), (  7.8265059616657573D-01,  6.2246127937414997D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.7881651238147598D-01,  6.2725181549514408D-01), &
(  7.7688846567323244D-01,  6.2963823891492698D-01), (  7.7495310659487382D-01,  6.3201873593980906D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.7106052426181382D-01,  6.3676186123628420D-01), &
(  7.6910333764557970D-01,  6.3912444486377573D-01), (  7.6713891193582040D-01,  6.4148101280858316D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.6318841726338138D-01,  6.4617601298331628D-01), &
(  7.6120238548426178D-01,  6.4851440102211244D-01), (  7.5920918897838796D-01,  6.5084668499638099D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.5520137689653655D-01,  6.5549285299961535D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.5116513190968637D-01,  6.6011434206742048D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4710060598018013D-01,  6.6471097820334479D-01), &
(  7.4505778544146595D-01,  6.6699992230363747D-01), (  7.4300795213512172D-01,  6.6928258834663601D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.3888732446061511D-01,  6.7382900037875604D-01), &
(  7.3681656887736979D-01,  6.7609270357531592D-01), (  7.3473887809596339D-01,  6.7835004312986147D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.3056276922782759D-01,  6.8284554638524808D-01), &
(  7.2846439044822520D-01,  6.8508366777270036D-01), (  7.2635915508434601D-01,  6.8731534089175905D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.2212819392921535D-01,  6.9175925836415775D-01), &
(  7.2000250796138165D-01,  6.9397146088965389D-01), (  7.1787004505573171D-01,  6.9617713149146299D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  7.1358486878079352D-01,  7.0056879394324834D-01), &
(  7.1143219574521643D-01,  7.0275474445722530D-01), (  7.0927282643886569D-01,  7.0493408037590488D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  7.0493408037590499D-01,  7.0927282643886558D-01), &
(  7.0275474445722541D-01,  7.1143219574521632D-01), (  7.0056879394324845D-01,  7.1358486878079352D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.9617713149146310D-01,  7.1787004505573160D-01), &
(  6.9397146088965400D-01,  7.2000250796138165D-01), (  6.9175925836415786D-01,  7.2212819392921523D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.8731534089175916D-01,  7.2635915508434590D-01), &
(  6.8508366777270047D-01,  7.2846439044822520D-01), (  6.8284554638524808D-01,  7.3056276922782759D-01), &
(  6.8060099779545313D-01,  7.3265427167241270D-01), (  6.7835004312986158D-01,  7.3473887809596339D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.7382900037875615D-01,  7.3888732446061511D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.6928258834663612D-01,  7.4300795213512161D-01), &
(  6.6699992230363758D-01,  7.4505778544146595D-01), (  6.6471097820334490D-01,  7.4710060598018013D-01)/
data (mpuu1(i), i =  1301,  1400) / &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.6011434206742059D-01,  7.5116513190968637D-01), &
(  6.5780669329707875D-01,  7.5318679904361241D-01), (  6.5549285299961546D-01,  7.5520137689653644D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.5084668499638099D-01,  7.5920918897838796D-01), &
(  6.4851440102211255D-01,  7.6120238548426178D-01), (  6.4617601298331639D-01,  7.6318841726338127D-01), &
(  6.4383154288979150D-01,  7.6516726562245885D-01), (  6.4148101280858316D-01,  7.6713891193582029D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  6.3676186123628431D-01,  7.7106052426181371D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.3201873593980906D-01,  7.7495310659487382D-01), &
(  6.2963823891492710D-01,  7.7688846567323244D-01), (  6.2725181549514419D-01,  7.7881651238147587D-01), &
(  6.2485948814238645D-01,  7.8073722857209438D-01), (  6.2246127937415008D-01,  7.8265059616657562D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  6.1764730793780398D-01,  7.8645521359908577D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  6.1281008242940982D-01,  7.9023022143731003D-01), &
(  6.1038280627630948D-01,  7.9210657730021228D-01), (  6.0794978496777374D-01,  7.9397547755433706D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  6.0306659854034828D-01,  7.9769084094339104D-01), &
(  6.0061647938386897D-01,  7.9953726910790501D-01), (  5.9816070699634238D-01,  8.0137617172314013D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.9323229503979991D-01,  8.0503133114296355D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.8828154822264533D-01,  8.0865618158817498D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  5.8330865293769840D-01,  8.1225058658520388D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  5.7831379641165570D-01,  8.1581441080673378D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.7329716669804232D-01,  8.1934752007679690D-01), &
(  5.7078074588696737D-01,  8.2110251499110465D-01), (  5.6825895267013160D-01,  8.2284978137582632D-01), &
(  5.6573181078361323D-01,  8.2458930278502529D-01), (  5.6319934401383420D-01,  8.2632106284566342D-01), &
(  5.6066157619733603D-01,  8.2804504525775569D-01), (  5.5811853122055621D-01,  8.2976123379452305D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.5301670558002758D-01,  8.3317016470191319D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.4789405917310030D-01,  8.3654772722351189D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.4275078486451600D-01,  8.3989379419599941D-01), &
(  5.4017147272989297D-01,  8.4155497743689833D-01), (  5.3758707629564551D-01,  8.4320823964184544D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.3240312787719801D-01,  8.4649093877405202D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  5.2719913478190139D-01,  8.4974176800085244D-01), &
(  5.2458968267846895D-01,  8.5135519310526520D-01), (  5.2197529293715439D-01,  8.5296060493036363D-01), &
(  5.1935599016558964D-01,  8.5455798836540053D-01), (  5.1673179901764998D-01,  8.5614732837519436D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  5.1146885043797052D-01,  8.5930181835700825D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  5.0618664534515545D-01,  8.6242395611104050D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  5.0088538261124094D-01,  8.6551362409056898D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.9556526182577254D-01,  8.6857070597134090D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.9022648328829116D-01,  8.7159508665595098D-01), &
(  4.8755016014843611D-01,  8.7309497841828998D-01), (  4.8486924800079112D-01,  8.7458665227817611D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.7949375766015306D-01,  8.7754529020726124D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  4.7410021465055002D-01,  8.8047088905216075D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.6868882203582796D-01,  8.8336333866573158D-01), &
(  4.6597649576796613D-01,  8.8479709843093779D-01), (  4.6325978355186026D-01,  8.8622253014888064D-01), &
(  4.6053871095824001D-01,  8.8763962040285393D-01), (  4.5781330359887729D-01,  8.8904835585466446D-01), &
(  4.5508358712634384D-01,  8.9044872324475788D-01), (  4.5234958723377100D-01,  8.9184070939234272D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.4686884016237433D-01,  8.9459948563138258D-01), &
(  4.4412214457042926D-01,  8.9596624975618511D-01), (  4.4137126873171662D-01,  8.9732458070541832D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  4.3585707992225547D-01,  9.0001589201616028D-01), &
(  4.3309381885315201D-01,  9.0134884704602203D-01), (  4.3032648134008261D-01,  9.0267331823725883D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.2477968120910881D-01,  9.0529675931811882D-01), &
(  4.2200027079979979D-01,  9.0659570451491533D-01), (  4.1921688836322396D-01,  9.0788611648766615D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  4.1363831223843456D-01,  9.1044129225806714D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  4.0804416286497874D-01,  9.1296219042839810D-01)/
data (mpuu1(i), i =  1401,  1500) / &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  4.0243465085941854D-01,  9.1544871608826783D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.9680998741671042D-01,  9.1790077562139039D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.9117038430225398D-01,  9.2031827670911048D-01), &
(  3.8834504669882630D-01,  9.2151403934204190D-01), (  3.8551605384391902D-01,  9.2270112833387852D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.7984720892405111D-01,  9.2504924078267758D-01), &
(  3.7700741021641831D-01,  9.2621024213831138D-01), (  3.7416406297145793D-01,  9.2736252565040111D-01), &
(  3.7131719395183760D-01,  9.2850608047321548D-01), (  3.6846682995337232D-01,  9.2964089584318121D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  3.6275572436739723D-01,  9.3188426558166815D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.5703096123343003D-01,  9.3409255040425887D-01), &
(  3.5416352542049051D-01,  9.3518350993894750D-01), (  3.5129275608556715D-01,  9.3626566717027826D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.4554132496398915D-01,  9.3840353406310806D-01), &
(  3.4266071731199438D-01,  9.3945922360218992D-01), (  3.3977688440682696D-01,  9.4050607059326830D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.3399965144200949D-01,  9.4257319760144687D-01), &
(  3.3110630575987643D-01,  9.4359345816196039D-01), (  3.2820984357909266D-01,  9.4460483726148026D-01), &
(  3.2531029216226298D-01,  9.4560732538052128D-01), (  3.2240767880106996D-01,  9.4660091308328353D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  3.1659337555616585D-01,  9.4856134991573027D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  3.1076715274961147D-01,  9.5048607394948170D-01), &
(  3.0784964004153498D-01,  9.5143502096900834D-01), (  3.0492922973540237D-01,  9.5237501271976588D-01), &
(  3.0200594931922820D-01,  9.5330604035419375D-01), (  2.9907982630804048D-01,  9.5422809510910567D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.9321916269425868D-01,  9.5604525134999641D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.8734745954472957D-01,  9.5782641302753291D-01), &
(  2.8440753721127182D-01,  9.5870347489587160D-01), (  2.8146493792575805D-01,  9.5957151308198452D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.7557181931095825D-01,  9.6128048581132064D-01), &
(  2.7262135544994898D-01,  9.6212140426904158D-01), (  2.6966832557291520D-01,  9.6295326687368388D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.6375467897483151D-01,  9.6458979328981265D-01), &
(  2.6079411791527557D-01,  9.6539444169768940D-01), (  2.5783110216215893D-01,  9.6619000344541262D-01), &
(  2.5486565960451463D-01,  9.6697647104485207D-01), (  2.5189781815421691D-01,  9.6775383709347551D-01), &
(  2.4892760574572026D-01,  9.6852209427441727D-01), (  2.4595505033579459D-01,  9.6928123535654853D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.4000302244874150D-01,  9.7077214072895035D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  2.3404195858354346D-01,  9.7222649707893627D-01), &
(  2.3105810828067125D-01,  9.7293995220556007D-01), (  2.2807208317088579D-01,  9.7364424965081187D-01), &
(  2.2508391135979278D-01,  9.7433938278557586D-01), (  2.2209362097320359D-01,  9.7502534506699412D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  2.1610679707621960D-01,  9.7636973133002114D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  2.1011183688046972D-01,  9.7767735782450993D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  2.0410896609281701D-01,  9.7894817531906220D-01), &
(  2.0110463484209193D-01,  9.7956976568544052D-01), (  1.9809841071795373D-01,  9.8018213596811732D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.9208039704989238D-01,  9.8137919331375456D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.8605515166344661D-01,  9.8253930228744124D-01), &
(  1.8303988795514103D-01,  9.8310548743121629D-01), (  1.8002290140569951D-01,  9.8366241921173025D-01), &
(  1.7700422041214886D-01,  9.8421009238692903D-01), (  1.7398387338746385D-01,  9.8474850180190421D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.6793829497473120D-01,  9.8579750916756737D-01), &
(  1.6491312048997006D-01,  9.8630809724459867D-01), (  1.6188639378011188D-01,  9.8680940181418542D-01), &
(  1.5885814333386139D-01,  9.8730141815785843D-01), (  1.5582839765426532D-01,  9.8778414164457218D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  1.4976453467732162D-01,  9.8872169196032378D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.4369503315029458D-01,  9.8962201746320078D-01), &
(  1.4065823933284924D-01,  9.9005821026229712D-01), (  1.3762012158648618D-01,  9.9048508425645698D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  1.3154002870288325D-01,  9.9131085984611544D-01), &
(  1.2849811079379322D-01,  9.9170975366909953D-01), (  1.2545498341154621D-01,  9.9209931314219180D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  1.1936521481099134D-01,  9.9285041445986510D-01), &
(  1.1631863091190486D-01,  9.9321194923479450D-01), (  1.1327095217756435D-01,  9.9356413552059530D-01)/
data (mpuu1(i), i =  1501,  1600) / &
(  1.1022220729388318D-01,  9.9390697000235606D-01), (  1.0717242495680887D-01,  9.9424044945318790D-01), &
(  1.0412163387205473D-01,  9.9456457073425542D-01), (  1.0106986275482786D-01,  9.9487933079480562D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  9.4963495329639061D-02,  9.9548075549192694D-01), &
(  9.1908956497132696D-02,  9.9576741446765982D-01), (  8.8853552582524684D-02,  9.9604470090125197D-01), &
(  8.5797312344439880D-02,  9.9631261218277800D-01), (  8.2740264549375803D-02,  9.9657114579055484D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  7.6623861392031617D-02,  9.9706007033948296D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  7.0504573389614009D-02,  9.9751145614030345D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  6.4382630929857410D-02,  9.9792528619859600D-01), &
(  6.1320736302208655D-02,  9.9811811290014918D-01), (  5.8258264500435732D-02,  9.9830154493389289D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), (  5.2131704680283317D-02,  9.9864021818026527D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  4.6003182130914644D-02,  9.9894129318685687D-01), &
(  4.2938256934940959D-02,  9.9907772775264536D-01), (  3.9872927587739845D-02,  9.9920475861836389D-01), &
(  3.6807222941358991D-02,  9.9932238458834954D-01), (  3.3741171851377642D-02,  9.9943060455546173D-01), &
(  3.0674803176636584D-02,  9.9952941750109314D-01), (  2.7608145778965820D-02,  9.9961882249517864D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  2.1474080275469608D-02,  9.9976940535121528D-01), &
(  1.8406729905804820D-02,  9.9983058179582340D-01), (  1.5339206284988220D-02,  9.9988234745421256D-01), &
(  1.2271538285719944D-02,  9.9992470183914450D-01), (  9.2037547820599599D-03,  9.9995764455196390D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), (  3.0679567629661379D-03,  9.9999529380957619D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -3.0679567629660156D-03,  9.9999529380957619D-01), &
( -6.1358846491543929D-03,  9.9998117528260111D-01), ( -9.2037547820598385D-03,  9.9995764455196390D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -1.5339206284988098D-02,  9.9988234745421256D-01), &
( -1.8406729905804695D-02,  9.9983058179582340D-01), ( -2.1474080275469484D-02,  9.9976940535121528D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -2.7608145778965695D-02,  9.9961882249517864D-01), &
( -3.0674803176636459D-02,  9.9952941750109314D-01), ( -3.3741171851377517D-02,  9.9943060455546173D-01), &
( -3.6807222941358866D-02,  9.9932238458834954D-01), ( -3.9872927587739720D-02,  9.9920475861836389D-01), &
( -4.2938256934940834D-02,  9.9907772775264536D-01), ( -4.6003182130914519D-02,  9.9894129318685687D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -5.2131704680283192D-02,  9.9864021818026527D-01), &
( -5.5195244349689913D-02,  9.9847558057329477D-01), ( -5.8258264500435607D-02,  9.9830154493389289D-01), &
( -6.1320736302208530D-02,  9.9811811290014918D-01), ( -6.4382630929857299D-02,  9.9792528619859600D-01), &
( -6.7443919563663995D-02,  9.9772306664419164D-01), ( -7.0504573389613898D-02,  9.9751145614030345D-01), &
( -7.3564563599667343D-02,  9.9729045667869021D-01), ( -7.6623861392031506D-02,  9.9706007033948296D-01), &
( -7.9682437971430015D-02,  9.9682029929116567D-01), ( -8.2740264549375692D-02,  9.9657114579055484D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -8.8853552582524573D-02,  9.9604470090125197D-01), &
( -9.1908956497132585D-02,  9.9576741446765982D-01), ( -9.4963495329638950D-02,  9.9548075549192694D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.0106986275482775D-01,  9.9487933079480562D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.0717242495680876D-01,  9.9424044945318790D-01), &
( -1.1022220729388307D-01,  9.9390697000235606D-01), ( -1.1327095217756424D-01,  9.9356413552059530D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.1936521481099123D-01,  9.9285041445986510D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.2545498341154609D-01,  9.9209931314219180D-01), &
( -1.2849811079379311D-01,  9.9170975366909953D-01), ( -1.3154002870288317D-01,  9.9131085984611544D-01), &
( -1.3458070850712611D-01,  9.9090263542778001D-01), ( -1.3762012158648607D-01,  9.9048508425645698D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -1.4369503315029447D-01,  9.8962201746320089D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.4976453467732151D-01,  9.8872169196032378D-01), &
( -1.5279718525844330D-01,  9.8825756773074946D-01), ( -1.5582839765426520D-01,  9.8778414164457218D-01), &
( -1.5885814333386128D-01,  9.8730141815785843D-01), ( -1.6188639378011177D-01,  9.8680940181418553D-01), &
( -1.6491312048996995D-01,  9.8630809724459867D-01), ( -1.6793829497473109D-01,  9.8579750916756748D-01), &
( -1.7096188876030124D-01,  9.8527764238894122D-01), ( -1.7398387338746374D-01,  9.8474850180190421D-01), &
( -1.7700422041214875D-01,  9.8421009238692903D-01), ( -1.8002290140569940D-01,  9.8366241921173025D-01), &
( -1.8303988795514095D-01,  9.8310548743121629D-01), ( -1.8605515166344652D-01,  9.8253930228744124D-01), &
( -1.8906866414980616D-01,  9.8196386910955524D-01), ( -1.9208039704989227D-01,  9.8137919331375456D-01)/
data (mpuu1(i), i =  1601,  1700) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -1.9809841071795362D-01,  9.8018213596811743D-01), &
( -2.0110463484209182D-01,  9.7956976568544052D-01), ( -2.0410896609281690D-01,  9.7894817531906220D-01), &
( -2.0711137619221845D-01,  9.7831737071962765D-01), ( -2.1011183688046961D-01,  9.7767735782450993D-01), &
( -2.1311031991609125D-01,  9.7702814265775439D-01), ( -2.1610679707621949D-01,  9.7636973133002114D-01), &
( -2.1910124015686966D-01,  9.7570213003852857D-01), ( -2.2209362097320348D-01,  9.7502534506699412D-01), &
( -2.2508391135979267D-01,  9.7433938278557586D-01), ( -2.2807208317088568D-01,  9.7364424965081198D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -2.3404195858354335D-01,  9.7222649707893627D-01), &
( -2.3702360599436723D-01,  9.7150389098625178D-01), ( -2.4000302244874139D-01,  9.7077214072895035D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.4595505033579448D-01,  9.6928123535654853D-01), &
( -2.4892760574572015D-01,  9.6852209427441727D-01), ( -2.5189781815421680D-01,  9.6775383709347551D-01), &
( -2.5486565960451452D-01,  9.6697647104485207D-01), ( -2.5783110216215882D-01,  9.6619000344541262D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -2.6375467897483140D-01,  9.6458979328981276D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -2.6966832557291509D-01,  9.6295326687368388D-01), &
( -2.7262135544994887D-01,  9.6212140426904158D-01), ( -2.7557181931095814D-01,  9.6128048581132064D-01), &
( -2.7851968938505295D-01,  9.6043051941556590D-01), ( -2.8146493792575794D-01,  9.5957151308198452D-01), &
( -2.8440753721127171D-01,  9.5870347489587160D-01), ( -2.8734745954472946D-01,  9.5782641302753291D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -2.9321916269425857D-01,  9.5604525134999652D-01), &
( -2.9615088824362384D-01,  9.5514116830577067D-01), ( -2.9907982630804036D-01,  9.5422809510910567D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -3.0492922973540232D-01,  9.5237501271976588D-01), &
( -3.0784964004153487D-01,  9.5143502096900834D-01), ( -3.1076715274961136D-01,  9.5048607394948181D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -3.1659337555616573D-01,  9.4856134991573038D-01), &
( -3.1950203081601564D-01,  9.4758559101774120D-01), ( -3.2240767880106991D-01,  9.4660091308328353D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.2820984357909255D-01,  9.4460483726148026D-01), &
( -3.3110630575987632D-01,  9.4359345816196039D-01), ( -3.3399965144200938D-01,  9.4257319760144687D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.3977688440682685D-01,  9.4050607059326830D-01), &
( -3.4266071731199427D-01,  9.3945922360218992D-01), ( -3.4554132496398904D-01,  9.3840353406310817D-01), &
( -3.4841868024943440D-01,  9.3733901191257496D-01), ( -3.5129275608556704D-01,  9.3626566717027826D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -3.5703096123342992D-01,  9.3409255040425898D-01), &
( -3.5989503653498817D-01,  9.3299279883473885D-01), ( -3.6275572436739711D-01,  9.3188426558166815D-01), &
( -3.6561299780477385D-01,  9.3076696107898371D-01), ( -3.6846682995337221D-01,  9.2964089584318133D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -3.7416406297145788D-01,  9.2736252565040111D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -3.7984720892405099D-01,  9.2504924078267770D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -3.8551605384391890D-01,  9.2270112833387852D-01), &
( -3.8834504669882619D-01,  9.2151403934204201D-01), ( -3.9117038430225387D-01,  9.2031827670911059D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -3.9680998741671031D-01,  9.1790077562139050D-01), &
( -3.9962419984564673D-01,  9.1667905992104270D-01), ( -4.0243465085941843D-01,  9.1544871608826783D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.0804416286497863D-01,  9.1296219042839821D-01), &
( -4.1084317105790380D-01,  9.1170603200542988D-01), ( -4.1363831223843450D-01,  9.1044129225806725D-01), &
( -4.1642956009763699D-01,  9.0916798309052249D-01), ( -4.1921688836322407D-01,  9.0788611648766615D-01), &
( -4.2200027079979968D-01,  9.0659570451491533D-01), ( -4.2477968120910875D-01,  9.0529675931811882D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.3032648134008272D-01,  9.0267331823725883D-01), &
( -4.3309381885315196D-01,  9.0134884704602203D-01), ( -4.3585707992225536D-01,  9.0001589201616028D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -4.4137126873171673D-01,  8.9732458070541821D-01), &
( -4.4412214457042914D-01,  8.9596624975618522D-01), ( -4.4686884016237399D-01,  8.9459948563138281D-01), &
( -4.4961132965460671D-01,  8.9322430119551521D-01), ( -4.5234958723377089D-01,  8.9184070939234272D-01), &
( -4.5508358712634372D-01,  8.9044872324475799D-01), ( -4.5781330359887701D-01,  8.8904835585466468D-01), &
( -4.6053871095824012D-01,  8.8763962040285393D-01), ( -4.6325978355186015D-01,  8.8622253014888064D-01), &
( -4.6597649576796601D-01,  8.8479709843093790D-01), ( -4.6868882203582768D-01,  8.8336333866573169D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.7410021465054997D-01,  8.8047088905216087D-01), &
( -4.7679923006332198D-01,  8.7901222642863353D-01), ( -4.7949375766015306D-01,  8.7754529020726124D-01)/
data (mpuu1(i), i =  1701,  1800) / &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -4.8486924800079095D-01,  8.7458665227817622D-01), &
( -4.8755016014843572D-01,  8.7309497841829020D-01), ( -4.9022648328829116D-01,  8.7159508665595098D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -4.9556526182577232D-01,  8.6857070597134101D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -5.0088538261124071D-01,  8.6551362409056909D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.0618664534515512D-01,  8.6242395611104072D-01), &
( -5.0883014254310710D-01,  8.6086693863776720D-01), ( -5.1146885043797030D-01,  8.5930181835700847D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.1673179901764965D-01,  8.5614732837519458D-01), &
( -5.1935599016558964D-01,  8.5455798836540053D-01), ( -5.2197529293715428D-01,  8.5296060493036374D-01), &
( -5.2458968267846873D-01,  8.5135519310526520D-01), ( -5.2719913478190106D-01,  8.4974176800085266D-01), &
( -5.2980362468629461D-01,  8.4812034480329723D-01), ( -5.3240312787719779D-01,  8.4649093877405213D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.3758707629564551D-01,  8.4320823964184544D-01), &
( -5.4017147272989285D-01,  8.4155497743689844D-01), ( -5.4275078486451578D-01,  8.3989379419599963D-01), &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.4789405917310019D-01,  8.3654772722351201D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -5.5301670558002736D-01,  8.3317016470191330D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.5811853122055610D-01,  8.2976123379452305D-01), &
( -5.6066157619733592D-01,  8.2804504525775591D-01), ( -5.6319934401383387D-01,  8.2632106284566365D-01), &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.6825895267013149D-01,  8.2284978137582643D-01), &
( -5.7078074588696714D-01,  8.2110251499110476D-01), ( -5.7329716669804198D-01,  8.1934752007679712D-01), &
( -5.7580819141784534D-01,  8.1758481315158371D-01), ( -5.7831379641165548D-01,  8.1581441080673389D-01), &
( -5.8081395809576430D-01,  8.1403632970594852D-01), ( -5.8330865293769840D-01,  8.1225058658520388D-01), &
( -5.8579785745643886D-01,  8.1045719825259477D-01), ( -5.8828154822264522D-01,  8.0865618158817509D-01), &
( -5.9075970185887405D-01,  8.0684755354379945D-01), ( -5.9323229503979991D-01,  8.0503133114296355D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -5.9816070699634216D-01,  8.0137617172314035D-01), &
( -6.0061647938386864D-01,  7.9953726910790524D-01), ( -6.0306659854034816D-01,  7.9769084094339116D-01), &
( -6.0551104140432543D-01,  7.9583690460888357D-01), ( -6.0794978496777352D-01,  7.9397547755433728D-01), &
( -6.1038280627630948D-01,  7.9210657730021228D-01), ( -6.1281008242940971D-01,  7.9023022143731003D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -6.1764730793780376D-01,  7.8645521359908588D-01), &
( -6.2005721176328921D-01,  7.8455659715557524D-01), ( -6.2246127937414997D-01,  7.8265059616657573D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.2725181549514386D-01,  7.7881651238147620D-01), &
( -6.2963823891492698D-01,  7.7688846567323244D-01), ( -6.3201873593980895D-01,  7.7495310659487393D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.3676186123628431D-01,  7.7106052426181371D-01), &
( -6.3912444486377573D-01,  7.6910333764557970D-01), ( -6.4148101280858305D-01,  7.6713891193582051D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.4617601298331639D-01,  7.6318841726338127D-01), &
( -6.4851440102211244D-01,  7.6120238548426189D-01), ( -6.5084668499638076D-01,  7.5920918897838818D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -6.5549285299961535D-01,  7.5520137689653655D-01), &
( -6.5780669329707853D-01,  7.5318679904361252D-01), ( -6.6011434206742026D-01,  7.5116513190968659D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -6.6471097820334479D-01,  7.4710060598018013D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -6.6928258834663579D-01,  7.4300795213512183D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.7382900037875604D-01,  7.3888732446061522D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -6.7835004312986125D-01,  7.3473887809596372D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -6.8284554638524797D-01,  7.3056276922782759D-01), &
( -6.8508366777270024D-01,  7.2846439044822531D-01), ( -6.8731534089175916D-01,  7.2635915508434590D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -6.9175925836415764D-01,  7.2212819392921546D-01), &
( -6.9397146088965378D-01,  7.2000250796138188D-01), ( -6.9617713149146299D-01,  7.1787004505573171D-01), &
( -6.9837624940897280D-01,  7.1573082528381871D-01), ( -7.0056879394324822D-01,  7.1358486878079375D-01), &
( -7.0275474445722508D-01,  7.1143219574521677D-01), ( -7.0493408037590488D-01,  7.0927282643886569D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.0927282643886547D-01,  7.0493408037590510D-01), &
( -7.1143219574521654D-01,  7.0275474445722519D-01), ( -7.1358486878079352D-01,  7.0056879394324834D-01), &
( -7.1573082528381859D-01,  6.9837624940897292D-01), ( -7.1787004505573160D-01,  6.9617713149146310D-01), &
( -7.2000250796138165D-01,  6.9397146088965389D-01), ( -7.2212819392921523D-01,  6.9175925836415786D-01)/
data (mpuu1(i), i =  1801,  1900) / &
( -7.2424708295146689D-01,  6.8954054473706705D-01), ( -7.2635915508434579D-01,  6.8731534089175927D-01), &
( -7.2846439044822520D-01,  6.8508366777270036D-01), ( -7.3056276922782759D-01,  6.8284554638524808D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.3473887809596361D-01,  6.7835004312986147D-01), &
( -7.3681656887736979D-01,  6.7609270357531592D-01), ( -7.3888732446061511D-01,  6.7382900037875615D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.4300795213512172D-01,  6.6928258834663601D-01), &
( -7.4505778544146595D-01,  6.6699992230363758D-01), ( -7.4710060598018002D-01,  6.6471097820334502D-01), &
( -7.4913639452345904D-01,  6.6241577759017201D-01), ( -7.5116513190968637D-01,  6.6011434206742048D-01), &
( -7.5318679904361241D-01,  6.5780669329707875D-01), ( -7.5520137689653644D-01,  6.5549285299961557D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -7.5920918897838796D-01,  6.5084668499638099D-01), &
( -7.6120238548426178D-01,  6.4851440102211255D-01), ( -7.6318841726338116D-01,  6.4617601298331651D-01), &
( -7.6516726562245896D-01,  6.4383154288979139D-01), ( -7.6713891193582029D-01,  6.4148101280858316D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -7.7106052426181360D-01,  6.3676186123628442D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.7495310659487382D-01,  6.3201873593980906D-01), &
( -7.7688846567323233D-01,  6.2963823891492721D-01), ( -7.7881651238147609D-01,  6.2725181549514408D-01), &
( -7.8073722857209449D-01,  6.2485948814238634D-01), ( -7.8265059616657562D-01,  6.2246127937415008D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), ( -7.8645521359908577D-01,  6.1764730793780387D-01), &
( -7.8834642762660623D-01,  6.1523159058062693D-01), ( -7.9023022143730992D-01,  6.1281008242940982D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -7.9397547755433717D-01,  6.0794978496777363D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -7.9769084094339093D-01,  6.0306659854034839D-01), &
( -7.9953726910790501D-01,  6.0061647938386886D-01), ( -8.0137617172314024D-01,  5.9816070699634238D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.0503133114296344D-01,  5.9323229503980002D-01), &
( -8.0684755354379933D-01,  5.9075970185887416D-01), ( -8.0865618158817498D-01,  5.8828154822264533D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.1225058658520366D-01,  5.8330865293769851D-01), &
( -8.1403632970594841D-01,  5.8081395809576453D-01), ( -8.1581441080673378D-01,  5.7831379641165570D-01), &
( -8.1758481315158360D-01,  5.7580819141784545D-01), ( -8.1934752007679701D-01,  5.7329716669804209D-01), &
( -8.2110251499110465D-01,  5.7078074588696726D-01), ( -8.2284978137582621D-01,  5.6825895267013171D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.2632106284566353D-01,  5.6319934401383409D-01), &
( -8.2804504525775569D-01,  5.6066157619733603D-01), ( -8.2976123379452293D-01,  5.5811853122055632D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.3317016470191319D-01,  5.5301670558002747D-01), &
( -8.3486287498638001D-01,  5.5045797293660492D-01), ( -8.3654772722351189D-01,  5.4789405917310030D-01), &
( -8.3822470555483808D-01,  5.4532498842204635D-01), ( -8.3989379419599952D-01,  5.4275078486451589D-01), &
( -8.4155497743689833D-01,  5.4017147272989297D-01), ( -8.4320823964184533D-01,  5.3758707629564573D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.4649093877405202D-01,  5.3240312787719801D-01), &
( -8.4812034480329712D-01,  5.2980362468629483D-01), ( -8.4974176800085255D-01,  5.2719913478190128D-01), &
( -8.5135519310526520D-01,  5.2458968267846895D-01), ( -8.5296060493036363D-01,  5.2197529293715439D-01), &
( -8.5455798836540042D-01,  5.1935599016558975D-01), ( -8.5614732837519458D-01,  5.1673179901764976D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.5930181835700825D-01,  5.1146885043797052D-01), &
( -8.6086693863776720D-01,  5.0883014254310732D-01), ( -8.6242395611104050D-01,  5.0618664534515523D-01), &
( -8.6397285612158670D-01,  5.0353838372571758D-01), ( -8.6551362409056898D-01,  5.0088538261124094D-01), &
( -8.6704624551569265D-01,  4.9822766697278176D-01), ( -8.6857070597134090D-01,  4.9556526182577254D-01), &
( -8.7008699110871135D-01,  4.9289819222978415D-01), ( -8.7159508665595098D-01,  4.9022648328829138D-01), &
( -8.7309497841829020D-01,  4.8755016014843588D-01), ( -8.7458665227817611D-01,  4.8486924800079112D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -8.7754529020726113D-01,  4.7949375766015329D-01), &
( -8.7901222642863353D-01,  4.7679923006332209D-01), ( -8.8047088905216075D-01,  4.7410021465055008D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.8336333866573169D-01,  4.6868882203582785D-01), &
( -8.8479709843093779D-01,  4.6597649576796618D-01), ( -8.8622253014888053D-01,  4.6325978355186032D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -8.8904835585466457D-01,  4.5781330359887717D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -8.9184070939234261D-01,  4.5234958723377100D-01), &
( -8.9322430119551521D-01,  4.4961132965460687D-01), ( -8.9459948563138270D-01,  4.4686884016237416D-01), &
( -8.9596624975618511D-01,  4.4412214457042931D-01), ( -8.9732458070541821D-01,  4.4137126873171689D-01)/
data (mpuu1(i), i =  1901,  2000) / &
( -8.9867446569395393D-01,  4.3861623853852755D-01), ( -9.0001589201616028D-01,  4.3585707992225547D-01), &
( -9.0134884704602192D-01,  4.3309381885315207D-01), ( -9.0267331823725871D-01,  4.3032648134008289D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.0529675931811870D-01,  4.2477968120910886D-01), &
( -9.0659570451491533D-01,  4.2200027079979985D-01), ( -9.0788611648766604D-01,  4.1921688836322424D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.1044129225806714D-01,  4.1363831223843461D-01), &
( -9.1170603200542977D-01,  4.1084317105790413D-01), ( -9.1296219042839821D-01,  4.0804416286497858D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.1544871608826772D-01,  4.0243465085941854D-01), &
( -9.1667905992104259D-01,  3.9962419984564707D-01), ( -9.1790077562139050D-01,  3.9680998741671025D-01), &
( -9.1911385169005777D-01,  3.9399204006104815D-01), ( -9.2031827670911048D-01,  3.9117038430225404D-01), &
( -9.2151403934204179D-01,  3.8834504669882658D-01), ( -9.2270112833387863D-01,  3.8551605384391885D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.2504924078267747D-01,  3.7984720892405138D-01), &
( -9.2621024213831138D-01,  3.7700741021641815D-01), ( -9.2736252565040111D-01,  3.7416406297145799D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.2964089584318121D-01,  3.6846682995337260D-01), &
( -9.3076696107898371D-01,  3.6561299780477380D-01), ( -9.3188426558166815D-01,  3.6275572436739728D-01), &
( -9.3299279883473885D-01,  3.5989503653498833D-01), ( -9.3409255040425876D-01,  3.5703096123343031D-01), &
( -9.3518350993894761D-01,  3.5416352542049034D-01), ( -9.3626566717027826D-01,  3.5129275608556720D-01), &
( -9.3733901191257485D-01,  3.4841868024943479D-01), ( -9.3840353406310817D-01,  3.4554132496398898D-01), &
( -9.3945922360218992D-01,  3.4266071731199443D-01), ( -9.4050607059326830D-01,  3.3977688440682702D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4257319760144687D-01,  3.3399965144200933D-01), &
( -9.4359345816196039D-01,  3.3110630575987648D-01), ( -9.4460483726148015D-01,  3.2820984357909272D-01), &
( -9.4560732538052128D-01,  3.2531029216226320D-01), ( -9.4660091308328353D-01,  3.2240767880106985D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.4856134991573027D-01,  3.1659337555616607D-01), &
( -9.4952818059303667D-01,  3.1368174039889141D-01), ( -9.5048607394948170D-01,  3.1076715274961153D-01), &
( -9.5143502096900834D-01,  3.0784964004153503D-01), ( -9.5237501271976577D-01,  3.0492922973540265D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.5422809510910556D-01,  2.9907982630804053D-01), &
( -9.5514116830577067D-01,  2.9615088824362401D-01), ( -9.5604525134999641D-01,  2.9321916269425896D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.5782641302753291D-01,  2.8734745954472962D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.5957151308198452D-01,  2.8146493792575789D-01), &
( -9.6043051941556579D-01,  2.7851968938505312D-01), ( -9.6128048581132064D-01,  2.7557181931095831D-01), &
( -9.6212140426904158D-01,  2.7262135544994925D-01), ( -9.6295326687368388D-01,  2.6966832557291504D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.6458979328981265D-01,  2.6375467897483157D-01), &
( -9.6539444169768929D-01,  2.6079411791527585D-01), ( -9.6619000344541250D-01,  2.5783110216215899D-01), &
( -9.6697647104485207D-01,  2.5486565960451468D-01), ( -9.6775383709347540D-01,  2.5189781815421719D-01), &
( -9.6852209427441738D-01,  2.4892760574572009D-01), ( -9.6928123535654853D-01,  2.4595505033579465D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7077214072895024D-01,  2.4000302244874175D-01), &
( -9.7150389098625178D-01,  2.3702360599436717D-01), ( -9.7222649707893627D-01,  2.3404195858354349D-01), &
( -9.7293995220556007D-01,  2.3105810828067130D-01), ( -9.7364424965081187D-01,  2.2807208317088606D-01), &
( -9.7433938278557586D-01,  2.2508391135979283D-01), ( -9.7502534506699412D-01,  2.2209362097320365D-01), &
( -9.7570213003852846D-01,  2.1910124015687002D-01), ( -9.7636973133002114D-01,  2.1610679707621944D-01), &
( -9.7702814265775439D-01,  2.1311031991609142D-01), ( -9.7767735782450993D-01,  2.1011183688046978D-01), &
( -9.7831737071962754D-01,  2.0711137619221884D-01), ( -9.7894817531906220D-01,  2.0410896609281684D-01), &
( -9.7956976568544052D-01,  2.0110463484209198D-01), ( -9.8018213596811732D-01,  1.9809841071795378D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8137919331375456D-01,  1.9208039704989244D-01), &
( -9.8196386910955524D-01,  1.8906866414980633D-01), ( -9.8253930228744124D-01,  1.8605515166344688D-01), &
( -9.8310548743121640D-01,  1.8303988795514090D-01), ( -9.8366241921173025D-01,  1.8002290140569957D-01), &
( -9.8421009238692903D-01,  1.7700422041214892D-01), ( -9.8474850180190421D-01,  1.7398387338746410D-01), &
( -9.8527764238894122D-01,  1.7096188876030119D-01), ( -9.8579750916756737D-01,  1.6793829497473126D-01), &
( -9.8630809724459856D-01,  1.6491312048997012D-01), ( -9.8680940181418553D-01,  1.6188639378011171D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.8778414164457218D-01,  1.5582839765426537D-01), &
( -9.8825756773074946D-01,  1.5279718525844369D-01), ( -9.8872169196032378D-01,  1.4976453467732145D-01)/
data (mpuu1(i), i =  2001,  2100) / &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.8962201746320078D-01,  1.4369503315029464D-01), &
( -9.9005821026229701D-01,  1.4065823933284952D-01), ( -9.9048508425645709D-01,  1.3762012158648601D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9131085984611544D-01,  1.3154002870288331D-01), &
( -9.9170975366909953D-01,  1.2849811079379306D-01), ( -9.9209931314219180D-01,  1.2545498341154626D-01), &
( -9.9247953459870997D-01,  1.2241067519921635D-01), ( -9.9285041445986510D-01,  1.1936521481099163D-01), &
( -9.9321194923479450D-01,  1.1631863091190471D-01), ( -9.9356413552059530D-01,  1.1327095217756442D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9424044945318790D-01,  1.0717242495680916D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9487933079480562D-01,  1.0106986275482793D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9548075549192694D-01,  9.4963495329638908D-02), &
( -9.9576741446765982D-01,  9.1908956497132765D-02), ( -9.9604470090125197D-01,  8.8853552582524753D-02), &
( -9.9631261218277800D-01,  8.5797312344440158D-02), ( -9.9657114579055484D-01,  8.2740264549375650D-02), &
( -9.9682029929116567D-01,  7.9682437971430195D-02), ( -9.9706007033948296D-01,  7.6623861392031686D-02), &
( -9.9729045667869021D-01,  7.3564563599667745D-02), ( -9.9751145614030345D-01,  7.0504573389613856D-02), &
( -9.9772306664419164D-01,  6.7443919563664176D-02), ( -9.9792528619859600D-01,  6.4382630929857701D-02), &
( -9.9811811290014918D-01,  6.1320736302208495D-02), ( -9.9830154493389289D-01,  5.8258264500435794D-02), &
( -9.9847558057329477D-01,  5.5195244349690094D-02), ( -9.9864021818026516D-01,  5.2131704680283601D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9894129318685687D-01,  4.6003182130914706D-02), &
( -9.9907772775264536D-01,  4.2938256934941021D-02), ( -9.9920475861836389D-01,  3.9872927587740130D-02), &
( -9.9932238458834954D-01,  3.6807222941358832D-02), ( -9.9943060455546173D-01,  3.3741171851377705D-02), &
( -9.9952941750109314D-01,  3.0674803176636865D-02), ( -9.9961882249517864D-01,  2.7608145778965656D-02), &
( -9.9969881869620425D-01,  2.4541228522912326D-02), ( -9.9976940535121528D-01,  2.1474080275469667D-02), &
( -9.9983058179582340D-01,  1.8406729905805101D-02), ( -9.9988234745421256D-01,  1.5339206284988060D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9995764455196390D-01,  9.2037547820600224D-03), &
( -9.9998117528260111D-01,  6.1358846491547988D-03), ( -9.9999529380957619D-01,  3.0679567629659770D-03), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9999882345170188D-01,  1.5339801862847655D-03), &
(  9.9999529380957619D-01,  3.0679567629659761D-03), (  9.9998941108192840D-01,  4.6019261204485705D-03), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9997058643097414D-01,  7.6698287395310970D-03), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9994234967602391D-01,  1.0737659167264491D-02), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9990470108285290D-01,  1.3805388528060391D-02), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9985764100582386D-01,  1.6872987947281710D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9980116988788426D-01,  1.9940428551514441D-02), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9973528826056168D-01,  2.3007681468839369D-02), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9965999674395922D-01,  2.6074717829103901D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9957529604674922D-01,  2.9141508764193722D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9948118696616695D-01,  3.2208025408304586D-02), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9937767038800285D-01,  3.5274238898213947D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9926474728659442D-01,  3.8340120373552694D-02), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9914241872481691D-01,  4.1405640977076739D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9901068585407338D-01,  4.4470771854938668D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9886954991428356D-01,  4.7535484156959303D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9871901223387294D-01,  5.0599749036899282D-02), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9855907422975931D-01,  5.3663537652730520D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9838973740734016D-01,  5.6726821166907748D-02), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9821100336047819D-01,  5.9789570746639868D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9802287377148624D-01,  6.2851757564161406D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9782535041111164D-01,  6.5913352797003805D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9761843513851955D-01,  6.8974327628266746D-02), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9740212990127530D-01,  7.2034653246889332D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9717643673532619D-01,  7.5094300847921305D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9694135776498216D-01,  7.8153241632794232D-02)/
data (mpuu1(i), i =  2101,  2200) / &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9669689520289606D-01,  8.1211446809592441D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9644305135004263D-01,  8.4268887593324071D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9617982859569698D-01,  8.7325535206192059D-02), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.9590722941741172D-01,  9.0381360877864983D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9562525638099431D-01,  9.3436335845747787D-02), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.9533391214048228D-01,  9.6490431355252593D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9503319943811863D-01,  9.9543618660069319D-02), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9472312110432570D-01,  1.0259586902243628D-01), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9440368005767910D-01,  1.0564715371341062D-01), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9407487930487937D-01,  1.0869744401313872D-01), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9373672194072460D-01,  1.1174671121112659D-01), &
(  9.9356413552059530D-01,  1.1327095217756435D-01), (  9.9338921114808065D-01,  1.1479492660651008D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9303235019785141D-01,  1.1784206150832498D-01), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.9266614244894802D-01,  1.2088808723577708D-01), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.9229059134825737D-01,  1.2393297511851216D-01), &
(  9.9209931314219180D-01,  1.2545498341154623D-01), (  9.9190570043060933D-01,  1.2697669649688587D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9151147331874390D-01,  1.3001922272223335D-01), &
(  9.9131085984611544D-01,  1.3154002870288312D-01), (  9.9110791372327689D-01,  1.3306052515713906D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.9069502544266463D-01,  1.3610057517570620D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.9027281236316911D-01,  1.3913934416382620D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8984127845882053D-01,  1.4217680351944803D-01), &
(  9.8962201746320089D-01,  1.4369503315029447D-01), (  9.8940042779138038D-01,  1.4521292465284746D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8895026451030299D-01,  1.4824767898689603D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8849079285269659D-01,  1.5128103795733022D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8802201714328353D-01,  1.5431297301302010D-01), &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.8754394179435923D-01,  1.5734345561623825D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8705657130575097D-01,  1.6037245724292828D-01), &
(  9.8680940181418553D-01,  1.6188639378011183D-01), (  9.8655991026477541D-01,  1.6339994938297323D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8605396334619544D-01,  1.6642590354046410D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.8553873531217606D-01,  1.6945029123396796D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8501423101223984D-01,  1.7247308399679595D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8448045538322093D-01,  1.7549425337727143D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8393741344921892D-01,  1.7851377093899751D-01), &
(  9.8366241921173025D-01,  1.8002290140569951D-01), (  9.8338511032155118D-01,  1.8153160826112497D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8282355119870524D-01,  1.8454773693861962D-01), &
(  9.8253930228744124D-01,  1.8605515166344663D-01), (  9.8225274136628937D-01,  1.8756212858252960D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.8167268619698311D-01,  1.9057475482025274D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.8108339115048671D-01,  1.9358558729580361D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.8048486177346938D-01,  1.9659459767008022D-01), &
(  9.8018213596811743D-01,  1.9809841071795356D-01), (  9.7987710369951764D-01,  1.9960175762113097D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.7926012264908202D-01,  2.0260703884442113D-01), &
(  9.7894817531906220D-01,  2.0410896609281687D-01), (  9.7863392442942321D-01,  2.0561041305309924D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7799851493455714D-01,  2.0861185197826349D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.7735390014520007D-01,  2.1161132736922755D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7670008612871184D-01,  2.1460881099378676D-01), &
(  9.7636973133002114D-01,  2.1610679707621952D-01), (  9.7603707903903902D-01,  2.1760427463848364D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7536488511665698D-01,  2.2059769010887351D-01), &
(  9.7502534506699412D-01,  2.2209362097320351D-01), (  9.7468351068851067D-01,  2.2358902922978999D-01), &
(  9.7433938278557586D-01,  2.2508391135979283D-01), (  9.7399296216795583D-01,  2.2657826384561000D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7329324605469825D-01,  2.2956536582051887D-01)/
data (mpuu1(i), i =  2201,  2300) / &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7258436893473221D-01,  2.3255030703877524D-01), &
(  9.7222649707893627D-01,  2.3404195858354343D-01), (  9.7186633748027940D-01,  2.3553305940497549D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.7113915844972509D-01,  2.3851359484431842D-01), &
(  9.7077214072895035D-01,  2.4000302244874150D-01), (  9.7040283868755550D-01,  2.4149188530286933D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6965738512429245D-01,  2.4446790274782415D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6890280477642887D-01,  2.4744161916777327D-01), &
(  9.6852209427441727D-01,  2.4892760574572015D-01), (  9.6813910474636244D-01,  2.5041300657296522D-01), &
(  9.6775383709347551D-01,  2.5189781815421697D-01), (  9.6736629222232851D-01,  2.5338203699557016D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6658437447833312D-01,  2.5634868248994291D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.6579335887408368D-01,  2.5931291513288623D-01), &
(  9.6539444169768940D-01,  2.6079411791527551D-01), (  9.6499325285492032D-01,  2.6227470702391359D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.6418406395174583D-01,  2.6523403028551179D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.6336579978095405D-01,  2.6819085706340318D-01), &
(  9.6295326687368388D-01,  2.6966832557291509D-01), (  9.6253846804435916D-01,  2.7114515952680801D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.6170207652912254D-01,  2.7409690986870638D-01), &
(  9.6128048581132064D-01,  2.7557181931095814D-01), (  9.6085663310767966D-01,  2.7704608030609990D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.6000214573766596D-01,  2.7999264308027322D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.5913862246184189D-01,  2.8293657045705539D-01), &
(  9.5870347489587160D-01,  2.8440753721127188D-01), (  9.5826607140801767D-01,  2.8587783472708062D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.5738450078897586D-01,  2.8881640820604948D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.5649391890239510D-01,  2.9175226323498926D-01), &
(  9.5604525134999641D-01,  2.9321916269425863D-01), (  9.5559433413077111D-01,  2.9468537218051433D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.5468575494133834D-01,  2.9761570743508620D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.5376818988599033D-01,  3.0054324141727345D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.5284164760119872D-01,  3.0346794657201132D-01), &
(  9.5237501271976588D-01,  3.0492922973540237D-01), (  9.5190613680793235D-01,  3.0638979537086092D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.5096166631157508D-01,  3.0930876031226873D-01), &
(  9.5048607394948170D-01,  3.1076715274961147D-01), (  9.5000824500184300D-01,  3.1222481392182488D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4904588185270056D-01,  3.1513792875252244D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4807458592227623D-01,  3.1804807738501495D-01), &
(  9.4758559101774109D-01,  3.1950203081601569D-01), (  9.4709436635277722D-01,  3.2095523242787521D-01), &
(  9.4660091308328353D-01,  3.2240767880106985D-01), (  9.4610523237040345D-01,  3.2385936651785285D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4510719328526061D-01,  3.2676045232013173D-01), &
(  9.4460483726148026D-01,  3.2820984357909250D-01), (  9.4410025849127266D-01,  3.2965846252858749D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.4308443746609349D-01,  3.3255336986604422D-01), &
(  9.4257319760144687D-01,  3.3399965144200938D-01), (  9.4205973977101731D-01,  3.3544514708453160D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.4102617505088926D-01,  3.3833376696554113D-01), &
(  9.4050607059326830D-01,  3.3977688440682685D-01), (  9.3998375303401405D-01,  3.4121920232028236D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3893248353206449D-01,  3.4410142598993881D-01), &
(  9.3840353406310806D-01,  3.4554132496398909D-01), (  9.3787237643998989D-01,  3.4698041084592368D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3680344173592156D-01,  3.4985612979013492D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.3572568948108037D-01,  3.5272855575521073D-01), &
(  9.3518350993894761D-01,  3.5416352542049034D-01), (  9.3463912981968078D-01,  3.5559766170478385D-01), &
(  9.3409255040425898D-01,  3.5703096123342998D-01), (  9.3354377297883617D-01,  3.5846342063373654D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.3243962926846236D-01,  3.6132580556845428D-01), &
(  9.3188426558166815D-01,  3.6275572436739723D-01), (  9.3132670908118043D-01,  3.6418478956707989D-01), &
(  9.3076696107898371D-01,  3.6561299780477385D-01), (  9.3020502289221907D-01,  3.6704034571976718D-01), &
(  9.2964089584318121D-01,  3.6846682995337232D-01), (  9.2907458125931575D-01,  3.6989244714893410D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2793539482261789D-01,  3.7274106700951576D-01), &
(  9.2736252565040111D-01,  3.7416406297145793D-01), (  9.2678747430458175D-01,  3.7558617848921722D-01)/
data (mpuu1(i), i =  2301,  2400) / &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.2563083050987272D-01,  3.7842775480876556D-01), &
(  9.2504924078267758D-01,  3.7984720892405116D-01), (  9.2446547432526260D-01,  3.8126576922216238D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.2329141671952764D-01,  3.8410019501693504D-01), &
(  9.2270112833387863D-01,  3.8551605384391885D-01), (  9.2210866874334507D-01,  3.8693100551438858D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  9.2091724152918952D-01,  3.8975817406985641D-01), &
(  9.2031827670911059D-01,  3.9117038430225387D-01), (  9.1971714629122736D-01,  3.9258167407295147D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1850839432521225D-01,  3.9540147894781635D-01), &
(  9.1790077562139050D-01,  3.9680998741671031D-01), (  9.1729099700837791D-01,  3.9821756215337356D-01), &
(  9.1667905992104270D-01,  3.9962419984564679D-01), (  9.1606496579933172D-01,  4.0102989718357562D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.1483031223794620D-01,  4.0383845756765407D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.1358704794525081D-01,  4.0664321687036903D-01), &
(  9.1296219042839821D-01,  4.0804416286497869D-01), (  9.1233518462332275D-01,  4.0944414869225759D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.1107473405517636D-01,  4.1224122666988289D-01), &
(  9.1044129225806725D-01,  4.1363831223843456D-01), (  9.0980570810465222D-01,  4.1503442447608163D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0852811871630612D-01,  4.1782371582021227D-01), &
(  9.0788611648766626D-01,  4.1921688836322391D-01), (  9.0724197791529582D-01,  4.2060907444840251D-01), &
(  9.0659570451491533D-01,  4.2200027079979968D-01), (  9.0594729780726846D-01,  4.2339047414379605D-01), &
(  9.0529675931811882D-01,  4.2477968120910881D-01), (  9.0464409057824624D-01,  4.2616788872679962D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  9.0333236849451182D-01,  4.2894129205532949D-01), &
(  9.0267331823725883D-01,  4.3032648134008261D-01), (  9.0201214390249318D-01,  4.3171065802505726D-01), &
(  9.0134884704602203D-01,  4.3309381885315196D-01), (  9.0068342922864697D-01,  4.3447596056965565D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9934623697934157D-01,  4.3723717366104409D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9800057974073988D-01,  4.3999427130963326D-01), &
(  8.9732458070541832D-01,  4.4137126873171667D-01), (  8.9664647017868027D-01,  4.4274722756457002D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.9528392103855758D-01,  4.4549601651398174D-01), &
(  8.9459948563138270D-01,  4.4686884016237416D-01), (  8.9391294514520325D-01,  4.4824061228521989D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.9253355540276458D-01,  4.5098098904510386D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.9114576479458318D-01,  4.5371712100016387D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.8974958638307289D-01,  4.5644898239688392D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.8834503330959635D-01,  4.5917654752194409D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8693211879434219D-01,  4.6189979070246273D-01), &
(  8.8622253014888064D-01,  4.6325978355186015D-01), (  8.8551085613619995D-01,  4.6461868630623782D-01), &
(  8.8479709843093779D-01,  4.6597649576796618D-01), (  8.8408125871263499D-01,  4.6733320874198847D-01), &
(  8.8336333866573158D-01,  4.6868882203582796D-01), (  8.8264333997956279D-01,  4.7004333245959562D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.8119711347122198D-01,  4.7274903195034279D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.7974259280004741D-01,  4.7545028174715587D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7827979165654158D-01,  4.7814705642484301D-01), &
(  8.7754529020726135D-01,  4.7949375766015301D-01), (  8.7680872380914565D-01,  4.8083933060033396D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7532940310411089D-01,  4.8352707893291874D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.7384184346536686D-01,  4.8621027612448642D-01), &
(  8.7309497841829009D-01,  4.8755016014843600D-01), (  8.7234605889439154D-01,  4.8888889691976317D-01), &
(  8.7159508665595098D-01,  4.9022648328829116D-01), (  8.7084206347007886D-01,  4.9156291610654990D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.6932987134860684D-01,  4.9423230851595967D-01), &
(  8.6857070597134090D-01,  4.9556526182577254D-01), (  8.6780949676330332D-01,  4.9689704902265447D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.6628095402451299D-01,  4.9955711254508184D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.6474425751946238D-01,  5.0221247404571079D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.6319942171212416D-01,  5.0486310853126759D-01), &
(  8.6242395611104050D-01,  5.0618664534515523D-01), (  8.6164646114308130D-01,  5.0750899105297087D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.6008539042939014D-01,  5.1015009670676681D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.5851622426444285D-01,  5.1278640063356296D-01)/
data (mpuu1(i), i =  2401,  2500) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.5693897741782876D-01,  5.1541787801946293D-01), &
(  8.5614732837519447D-01,  5.1673179901764987D-01), (  8.5535366473519603D-01,  5.1804450409599934D-01), &
(  8.5455798836540053D-01,  5.1935599016558964D-01), (  8.5376030113811141D-01,  5.2066625414036716D-01), &
(  8.5296060493036363D-01,  5.2197529293715439D-01), (  8.5215890162391983D-01,  5.2328310347565643D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.5054948126560348D-01,  5.2589502747108463D-01), &
(  8.4974176800085255D-01,  5.2719913478190139D-01), (  8.4893205521163961D-01,  5.2850200154222848D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.4730663868585832D-01,  5.3110400115125500D-01), &
(  8.4649093877405213D-01,  5.3240312787719790D-01), (  8.4567324698729907D-01,  5.3370100180715296D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.4403189549006641D-01,  5.3629297906596318D-01), &
(  8.4320823964184544D-01,  5.3758707629564539D-01), (  8.4238259964318585D-01,  5.3887990853100842D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  8.4072537497045807D-01,  5.4146176585312344D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.3906023707031274D-01,  5.4403852673088382D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3738720161566194D-01,  5.4661016691083486D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  8.3570628435375260D-01,  5.4917666218771966D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.3401750110601813D-01,  5.5173798840470734D-01), &
(  8.3317016470191319D-01,  5.5301670558002747D-01), (  8.3232086776792968D-01,  5.5429412145362000D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.3061640030884631D-01,  5.5684503727516010D-01), &
(  8.2976123379452305D-01,  5.5811853122055610D-01), (  8.2890411477186487D-01,  5.5939071185913614D-01), &
(  8.2804504525775580D-01,  5.6066157619733603D-01), (  8.2718402727366913D-01,  5.6193112124468947D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.2545615400437755D-01,  5.6446624152051950D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.2372051122739143D-01,  5.6699604882510868D-01), &
(  8.2284978137582643D-01,  5.6825895267013149D-01), (  8.2197711527924155D-01,  5.6952051934694714D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  8.2022598256943469D-01,  5.7203962932475705D-01), &
(  8.1934752007679701D-01,  5.7329716669804220D-01), (  8.1846712958029866D-01,  5.7455335504771576D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.1670057286682785D-01,  5.7706167285567944D-01), &
(  8.1581441080673378D-01,  5.7831379641165559D-01), (  8.1492632905652662D-01,  5.7956455913940563D-01), &
(  8.1403632970594841D-01,  5.8081395809576453D-01), (  8.1314441484925359D-01,  5.8206199034077544D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  8.1135484701706373D-01,  5.8455394295301533D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.0955764240405126D-01,  5.8704039352091797D-01), &
(  8.0865618158817498D-01,  5.8828154822264522D-01), (  8.0775281792619036D-01,  5.8952131864106394D-01), &
(  8.0684755354379933D-01,  5.9075970185887416D-01), (  8.0594039057117628D-01,  5.9199669496204099D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  8.0412037739826570D-01,  5.9446649918466443D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  8.0229279553811572D-01,  5.9693070806219650D-01), &
(  8.0137617172314024D-01,  5.9816070699634238D-01), (  8.0045766219262282D-01,  5.9938929840056454D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.9861499463476093D-01,  6.0184224705858003D-01), &
(  7.9769084094339116D-01,  6.0306659854034816D-01), (  7.9676481020841883D-01,  6.0428953094815596D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.9490712632823701D-01,  6.0673112703452448D-01), &
(  7.9397547755433717D-01,  6.0794978496777363D-01), (  7.9304196047944364D-01,  6.0916701233645321D-01), &
(  7.9210657730021239D-01,  6.1038280627630948D-01), (  7.9116933021769009D-01,  6.1159716392646191D-01), &
(  7.9023022143731003D-01,  6.1281008242940971D-01), (  7.8928925316888565D-01,  6.1402155893103849D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.8740174702903132D-01,  6.1644017453085365D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.8550682956405393D-01,  6.1885298796097632D-01), &
(  7.8455659715557524D-01,  6.2005721176328910D-01), (  7.8360451860963831D-01,  6.2125997651108755D-01), &
(  7.8265059616657573D-01,  6.2246127937414997D-01), (  7.8169483207105950D-01,  6.2366111752569453D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.7977778792301455D-01,  6.2605638840434352D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.7785340420945315D-01,  6.2844576660183271D-01), &
(  7.7688846567323244D-01,  6.2963823891492698D-01), (  7.7592169904340769D-01,  6.3082922962842447D-01), &
(  7.7495310659487382D-01,  6.3201873593980906D-01), (  7.7398269060682290D-01,  6.3320675505005719D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.7203639715038452D-01,  6.3557832048855611D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.7008283699334790D-01,  6.3794390362184406D-01)/
data (mpuu1(i), i =  2501,  2600) / &
(  7.6910333764557970D-01,  6.3912444486377573D-01), (  7.6812202852336542D-01,  6.4030348218415167D-01), &
(  7.6713891193582040D-01,  6.4148101280858316D-01), (  7.6615399019631292D-01,  6.4265703396622686D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.6417874053611667D-01,  6.4500453681554393D-01), &
(  7.6318841726338138D-01,  6.4617601298331628D-01), (  7.6219629813457890D-01,  6.4734596863651206D-01), &
(  7.6120238548426178D-01,  6.4851440102211244D-01), (  7.6020668165120242D-01,  6.4968130739068319D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.5820990981301528D-01,  6.5201053109695950D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.5620600141439454D-01,  6.5433361783180044D-01), &
(  7.5520137689653655D-01,  6.5549285299961535D-01), (  7.5419497531688917D-01,  6.5665054572942905D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.5217685044904270D-01,  6.5896129298203732D-01), &
(  7.5116513190968637D-01,  6.6011434206742048D-01), (  7.5015164580621507D-01,  6.6126583783999227D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4811938045040360D-01,  6.6356415861203977D-01), &
(  7.4710060598018013D-01,  6.6471097820334479D-01), (  7.4608007351006378D-01,  6.6585623366550972D-01), &
(  7.4505778544146595D-01,  6.6699992230363747D-01), (  7.4403374417992929D-01,  6.6814204142651845D-01), &
(  7.4300795213512172D-01,  6.6928258834663601D-01), (  7.4198041172083107D-01,  6.7042156038017309D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.3992009545951620D-01,  6.7269476907077286D-01), &
(  7.3888732446061511D-01,  6.7382900037875604D-01), (  7.3785281478846598D-01,  6.7496164610201204D-01), &
(  7.3681656887736979D-01,  6.7609270357531592D-01), (  7.3577858916571359D-01,  6.7722217013718033D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  7.3369743811466037D-01,  6.7947631989936497D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.3160938122389263D-01,  6.8172407417164971D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.2951443814699701D-01,  6.8396541179731551D-01), &
(  7.2846439044822520D-01,  6.8508366777270036D-01), (  7.2741262860237577D-01,  6.8620031168003859D-01), &
(  7.2635915508434601D-01,  6.8731534089175905D-01), (  7.2530397237306077D-01,  6.8842875278409044D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.2318848930652746D-01,  6.9065071413453460D-01), &
(  7.2212819392921535D-01,  6.9175925836415775D-01), (  7.2106619931450811D-01,  6.9286617481742463D-01), &
(  7.2000250796138165D-01,  6.9397146088965389D-01), (  7.1893712237280449D-01,  6.9507511398000088D-01), &
(  7.1787004505573171D-01,  6.9617713149146299D-01), (  7.1680127852109954D-01,  6.9727751083088652D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  7.1465868786276909D-01,  6.9947334464028377D-01), &
(  7.1358486878079352D-01,  7.0056879394324834D-01), (  7.1250937056469232D-01,  7.0166259474016845D-01), &
(  7.1143219574521643D-01,  7.0275474445722530D-01), (  7.1035334685706242D-01,  7.0384524052448494D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  7.0819063703319540D-01,  7.0602126144933974D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  7.0602126144933985D-01,  7.0819063703319529D-01), &
(  7.0493408037590499D-01,  7.0927282643886558D-01), (  7.0384524052448505D-01,  7.1035334685706231D-01), &
(  7.0275474445722541D-01,  7.1143219574521632D-01), (  7.0166259474016857D-01,  7.1250937056469232D-01), &
(  7.0056879394324845D-01,  7.1358486878079352D-01), (  6.9947334464028388D-01,  7.1465868786276898D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.9727751083088663D-01,  7.1680127852109943D-01), &
(  6.9617713149146310D-01,  7.1787004505573160D-01), (  6.9507511398000088D-01,  7.1893712237280438D-01), &
(  6.9397146088965400D-01,  7.2000250796138165D-01), (  6.9286617481742474D-01,  7.2106619931450799D-01), &
(  6.9175925836415786D-01,  7.2212819392921523D-01), (  6.9065071413453472D-01,  7.2318848930652724D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.8842875278409055D-01,  7.2530397237306066D-01), &
(  6.8731534089175916D-01,  7.2635915508434590D-01), (  6.8620031168003870D-01,  7.2741262860237565D-01), &
(  6.8508366777270047D-01,  7.2846439044822520D-01), (  6.8396541179731551D-01,  7.2951443814699690D-01), &
(  6.8284554638524808D-01,  7.3056276922782759D-01), (  6.8172407417164982D-01,  7.3160938122389252D-01), &
(  6.8060099779545313D-01,  7.3265427167241270D-01), (  6.7947631989936508D-01,  7.3369743811466026D-01), &
(  6.7835004312986158D-01,  7.3473887809596339D-01), (  6.7722217013718045D-01,  7.3577858916571348D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.7496164610201204D-01,  7.3785281478846598D-01), &
(  6.7382900037875615D-01,  7.3888732446061511D-01), (  6.7269476907077297D-01,  7.3992009545951609D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.7042156038017320D-01,  7.4198041172083096D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.6814204142651856D-01,  7.4403374417992918D-01), &
(  6.6699992230363758D-01,  7.4505778544146595D-01), (  6.6585623366550972D-01,  7.4608007351006367D-01), &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.6356415861203988D-01,  7.4811938045040349D-01)/
data (mpuu1(i), i =  2601,  2700) / &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.6126583783999227D-01,  7.5015164580621496D-01), &
(  6.6011434206742059D-01,  7.5116513190968637D-01), (  6.5896129298203732D-01,  7.5217685044904270D-01), &
(  6.5780669329707875D-01,  7.5318679904361241D-01), (  6.5665054572942905D-01,  7.5419497531688917D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  6.5433361783180055D-01,  7.5620600141439454D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.5201053109695961D-01,  7.5820990981301528D-01), &
(  6.5084668499638099D-01,  7.5920918897838796D-01), (  6.4968130739068330D-01,  7.6020668165120231D-01), &
(  6.4851440102211255D-01,  7.6120238548426178D-01), (  6.4734596863651217D-01,  7.6219629813457890D-01), &
(  6.4617601298331639D-01,  7.6318841726338127D-01), (  6.4500453681554404D-01,  7.6417874053611667D-01), &
(  6.4383154288979150D-01,  7.6516726562245885D-01), (  6.4265703396622698D-01,  7.6615399019631281D-01), &
(  6.4148101280858316D-01,  7.6713891193582029D-01), (  6.4030348218415178D-01,  7.6812202852336531D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  6.3794390362184417D-01,  7.7008283699334790D-01), &
(  6.3676186123628431D-01,  7.7106052426181371D-01), (  6.3557832048855623D-01,  7.7203639715038441D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.3320675505005730D-01,  7.7398269060682279D-01), &
(  6.3201873593980906D-01,  7.7495310659487382D-01), (  6.3082922962842458D-01,  7.7592169904340758D-01), &
(  6.2963823891492710D-01,  7.7688846567323244D-01), (  6.2844576660183271D-01,  7.7785340420945304D-01), &
(  6.2725181549514419D-01,  7.7881651238147587D-01), (  6.2605638840434363D-01,  7.7977778792301444D-01), &
(  6.2485948814238645D-01,  7.8073722857209438D-01), (  6.2366111752569464D-01,  7.8169483207105939D-01), &
(  6.2246127937415008D-01,  7.8265059616657562D-01), (  6.2125997651108766D-01,  7.8360451860963820D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  6.1885298796097643D-01,  7.8550682956405393D-01), &
(  6.1764730793780398D-01,  7.8645521359908577D-01), (  6.1644017453085365D-01,  7.8740174702903132D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  6.1402155893103849D-01,  7.8928925316888554D-01), &
(  6.1281008242940982D-01,  7.9023022143731003D-01), (  6.1159716392646202D-01,  7.9116933021769009D-01), &
(  6.1038280627630948D-01,  7.9210657730021228D-01), (  6.0916701233645332D-01,  7.9304196047944364D-01), &
(  6.0794978496777374D-01,  7.9397547755433706D-01), (  6.0673112703452459D-01,  7.9490712632823701D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  6.0428953094815607D-01,  7.9676481020841872D-01), &
(  6.0306659854034828D-01,  7.9769084094339104D-01), (  6.0184224705858014D-01,  7.9861499463476082D-01), &
(  6.0061647938386897D-01,  7.9953726910790501D-01), (  5.9938929840056465D-01,  8.0045766219262271D-01), &
(  5.9816070699634238D-01,  8.0137617172314013D-01), (  5.9693070806219650D-01,  8.0229279553811561D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.9446649918466454D-01,  8.0412037739826570D-01), &
(  5.9323229503979991D-01,  8.0503133114296355D-01), (  5.9199669496204099D-01,  8.0594039057117628D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.8952131864106394D-01,  8.0775281792619025D-01), &
(  5.8828154822264533D-01,  8.0865618158817498D-01), (  5.8704039352091808D-01,  8.0955764240405115D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  5.8455394295301544D-01,  8.1135484701706373D-01), &
(  5.8330865293769840D-01,  8.1225058658520388D-01), (  5.8206199034077555D-01,  8.1314441484925348D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  5.7956455913940574D-01,  8.1492632905652651D-01), &
(  5.7831379641165570D-01,  8.1581441080673378D-01), (  5.7706167285567955D-01,  8.1670057286682773D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.7455335504771587D-01,  8.1846712958029866D-01), &
(  5.7329716669804232D-01,  8.1934752007679690D-01), (  5.7203962932475716D-01,  8.2022598256943469D-01), &
(  5.7078074588696737D-01,  8.2110251499110465D-01), (  5.6952051934694725D-01,  8.2197711527924144D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.6699604882510868D-01,  8.2372051122739132D-01), &
(  5.6573181078361323D-01,  8.2458930278502529D-01), (  5.6446624152051950D-01,  8.2545615400437744D-01), &
(  5.6319934401383420D-01,  8.2632106284566342D-01), (  5.6193112124468947D-01,  8.2718402727366902D-01), &
(  5.6066157619733603D-01,  8.2804504525775569D-01), (  5.5939071185913614D-01,  8.2890411477186476D-01), &
(  5.5811853122055621D-01,  8.2976123379452305D-01), (  5.5684503727516022D-01,  8.3061640030884620D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.5429412145362011D-01,  8.3232086776792968D-01), &
(  5.5301670558002758D-01,  8.3317016470191319D-01), (  5.5173798840470745D-01,  8.3401750110601802D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.4917666218771977D-01,  8.3570628435375249D-01), &
(  5.4789405917310030D-01,  8.3654772722351189D-01), (  5.4661016691083497D-01,  8.3738720161566182D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.4403852673088393D-01,  8.3906023707031263D-01), &
(  5.4275078486451600D-01,  8.3989379419599941D-01), (  5.4146176585312356D-01,  8.4072537497045796D-01)/
data (mpuu1(i), i =  2701,  2800) / &
(  5.4017147272989297D-01,  8.4155497743689833D-01), (  5.3887990853100842D-01,  8.4238259964318585D-01), &
(  5.3758707629564551D-01,  8.4320823964184544D-01), (  5.3629297906596318D-01,  8.4403189549006641D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.3370100180715296D-01,  8.4567324698729907D-01), &
(  5.3240312787719801D-01,  8.4649093877405202D-01), (  5.3110400115125511D-01,  8.4730663868585832D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  5.2850200154222848D-01,  8.4893205521163961D-01), &
(  5.2719913478190139D-01,  8.4974176800085244D-01), (  5.2589502747108485D-01,  8.5054948126560337D-01), &
(  5.2458968267846895D-01,  8.5135519310526520D-01), (  5.2328310347565643D-01,  8.5215890162391983D-01), &
(  5.2197529293715439D-01,  8.5296060493036363D-01), (  5.2066625414036727D-01,  8.5376030113811130D-01), &
(  5.1935599016558964D-01,  8.5455798836540053D-01), (  5.1804450409599945D-01,  8.5535366473519603D-01), &
(  5.1673179901764998D-01,  8.5614732837519436D-01), (  5.1541787801946315D-01,  8.5693897741782865D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  5.1278640063356307D-01,  8.5851622426444274D-01), &
(  5.1146885043797052D-01,  8.5930181835700825D-01), (  5.1015009670676681D-01,  8.6008539042939014D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  5.0750899105297098D-01,  8.6164646114308130D-01), &
(  5.0618664534515545D-01,  8.6242395611104050D-01), (  5.0486310853126759D-01,  8.6319942171212416D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  5.0221247404571090D-01,  8.6474425751946238D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  4.9955711254508189D-01,  8.6628095402451299D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.9689704902265469D-01,  8.6780949676330321D-01), &
(  4.9556526182577254D-01,  8.6857070597134090D-01), (  4.9423230851595978D-01,  8.6932987134860673D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.9156291610655012D-01,  8.7084206347007886D-01), &
(  4.9022648328829116D-01,  8.7159508665595098D-01), (  4.8888889691976323D-01,  8.7234605889439143D-01), &
(  4.8755016014843611D-01,  8.7309497841828998D-01), (  4.8621027612448658D-01,  8.7384184346536675D-01), &
(  4.8486924800079112D-01,  8.7458665227817611D-01), (  4.8352707893291880D-01,  8.7532940310411078D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.8083933060033396D-01,  8.7680872380914565D-01), &
(  4.7949375766015306D-01,  8.7754529020726124D-01), (  4.7814705642484312D-01,  8.7827979165654146D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  4.7545028174715587D-01,  8.7974259280004741D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.7274903195034290D-01,  8.8119711347122198D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.7004333245959562D-01,  8.8264333997956279D-01), &
(  4.6868882203582796D-01,  8.8336333866573158D-01), (  4.6733320874198853D-01,  8.8408125871263499D-01), &
(  4.6597649576796613D-01,  8.8479709843093779D-01), (  4.6461868630623782D-01,  8.8551085613619995D-01), &
(  4.6325978355186026D-01,  8.8622253014888064D-01), (  4.6189979070246284D-01,  8.8693211879434208D-01), &
(  4.6053871095824001D-01,  8.8763962040285393D-01), (  4.5917654752194415D-01,  8.8834503330959635D-01), &
(  4.5781330359887729D-01,  8.8904835585466446D-01), (  4.5644898239688386D-01,  8.8974958638307289D-01), &
(  4.5508358712634384D-01,  8.9044872324475788D-01), (  4.5371712100016393D-01,  8.9114576479458318D-01), &
(  4.5234958723377100D-01,  8.9184070939234272D-01), (  4.5098098904510381D-01,  8.9253355540276469D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.4824061228522000D-01,  8.9391294514520325D-01), &
(  4.4686884016237433D-01,  8.9459948563138258D-01), (  4.4549601651398174D-01,  8.9528392103855758D-01), &
(  4.4412214457042926D-01,  8.9596624975618511D-01), (  4.4274722756457013D-01,  8.9664647017868015D-01), &
(  4.4137126873171662D-01,  8.9732458070541832D-01), (  4.3999427130963326D-01,  8.9800057974073988D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  4.3723717366104420D-01,  8.9934623697934146D-01), &
(  4.3585707992225547D-01,  9.0001589201616028D-01), (  4.3447596056965571D-01,  9.0068342922864686D-01), &
(  4.3309381885315201D-01,  9.0134884704602203D-01), (  4.3171065802505737D-01,  9.0201214390249307D-01), &
(  4.3032648134008261D-01,  9.0267331823725883D-01), (  4.2894129205532955D-01,  9.0333236849451182D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.2616788872679956D-01,  9.0464409057824624D-01), &
(  4.2477968120910881D-01,  9.0529675931811882D-01), (  4.2339047414379610D-01,  9.0594729780726846D-01), &
(  4.2200027079979979D-01,  9.0659570451491533D-01), (  4.2060907444840251D-01,  9.0724197791529582D-01), &
(  4.1921688836322396D-01,  9.0788611648766615D-01), (  4.1782371582021238D-01,  9.0852811871630612D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  4.1503442447608163D-01,  9.0980570810465222D-01), &
(  4.1363831223843456D-01,  9.1044129225806714D-01), (  4.1224122666988300D-01,  9.1107473405517625D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  4.0944414869225759D-01,  9.1233518462332275D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  4.0664321687036914D-01,  9.1358704794525081D-01)/
data (mpuu1(i), i =  2801,  2900) / &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  4.0383845756765413D-01,  9.1483031223794620D-01), &
(  4.0243465085941854D-01,  9.1544871608826783D-01), (  4.0102989718357579D-01,  9.1606496579933161D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.9821756215337362D-01,  9.1729099700837791D-01), &
(  3.9680998741671042D-01,  9.1790077562139039D-01), (  3.9540147894781630D-01,  9.1850839432521225D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.9258167407295153D-01,  9.1971714629122736D-01), &
(  3.9117038430225398D-01,  9.2031827670911048D-01), (  3.8975817406985641D-01,  9.2091724152918952D-01), &
(  3.8834504669882630D-01,  9.2151403934204190D-01), (  3.8693100551438869D-01,  9.2210866874334507D-01), &
(  3.8551605384391902D-01,  9.2270112833387852D-01), (  3.8410019501693504D-01,  9.2329141671952764D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.8126576922216249D-01,  9.2446547432526260D-01), &
(  3.7984720892405111D-01,  9.2504924078267758D-01), (  3.7842775480876556D-01,  9.2563083050987272D-01), &
(  3.7700741021641831D-01,  9.2621024213831138D-01), (  3.7558617848921733D-01,  9.2678747430458175D-01), &
(  3.7416406297145793D-01,  9.2736252565040111D-01), (  3.7274106700951581D-01,  9.2793539482261789D-01), &
(  3.7131719395183760D-01,  9.2850608047321548D-01), (  3.6989244714893421D-01,  9.2907458125931575D-01), &
(  3.6846682995337232D-01,  9.2964089584318121D-01), (  3.6704034571976724D-01,  9.3020502289221907D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  3.6418478956707984D-01,  9.3132670908118054D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  3.6132580556845434D-01,  9.3243962926846236D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.5846342063373654D-01,  9.3354377297883617D-01), &
(  3.5703096123343003D-01,  9.3409255040425887D-01), (  3.5559766170478396D-01,  9.3463912981968078D-01), &
(  3.5416352542049051D-01,  9.3518350993894750D-01), (  3.5272855575521073D-01,  9.3572568948108037D-01), &
(  3.5129275608556715D-01,  9.3626566717027826D-01), (  3.4985612979013503D-01,  9.3680344173592156D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.4698041084592368D-01,  9.3787237643998989D-01), &
(  3.4554132496398915D-01,  9.3840353406310806D-01), (  3.4410142598993898D-01,  9.3893248353206449D-01), &
(  3.4266071731199438D-01,  9.3945922360218992D-01), (  3.4121920232028241D-01,  9.3998375303401394D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  3.3833376696554129D-01,  9.4102617505088926D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.3544514708453166D-01,  9.4205973977101731D-01), &
(  3.3399965144200949D-01,  9.4257319760144687D-01), (  3.3255336986604417D-01,  9.4308443746609349D-01), &
(  3.3110630575987643D-01,  9.4359345816196039D-01), (  3.2965846252858755D-01,  9.4410025849127266D-01), &
(  3.2820984357909266D-01,  9.4460483726148026D-01), (  3.2676045232013173D-01,  9.4510719328526061D-01), &
(  3.2531029216226298D-01,  9.4560732538052128D-01), (  3.2385936651785296D-01,  9.4610523237040334D-01), &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  3.2095523242787521D-01,  9.4709436635277722D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  3.1804807738501506D-01,  9.4807458592227623D-01), &
(  3.1659337555616585D-01,  9.4856134991573027D-01), (  3.1513792875252244D-01,  9.4904588185270056D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  3.1222481392182505D-01,  9.5000824500184300D-01), &
(  3.1076715274961147D-01,  9.5048607394948170D-01), (  3.0930876031226873D-01,  9.5096166631157508D-01), &
(  3.0784964004153498D-01,  9.5143502096900834D-01), (  3.0638979537086108D-01,  9.5190613680793223D-01), &
(  3.0492922973540237D-01,  9.5237501271976588D-01), (  3.0346794657201137D-01,  9.5284164760119872D-01), &
(  3.0200594931922820D-01,  9.5330604035419375D-01), (  3.0054324141727340D-01,  9.5376818988599033D-01), &
(  2.9907982630804048D-01,  9.5422809510910567D-01), (  2.9761570743508631D-01,  9.5468575494133834D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.9468537218051433D-01,  9.5559433413077111D-01), &
(  2.9321916269425868D-01,  9.5604525134999641D-01), (  2.9175226323498937D-01,  9.5649391890239510D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.8881640820604948D-01,  9.5738450078897586D-01), &
(  2.8734745954472957D-01,  9.5782641302753291D-01), (  2.8587783472708073D-01,  9.5826607140801767D-01), &
(  2.8440753721127182D-01,  9.5870347489587160D-01), (  2.8293657045705539D-01,  9.5913862246184189D-01), &
(  2.8146493792575805D-01,  9.5957151308198452D-01), (  2.7999264308027338D-01,  9.6000214573766585D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.7704608030609995D-01,  9.6085663310767966D-01), &
(  2.7557181931095825D-01,  9.6128048581132064D-01), (  2.7409690986870633D-01,  9.6170207652912254D-01), &
(  2.7262135544994898D-01,  9.6212140426904158D-01), (  2.7114515952680807D-01,  9.6253846804435916D-01), &
(  2.6966832557291520D-01,  9.6295326687368388D-01), (  2.6819085706340312D-01,  9.6336579978095405D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.6523403028551190D-01,  9.6418406395174572D-01), &
(  2.6375467897483151D-01,  9.6458979328981265D-01), (  2.6227470702391359D-01,  9.6499325285492032D-01)/
data (mpuu1(i), i =  2901,  3000) / &
(  2.6079411791527557D-01,  9.6539444169768940D-01), (  2.5931291513288635D-01,  9.6579335887408368D-01), &
(  2.5783110216215893D-01,  9.6619000344541262D-01), (  2.5634868248994291D-01,  9.6658437447833312D-01), &
(  2.5486565960451463D-01,  9.6697647104485207D-01), (  2.5338203699557027D-01,  9.6736629222232851D-01), &
(  2.5189781815421691D-01,  9.6775383709347551D-01), (  2.5041300657296528D-01,  9.6813910474636244D-01), &
(  2.4892760574572026D-01,  9.6852209427441727D-01), (  2.4744161916777344D-01,  9.6890280477642887D-01), &
(  2.4595505033579459D-01,  9.6928123535654853D-01), (  2.4446790274782421D-01,  9.6965738512429245D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.4149188530286927D-01,  9.7040283868755550D-01), &
(  2.4000302244874150D-01,  9.7077214072895035D-01), (  2.3851359484431850D-01,  9.7113915844972509D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  2.3553305940497546D-01,  9.7186633748027940D-01), &
(  2.3404195858354346D-01,  9.7222649707893627D-01), (  2.3255030703877533D-01,  9.7258436893473221D-01), &
(  2.3105810828067125D-01,  9.7293995220556007D-01), (  2.2956536582051887D-01,  9.7329324605469825D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  2.2657826384561011D-01,  9.7399296216795583D-01), &
(  2.2508391135979278D-01,  9.7433938278557586D-01), (  2.2358902922978999D-01,  9.7468351068851067D-01), &
(  2.2209362097320359D-01,  9.7502534506699412D-01), (  2.2059769010887365D-01,  9.7536488511665687D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  2.1760427463848367D-01,  9.7603707903903902D-01), &
(  2.1610679707621960D-01,  9.7636973133002114D-01), (  2.1460881099378692D-01,  9.7670008612871184D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  2.1161132736922761D-01,  9.7735390014519996D-01), &
(  2.1011183688046972D-01,  9.7767735782450993D-01), (  2.0861185197826343D-01,  9.7799851493455714D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  2.0561041305309932D-01,  9.7863392442942310D-01), &
(  2.0410896609281701D-01,  9.7894817531906220D-01), (  2.0260703884442111D-01,  9.7926012264908202D-01), &
(  2.0110463484209193D-01,  9.7956976568544052D-01), (  1.9960175762113105D-01,  9.7987710369951764D-01), &
(  1.9809841071795373D-01,  9.8018213596811732D-01), (  1.9659459767008022D-01,  9.8048486177346938D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.9358558729580372D-01,  9.8108339115048659D-01), &
(  1.9208039704989238D-01,  9.8137919331375456D-01), (  1.9057475482025277D-01,  9.8167268619698311D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.8756212858252974D-01,  9.8225274136628937D-01), &
(  1.8605515166344661D-01,  9.8253930228744124D-01), (  1.8454773693861964D-01,  9.8282355119870524D-01), &
(  1.8303988795514103D-01,  9.8310548743121629D-01), (  1.8153160826112513D-01,  9.8338511032155118D-01), &
(  1.8002290140569951D-01,  9.8366241921173025D-01), (  1.7851377093899756D-01,  9.8393741344921892D-01), &
(  1.7700422041214886D-01,  9.8421009238692903D-01), (  1.7549425337727137D-01,  9.8448045538322093D-01), &
(  1.7398387338746385D-01,  9.8474850180190421D-01), (  1.7247308399679603D-01,  9.8501423101223984D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.6945029123396793D-01,  9.8553873531217606D-01), &
(  1.6793829497473120D-01,  9.8579750916756737D-01), (  1.6642590354046422D-01,  9.8605396334619544D-01), &
(  1.6491312048997006D-01,  9.8630809724459867D-01), (  1.6339994938297323D-01,  9.8655991026477541D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.6037245724292840D-01,  9.8705657130575097D-01), &
(  1.5885814333386139D-01,  9.8730141815785843D-01), (  1.5734345561623828D-01,  9.8754394179435923D-01), &
(  1.5582839765426532D-01,  9.8778414164457218D-01), (  1.5431297301302024D-01,  9.8802201714328353D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  1.5128103795733025D-01,  9.8849079285269659D-01), &
(  1.4976453467732162D-01,  9.8872169196032378D-01), (  1.4824767898689620D-01,  9.8895026451030299D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.4521292465284752D-01,  9.8940042779138038D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  1.4217680351944800D-01,  9.8984127845882053D-01), &
(  1.4065823933284924D-01,  9.9005821026229712D-01), (  1.3913934416382628D-01,  9.9027281236316911D-01), &
(  1.3762012158648618D-01,  9.9048508425645698D-01), (  1.3610057517570617D-01,  9.9069502544266463D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  1.3306052515713918D-01,  9.9110791372327678D-01), &
(  1.3154002870288325D-01,  9.9131085984611544D-01), (  1.3001922272223335D-01,  9.9151147331874390D-01), &
(  1.2849811079379322D-01,  9.9170975366909953D-01), (  1.2697669649688598D-01,  9.9190570043060933D-01), &
(  1.2545498341154621D-01,  9.9209931314219180D-01), (  1.2393297511851219D-01,  9.9229059134825737D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  1.2088808723577722D-01,  9.9266614244894802D-01), &
(  1.1936521481099134D-01,  9.9285041445986510D-01), (  1.1784206150832502D-01,  9.9303235019785141D-01), &
(  1.1631863091190486D-01,  9.9321194923479450D-01), (  1.1479492660651025D-01,  9.9338921114808065D-01), &
(  1.1327095217756435D-01,  9.9356413552059530D-01), (  1.1174671121112666D-01,  9.9373672194072460D-01)/
data (mpuu1(i), i =  3001,  3100) / &
(  1.1022220729388318D-01,  9.9390697000235606D-01), (  1.0869744401313867D-01,  9.9407487930487937D-01), &
(  1.0717242495680887D-01,  9.9424044945318790D-01), (  1.0564715371341070D-01,  9.9440368005767910D-01), &
(  1.0412163387205473D-01,  9.9456457073425542D-01), (  1.0259586902243627D-01,  9.9472312110432570D-01), &
(  1.0106986275482786D-01,  9.9487933079480562D-01), (  9.9543618660069430D-02,  9.9503319943811863D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  9.6490431355252593D-02,  9.9533391214048228D-01), &
(  9.4963495329639061D-02,  9.9548075549192694D-01), (  9.3436335845747912D-02,  9.9562525638099431D-01), &
(  9.1908956497132696D-02,  9.9576741446765982D-01), (  9.0381360877865011D-02,  9.9590722941741172D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  8.7325535206192212D-02,  9.9617982859569687D-01), &
(  8.5797312344439880D-02,  9.9631261218277800D-01), (  8.4268887593324113D-02,  9.9644305135004263D-01), &
(  8.2740264549375803D-02,  9.9657114579055484D-01), (  8.1211446809592386D-02,  9.9669689520289606D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  7.8153241632794301D-02,  9.9694135776498216D-01), &
(  7.6623861392031617D-02,  9.9706007033948296D-01), (  7.5094300847921278D-02,  9.9717643673532619D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  7.2034653246889416D-02,  9.9740212990127530D-01), &
(  7.0504573389614009D-02,  9.9751145614030345D-01), (  6.8974327628266732D-02,  9.9761843513851955D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  6.5913352797003916D-02,  9.9782535041111164D-01), &
(  6.4382630929857410D-02,  9.9792528619859600D-01), (  6.2851757564161420D-02,  9.9802287377148624D-01), &
(  6.1320736302208655D-02,  9.9811811290014918D-01), (  5.9789570746640007D-02,  9.9821100336047819D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), (  5.6726821166907783D-02,  9.9838973740734016D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), (  5.3663537652730679D-02,  9.9855907422975931D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  5.0599749036899337D-02,  9.9871901223387294D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  4.7535484156959261D-02,  9.9886954991428356D-01), &
(  4.6003182130914644D-02,  9.9894129318685687D-01), (  4.4470771854938744D-02,  9.9901068585407338D-01), &
(  4.2938256934940959D-02,  9.9907772775264536D-01), (  4.1405640977076719D-02,  9.9914241872481691D-01), &
(  3.9872927587739845D-02,  9.9920475861836389D-01), (  3.8340120373552791D-02,  9.9926474728659442D-01), &
(  3.6807222941358991D-02,  9.9932238458834954D-01), (  3.5274238898213947D-02,  9.9937767038800285D-01), &
(  3.3741171851377642D-02,  9.9943060455546173D-01), (  3.2208025408304704D-02,  9.9948118696616695D-01), &
(  3.0674803176636584D-02,  9.9952941750109314D-01), (  2.9141508764193743D-02,  9.9957529604674922D-01), &
(  2.7608145778965820D-02,  9.9961882249517864D-01), (  2.6074717829104040D-02,  9.9965999674395922D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  2.3007681468839410D-02,  9.9973528826056168D-01), &
(  2.1474080275469608D-02,  9.9976940535121528D-01), (  1.9940428551514601D-02,  9.9980116988788426D-01), &
(  1.8406729905804820D-02,  9.9983058179582340D-01), (  1.6872987947281773D-02,  9.9985764100582386D-01), &
(  1.5339206284988220D-02,  9.9988234745421256D-01), (  1.3805388528060349D-02,  9.9990470108285290D-01), &
(  1.2271538285719944D-02,  9.9992470183914450D-01), (  1.0737659167264570D-02,  9.9994234967602391D-01), &
(  9.2037547820599599D-03,  9.9995764455196390D-01), (  7.6698287395310771D-03,  9.9997058643097414D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), (  4.6019261204486720D-03,  9.9998941108192840D-01), &
(  3.0679567629661379D-03,  9.9999529380957619D-01), (  1.5339801862847659D-03,  9.9999882345170188D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -1.5339801862846436D-03,  9.9999882345170188D-01), &
( -3.0679567629660156D-03,  9.9999529380957619D-01), ( -4.6019261204485488D-03,  9.9998941108192840D-01), &
( -6.1358846491543929D-03,  9.9998117528260111D-01), ( -7.6698287395309539D-03,  9.9997058643097414D-01), &
( -9.2037547820598385D-03,  9.9995764455196390D-01), ( -1.0737659167264449D-02,  9.9994234967602391D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -1.3805388528060228D-02,  9.9990470108285290D-01), &
( -1.5339206284988098D-02,  9.9988234745421256D-01), ( -1.6872987947281648D-02,  9.9985764100582386D-01), &
( -1.8406729905804695D-02,  9.9983058179582340D-01), ( -1.9940428551514476D-02,  9.9980116988788426D-01), &
( -2.1474080275469484D-02,  9.9976940535121528D-01), ( -2.3007681468839285D-02,  9.9973528826056168D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -2.6074717829103915D-02,  9.9965999674395922D-01), &
( -2.7608145778965695D-02,  9.9961882249517864D-01), ( -2.9141508764193618D-02,  9.9957529604674922D-01), &
( -3.0674803176636459D-02,  9.9952941750109314D-01), ( -3.2208025408304579D-02,  9.9948118696616695D-01), &
( -3.3741171851377517D-02,  9.9943060455546173D-01), ( -3.5274238898213822D-02,  9.9937767038800285D-01), &
( -3.6807222941358866D-02,  9.9932238458834954D-01), ( -3.8340120373552666D-02,  9.9926474728659442D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -4.1405640977076594D-02,  9.9914241872481691D-01)/
data (mpuu1(i), i =  3101,  3200) / &
( -4.2938256934940834D-02,  9.9907772775264536D-01), ( -4.4470771854938619D-02,  9.9901068585407338D-01), &
( -4.6003182130914519D-02,  9.9894129318685687D-01), ( -4.7535484156959136D-02,  9.9886954991428356D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -5.0599749036899212D-02,  9.9871901223387294D-01), &
( -5.2131704680283192D-02,  9.9864021818026527D-01), ( -5.3663537652730554D-02,  9.9855907422975931D-01), &
( -5.5195244349689913D-02,  9.9847558057329477D-01), ( -5.6726821166907658D-02,  9.9838973740734016D-01), &
( -5.8258264500435607D-02,  9.9830154493389289D-01), ( -5.9789570746639882D-02,  9.9821100336047819D-01), &
( -6.1320736302208530D-02,  9.9811811290014918D-01), ( -6.2851757564161309D-02,  9.9802287377148624D-01), &
( -6.4382630929857299D-02,  9.9792528619859600D-01), ( -6.5913352797003805D-02,  9.9782535041111164D-01), &
( -6.7443919563663995D-02,  9.9772306664419164D-01), ( -6.8974327628266621D-02,  9.9761843513851955D-01), &
( -7.0504573389613898D-02,  9.9751145614030345D-01), ( -7.2034653246889305D-02,  9.9740212990127530D-01), &
( -7.3564563599667343D-02,  9.9729045667869021D-01), ( -7.5094300847921167D-02,  9.9717643673532619D-01), &
( -7.6623861392031506D-02,  9.9706007033948296D-01), ( -7.8153241632794190D-02,  9.9694135776498216D-01), &
( -7.9682437971430015D-02,  9.9682029929116567D-01), ( -8.1211446809592275D-02,  9.9669689520289606D-01), &
( -8.2740264549375692D-02,  9.9657114579055484D-01), ( -8.4268887593324002D-02,  9.9644305135004263D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -8.7325535206192101D-02,  9.9617982859569687D-01), &
( -8.8853552582524573D-02,  9.9604470090125197D-01), ( -9.0381360877864900D-02,  9.9590722941741172D-01), &
( -9.1908956497132585D-02,  9.9576741446765982D-01), ( -9.3436335845747800D-02,  9.9562525638099431D-01), &
( -9.4963495329638950D-02,  9.9548075549192694D-01), ( -9.6490431355252482D-02,  9.9533391214048228D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -9.9543618660069319D-02,  9.9503319943811863D-01), &
( -1.0106986275482775D-01,  9.9487933079480562D-01), ( -1.0259586902243616D-01,  9.9472312110432570D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.0564715371341059D-01,  9.9440368005767910D-01), &
( -1.0717242495680876D-01,  9.9424044945318790D-01), ( -1.0869744401313856D-01,  9.9407487930487948D-01), &
( -1.1022220729388307D-01,  9.9390697000235606D-01), ( -1.1174671121112655D-01,  9.9373672194072460D-01), &
( -1.1327095217756424D-01,  9.9356413552059530D-01), ( -1.1479492660651014D-01,  9.9338921114808065D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.1784206150832491D-01,  9.9303235019785141D-01), &
( -1.1936521481099123D-01,  9.9285041445986510D-01), ( -1.2088808723577711D-01,  9.9266614244894802D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.2393297511851208D-01,  9.9229059134825737D-01), &
( -1.2545498341154609D-01,  9.9209931314219180D-01), ( -1.2697669649688587D-01,  9.9190570043060933D-01), &
( -1.2849811079379311D-01,  9.9170975366909953D-01), ( -1.3001922272223324D-01,  9.9151147331874401D-01), &
( -1.3154002870288317D-01,  9.9131085984611544D-01), ( -1.3306052515713906D-01,  9.9110791372327689D-01), &
( -1.3458070850712611D-01,  9.9090263542778001D-01), ( -1.3610057517570606D-01,  9.9069502544266463D-01), &
( -1.3762012158648607D-01,  9.9048508425645698D-01), ( -1.3913934416382617D-01,  9.9027281236316911D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -1.4217680351944789D-01,  9.8984127845882053D-01), &
( -1.4369503315029447D-01,  9.8962201746320089D-01), ( -1.4521292465284741D-01,  9.8940042779138038D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.4824767898689609D-01,  9.8895026451030299D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -1.5128103795733014D-01,  9.8849079285269670D-01), &
( -1.5279718525844330D-01,  9.8825756773074946D-01), ( -1.5431297301302013D-01,  9.8802201714328353D-01), &
( -1.5582839765426520D-01,  9.8778414164457218D-01), ( -1.5734345561623816D-01,  9.8754394179435934D-01), &
( -1.5885814333386128D-01,  9.8730141815785843D-01), ( -1.6037245724292828D-01,  9.8705657130575097D-01), &
( -1.6188639378011177D-01,  9.8680940181418553D-01), ( -1.6339994938297311D-01,  9.8655991026477552D-01), &
( -1.6491312048996995D-01,  9.8630809724459867D-01), ( -1.6642590354046410D-01,  9.8605396334619544D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -1.6945029123396782D-01,  9.8553873531217606D-01), &
( -1.7096188876030124D-01,  9.8527764238894122D-01), ( -1.7247308399679592D-01,  9.8501423101223984D-01), &
( -1.7398387338746374D-01,  9.8474850180190421D-01), ( -1.7549425337727126D-01,  9.8448045538322093D-01), &
( -1.7700422041214875D-01,  9.8421009238692903D-01), ( -1.7851377093899745D-01,  9.8393741344921892D-01), &
( -1.8002290140569940D-01,  9.8366241921173025D-01), ( -1.8153160826112502D-01,  9.8338511032155118D-01), &
( -1.8303988795514095D-01,  9.8310548743121629D-01), ( -1.8454773693861953D-01,  9.8282355119870535D-01), &
( -1.8605515166344652D-01,  9.8253930228744124D-01), ( -1.8756212858252963D-01,  9.8225274136628937D-01), &
( -1.8906866414980616D-01,  9.8196386910955524D-01), ( -1.9057475482025266D-01,  9.8167268619698311D-01), &
( -1.9208039704989227D-01,  9.8137919331375456D-01), ( -1.9358558729580361D-01,  9.8108339115048671D-01)/
data (mpuu1(i), i =  3201,  3300) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -1.9659459767008011D-01,  9.8048486177346938D-01), &
( -1.9809841071795362D-01,  9.8018213596811743D-01), ( -1.9960175762113094D-01,  9.7987710369951764D-01), &
( -2.0110463484209182D-01,  9.7956976568544052D-01), ( -2.0260703884442099D-01,  9.7926012264908213D-01), &
( -2.0410896609281690D-01,  9.7894817531906220D-01), ( -2.0561041305309921D-01,  9.7863392442942321D-01), &
( -2.0711137619221845D-01,  9.7831737071962765D-01), ( -2.0861185197826332D-01,  9.7799851493455714D-01), &
( -2.1011183688046961D-01,  9.7767735782450993D-01), ( -2.1161132736922750D-01,  9.7735390014520007D-01), &
( -2.1311031991609125D-01,  9.7702814265775439D-01), ( -2.1460881099378681D-01,  9.7670008612871184D-01), &
( -2.1610679707621949D-01,  9.7636973133002114D-01), ( -2.1760427463848356D-01,  9.7603707903903913D-01), &
( -2.1910124015686966D-01,  9.7570213003852857D-01), ( -2.2059769010887353D-01,  9.7536488511665698D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.2358902922978990D-01,  9.7468351068851067D-01), &
( -2.2508391135979267D-01,  9.7433938278557586D-01), ( -2.2657826384561000D-01,  9.7399296216795583D-01), &
( -2.2807208317088568D-01,  9.7364424965081198D-01), ( -2.2956536582051876D-01,  9.7329324605469825D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -2.3255030703877522D-01,  9.7258436893473221D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -2.3553305940497535D-01,  9.7186633748027940D-01), &
( -2.3702360599436723D-01,  9.7150389098625178D-01), ( -2.3851359484431839D-01,  9.7113915844972509D-01), &
( -2.4000302244874139D-01,  9.7077214072895035D-01), ( -2.4149188530286919D-01,  9.7040283868755550D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.4446790274782410D-01,  9.6965738512429245D-01), &
( -2.4595505033579448D-01,  9.6928123535654853D-01), ( -2.4744161916777332D-01,  9.6890280477642887D-01), &
( -2.4892760574572015D-01,  9.6852209427441727D-01), ( -2.5041300657296517D-01,  9.6813910474636244D-01), &
( -2.5189781815421680D-01,  9.6775383709347551D-01), ( -2.5338203699557016D-01,  9.6736629222232851D-01), &
( -2.5486565960451452D-01,  9.6697647104485207D-01), ( -2.5634868248994280D-01,  9.6658437447833312D-01), &
( -2.5783110216215882D-01,  9.6619000344541262D-01), ( -2.5931291513288623D-01,  9.6579335887408368D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -2.6227470702391348D-01,  9.6499325285492044D-01), &
( -2.6375467897483140D-01,  9.6458979328981276D-01), ( -2.6523403028551179D-01,  9.6418406395174583D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -2.6819085706340307D-01,  9.6336579978095405D-01), &
( -2.6966832557291509D-01,  9.6295326687368388D-01), ( -2.7114515952680796D-01,  9.6253846804435916D-01), &
( -2.7262135544994887D-01,  9.6212140426904158D-01), ( -2.7409690986870622D-01,  9.6170207652912254D-01), &
( -2.7557181931095814D-01,  9.6128048581132064D-01), ( -2.7704608030609984D-01,  9.6085663310767966D-01), &
( -2.7851968938505295D-01,  9.6043051941556590D-01), ( -2.7999264308027327D-01,  9.6000214573766585D-01), &
( -2.8146493792575794D-01,  9.5957151308198452D-01), ( -2.8293657045705528D-01,  9.5913862246184201D-01), &
( -2.8440753721127171D-01,  9.5870347489587160D-01), ( -2.8587783472708062D-01,  9.5826607140801767D-01), &
( -2.8734745954472946D-01,  9.5782641302753291D-01), ( -2.8881640820604937D-01,  9.5738450078897597D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -2.9175226323498926D-01,  9.5649391890239510D-01), &
( -2.9321916269425857D-01,  9.5604525134999652D-01), ( -2.9468537218051422D-01,  9.5559433413077111D-01), &
( -2.9615088824362384D-01,  9.5514116830577067D-01), ( -2.9761570743508620D-01,  9.5468575494133834D-01), &
( -2.9907982630804036D-01,  9.5422809510910567D-01), ( -3.0054324141727329D-01,  9.5376818988599033D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -3.0346794657201126D-01,  9.5284164760119872D-01), &
( -3.0492922973540232D-01,  9.5237501271976588D-01), ( -3.0638979537086097D-01,  9.5190613680793235D-01), &
( -3.0784964004153487D-01,  9.5143502096900834D-01), ( -3.0930876031226867D-01,  9.5096166631157508D-01), &
( -3.1076715274961136D-01,  9.5048607394948181D-01), ( -3.1222481392182494D-01,  9.5000824500184300D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -3.1513792875252233D-01,  9.4904588185270056D-01), &
( -3.1659337555616573D-01,  9.4856134991573038D-01), ( -3.1804807738501495D-01,  9.4807458592227623D-01), &
( -3.1950203081601564D-01,  9.4758559101774120D-01), ( -3.2095523242787510D-01,  9.4709436635277722D-01), &
( -3.2240767880106991D-01,  9.4660091308328353D-01), ( -3.2385936651785285D-01,  9.4610523237040345D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.2676045232013168D-01,  9.4510719328526061D-01), &
( -3.2820984357909255D-01,  9.4460483726148026D-01), ( -3.2965846252858744D-01,  9.4410025849127266D-01), &
( -3.3110630575987632D-01,  9.4359345816196039D-01), ( -3.3255336986604411D-01,  9.4308443746609349D-01), &
( -3.3399965144200938D-01,  9.4257319760144687D-01), ( -3.3544514708453155D-01,  9.4205973977101742D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.3833376696554118D-01,  9.4102617505088926D-01), &
( -3.3977688440682685D-01,  9.4050607059326830D-01), ( -3.4121920232028230D-01,  9.3998375303401405D-01)/
data (mpuu1(i), i =  3301,  3400) / &
( -3.4266071731199427D-01,  9.3945922360218992D-01), ( -3.4410142598993887D-01,  9.3893248353206449D-01), &
( -3.4554132496398904D-01,  9.3840353406310817D-01), ( -3.4698041084592357D-01,  9.3787237643998989D-01), &
( -3.4841868024943440D-01,  9.3733901191257496D-01), ( -3.4985612979013492D-01,  9.3680344173592156D-01), &
( -3.5129275608556704D-01,  9.3626566717027826D-01), ( -3.5272855575521062D-01,  9.3572568948108037D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -3.5559766170478385D-01,  9.3463912981968078D-01), &
( -3.5703096123342992D-01,  9.3409255040425898D-01), ( -3.5846342063373643D-01,  9.3354377297883628D-01), &
( -3.5989503653498817D-01,  9.3299279883473885D-01), ( -3.6132580556845423D-01,  9.3243962926846247D-01), &
( -3.6275572436739711D-01,  9.3188426558166815D-01), ( -3.6418478956707973D-01,  9.3132670908118054D-01), &
( -3.6561299780477385D-01,  9.3076696107898371D-01), ( -3.6704034571976712D-01,  9.3020502289221907D-01), &
( -3.6846682995337221D-01,  9.2964089584318133D-01), ( -3.6989244714893416D-01,  9.2907458125931575D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -3.7274106700951570D-01,  9.2793539482261789D-01), &
( -3.7416406297145788D-01,  9.2736252565040111D-01), ( -3.7558617848921722D-01,  9.2678747430458175D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -3.7842775480876550D-01,  9.2563083050987283D-01), &
( -3.7984720892405099D-01,  9.2504924078267770D-01), ( -3.8126576922216238D-01,  9.2446547432526260D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -3.8410019501693493D-01,  9.2329141671952764D-01), &
( -3.8551605384391890D-01,  9.2270112833387852D-01), ( -3.8693100551438858D-01,  9.2210866874334507D-01), &
( -3.8834504669882619D-01,  9.2151403934204201D-01), ( -3.8975817406985630D-01,  9.2091724152918952D-01), &
( -3.9117038430225387D-01,  9.2031827670911059D-01), ( -3.9258167407295147D-01,  9.1971714629122736D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -3.9540147894781619D-01,  9.1850839432521225D-01), &
( -3.9680998741671031D-01,  9.1790077562139050D-01), ( -3.9821756215337356D-01,  9.1729099700837802D-01), &
( -3.9962419984564673D-01,  9.1667905992104270D-01), ( -4.0102989718357568D-01,  9.1606496579933172D-01), &
( -4.0243465085941843D-01,  9.1544871608826783D-01), ( -4.0383845756765402D-01,  9.1483031223794620D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.0664321687036903D-01,  9.1358704794525081D-01), &
( -4.0804416286497863D-01,  9.1296219042839821D-01), ( -4.0944414869225754D-01,  9.1233518462332286D-01), &
( -4.1084317105790380D-01,  9.1170603200542988D-01), ( -4.1224122666988289D-01,  9.1107473405517636D-01), &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.1503442447608152D-01,  9.0980570810465233D-01), &
( -4.1642956009763699D-01,  9.0916798309052249D-01), ( -4.1782371582021227D-01,  9.0852811871630612D-01), &
( -4.1921688836322407D-01,  9.0788611648766615D-01), ( -4.2060907444840240D-01,  9.0724197791529593D-01), &
( -4.2200027079979968D-01,  9.0659570451491533D-01), ( -4.2339047414379577D-01,  9.0594729780726857D-01), &
( -4.2477968120910875D-01,  9.0529675931811882D-01), ( -4.2616788872679967D-01,  9.0464409057824624D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.2894129205532944D-01,  9.0333236849451182D-01), &
( -4.3032648134008272D-01,  9.0267331823725883D-01), ( -4.3171065802505709D-01,  9.0201214390249329D-01), &
( -4.3309381885315196D-01,  9.0134884704602203D-01), ( -4.3447596056965582D-01,  9.0068342922864686D-01), &
( -4.3585707992225536D-01,  9.0001589201616028D-01), ( -4.3723717366104409D-01,  8.9934623697934157D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -4.3999427130963314D-01,  8.9800057974073988D-01), &
( -4.4137126873171673D-01,  8.9732458070541821D-01), ( -4.4274722756456980D-01,  8.9664647017868027D-01), &
( -4.4412214457042914D-01,  8.9596624975618522D-01), ( -4.4549601651398185D-01,  8.9528392103855747D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.4824061228521989D-01,  8.9391294514520325D-01), &
( -4.4961132965460671D-01,  8.9322430119551521D-01), ( -4.5098098904510375D-01,  8.9253355540276469D-01), &
( -4.5234958723377089D-01,  8.9184070939234272D-01), ( -4.5371712100016365D-01,  8.9114576479458341D-01), &
( -4.5508358712634372D-01,  8.9044872324475799D-01), ( -4.5644898239688397D-01,  8.8974958638307278D-01), &
( -4.5781330359887701D-01,  8.8904835585466468D-01), ( -4.5917654752194403D-01,  8.8834503330959635D-01), &
( -4.6053871095824012D-01,  8.8763962040285393D-01), ( -4.6189979070246256D-01,  8.8693211879434231D-01), &
( -4.6325978355186015D-01,  8.8622253014888064D-01), ( -4.6461868630623793D-01,  8.8551085613619984D-01), &
( -4.6597649576796601D-01,  8.8479709843093790D-01), ( -4.6733320874198847D-01,  8.8408125871263499D-01), &
( -4.6868882203582768D-01,  8.8336333866573169D-01), ( -4.7004333245959551D-01,  8.8264333997956279D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.7274903195034257D-01,  8.8119711347122220D-01), &
( -4.7410021465054997D-01,  8.8047088905216087D-01), ( -4.7545028174715598D-01,  8.7974259280004741D-01), &
( -4.7679923006332198D-01,  8.7901222642863353D-01), ( -4.7814705642484301D-01,  8.7827979165654158D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -4.8083933060033379D-01,  8.7680872380914576D-01)/
data (mpuu1(i), i =  3401,  3500) / &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -4.8352707893291841D-01,  8.7532940310411100D-01), &
( -4.8486924800079095D-01,  8.7458665227817622D-01), ( -4.8621027612448642D-01,  8.7384184346536686D-01), &
( -4.8755016014843572D-01,  8.7309497841829020D-01), ( -4.8888889691976306D-01,  8.7234605889439154D-01), &
( -4.9022648328829116D-01,  8.7159508665595098D-01), ( -4.9156291610654973D-01,  8.7084206347007909D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -4.9423230851595978D-01,  8.6932987134860673D-01), &
( -4.9556526182577232D-01,  8.6857070597134101D-01), ( -4.9689704902265447D-01,  8.6780949676330332D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -4.9955711254508173D-01,  8.6628095402451311D-01), &
( -5.0088538261124071D-01,  8.6551362409056909D-01), ( -5.0221247404571057D-01,  8.6474425751946249D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.0486310853126759D-01,  8.6319942171212416D-01), &
( -5.0618664534515512D-01,  8.6242395611104072D-01), ( -5.0750899105297076D-01,  8.6164646114308141D-01), &
( -5.0883014254310710D-01,  8.6086693863776720D-01), ( -5.1015009670676659D-01,  8.6008539042939025D-01), &
( -5.1146885043797030D-01,  8.5930181835700847D-01), ( -5.1278640063356273D-01,  8.5851622426444296D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.1541787801946293D-01,  8.5693897741782876D-01), &
( -5.1673179901764965D-01,  8.5614732837519458D-01), ( -5.1804450409599923D-01,  8.5535366473519603D-01), &
( -5.1935599016558964D-01,  8.5455798836540053D-01), ( -5.2066625414036694D-01,  8.5376030113811152D-01), &
( -5.2197529293715428D-01,  8.5296060493036374D-01), ( -5.2328310347565643D-01,  8.5215890162391983D-01), &
( -5.2458968267846873D-01,  8.5135519310526520D-01), ( -5.2589502747108463D-01,  8.5054948126560348D-01), &
( -5.2719913478190106D-01,  8.4974176800085266D-01), ( -5.2850200154222826D-01,  8.4893205521163972D-01), &
( -5.2980362468629461D-01,  8.4812034480329723D-01), ( -5.3110400115125467D-01,  8.4730663868585854D-01), &
( -5.3240312787719779D-01,  8.4649093877405213D-01), ( -5.3370100180715296D-01,  8.4567324698729907D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.3629297906596307D-01,  8.4403189549006652D-01), &
( -5.3758707629564551D-01,  8.4320823964184544D-01), ( -5.3887990853100820D-01,  8.4238259964318596D-01), &
( -5.4017147272989285D-01,  8.4155497743689844D-01), ( -5.4146176585312322D-01,  8.4072537497045818D-01), &
( -5.4275078486451578D-01,  8.3989379419599963D-01), ( -5.4403852673088382D-01,  8.3906023707031274D-01), &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.4661016691083475D-01,  8.3738720161566205D-01), &
( -5.4789405917310019D-01,  8.3654772722351201D-01), ( -5.4917666218771954D-01,  8.3570628435375272D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -5.5173798840470745D-01,  8.3401750110601802D-01), &
( -5.5301670558002736D-01,  8.3317016470191330D-01), ( -5.5429412145362000D-01,  8.3232086776792968D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.5684503727515988D-01,  8.3061640030884643D-01), &
( -5.5811853122055610D-01,  8.2976123379452305D-01), ( -5.5939071185913580D-01,  8.2890411477186510D-01), &
( -5.6066157619733592D-01,  8.2804504525775591D-01), ( -5.6193112124468947D-01,  8.2718402727366913D-01), &
( -5.6319934401383387D-01,  8.2632106284566365D-01), ( -5.6446624152051939D-01,  8.2545615400437755D-01), &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.6699604882510846D-01,  8.2372051122739154D-01), &
( -5.6825895267013149D-01,  8.2284978137582643D-01), ( -5.6952051934694725D-01,  8.2197711527924144D-01), &
( -5.7078074588696714D-01,  8.2110251499110476D-01), ( -5.7203962932475705D-01,  8.2022598256943469D-01), &
( -5.7329716669804198D-01,  8.1934752007679712D-01), ( -5.7455335504771565D-01,  8.1846712958029877D-01), &
( -5.7580819141784534D-01,  8.1758481315158371D-01), ( -5.7706167285567933D-01,  8.1670057286682796D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -5.7956455913940574D-01,  8.1492632905652651D-01), &
( -5.8081395809576430D-01,  8.1403632970594852D-01), ( -5.8206199034077544D-01,  8.1314441484925359D-01), &
( -5.8330865293769840D-01,  8.1225058658520388D-01), ( -5.8455394295301510D-01,  8.1135484701706395D-01), &
( -5.8579785745643886D-01,  8.1045719825259477D-01), ( -5.8704039352091775D-01,  8.0955764240405148D-01), &
( -5.8828154822264522D-01,  8.0865618158817509D-01), ( -5.8952131864106394D-01,  8.0775281792619036D-01), &
( -5.9075970185887405D-01,  8.0684755354379945D-01), ( -5.9199669496204088D-01,  8.0594039057117639D-01), &
( -5.9323229503979991D-01,  8.0503133114296355D-01), ( -5.9446649918466432D-01,  8.0412037739826592D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -5.9693070806219650D-01,  8.0229279553811561D-01), &
( -5.9816070699634216D-01,  8.0137617172314035D-01), ( -5.9938929840056454D-01,  8.0045766219262282D-01), &
( -6.0061647938386864D-01,  7.9953726910790524D-01), ( -6.0184224705857992D-01,  7.9861499463476093D-01), &
( -6.0306659854034816D-01,  7.9769084094339116D-01), ( -6.0428953094815585D-01,  7.9676481020841894D-01), &
( -6.0551104140432543D-01,  7.9583690460888357D-01), ( -6.0673112703452459D-01,  7.9490712632823701D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.0916701233645310D-01,  7.9304196047944375D-01)/
data (mpuu1(i), i =  3501,  3600) / &
( -6.1038280627630948D-01,  7.9210657730021228D-01), ( -6.1159716392646180D-01,  7.9116933021769031D-01), &
( -6.1281008242940971D-01,  7.9023022143731003D-01), ( -6.1402155893103816D-01,  7.8928925316888587D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -6.1644017453085365D-01,  7.8740174702903132D-01), &
( -6.1764730793780376D-01,  7.8645521359908588D-01), ( -6.1885298796097621D-01,  7.8550682956405404D-01), &
( -6.2005721176328921D-01,  7.8455659715557524D-01), ( -6.2125997651108744D-01,  7.8360451860963831D-01), &
( -6.2246127937414997D-01,  7.8265059616657573D-01), ( -6.2366111752569464D-01,  7.8169483207105939D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.2605638840434352D-01,  7.7977778792301455D-01), &
( -6.2725181549514386D-01,  7.7881651238147620D-01), ( -6.2844576660183260D-01,  7.7785340420945315D-01), &
( -6.2963823891492698D-01,  7.7688846567323244D-01), ( -6.3082922962842436D-01,  7.7592169904340780D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.3320675505005730D-01,  7.7398269060682279D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.3557832048855611D-01,  7.7203639715038452D-01), &
( -6.3676186123628431D-01,  7.7106052426181371D-01), ( -6.3794390362184394D-01,  7.7008283699334812D-01), &
( -6.3912444486377573D-01,  7.6910333764557970D-01), ( -6.4030348218415145D-01,  7.6812202852336564D-01), &
( -6.4148101280858305D-01,  7.6713891193582051D-01), ( -6.4265703396622686D-01,  7.6615399019631292D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.4500453681554393D-01,  7.6417874053611679D-01), &
( -6.4617601298331639D-01,  7.6318841726338127D-01), ( -6.4734596863651195D-01,  7.6219629813457912D-01), &
( -6.4851440102211244D-01,  7.6120238548426189D-01), ( -6.4968130739068330D-01,  7.6020668165120231D-01), &
( -6.5084668499638076D-01,  7.5920918897838818D-01), ( -6.5201053109695950D-01,  7.5820990981301528D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -6.5433361783180044D-01,  7.5620600141439454D-01), &
( -6.5549285299961535D-01,  7.5520137689653655D-01), ( -6.5665054572942883D-01,  7.5419497531688928D-01), &
( -6.5780669329707853D-01,  7.5318679904361252D-01), ( -6.5896129298203732D-01,  7.5217685044904270D-01), &
( -6.6011434206742026D-01,  7.5116513190968659D-01), ( -6.6126583783999215D-01,  7.5015164580621507D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -6.6356415861203966D-01,  7.4811938045040371D-01), &
( -6.6471097820334479D-01,  7.4710060598018013D-01), ( -6.6585623366550939D-01,  7.4608007351006400D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -6.6814204142651845D-01,  7.4403374417992929D-01), &
( -6.6928258834663579D-01,  7.4300795213512183D-01), ( -6.7042156038017298D-01,  7.4198041172083107D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.7269476907077275D-01,  7.3992009545951631D-01), &
( -6.7382900037875604D-01,  7.3888732446061522D-01), ( -6.7496164610201204D-01,  7.3785281478846598D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -6.7722217013718033D-01,  7.3577858916571359D-01), &
( -6.7835004312986125D-01,  7.3473887809596372D-01), ( -6.7947631989936497D-01,  7.3369743811466037D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -6.8172407417164960D-01,  7.3160938122389274D-01), &
( -6.8284554638524797D-01,  7.3056276922782759D-01), ( -6.8396541179731551D-01,  7.2951443814699701D-01), &
( -6.8508366777270024D-01,  7.2846439044822531D-01), ( -6.8620031168003859D-01,  7.2741262860237588D-01), &
( -6.8731534089175916D-01,  7.2635915508434590D-01), ( -6.8842875278409033D-01,  7.2530397237306088D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -6.9065071413453438D-01,  7.2318848930652768D-01), &
( -6.9175925836415764D-01,  7.2212819392921546D-01), ( -6.9286617481742463D-01,  7.2106619931450811D-01), &
( -6.9397146088965378D-01,  7.2000250796138188D-01), ( -6.9507511398000077D-01,  7.1893712237280449D-01), &
( -6.9617713149146299D-01,  7.1787004505573171D-01), ( -6.9727751083088640D-01,  7.1680127852109965D-01), &
( -6.9837624940897280D-01,  7.1573082528381871D-01), ( -6.9947334464028388D-01,  7.1465868786276898D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.0166259474016845D-01,  7.1250937056469232D-01), &
( -7.0275474445722508D-01,  7.1143219574521677D-01), ( -7.0384524052448483D-01,  7.1035334685706242D-01), &
( -7.0493408037590488D-01,  7.0927282643886569D-01), ( -7.0602126144933952D-01,  7.0819063703319551D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.0819063703319540D-01,  7.0602126144933974D-01), &
( -7.0927282643886547D-01,  7.0493408037590510D-01), ( -7.1035334685706231D-01,  7.0384524052448505D-01), &
( -7.1143219574521654D-01,  7.0275474445722519D-01), ( -7.1250937056469232D-01,  7.0166259474016868D-01), &
( -7.1358486878079352D-01,  7.0056879394324834D-01), ( -7.1465868786276887D-01,  6.9947334464028399D-01), &
( -7.1573082528381859D-01,  6.9837624940897292D-01), ( -7.1680127852109954D-01,  6.9727751083088652D-01), &
( -7.1787004505573160D-01,  6.9617713149146310D-01), ( -7.1893712237280438D-01,  6.9507511398000088D-01), &
( -7.2000250796138165D-01,  6.9397146088965389D-01), ( -7.2106619931450799D-01,  6.9286617481742485D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.2318848930652746D-01,  6.9065071413453460D-01)/
data (mpuu1(i), i =  3601,  3700) / &
( -7.2424708295146689D-01,  6.8954054473706705D-01), ( -7.2530397237306077D-01,  6.8842875278409044D-01), &
( -7.2635915508434579D-01,  6.8731534089175927D-01), ( -7.2741262860237565D-01,  6.8620031168003870D-01), &
( -7.2846439044822520D-01,  6.8508366777270036D-01), ( -7.2951443814699690D-01,  6.8396541179731563D-01), &
( -7.3056276922782759D-01,  6.8284554638524808D-01), ( -7.3160938122389263D-01,  6.8172407417164971D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.3369743811466026D-01,  6.7947631989936508D-01), &
( -7.3473887809596361D-01,  6.7835004312986147D-01), ( -7.3577858916571337D-01,  6.7722217013718056D-01), &
( -7.3681656887736979D-01,  6.7609270357531592D-01), ( -7.3785281478846576D-01,  6.7496164610201226D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.3992009545951620D-01,  6.7269476907077286D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.4198041172083096D-01,  6.7042156038017320D-01), &
( -7.4300795213512172D-01,  6.6928258834663601D-01), ( -7.4403374417992918D-01,  6.6814204142651867D-01), &
( -7.4505778544146595D-01,  6.6699992230363758D-01), ( -7.4608007351006389D-01,  6.6585623366550961D-01), &
( -7.4710060598018002D-01,  6.6471097820334502D-01), ( -7.4811938045040360D-01,  6.6356415861203977D-01), &
( -7.4913639452345904D-01,  6.6241577759017201D-01), ( -7.5015164580621496D-01,  6.6126583783999227D-01), &
( -7.5116513190968637D-01,  6.6011434206742048D-01), ( -7.5217685044904259D-01,  6.5896129298203754D-01), &
( -7.5318679904361241D-01,  6.5780669329707875D-01), ( -7.5419497531688917D-01,  6.5665054572942905D-01), &
( -7.5520137689653644D-01,  6.5549285299961557D-01), ( -7.5620600141439454D-01,  6.5433361783180055D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -7.5820990981301517D-01,  6.5201053109695972D-01), &
( -7.5920918897838796D-01,  6.5084668499638099D-01), ( -7.6020668165120220D-01,  6.4968130739068342D-01), &
( -7.6120238548426178D-01,  6.4851440102211255D-01), ( -7.6219629813457890D-01,  6.4734596863651206D-01), &
( -7.6318841726338116D-01,  6.4617601298331651D-01), ( -7.6417874053611667D-01,  6.4500453681554404D-01), &
( -7.6516726562245896D-01,  6.4383154288979139D-01), ( -7.6615399019631281D-01,  6.4265703396622709D-01), &
( -7.6713891193582029D-01,  6.4148101280858316D-01), ( -7.6812202852336542D-01,  6.4030348218415156D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -7.7008283699334790D-01,  6.3794390362184406D-01), &
( -7.7106052426181360D-01,  6.3676186123628442D-01), ( -7.7203639715038441D-01,  6.3557832048855623D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.7398269060682257D-01,  6.3320675505005741D-01), &
( -7.7495310659487382D-01,  6.3201873593980906D-01), ( -7.7592169904340769D-01,  6.3082922962842447D-01), &
( -7.7688846567323233D-01,  6.2963823891492721D-01), ( -7.7785340420945304D-01,  6.2844576660183271D-01), &
( -7.7881651238147609D-01,  6.2725181549514408D-01), ( -7.7977778792301433D-01,  6.2605638840434363D-01), &
( -7.8073722857209449D-01,  6.2485948814238634D-01), ( -7.8169483207105928D-01,  6.2366111752569486D-01), &
( -7.8265059616657562D-01,  6.2246127937415008D-01), ( -7.8360451860963831D-01,  6.2125997651108755D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), ( -7.8550682956405393D-01,  6.1885298796097643D-01), &
( -7.8645521359908577D-01,  6.1764730793780387D-01), ( -7.8740174702903132D-01,  6.1644017453085376D-01), &
( -7.8834642762660623D-01,  6.1523159058062693D-01), ( -7.8928925316888576D-01,  6.1402155893103838D-01), &
( -7.9023022143730992D-01,  6.1281008242940982D-01), ( -7.9116933021769009D-01,  6.1159716392646191D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -7.9304196047944364D-01,  6.0916701233645332D-01), &
( -7.9397547755433717D-01,  6.0794978496777363D-01), ( -7.9490712632823679D-01,  6.0673112703452470D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -7.9676481020841883D-01,  6.0428953094815596D-01), &
( -7.9769084094339093D-01,  6.0306659854034839D-01), ( -7.9861499463476082D-01,  6.0184224705858014D-01), &
( -7.9953726910790501D-01,  6.0061647938386886D-01), ( -8.0045766219262271D-01,  5.9938929840056465D-01), &
( -8.0137617172314024D-01,  5.9816070699634238D-01), ( -8.0229279553811561D-01,  5.9693070806219672D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.0412037739826570D-01,  5.9446649918466443D-01), &
( -8.0503133114296344D-01,  5.9323229503980002D-01), ( -8.0594039057117628D-01,  5.9199669496204099D-01), &
( -8.0684755354379933D-01,  5.9075970185887416D-01), ( -8.0775281792619025D-01,  5.8952131864106405D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), ( -8.0955764240405137D-01,  5.8704039352091786D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.1135484701706373D-01,  5.8455394295301533D-01), &
( -8.1225058658520366D-01,  5.8330865293769851D-01), ( -8.1314441484925348D-01,  5.8206199034077566D-01), &
( -8.1403632970594841D-01,  5.8081395809576453D-01), ( -8.1492632905652640D-01,  5.7956455913940597D-01), &
( -8.1581441080673378D-01,  5.7831379641165570D-01), ( -8.1670057286682785D-01,  5.7706167285567944D-01), &
( -8.1758481315158360D-01,  5.7580819141784545D-01), ( -8.1846712958029866D-01,  5.7455335504771587D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.2022598256943458D-01,  5.7203962932475727D-01)/
data (mpuu1(i), i =  3701,  3800) / &
( -8.2110251499110465D-01,  5.7078074588696726D-01), ( -8.2197711527924144D-01,  5.6952051934694747D-01), &
( -8.2284978137582621D-01,  5.6825895267013171D-01), ( -8.2372051122739143D-01,  5.6699604882510868D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.2545615400437744D-01,  5.6446624152051950D-01), &
( -8.2632106284566353D-01,  5.6319934401383409D-01), ( -8.2718402727366902D-01,  5.6193112124468958D-01), &
( -8.2804504525775569D-01,  5.6066157619733603D-01), ( -8.2890411477186499D-01,  5.5939071185913603D-01), &
( -8.2976123379452293D-01,  5.5811853122055632D-01), ( -8.3061640030884631D-01,  5.5684503727516010D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.3232086776792957D-01,  5.5429412145362023D-01), &
( -8.3317016470191319D-01,  5.5301670558002747D-01), ( -8.3401750110601802D-01,  5.5173798840470767D-01), &
( -8.3486287498638001D-01,  5.5045797293660492D-01), ( -8.3570628435375260D-01,  5.4917666218771966D-01), &
( -8.3654772722351189D-01,  5.4789405917310030D-01), ( -8.3738720161566182D-01,  5.4661016691083497D-01), &
( -8.3822470555483808D-01,  5.4532498842204635D-01), ( -8.3906023707031263D-01,  5.4403852673088404D-01), &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.4072537497045818D-01,  5.4146176585312333D-01), &
( -8.4155497743689833D-01,  5.4017147272989297D-01), ( -8.4238259964318585D-01,  5.3887990853100842D-01), &
( -8.4320823964184533D-01,  5.3758707629564573D-01), ( -8.4403189549006641D-01,  5.3629297906596318D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.4567324698729895D-01,  5.3370100180715319D-01), &
( -8.4649093877405202D-01,  5.3240312787719801D-01), ( -8.4730663868585843D-01,  5.3110400115125489D-01), &
( -8.4812034480329712D-01,  5.2980362468629483D-01), ( -8.4893205521163961D-01,  5.2850200154222848D-01), &
( -8.4974176800085255D-01,  5.2719913478190128D-01), ( -8.5054948126560337D-01,  5.2589502747108485D-01), &
( -8.5135519310526520D-01,  5.2458968267846895D-01), ( -8.5215890162391972D-01,  5.2328310347565665D-01), &
( -8.5296060493036363D-01,  5.2197529293715439D-01), ( -8.5376030113811141D-01,  5.2066625414036716D-01), &
( -8.5455798836540042D-01,  5.1935599016558975D-01), ( -8.5535366473519603D-01,  5.1804450409599945D-01), &
( -8.5614732837519458D-01,  5.1673179901764976D-01), ( -8.5693897741782865D-01,  5.1541787801946315D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.5851622426444285D-01,  5.1278640063356296D-01), &
( -8.5930181835700825D-01,  5.1146885043797052D-01), ( -8.6008539042939014D-01,  5.1015009670676681D-01), &
( -8.6086693863776720D-01,  5.0883014254310732D-01), ( -8.6164646114308130D-01,  5.0750899105297098D-01), &
( -8.6242395611104050D-01,  5.0618664534515523D-01), ( -8.6319942171212405D-01,  5.0486310853126770D-01), &
( -8.6397285612158670D-01,  5.0353838372571758D-01), ( -8.6474425751946238D-01,  5.0221247404571068D-01), &
( -8.6551362409056898D-01,  5.0088538261124094D-01), ( -8.6628095402451299D-01,  4.9955711254508189D-01), &
( -8.6704624551569265D-01,  4.9822766697278176D-01), ( -8.6780949676330321D-01,  4.9689704902265469D-01), &
( -8.6857070597134090D-01,  4.9556526182577254D-01), ( -8.6932987134860662D-01,  4.9423230851595995D-01), &
( -8.7008699110871135D-01,  4.9289819222978415D-01), ( -8.7084206347007886D-01,  4.9156291610654990D-01), &
( -8.7159508665595098D-01,  4.9022648328829138D-01), ( -8.7234605889439143D-01,  4.8888889691976323D-01), &
( -8.7309497841829020D-01,  4.8755016014843588D-01), ( -8.7384184346536675D-01,  4.8621027612448658D-01), &
( -8.7458665227817611D-01,  4.8486924800079112D-01), ( -8.7532940310411089D-01,  4.8352707893291863D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -8.7680872380914565D-01,  4.8083933060033396D-01), &
( -8.7754529020726113D-01,  4.7949375766015329D-01), ( -8.7827979165654146D-01,  4.7814705642484318D-01), &
( -8.7901222642863353D-01,  4.7679923006332209D-01), ( -8.7974259280004730D-01,  4.7545028174715609D-01), &
( -8.8047088905216075D-01,  4.7410021465055008D-01), ( -8.8119711347122209D-01,  4.7274903195034274D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.8264333997956279D-01,  4.7004333245959568D-01), &
( -8.8336333866573169D-01,  4.6868882203582785D-01), ( -8.8408125871263488D-01,  4.6733320874198858D-01), &
( -8.8479709843093779D-01,  4.6597649576796618D-01), ( -8.8551085613619984D-01,  4.6461868630623809D-01), &
( -8.8622253014888053D-01,  4.6325978355186032D-01), ( -8.8693211879434219D-01,  4.6189979070246273D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -8.8834503330959624D-01,  4.5917654752194420D-01), &
( -8.8904835585466457D-01,  4.5781330359887717D-01), ( -8.8974958638307267D-01,  4.5644898239688414D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -8.9114576479458329D-01,  4.5371712100016376D-01), &
( -8.9184070939234261D-01,  4.5234958723377100D-01), ( -8.9253355540276458D-01,  4.5098098904510386D-01), &
( -8.9322430119551521D-01,  4.4961132965460687D-01), ( -8.9391294514520325D-01,  4.4824061228522005D-01), &
( -8.9459948563138270D-01,  4.4686884016237416D-01), ( -8.9528392103855747D-01,  4.4549601651398196D-01), &
( -8.9596624975618511D-01,  4.4412214457042931D-01), ( -8.9664647017868027D-01,  4.4274722756456997D-01), &
( -8.9732458070541821D-01,  4.4137126873171689D-01), ( -8.9800057974073977D-01,  4.3999427130963331D-01)/
data (mpuu1(i), i =  3801,  3900) / &
( -8.9867446569395393D-01,  4.3861623853852755D-01), ( -8.9934623697934146D-01,  4.3723717366104425D-01), &
( -9.0001589201616028D-01,  4.3585707992225547D-01), ( -9.0068342922864675D-01,  4.3447596056965598D-01), &
( -9.0134884704602192D-01,  4.3309381885315207D-01), ( -9.0201214390249318D-01,  4.3171065802505726D-01), &
( -9.0267331823725871D-01,  4.3032648134008289D-01), ( -9.0333236849451182D-01,  4.2894129205532960D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.0464409057824613D-01,  4.2616788872679984D-01), &
( -9.0529675931811870D-01,  4.2477968120910886D-01), ( -9.0594729780726846D-01,  4.2339047414379594D-01), &
( -9.0659570451491533D-01,  4.2200027079979985D-01), ( -9.0724197791529582D-01,  4.2060907444840251D-01), &
( -9.0788611648766604D-01,  4.1921688836322424D-01), ( -9.0852811871630612D-01,  4.1782371582021244D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.0980570810465211D-01,  4.1503442447608185D-01), &
( -9.1044129225806714D-01,  4.1363831223843461D-01), ( -9.1107473405517636D-01,  4.1224122666988283D-01), &
( -9.1170603200542977D-01,  4.1084317105790413D-01), ( -9.1233518462332275D-01,  4.0944414869225765D-01), &
( -9.1296219042839821D-01,  4.0804416286497858D-01), ( -9.1358704794525081D-01,  4.0664321687036920D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.1483031223794598D-01,  4.0383845756765441D-01), &
( -9.1544871608826772D-01,  4.0243465085941854D-01), ( -9.1606496579933172D-01,  4.0102989718357562D-01), &
( -9.1667905992104259D-01,  3.9962419984564707D-01), ( -9.1729099700837791D-01,  3.9821756215337367D-01), &
( -9.1790077562139050D-01,  3.9680998741671025D-01), ( -9.1850839432521214D-01,  3.9540147894781652D-01), &
( -9.1911385169005777D-01,  3.9399204006104815D-01), ( -9.1971714629122736D-01,  3.9258167407295141D-01), &
( -9.2031827670911048D-01,  3.9117038430225404D-01), ( -9.2091724152918941D-01,  3.8975817406985647D-01), &
( -9.2151403934204179D-01,  3.8834504669882658D-01), ( -9.2210866874334507D-01,  3.8693100551438869D-01), &
( -9.2270112833387863D-01,  3.8551605384391885D-01), ( -9.2329141671952752D-01,  3.8410019501693532D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.2446547432526271D-01,  3.8126576922216232D-01), &
( -9.2504924078267747D-01,  3.7984720892405138D-01), ( -9.2563083050987272D-01,  3.7842775480876562D-01), &
( -9.2621024213831138D-01,  3.7700741021641815D-01), ( -9.2678747430458175D-01,  3.7558617848921738D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.2793539482261778D-01,  3.7274106700951604D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.2907458125931575D-01,  3.6989244714893410D-01), &
( -9.2964089584318121D-01,  3.6846682995337260D-01), ( -9.3020502289221896D-01,  3.6704034571976729D-01), &
( -9.3076696107898371D-01,  3.6561299780477380D-01), ( -9.3132670908118032D-01,  3.6418478956708011D-01), &
( -9.3188426558166815D-01,  3.6275572436739728D-01), ( -9.3243962926846247D-01,  3.6132580556845417D-01), &
( -9.3299279883473885D-01,  3.5989503653498833D-01), ( -9.3354377297883617D-01,  3.5846342063373660D-01), &
( -9.3409255040425876D-01,  3.5703096123343031D-01), ( -9.3463912981968067D-01,  3.5559766170478402D-01), &
( -9.3518350993894761D-01,  3.5416352542049034D-01), ( -9.3572568948108026D-01,  3.5272855575521095D-01), &
( -9.3626566717027826D-01,  3.5129275608556720D-01), ( -9.3680344173592167D-01,  3.4985612979013486D-01), &
( -9.3733901191257485D-01,  3.4841868024943479D-01), ( -9.3787237643998977D-01,  3.4698041084592374D-01), &
( -9.3840353406310817D-01,  3.4554132496398898D-01), ( -9.3893248353206449D-01,  3.4410142598993904D-01), &
( -9.3945922360218992D-01,  3.4266071731199443D-01), ( -9.3998375303401382D-01,  3.4121920232028269D-01), &
( -9.4050607059326830D-01,  3.3977688440682702D-01), ( -9.4102617505088926D-01,  3.3833376696554113D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4205973977101731D-01,  3.3544514708453171D-01), &
( -9.4257319760144687D-01,  3.3399965144200933D-01), ( -9.4308443746609338D-01,  3.3255336986604445D-01), &
( -9.4359345816196039D-01,  3.3110630575987648D-01), ( -9.4410025849127266D-01,  3.2965846252858744D-01), &
( -9.4460483726148015D-01,  3.2820984357909272D-01), ( -9.4510719328526061D-01,  3.2676045232013179D-01), &
( -9.4560732538052128D-01,  3.2531029216226320D-01), ( -9.4610523237040334D-01,  3.2385936651785302D-01), &
( -9.4660091308328353D-01,  3.2240767880106985D-01), ( -9.4709436635277711D-01,  3.2095523242787549D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.4807458592227623D-01,  3.1804807738501489D-01), &
( -9.4856134991573027D-01,  3.1659337555616607D-01), ( -9.4904588185270056D-01,  3.1513792875252244D-01), &
( -9.4952818059303667D-01,  3.1368174039889141D-01), ( -9.5000824500184300D-01,  3.1222481392182511D-01), &
( -9.5048607394948170D-01,  3.1076715274961153D-01), ( -9.5096166631157497D-01,  3.0930876031226900D-01), &
( -9.5143502096900834D-01,  3.0784964004153503D-01), ( -9.5190613680793235D-01,  3.0638979537086092D-01), &
( -9.5237501271976577D-01,  3.0492922973540265D-01), ( -9.5284164760119860D-01,  3.0346794657201143D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.5376818988599021D-01,  3.0054324141727368D-01), &
( -9.5422809510910556D-01,  2.9907982630804053D-01), ( -9.5468575494133834D-01,  2.9761570743508614D-01)/
data (mpuu1(i), i =  3901,  4000) / &
( -9.5514116830577067D-01,  2.9615088824362401D-01), ( -9.5559433413077111D-01,  2.9468537218051438D-01), &
( -9.5604525134999641D-01,  2.9321916269425896D-01), ( -9.5649391890239499D-01,  2.9175226323498943D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.5738450078897586D-01,  2.8881640820604976D-01), &
( -9.5782641302753291D-01,  2.8734745954472962D-01), ( -9.5826607140801767D-01,  2.8587783472708056D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.5913862246184189D-01,  2.8293657045705545D-01), &
( -9.5957151308198452D-01,  2.8146493792575789D-01), ( -9.6000214573766585D-01,  2.7999264308027344D-01), &
( -9.6043051941556579D-01,  2.7851968938505312D-01), ( -9.6085663310767955D-01,  2.7704608030610023D-01), &
( -9.6128048581132064D-01,  2.7557181931095831D-01), ( -9.6170207652912254D-01,  2.7409690986870638D-01), &
( -9.6212140426904158D-01,  2.7262135544994925D-01), ( -9.6253846804435916D-01,  2.7114515952680812D-01), &
( -9.6295326687368388D-01,  2.6966832557291504D-01), ( -9.6336579978095394D-01,  2.6819085706340340D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.6418406395174583D-01,  2.6523403028551173D-01), &
( -9.6458979328981265D-01,  2.6375467897483157D-01), ( -9.6499325285492032D-01,  2.6227470702391364D-01), &
( -9.6539444169768929D-01,  2.6079411791527585D-01), ( -9.6579335887408357D-01,  2.5931291513288640D-01), &
( -9.6619000344541250D-01,  2.5783110216215899D-01), ( -9.6658437447833301D-01,  2.5634868248994314D-01), &
( -9.6697647104485207D-01,  2.5486565960451468D-01), ( -9.6736629222232851D-01,  2.5338203699557010D-01), &
( -9.6775383709347540D-01,  2.5189781815421719D-01), ( -9.6813910474636233D-01,  2.5041300657296534D-01), &
( -9.6852209427441738D-01,  2.4892760574572009D-01), ( -9.6890280477642887D-01,  2.4744161916777349D-01), &
( -9.6928123535654853D-01,  2.4595505033579465D-01), ( -9.6965738512429234D-01,  2.4446790274782448D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7040283868755550D-01,  2.4149188530286933D-01), &
( -9.7077214072895024D-01,  2.4000302244874175D-01), ( -9.7113915844972509D-01,  2.3851359484431855D-01), &
( -9.7150389098625178D-01,  2.3702360599436717D-01), ( -9.7186633748027929D-01,  2.3553305940497574D-01), &
( -9.7222649707893627D-01,  2.3404195858354349D-01), ( -9.7258436893473221D-01,  2.3255030703877516D-01), &
( -9.7293995220556007D-01,  2.3105810828067130D-01), ( -9.7329324605469825D-01,  2.2956536582051892D-01), &
( -9.7364424965081187D-01,  2.2807208317088606D-01), ( -9.7399296216795583D-01,  2.2657826384561017D-01), &
( -9.7433938278557586D-01,  2.2508391135979283D-01), ( -9.7468351068851067D-01,  2.2358902922979026D-01), &
( -9.7502534506699412D-01,  2.2209362097320365D-01), ( -9.7536488511665698D-01,  2.2059769010887348D-01), &
( -9.7570213003852846D-01,  2.1910124015687002D-01), ( -9.7603707903903902D-01,  2.1760427463848372D-01), &
( -9.7636973133002114D-01,  2.1610679707621944D-01), ( -9.7670008612871173D-01,  2.1460881099378698D-01), &
( -9.7702814265775439D-01,  2.1311031991609142D-01), ( -9.7735390014519996D-01,  2.1161132736922789D-01), &
( -9.7767735782450993D-01,  2.1011183688046978D-01), ( -9.7799851493455714D-01,  2.0861185197826349D-01), &
( -9.7831737071962754D-01,  2.0711137619221884D-01), ( -9.7863392442942310D-01,  2.0561041305309938D-01), &
( -9.7894817531906220D-01,  2.0410896609281684D-01), ( -9.7926012264908202D-01,  2.0260703884442136D-01), &
( -9.7956976568544052D-01,  2.0110463484209198D-01), ( -9.7987710369951764D-01,  1.9960175762113089D-01), &
( -9.8018213596811732D-01,  1.9809841071795378D-01), ( -9.8048486177346938D-01,  1.9659459767008028D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8108339115048659D-01,  1.9358558729580377D-01), &
( -9.8137919331375456D-01,  1.9208039704989244D-01), ( -9.8167268619698311D-01,  1.9057475482025305D-01), &
( -9.8196386910955524D-01,  1.8906866414980633D-01), ( -9.8225274136628937D-01,  1.8756212858252957D-01), &
( -9.8253930228744124D-01,  1.8605515166344688D-01), ( -9.8282355119870524D-01,  1.8454773693861970D-01), &
( -9.8310548743121640D-01,  1.8303988795514090D-01), ( -9.8338511032155118D-01,  1.8153160826112519D-01), &
( -9.8366241921173025D-01,  1.8002290140569957D-01), ( -9.8393741344921892D-01,  1.7851377093899740D-01), &
( -9.8421009238692903D-01,  1.7700422041214892D-01), ( -9.8448045538322093D-01,  1.7549425337727143D-01), &
( -9.8474850180190421D-01,  1.7398387338746410D-01), ( -9.8501423101223984D-01,  1.7247308399679609D-01), &
( -9.8527764238894122D-01,  1.7096188876030119D-01), ( -9.8553873531217606D-01,  1.6945029123396821D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.8605396334619544D-01,  1.6642590354046405D-01), &
( -9.8630809724459856D-01,  1.6491312048997012D-01), ( -9.8655991026477541D-01,  1.6339994938297328D-01), &
( -9.8680940181418553D-01,  1.6188639378011171D-01), ( -9.8705657130575097D-01,  1.6037245724292842D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.8754394179435923D-01,  1.5734345561623855D-01), &
( -9.8778414164457218D-01,  1.5582839765426537D-01), ( -9.8802201714328353D-01,  1.5431297301302008D-01), &
( -9.8825756773074946D-01,  1.5279718525844369D-01), ( -9.8849079285269659D-01,  1.5128103795733031D-01), &
( -9.8872169196032378D-01,  1.4976453467732145D-01), ( -9.8895026451030299D-01,  1.4824767898689625D-01)/
data (mpuu1(i), i =  4001,  4100) / &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.8940042779138038D-01,  1.4521292465284735D-01), &
( -9.8962201746320078D-01,  1.4369503315029464D-01), ( -9.8984127845882053D-01,  1.4217680351944806D-01), &
( -9.9005821026229701D-01,  1.4065823933284952D-01), ( -9.9027281236316911D-01,  1.3913934416382634D-01), &
( -9.9048508425645709D-01,  1.3762012158648601D-01), ( -9.9069502544266463D-01,  1.3610057517570645D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9110791372327689D-01,  1.3306052515713901D-01), &
( -9.9131085984611544D-01,  1.3154002870288331D-01), ( -9.9151147331874390D-01,  1.3001922272223340D-01), &
( -9.9170975366909953D-01,  1.2849811079379306D-01), ( -9.9190570043060933D-01,  1.2697669649688603D-01), &
( -9.9209931314219180D-01,  1.2545498341154626D-01), ( -9.9229059134825726D-01,  1.2393297511851248D-01), &
( -9.9247953459870997D-01,  1.2241067519921635D-01), ( -9.9266614244894802D-01,  1.2088808723577707D-01), &
( -9.9285041445986510D-01,  1.1936521481099163D-01), ( -9.9303235019785141D-01,  1.1784206150832509D-01), &
( -9.9321194923479450D-01,  1.1631863091190471D-01), ( -9.9338921114808065D-01,  1.1479492660651032D-01), &
( -9.9356413552059530D-01,  1.1327095217756442D-01), ( -9.9373672194072460D-01,  1.1174671121112650D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9407487930487937D-01,  1.0869744401313874D-01), &
( -9.9424044945318790D-01,  1.0717242495680916D-01), ( -9.9440368005767910D-01,  1.0564715371341077D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9472312110432570D-01,  1.0259586902243656D-01), &
( -9.9487933079480562D-01,  1.0106986275482793D-01), ( -9.9503319943811863D-01,  9.9543618660069277D-02), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9533391214048228D-01,  9.6490431355252662D-02), &
( -9.9548075549192694D-01,  9.4963495329638908D-02), ( -9.9562525638099431D-01,  9.3436335845747981D-02), &
( -9.9576741446765982D-01,  9.1908956497132765D-02), ( -9.9590722941741172D-01,  9.0381360877865302D-02), &
( -9.9604470090125197D-01,  8.8853552582524753D-02), ( -9.9617982859569698D-01,  8.7325535206192059D-02), &
( -9.9631261218277800D-01,  8.5797312344440158D-02), ( -9.9644305135004263D-01,  8.4268887593324182D-02), &
( -9.9657114579055484D-01,  8.2740264549375650D-02), ( -9.9669689520289606D-01,  8.1211446809592663D-02), &
( -9.9682029929116567D-01,  7.9682437971430195D-02), ( -9.9694135776498216D-01,  7.8153241632794149D-02), &
( -9.9706007033948296D-01,  7.6623861392031686D-02), ( -9.9717643673532608D-01,  7.5094300847921347D-02), &
( -9.9729045667869021D-01,  7.3564563599667745D-02), ( -9.9740212990127530D-01,  7.2034653246889485D-02), &
( -9.9751145614030345D-01,  7.0504573389613856D-02), ( -9.9761843513851955D-01,  6.8974327628267024D-02), &
( -9.9772306664419164D-01,  6.7443919563664176D-02), ( -9.9782535041111164D-01,  6.5913352797003763D-02), &
( -9.9792528619859600D-01,  6.4382630929857701D-02), ( -9.9802287377148624D-01,  6.2851757564161490D-02), &
( -9.9811811290014918D-01,  6.1320736302208495D-02), ( -9.9821100336047819D-01,  5.9789570746640069D-02), &
( -9.9830154493389289D-01,  5.8258264500435794D-02), ( -9.9838973740734016D-01,  5.6726821166908067D-02), &
( -9.9847558057329477D-01,  5.5195244349690094D-02), ( -9.9855907422975931D-01,  5.3663537652730520D-02), &
( -9.9864021818026516D-01,  5.2131704680283601D-02), ( -9.9871901223387294D-01,  5.0599749036899400D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9886954991428356D-01,  4.7535484156959545D-02), &
( -9.9894129318685687D-01,  4.6003182130914706D-02), ( -9.9901068585407338D-01,  4.4470771854938584D-02), &
( -9.9907772775264536D-01,  4.2938256934941021D-02), ( -9.9914241872481691D-01,  4.1405640977076781D-02), &
( -9.9920475861836389D-01,  3.9872927587740130D-02), ( -9.9926474728659442D-01,  3.8340120373552854D-02), &
( -9.9932238458834954D-01,  3.6807222941358832D-02), ( -9.9937767038800285D-01,  3.5274238898214232D-02), &
( -9.9943060455546173D-01,  3.3741171851377705D-02), ( -9.9948118696616695D-01,  3.2208025408304544D-02), &
( -9.9952941750109314D-01,  3.0674803176636865D-02), ( -9.9957529604674922D-01,  2.9141508764193802D-02), &
( -9.9961882249517864D-01,  2.7608145778965656D-02), ( -9.9965999674395922D-01,  2.6074717829104099D-02), &
( -9.9969881869620425D-01,  2.4541228522912326D-02), ( -9.9973528826056168D-01,  2.3007681468839691D-02), &
( -9.9976940535121528D-01,  2.1474080275469667D-02), ( -9.9980116988788426D-01,  1.9940428551514438D-02), &
( -9.9983058179582340D-01,  1.8406729905805101D-02), ( -9.9985764100582386D-01,  1.6872987947281832D-02), &
( -9.9988234745421256D-01,  1.5339206284988060D-02), ( -9.9990470108285279D-01,  1.3805388528060633D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9994234967602391D-01,  1.0737659167264411D-02), &
( -9.9995764455196390D-01,  9.2037547820600224D-03), ( -9.9997058643097414D-01,  7.6698287395311378D-03), &
( -9.9998117528260111D-01,  6.1358846491547988D-03), ( -9.9998941108192840D-01,  4.6019261204487327D-03), &
( -9.9999529380957619D-01,  3.0679567629659770D-03), ( -9.9999882345170188D-01,  1.5339801862850493D-03), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  9.9999970586288223D-01,  7.6699031874270449D-04), &
(  9.9999882345170188D-01,  1.5339801862847655D-03), (  9.9999735276697821D-01,  2.3009691514258050D-03)/
data (mpuu1(i), i =  4101,  4200) / &
(  9.9999529380957619D-01,  3.0679567629659761D-03), (  9.9999264658070719D-01,  3.8349425697062275D-03), &
(  9.9998941108192840D-01,  4.6019261204485705D-03), (  9.9998558731514320D-01,  5.3689069639963425D-03), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9997617498689761D-01,  6.9028587247297558D-03), &
(  9.9997058643097414D-01,  7.6698287395310970D-03), (  9.9996440961811828D-01,  8.4367942423697988D-03), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9995029123649048D-01,  9.9707099074180308D-03), &
(  9.9994234967602391D-01,  1.0737659167264491D-02), (  9.9993381987523600D-01,  1.1504602110422714D-02), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9991499557311347D-01,  1.3038467241987334D-02), &
(  9.9990470108285290D-01,  1.3805388528060391D-02), (  9.9989381837441849D-01,  1.4572301692779064D-02), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9987028832898295D-01,  1.6106101853537287D-02), &
(  9.9985764100582386D-01,  1.6872987947281710D-02), (  9.9984440549217524D-01,  1.7639864115082053D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9981616992490041D-01,  1.9173584868322623D-02), &
(  9.9980116988788426D-01,  1.9940428551514441D-02), (  9.9978558169359921D-01,  2.0707260504265895D-02), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9975264087024884D-01,  2.2240887414024961D-02), &
(  9.9973528826056168D-01,  2.3007681468839369D-02), (  9.9971734753236219D-01,  2.3774461988827555D-02), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9967970176298793D-01,  2.5307980620024571D-02), &
(  9.9965999674395922D-01,  2.6074717829103901D-02), (  9.9963970365071020D-01,  2.6841439699098531D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9959735328964838D-01,  2.8374835617672099D-02), &
(  9.9957529604674922D-01,  2.9141508764193722D-02), (  9.9955265077945699D-01,  2.9908164767516555D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9950559622532531D-01,  3.1441423540560301D-02), &
(  9.9948118696616695D-01,  3.2208025408304586D-02), (  9.9945618973797734D-01,  3.2974608328897335D-02), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9940443143367130D-01,  3.4507715524795750D-02), &
(  9.9937767038800285D-01,  3.5274238898213947D-02), (  9.9935032143419944D-01,  3.6040741520706229D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9929385986688779D-01,  3.7573682709270494D-02), &
(  9.9926474728659442D-01,  3.8340120373552694D-02), (  9.9923504686459585D-01,  3.9106535483329888D-02), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9917388256571638D-01,  4.0639296235933736D-02), &
(  9.9914241872481691D-01,  4.1405640977076739D-02), (  9.9911036711417489D-01,  4.2171961360347947D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9904450065942929D-01,  4.3704527250063421D-02), &
(  9.9901068585407338D-01,  4.4470771854938668D-02), (  9.9897628335646982D-01,  4.5236990298804590D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9890571536581829D-01,  4.6769346900537863D-02), &
(  9.9886954991428356D-01,  4.7535484156959303D-02), (  9.9883279685352799D-01,  4.8301593449480144D-02), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9875752799118334D-01,  4.9833726340107277D-02), &
(  9.9871901223387294D-01,  5.0599749036899282D-02), (  9.9867990895589909D-01,  5.1365741967162593D-02), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9859993993032037D-01,  5.2897636725665324D-02), &
(  9.9855907422975931D-01,  5.3663537652730520D-02), (  9.9851762110262221D-01,  5.4429407010919133D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9843295266650844D-01,  5.5961049218520569D-02), &
(  9.9838973740734016D-01,  5.6726821166907748D-02), (  9.9834593482121237D-01,  5.7492559744367566D-02), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9825656777149518D-01,  5.9023934984667931D-02), &
(  9.9821100336047819D-01,  5.9789570746639868D-02), (  9.9816485172764624D-01,  6.0555171335947788D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9807078690548234D-01,  6.2086265195060088D-02), &
(  9.9802287377148624D-01,  6.2851757564161406D-02), (  9.9797437352634699D-01,  6.3617212959193106D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9787561181711015D-01,  6.5148011025878833D-02), &
(  9.9782535041111164D-01,  6.5913352797003805D-02), (  9.9777450201016782D-01,  6.6678655793001557D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9767104434344100D-01,  6.8209143658806329D-02), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9756523906037575D-01,  6.9739471021907307D-02), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9745708640994191D-01,  7.1269634281296401D-02), &
(  9.9740212990127530D-01,  7.2034653246889332D-02), (  9.9734658664663323D-01,  7.2799629836351673D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9723374003046628D-01,  7.4329454086845756D-02), &
(  9.9717643673532619D-01,  7.5094300847921305D-02), (  9.9711854682697998D-01,  7.5859103432954447D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9700100730723529D-01,  7.7388574275265049D-02), &
(  9.9694135776498216D-01,  7.8153241632794232D-02), (  9.9688112174781385D-01,  7.8917863014784942D-02)/
data (mpuu1(i), i =  4201,  4300) / &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9675889043081800D-01,  8.0446966052950014D-02), &
(  9.9669689520289606D-01,  8.1211446809592441D-02), (  9.9663431364386990D-01,  8.1975879791633066D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9650739168011082D-01,  8.3504600633152432D-02), &
(  9.9644305135004263D-01,  8.4268887593324071D-02), (  9.9637812483820021D-01,  8.5033124980280275D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9624651342231552D-01,  8.6561449236251170D-02), &
(  9.9617982859569698D-01,  8.7325535206192059D-02), (  9.9611255774215113D-01,  8.8089569804770507D-02), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.9597625811291779D-01,  8.9617483090022959D-02), &
(  9.9590722941741172D-01,  9.0381360877864983D-02), (  9.9583761485534161D-01,  9.1145185496681005D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9569662829566352D-01,  9.2672673429913310D-02), &
(  9.9562525638099431D-01,  9.3436335845747787D-02), (  9.9555329876563847D-01,  9.4199943295393204D-02), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.9540762660253490D-01,  9.5726991499307162D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.9525961214913339D-01,  9.7253814448363271D-02), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.9510925575372611D-01,  9.8780408549799623D-02), &
(  9.9503319943811863D-01,  9.9543618660069319D-02), (  9.9495655777011638D-01,  1.0030677021139286D-01), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9480151855761711D-01,  1.0183289584146653D-01), &
(  9.9472312110432570D-01,  1.0259586902243628D-01), (  9.9464413848105071D-01,  1.0335878184889961D-01), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9448441791074760D-01,  1.0488442464313497D-01), &
(  9.9440368005767910D-01,  1.0564715371341062D-01), (  9.9432235722254581D-01,  1.0640982063418768D-01), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9415795679778973D-01,  1.0793496623265365D-01), &
(  9.9407487930487937D-01,  1.0869744401313872D-01), (  9.9399121702332938D-01,  1.0945985784971798D-01), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9382213829151966D-01,  1.1098449189716339D-01), &
(  9.9373672194072460D-01,  1.1174671121112659D-01), (  9.9365072100021912D-01,  1.1250886478737869D-01), &
(  9.9356413552059530D-01,  1.1327095217756435D-01), (  9.9347696555278919D-01,  1.1403297293336720D-01), &
(  9.9338921114808065D-01,  1.1479492660651008D-01), (  9.9330087235809328D-01,  1.1555681274875526D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9312244183049558D-01,  1.1708038064780059D-01), &
(  9.9303235019785141D-01,  1.1784206150832498D-01), (  9.9294167438986047D-01,  1.1860367304540072D-01), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.9275857046155114D-01,  1.2012668635710151D-01), &
(  9.9266614244894802D-01,  1.2088808723577708D-01), (  9.9257313047642881D-01,  1.2164941699910553D-01), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.9238535487085167D-01,  1.2317186138828048D-01), &
(  9.9229059134825737D-01,  1.2393297511851216D-01), (  9.9219524408667392D-01,  1.2469401594216764D-01), &
(  9.9209931314219180D-01,  1.2545498341154623D-01), (  9.9200279857124452D-01,  1.2621587707899035D-01), &
(  9.9190570043060933D-01,  1.2697669649688587D-01), (  9.9180801877740643D-01,  1.2773744121766231D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9161090516349537D-01,  1.2925870477779614D-01), &
(  9.9151147331874390D-01,  1.3001922272223335D-01), (  9.9141145819333854D-01,  1.3077966417971171D-01), &
(  9.9131085984611544D-01,  1.3154002870288312D-01), (  9.9120967833625406D-01,  1.3230031584444465D-01), &
(  9.9110791372327689D-01,  1.3306052515713906D-01), (  9.9100556606704937D-01,  1.3382065619375472D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.9079912186602037D-01,  1.3534068165013421D-01), &
(  9.9069502544266463D-01,  1.3610057517570620D-01), (  9.9059034621895015D-01,  1.3686038863681638D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.9037923961710816D-01,  1.3837977357778389D-01), &
(  9.9027281236316911D-01,  1.3913934416382620D-01), (  9.9016580255724840D-01,  1.3989883289777721D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8995003554160899D-01,  1.4141756302230302D-01), &
(  9.8984127845882053D-01,  1.4217680351944803D-01), (  9.8973193907791057D-01,  1.4293596037764267D-01), &
(  9.8962201746320089D-01,  1.4369503315029447D-01), (  9.8951151367935519D-01,  1.4445402139086047D-01), &
(  9.8940042779138038D-01,  1.4521292465284746D-01), (  9.8928875986462517D-01,  1.4597174248981221D-01), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8906367815788154D-01,  1.4748912010315357D-01), &
(  9.8895026451030299D-01,  1.4824767898689603D-01), (  9.8883626908876354D-01,  1.4900615066034845D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8860653319238645D-01,  1.5052283059167740D-01), &
(  9.8849079285269659D-01,  1.5128103795733022D-01), (  9.8837447100934128D-01,  1.5203915632824605D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8814008308569257D-01,  1.5355512430199345D-01), &
(  9.8802201714328353D-01,  1.5431297301302010D-01), (  9.8790336997297779D-01,  1.5507073094570051D-01)/
data (mpuu1(i), i =  4301,  4400) / &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.8766433222820571D-01,  1.5658597269299843D-01), &
(  9.8754394179435923D-01,  1.5734345561623825D-01), (  9.8742297041385541D-01,  1.5810084597837698D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8717928509787434D-01,  1.5961534723719306D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.8693327685367771D-01,  1.6112947290567881D-01), &
(  9.8680940181418553D-01,  1.6188639378011183D-01), (  9.8668494626014669D-01,  1.6264321942095031D-01), &
(  9.8655991026477541D-01,  1.6339994938297323D-01), (  9.8643429390162718D-01,  1.6415658322101581D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8618132036792827D-01,  1.6566956074478412D-01), &
(  9.8605396334619544D-01,  1.6642590354046410D-01), (  9.8592602625432113D-01,  1.6718214843207294D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.8566841216153755D-01,  1.6869434272361733D-01), &
(  9.8553873531217606D-01,  1.6945029123396796D-01), (  9.8540847869576842D-01,  1.7020614006107807D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8514622646866223D-01,  1.7171753688704997D-01), &
(  9.8501423101223984D-01,  1.7247308399679595D-01), (  9.8488165609732370D-01,  1.7322852964507032D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8461476820431260D-01,  1.7473911477962720D-01), &
(  9.8448045538322093D-01,  1.7549425337727143D-01), (  9.8434556341764190D-01,  1.7624928873616791D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8407404237077645D-01,  1.7775904796110717D-01), &
(  9.8393741344921892D-01,  1.7851377093899751D-01), (  9.8380020570263160D-01,  1.7926838890183575D-01), &
(  9.8366241921173025D-01,  1.8002290140569951D-01), (  9.8352405405757126D-01,  1.8077730800672859D-01), &
(  9.8338511032155118D-01,  1.8153160826112497D-01), (  9.8324558808540707D-01,  1.8228580172515330D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8296480844139644D-01,  1.8379386650747845D-01), &
(  9.8282355119870524D-01,  1.8454773693861962D-01), (  9.8268171578624086D-01,  1.8530149880508190D-01), &
(  9.8253930228744124D-01,  1.8605515166344663D-01), (  9.8239631078608469D-01,  1.8680869507035927D-01), &
(  9.8225274136628937D-01,  1.8756212858252960D-01), (  9.8210859411251361D-01,  1.8831545175673212D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.8181856644255250D-01,  1.8982176531865641D-01), &
(  9.8167268619698311D-01,  1.9057475482025274D-01), (  9.8152622845866477D-01,  1.9132763221163090D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.8123158084874973D-01,  1.9283304889220523D-01), &
(  9.8108339115048671D-01,  1.9358558729580361D-01), (  9.8093462430614164D-01,  1.9433801181798860D-01), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.8063535952960812D-01,  1.9584251744765785D-01), &
(  9.8048486177346938D-01,  1.9659459767008022D-01), (  9.8033378722334796D-01,  1.9734656224096592D-01), &
(  9.8018213596811743D-01,  1.9809841071795356D-01), (  9.8002990809699009D-01,  1.9885014265875009D-01), &
(  9.7987710369951764D-01,  1.9960175762113097D-01), (  9.7972372286559117D-01,  2.0035325516294045D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.7941523224963478D-01,  2.0185589621656805D-01), &
(  9.7926012264908202D-01,  2.0260703884442113D-01), (  9.7910443697502925D-01,  2.0335806228377332D-01), &
(  9.7894817531906220D-01,  2.0410896609281687D-01), (  9.7879133777310567D-01,  2.0485974982981442D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.7847593538061683D-01,  2.0636095532107551D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7815823053973505D-01,  2.0786167522507507D-01), &
(  9.7799851493455714D-01,  2.0861185197826349D-01), (  9.7783822399805043D-01,  2.0936190601047416D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.7751591650856928D-01,  2.1086164414708486D-01), &
(  9.7735390014520007D-01,  2.1161132736922755D-01), (  9.7719130882971228D-01,  2.1236088610587842D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7686440172531264D-01,  2.1385962835899375D-01), &
(  9.7670008612871184D-01,  2.1460881099378676D-01), (  9.7653519596461447D-01,  2.1535786737974555D-01), &
(  9.7636973133002114D-01,  2.1610679707621952D-01), (  9.7620369232227056D-01,  2.1685559964263262D-01), &
(  9.7603707903903902D-01,  2.1760427463848364D-01), (  9.7586989157834103D-01,  2.1835282162334632D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7553379451829136D-01,  2.1984952979877870D-01), &
(  9.7536488511665698D-01,  2.2059769010887351D-01), (  9.7519540193299037D-01,  2.2134572064703081D-01), &
(  9.7502534506699412D-01,  2.2209362097320351D-01), (  9.7485471461870843D-01,  2.2284139064742112D-01), &
(  9.7468351068851067D-01,  2.2358902922978999D-01), (  9.7451173337711572D-01,  2.2433653628049360D-01), &
(  9.7433938278557586D-01,  2.2508391135979283D-01), (  9.7416645901528032D-01,  2.2583115402802617D-01), &
(  9.7399296216795583D-01,  2.2657826384561000D-01), (  9.7381889234566610D-01,  2.2732524037303886D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7346903418613107D-01,  2.2881879179980222D-01), &
(  9.7329324605469825D-01,  2.2956536582051887D-01), (  9.7311688535992513D-01,  2.3031180479384544D-01)/
data (mpuu1(i), i =  4401,  4500) / &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7276244669568857D-01,  2.3180427584196478D-01), &
(  9.7258436893473221D-01,  2.3255030703877524D-01), (  9.7240571902744977D-01,  2.3329620143223162D-01), &
(  9.7222649707893627D-01,  2.3404195858354343D-01), (  9.7204670319462350D-01,  2.3478757805400097D-01), &
(  9.7186633748027940D-01,  2.3553305940497549D-01), (  9.7168540004200854D-01,  2.3627840219791957D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.7132181041978616D-01,  2.3776867035593419D-01), &
(  9.7113915844972509D-01,  2.3851359484431842D-01), (  9.7095593518351797D-01,  2.3925837902129998D-01), &
(  9.7077214072895035D-01,  2.4000302244874150D-01), (  9.7058777519414363D-01,  2.4074752468858843D-01), &
(  9.7040283868755550D-01,  2.4149188530286933D-01), (  9.7021733131797916D-01,  2.4223610385369601D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.6984460442671483D-01,  2.4372411301385216D-01), &
(  9.6965738512429245D-01,  2.4446790274782415D-01), (  9.6946959539741306D-01,  2.4521154866762754D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6909230511250621D-01,  2.4669840731494241D-01), &
(  9.6890280477642887D-01,  2.4744161916777327D-01), (  9.6871273445979478D-01,  2.4818468545707478D-01), &
(  9.6852209427441727D-01,  2.4892760574572015D-01), (  9.6833088433244519D-01,  2.4967037959666855D-01), &
(  9.6813910474636244D-01,  2.5041300657296522D-01), (  9.6794675562898780D-01,  2.5115548623774192D-01), &
(  9.6775383709347551D-01,  2.5189781815421697D-01), (  9.6756034925331447D-01,  2.5264000188569552D-01), &
(  9.6736629222232851D-01,  2.5338203699557016D-01), (  9.6717166611467664D-01,  2.5412392304732062D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6678070712768327D-01,  2.5560724623080738D-01), &
(  9.6658437447833312D-01,  2.5634868248994291D-01), (  9.6638747321229890D-01,  2.5708996794575312D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.6599196529384057D-01,  2.5857208470317034D-01), &
(  9.6579335887408368D-01,  2.5931291513288623D-01), (  9.6559418430297683D-01,  2.6005359301549519D-01), &
(  9.6539444169768940D-01,  2.6079411791527551D-01), (  9.6519413117572472D-01,  2.6153448939659552D-01), &
(  9.6499325285492032D-01,  2.6227470702391359D-01), (  9.6479180685344790D-01,  2.6301477036177900D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.6438721228285429D-01,  2.6449443242780163D-01), &
(  9.6418406395174583D-01,  2.6523403028551179D-01), (  9.6398034841599411D-01,  2.6597347211287559D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.6357121621025732D-01,  2.6745188593667762D-01), &
(  9.6336579978095405D-01,  2.6819085706340318D-01), (  9.6315981662837136D-01,  2.6892967042035726D-01), &
(  9.6295326687368388D-01,  2.6966832557291509D-01), (  9.6274615063839941D-01,  2.7040682208654482D-01), &
(  9.6253846804435916D-01,  2.7114515952680801D-01), (  9.6233021921373740D-01,  2.7188333745935972D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.6191202333311221D-01,  2.7335921306441868D-01), &
(  9.6170207652912254D-01,  2.7409690986870638D-01), (  9.6149156398057900D-01,  2.7483444542884394D-01), &
(  9.6128048581132064D-01,  2.7557181931095814D-01), (  9.6106884214551935D-01,  2.7630903108127108D-01), &
(  9.6085663310767966D-01,  2.7704608030609990D-01), (  9.6064385882263859D-01,  2.7778296655185769D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.6021661501196343D-01,  2.7925624837229118D-01), &
(  9.6000214573766596D-01,  2.7999264308027322D-01), (  9.5978711171883990D-01,  2.8072887307579719D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.5935534995393079D-01,  2.8220083719714756D-01), &
(  9.5913862246184189D-01,  2.8293657045705539D-01), (  9.5892133073321317D-01,  2.8367213727266843D-01), &
(  9.5870347489587160D-01,  2.8440753721127188D-01), (  9.5848505507797621D-01,  2.8514276984024867D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  9.5804652401481860D-01,  2.8661273143934779D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.5760573857564635D-01,  2.8808201861100413D-01), &
(  9.5738450078897586D-01,  2.8881640820604948D-01), (  9.5716269979767010D-01,  2.8955062789784303D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.5671740872340305D-01,  2.9101855584408509D-01), &
(  9.5649391890239510D-01,  2.9175226323498926D-01), (  9.5626986640065803D-01,  2.9248579899555388D-01), &
(  9.5604525134999641D-01,  2.9321916269425863D-01), (  9.5582007388254542D-01,  2.9395235389968466D-01), &
(  9.5559433413077111D-01,  2.9468537218051433D-01), (  9.5536803222747035D-01,  2.9541821710553201D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.5491374249913052D-01,  2.9688338516377827D-01), &
(  9.5468575494133834D-01,  2.9761570743508620D-01), (  9.5445720576651349D-01,  2.9834785462674140D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.5399842310389449D-01,  2.9981162204838335D-01), &
(  9.5376818988599033D-01,  3.0054324141727345D-01), (  9.5353739559083328D-01,  3.0127468398431795D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.5307412431217220D-01,  3.0273703699181914D-01), &
(  9.5284164760119872D-01,  3.0346794657201132D-01), (  9.5260861035803335D-01,  3.0419867762982911D-01)/
data (mpuu1(i), i =  4501,  4600) / &
(  9.5237501271976588D-01,  3.0492922973540237D-01), (  9.5214085482381583D-01,  3.0565960245896612D-01), &
(  9.5190613680793235D-01,  3.0638979537086092D-01), (  9.5167085881019386D-01,  3.0711980804153310D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.5119862342311323D-01,  3.0857929094152503D-01), &
(  9.5096166631157508D-01,  3.0930876031226873D-01), (  9.5072414977378961D-01,  3.1003804772463789D-01), &
(  9.5048607394948170D-01,  3.1076715274961147D-01), (  9.5024743897870523D-01,  3.1149607495827591D-01), &
(  9.5000824500184300D-01,  3.1222481392182488D-01), (  9.4976849215960668D-01,  3.1295336921156020D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4928731044350212D-01,  3.1440992705533666D-01), &
(  9.4904588185270056D-01,  3.1513792875252244D-01), (  9.4880389496265849D-01,  3.1586574506218396D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4831824685459920D-01,  3.1732081980642174D-01), &
(  9.4807458592227623D-01,  3.1804807738501495D-01), (  9.4783036726210101D-01,  3.1877514786411848D-01), &
(  9.4758559101774109D-01,  3.1950203081601569D-01), (  9.4734025733319205D-01,  3.2022872581309986D-01), &
(  9.4709436635277722D-01,  3.2095523242787521D-01), (  9.4684791822114800D-01,  3.2168155023295658D-01), &
(  9.4660091308328353D-01,  3.2240767880106985D-01), (  9.4635335108449059D-01,  3.2313361770505233D-01), &
(  9.4610523237040345D-01,  3.2385936651785285D-01), (  9.4585655708698391D-01,  3.2458492481253215D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4535753739763229D-01,  3.2603546814033024D-01), &
(  9.4510719328526061D-01,  3.2676045232013173D-01), (  9.4485629319067721D-01,  3.2748524427517800D-01), &
(  9.4460483726148026D-01,  3.2820984357909250D-01), (  9.4435282564559475D-01,  3.2893424980561220D-01), &
(  9.4410025849127266D-01,  3.2965846252858749D-01), (  9.4384713594709269D-01,  3.3038248132198278D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.4333922528510772D-01,  3.3182993541646111D-01), &
(  9.4308443746609349D-01,  3.3255336986604422D-01), (  9.4282909485480271D-01,  3.3327660868304793D-01), &
(  9.4257319760144687D-01,  3.3399965144200938D-01), (  9.4231674585656378D-01,  3.3472249771758122D-01), &
(  9.4205973977101731D-01,  3.3544514708453160D-01), (  9.4180217949599765D-01,  3.3616759911774452D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.4128539698392866D-01,  3.3761190948307462D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.4076639953639607D-01,  3.3905542541496964D-01), &
(  9.4050607059326830D-01,  3.3977688440682685D-01), (  9.4024518837465088D-01,  3.4049814351669716D-01), &
(  9.3998375303401405D-01,  3.4121920232028236D-01), (  9.3972176472515334D-01,  3.4194006039340219D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3919612981956990D-01,  3.4338117265211504D-01), &
(  9.3893248353206449D-01,  3.4410142598993881D-01), (  9.3866828489477017D-01,  3.4482147690175929D-01), &
(  9.3840353406310806D-01,  3.4554132496398909D-01), (  9.3813823119282436D-01,  3.4626096975316001D-01), &
(  9.3787237643998989D-01,  3.4698041084592368D-01), (  9.3760596996099999D-01,  3.4769964781905138D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3707150245175919D-01,  3.4913750771408497D-01), &
(  9.3680344173592156D-01,  3.4985612979013492D-01), (  9.3653482992275550D-01,  3.5057454605483751D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.3599595363683141D-01,  3.5201075945981908D-01), &
(  9.3572568948108037D-01,  3.5272855575521073D-01), (  9.3545487486201462D-01,  3.5344614454948081D-01), &
(  9.3518350993894761D-01,  3.5416352542049034D-01), (  9.3491159487151609D-01,  3.5488069794622279D-01), &
(  9.3463912981968078D-01,  3.5559766170478385D-01), (  9.3436611494372590D-01,  3.5631441627440241D-01), &
(  9.3409255040425898D-01,  3.5703096123342998D-01), (  9.3381843636221096D-01,  3.5774729616034190D-01), &
(  9.3354377297883617D-01,  3.5846342063373654D-01), (  9.3326856041571205D-01,  3.5917933423233650D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.3271648839814025D-01,  3.6061052712066227D-01), &
(  9.3243962926846236D-01,  3.6132580556845428D-01), (  9.3216222160857443D-01,  3.6204087145758418D-01), &
(  9.3188426558166815D-01,  3.6275572436739723D-01), (  9.3160576135125783D-01,  3.6347036387736376D-01), &
(  9.3132670908118043D-01,  3.6418478956707989D-01), (  9.3104710893559528D-01,  3.6489900101626727D-01), &
(  9.3076696107898371D-01,  3.6561299780477385D-01), (  9.3048626567614967D-01,  3.6632677951257359D-01), &
(  9.3020502289221907D-01,  3.6704034571976718D-01), (  9.2992323289263967D-01,  3.6775369600658198D-01), &
(  9.2964089584318121D-01,  3.6846682995337232D-01), (  9.2935801190993550D-01,  3.6917974714062002D-01), &
(  9.2907458125931575D-01,  3.6989244714893410D-01), (  9.2879060405805702D-01,  3.7060492955905167D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2822101067216944D-01,  3.7202923990828501D-01), &
(  9.2793539482261789D-01,  3.7274106700951576D-01), (  9.2764923309258118D-01,  3.7345267483678030D-01), &
(  9.2736252565040111D-01,  3.7416406297145793D-01), (  9.2707527266474010D-01,  3.7487523099505754D-01), &
(  9.2678747430458175D-01,  3.7558617848921722D-01), (  9.2649913073923051D-01,  3.7629690503570479D-01)/
data (mpuu1(i), i =  4601,  4700) / &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.2592080867177007D-01,  3.7771769361338564D-01), &
(  9.2563083050987272D-01,  3.7842775480876556D-01), (  9.2534030782320631D-01,  3.7913759338484732D-01), &
(  9.2504924078267758D-01,  3.7984720892405116D-01), (  9.2475762955951391D-01,  3.8055660100892852D-01), &
(  9.2446547432526260D-01,  3.8126576922216238D-01), (  9.2417277525179120D-01,  3.8197471314656722D-01), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  9.2358574627625667D-01,  3.8339192646080866D-01), &
(  9.2329141671952764D-01,  3.8410019501693504D-01), (  9.2299654401424625D-01,  3.8480823761681288D-01), &
(  9.2270112833387863D-01,  3.8551605384391885D-01), (  9.2240516985220999D-01,  3.8622364328186298D-01), &
(  9.2210866874334507D-01,  3.8693100551438858D-01), (  9.2181162518170812D-01,  3.8763814012537273D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  9.2121591139940873D-01,  3.8905172481889438D-01), &
(  9.2091724152918952D-01,  3.8975817406985641D-01), (  9.2061802990708386D-01,  3.9046439403612659D-01), &
(  9.2031827670911059D-01,  3.9117038430225387D-01), (  9.2001798211160657D-01,  3.9187614445292235D-01), &
(  9.1971714629122736D-01,  3.9258167407295147D-01), (  9.1941576942494707D-01,  3.9328697274729640D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1881139326416994D-01,  3.9469687559943356D-01), &
(  9.1850839432521225D-01,  3.9540147894781635D-01), (  9.1820485505143101D-01,  3.9610584969169627D-01), &
(  9.1790077562139050D-01,  3.9680998741671031D-01), (  9.1759615621397295D-01,  3.9751389170863233D-01), &
(  9.1729099700837791D-01,  3.9821756215337356D-01), (  9.1698529818412300D-01,  3.9892099833698291D-01), &
(  9.1667905992104270D-01,  3.9962419984564679D-01), (  9.1637228239928914D-01,  4.0032716626569009D-01), &
(  9.1606496579933172D-01,  4.0102989718357562D-01), (  9.1575711030195672D-01,  4.0173239218590501D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.1513978333968526D-01,  4.0313667279099530D-01), &
(  9.1483031223794620D-01,  4.0383845756765407D-01), (  9.1452030296510445D-01,  4.0454000477655300D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.1389867063591168D-01,  4.0594238484040251D-01), &
(  9.1358704794525081D-01,  4.0664321687036903D-01), (  9.1327488781486776D-01,  4.0734380968260797D-01), &
(  9.1296219042839821D-01,  4.0804416286497869D-01), (  9.1264895596979390D-01,  4.0874427600548136D-01), &
(  9.1233518462332275D-01,  4.0944414869225759D-01), (  9.1202087657356834D-01,  4.1014378051359024D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.1139065110412243D-01,  4.1154231991376522D-01), &
(  9.1107473405517636D-01,  4.1224122666988289D-01), (  9.1075828104443757D-01,  4.1293989091510808D-01), &
(  9.1044129225806725D-01,  4.1363831223843456D-01), (  9.1012376788254168D-01,  4.1433649022899910D-01), &
(  9.0980570810465222D-01,  4.1503442447608163D-01), (  9.0948711311150543D-01,  4.1573211456910536D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0884831822943912D-01,  4.1712676065138787D-01), &
(  9.0852811871630612D-01,  4.1782371582021227D-01), (  9.0820738473948870D-01,  4.1852042519410970D-01), &
(  9.0788611648766626D-01,  4.1921688836322391D-01), (  9.0756431414983263D-01,  4.1991310491784362D-01), &
(  9.0724197791529582D-01,  4.2060907444840251D-01), (  9.0691910797367814D-01,  4.2130479654547964D-01), &
(  9.0659570451491533D-01,  4.2200027079979968D-01), (  9.0627176772925766D-01,  4.2269549680223295D-01), &
(  9.0594729780726846D-01,  4.2339047414379605D-01), (  9.0562229493982527D-01,  4.2408520241565156D-01), &
(  9.0529675931811882D-01,  4.2477968120910881D-01), (  9.0497069113365325D-01,  4.2547391011562380D-01), &
(  9.0464409057824624D-01,  4.2616788872679962D-01), (  9.0431695784402832D-01,  4.2686161663438643D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  9.0366109660924798D-01,  4.2824831870653196D-01), &
(  9.0333236849451182D-01,  4.2894129205532949D-01), (  9.0300310897261715D-01,  4.2963401306901638D-01), &
(  9.0267331823725883D-01,  4.3032648134008261D-01), (  9.0234299648244420D-01,  4.3101869646116703D-01), &
(  9.0201214390249318D-01,  4.3171065802505726D-01), (  9.0168076069203773D-01,  4.3240236562469014D-01), &
(  9.0134884704602203D-01,  4.3309381885315196D-01), (  9.0101640315970233D-01,  4.3378501730367858D-01), &
(  9.0068342922864697D-01,  4.3447596056965565D-01), (  9.0034992544873560D-01,  4.3516664824461926D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9968132912742393D-01,  4.3654725519640120D-01), &
(  8.9934623697934157D-01,  4.3723717366104409D-01), (  8.9901061576903907D-01,  4.3792683491032286D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9833778695183431D-01,  4.3930538414009995D-01), &
(  8.9800057974073988D-01,  4.3999427130963326D-01), (  8.9766284425904086D-01,  4.4068289964187290D-01), &
(  8.9732458070541832D-01,  4.4137126873171667D-01), (  8.9698578927886397D-01,  4.4205937817421470D-01), &
(  8.9664647017868027D-01,  4.4274722756457002D-01), (  8.9630662360447955D-01,  4.4343481649813848D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.9562534883403000D-01,  4.4480921137710488D-01), &
(  8.9528392103855758D-01,  4.4549601651398174D-01), (  8.9494196657062075D-01,  4.4618255957703007D-01)/
data (mpuu1(i), i =  4701,  4800) / &
(  8.9459948563138270D-01,  4.4686884016237416D-01), (  8.9425647842231615D-01,  4.4755485786629301D-01), &
(  8.9391294514520325D-01,  4.4824061228521989D-01), (  8.9356888600213591D-01,  4.4892610301574326D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.9287919092805179D-01,  4.5029629179870861D-01), &
(  8.9253355540276458D-01,  4.5098098904510386D-01), (  8.9218739482298248D-01,  4.5166542099100249D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.9149349931479138D-01,  4.5303348737093158D-01), &
(  8.9114576479458318D-01,  4.5371712100016387D-01), (  8.9079750603628149D-01,  4.5440048771930358D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.9009941662519232D-01,  4.5576641881943464D-01), &
(  8.8974958638307289D-01,  4.5644898239688392D-01), (  8.8939923272419552D-01,  4.5713127745715698D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.8869695598089160D-01,  4.5849506042082627D-01), &
(  8.8834503330959635D-01,  4.5917654752194409D-01), (  8.8799258804780556D-01,  4.5985776450132954D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8728613058238315D-01,  4.6121938649209238D-01), &
(  8.8693211879434219D-01,  4.6189979070246273D-01), (  8.8657758524698704D-01,  4.6257992318908681D-01), &
(  8.8622253014888064D-01,  4.6325978355186015D-01), (  8.8586695370889279D-01,  4.6393937139083852D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.8515423764028511D-01,  4.6529772789843460D-01), &
(  8.8479709843093779D-01,  4.6597649576796618D-01), (  8.8443943871825370D-01,  4.6665498951553092D-01), &
(  8.8408125871263499D-01,  4.6733320874198847D-01), (  8.8372255862478966D-01,  4.6801115304835983D-01), &
(  8.8336333866573158D-01,  4.6868882203582796D-01), (  8.8300359904678083D-01,  4.6936621530573752D-01), &
(  8.8264333997956279D-01,  4.7004333245959562D-01), (  8.8228256167600871D-01,  4.7072017309907160D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.8155944820914378D-01,  4.7207302324236866D-01), &
(  8.8119711347122198D-01,  4.7274903195034279D-01), (  8.8083426034774193D-01,  4.7342476255224153D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.8010699979824036D-01,  4.7477538784791712D-01), &
(  8.7974259280004741D-01,  4.7545028174715587D-01), (  8.7937766827195329D-01,  4.7612489595124363D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7864626748506813D-01,  4.7747328368669806D-01), &
(  8.7827979165654158D-01,  4.7814705642484301D-01), (  8.7791279915864184D-01,  4.7882054788139394D-01), &
(  8.7754529020726135D-01,  4.7949375766015301D-01), (  8.7717726501859605D-01,  4.8016668536508839D-01), &
(  8.7680872380914565D-01,  4.8083933060033396D-01), (  8.7643966679571361D-01,  4.8151169297018986D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7570000622563460D-01,  4.8285556753176567D-01), &
(  8.7532940310411089D-01,  4.8352707893291874D-01), (  8.7495828504885165D-01,  4.8419830588754903D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.7421450501070630D-01,  4.8553990487794696D-01), &
(  8.7384184346536686D-01,  4.8621027612448642D-01), (  8.7346866786138488D-01,  4.8688036134604734D-01), &
(  8.7309497841829009D-01,  4.8755016014843600D-01), (  8.7272077535591430D-01,  4.8821967213762679D-01), &
(  8.7234605889439154D-01,  4.8888889691976317D-01), (  8.7197082925415781D-01,  4.8955783410115744D-01), &
(  8.7159508665595098D-01,  4.9022648328829116D-01), (  8.7121883132081102D-01,  4.9089484408781514D-01), &
(  8.7084206347007886D-01,  4.9156291610654990D-01), (  8.7046478332539767D-01,  4.9223069895148602D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.6970868704226567D-01,  4.9356539554877477D-01), &
(  8.6932987134860684D-01,  4.9423230851595967D-01), (  8.6895054425058238D-01,  4.9489893073901126D-01), &
(  8.6857070597134090D-01,  4.9556526182577254D-01), (  8.6819035673433131D-01,  4.9623130138425825D-01), &
(  8.6780949676330332D-01,  4.9689704902265447D-01), (  8.6742812628230692D-01,  4.9756250434931915D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.6666385468811113D-01,  4.9889253650174459D-01), &
(  8.6628095402451299D-01,  4.9955711254508184D-01), (  8.6589754375014882D-01,  5.0022139471184068D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.6512919527162380D-01,  5.0154907585267539D-01), &
(  8.6474425751946238D-01,  5.0221247404571079D-01), (  8.6435881106053403D-01,  5.0287557680008699D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.6358639292966810D-01,  5.0420089443269034D-01), &
(  8.6319942171212416D-01,  5.0486310853126759D-01), (  8.6281194269660033D-01,  5.0552502563188539D-01), &
(  8.6242395611104050D-01,  5.0618664534515523D-01), (  8.6203546218368721D-01,  5.0684796728186321D-01), &
(  8.6164646114308130D-01,  5.0750899105297087D-01), (  8.6125695321806217D-01,  5.0816971626961460D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.6047641763163207D-01,  5.0949026948493636D-01), &
(  8.6008539042939014D-01,  5.1015009670676681D-01), (  8.5969385726107261D-01,  5.1080962382043904D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.5890927394782390D-01,  5.1212777617155469D-01), &
(  8.5851622426444285D-01,  5.1278640063356296D-01), (  8.5812266953808614D-01,  5.1344472343654346D-01)/
data (mpuu1(i), i =  4801,  4900) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.5733404588281559D-01,  5.1476046251650120D-01), &
(  8.5693897741782876D-01,  5.1541787801946293D-01), (  8.5654340483771996D-01,  5.1607499031536663D-01), &
(  8.5614732837519447D-01,  5.1673179901764987D-01), (  8.5575074826325381D-01,  5.1738830373992906D-01), &
(  8.5535366473519603D-01,  5.1804450409599934D-01), (  8.5495607802461493D-01,  5.1870039969983495D-01), &
(  8.5455798836540053D-01,  5.1935599016558964D-01), (  8.5415939599173885D-01,  5.2001127510759604D-01), &
(  8.5376030113811141D-01,  5.2066625414036716D-01), (  8.5336070403929543D-01,  5.2132092687859566D-01), &
(  8.5296060493036363D-01,  5.2197529293715439D-01), (  8.5256000404668408D-01,  5.2262935193109661D-01), &
(  8.5215890162391983D-01,  5.2328310347565643D-01), (  8.5175729789802912D-01,  5.2393654718624860D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.5095258748217573D-01,  5.2524250956809471D-01), &
(  8.5054948126560348D-01,  5.2589502747108463D-01), (  8.5014587469268521D-01,  5.2654723600357944D-01), &
(  8.4974176800085255D-01,  5.2719913478190139D-01), (  8.4933716142783078D-01,  5.2785072342255523D-01), &
(  8.4893205521163961D-01,  5.2850200154222848D-01), (  8.4852644959059265D-01,  5.2915296875779061D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.4771374108865438D-01,  5.3045396894497632D-01), &
(  8.4730663868585832D-01,  5.3110400115125500D-01), (  8.4689903783439724D-01,  5.3175372092273332D-01), &
(  8.4649093877405213D-01,  5.3240312787719790D-01), (  8.4608234174489705D-01,  5.3305222163261945D-01), &
(  8.4567324698729907D-01,  5.3370100180715296D-01), (  8.4526365474191822D-01,  5.3434946801913752D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.4444297875191066D-01,  5.3564545702974109D-01), &
(  8.4403189549006641D-01,  5.3629297906596318D-01), (  8.4362031570600415D-01,  5.3694018561484291D-01), &
(  8.4320823964184544D-01,  5.3758707629564539D-01), (  8.4279566754000412D-01,  5.3823365072782170D-01), &
(  8.4238259964318585D-01,  5.3887990853100842D-01), (  8.4196903619438768D-01,  5.3952584932502889D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  8.4114042361429808D-01,  5.4081677836579667D-01), &
(  8.4072537497045807D-01,  5.4146176585312344D-01), (  8.4030983174954077D-01,  5.4210643481244392D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.3947726255457855D-01,  5.4339481563028480D-01), &
(  8.3906023707031274D-01,  5.4403852673088382D-01), (  8.3864271798852730D-01,  5.4468191778763453D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3780620001515094D-01,  5.4596773825581757D-01), &
(  8.3738720161566194D-01,  5.4661016691083486D-01), (  8.3696771060285702D-01,  5.4725227400917409D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  8.3612725172469227D-01,  5.4853552202506739D-01), &
(  8.3570628435375260D-01,  5.4917666218771966D-01), (  8.3528482535833737D-01,  5.4981747928389091D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.3444043348610319D-01,  5.5109814276907543D-01), &
(  8.3401750110601813D-01,  5.5173798840470734D-01), (  8.3359407809492514D-01,  5.5237750946709607D-01), &
(  8.3317016470191319D-01,  5.5301670558002747D-01), (  8.3274576117635946D-01,  5.5365557636747931D-01), &
(  8.3232086776792968D-01,  5.5429412145362000D-01), (  8.3189548472657759D-01,  5.5493234046281037D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  8.3104325074636232D-01,  5.5620779874873993D-01), &
(  8.3061640030884631D-01,  5.5684503727516010D-01), (  8.3018906124110237D-01,  5.5748194822399155D-01), &
(  8.2976123379452305D-01,  5.5811853122055610D-01), (  8.2933291822078825D-01,  5.5875478589036831D-01), &
(  8.2890411477186487D-01,  5.5939071185913614D-01), (  8.2847482370000713D-01,  5.6002630875276038D-01), &
(  8.2804504525775580D-01,  5.6066157619733603D-01), (  8.2761477969793840D-01,  5.6129651381915147D-01), &
(  8.2718402727366913D-01,  5.6193112124468947D-01), (  8.2675278823834852D-01,  5.6256539810062645D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.2588885134958678D-01,  5.6383295861137817D-01), &
(  8.2545615400437755D-01,  5.6446624152051950D-01), (  8.2502297106458022D-01,  5.6509919236871398D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.2415514942082857D-01,  5.6636409639306384D-01), &
(  8.2372051122739143D-01,  5.6699604882510868D-01), (  8.2328538846040011D-01,  5.6762766770798623D-01), &
(  8.2284978137582643D-01,  5.6825895267013149D-01), (  8.2241369022992639D-01,  5.6888990334017586D-01), &
(  8.2197711527924155D-01,  5.6952051934694714D-01), (  8.2154005678059761D-01,  5.7015080031947030D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  8.2066449016815746D-01,  5.7141035567885723D-01), &
(  8.2022598256943469D-01,  5.7203962932475705D-01), (  8.1978699245289899D-01,  5.7266856645448116D-01), &
(  8.1934752007679701D-01,  5.7329716669804220D-01), (  8.1890756569965895D-01,  5.7392542968565075D-01), &
(  8.1846712958029866D-01,  5.7455335504771576D-01), (  8.1802621197781344D-01,  5.7518094241484508D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.1714293336127297D-01,  5.7643510168772183D-01), &
(  8.1670057286682785D-01,  5.7706167285567944D-01), (  8.1625773192847739D-01,  5.7768790455312280D-01)/
data (mpuu1(i), i =  4901,  5000) / &
(  8.1581441080673378D-01,  5.7831379641165559D-01), (  8.1537060976239129D-01,  5.7893934806308178D-01), &
(  8.1492632905652662D-01,  5.7956455913940563D-01), (  8.1448156895049861D-01,  5.8018942927283168D-01), &
(  8.1403632970594841D-01,  5.8081395809576453D-01), (  8.1359061158479851D-01,  5.8143814524081017D-01), &
(  8.1314441484925359D-01,  5.8206199034077544D-01), (  8.1269773976179960D-01,  5.8268549302866846D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  8.1180295558251547D-01,  5.8393146970127618D-01), &
(  8.1135484701706373D-01,  5.8455394295301533D-01), (  8.1090626115245967D-01,  5.8517607232673041D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.1000765858164114D-01,  5.8641929797636050D-01), &
(  8.0955764240405126D-01,  5.8704039352091797D-01), (  8.0910714998455824D-01,  5.8766114372473666D-01), &
(  8.0865618158817498D-01,  5.8828154822264522D-01), (  8.0820473748019483D-01,  5.8890160664967572D-01), &
(  8.0775281792619036D-01,  5.8952131864106394D-01), (  8.0730042319201445D-01,  5.9014068383224882D-01), &
(  8.0684755354379933D-01,  5.9075970185887416D-01), (  8.0639420924795635D-01,  5.9137837235678758D-01), &
(  8.0594039057117628D-01,  5.9199669496204099D-01), (  8.0548609778042923D-01,  5.9261466931089113D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  8.0457609092630711D-01,  5.9384957178543363D-01), &
(  8.0412037739826570D-01,  5.9446649918466443D-01), (  8.0366419082692409D-01,  5.9508307687456996D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  8.0275039962806916D-01,  5.9631518167574371D-01), &
(  8.0229279553811572D-01,  5.9693070806219650D-01), (  8.0183471947998131D-01,  5.9754588328969316D-01), &
(  8.0137617172314024D-01,  5.9816070699634238D-01), (  8.0091715253734430D-01,  5.9877517882045872D-01), &
(  8.0045766219262282D-01,  5.9938929840056454D-01), (  7.9999770095928191D-01,  6.0000306537538894D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.9907636690935235D-01,  6.0122954006514850D-01), &
(  7.9861499463476093D-01,  6.0184224705858003D-01), (  7.9815315255554375D-01,  6.0245460000372375D-01), &
(  7.9769084094339116D-01,  6.0306659854034816D-01), (  7.9722806007026881D-01,  6.0367824230843037D-01), &
(  7.9676481020841883D-01,  6.0428953094815596D-01), (  7.9630109163035911D-01,  6.0490046409991982D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.9537224941706131D-01,  6.0612126250218612D-01), &
(  7.9490712632823701D-01,  6.0673112703452448D-01), (  7.9444153561603059D-01,  6.0734063464257293D-01), &
(  7.9397547755433717D-01,  6.0794978496777363D-01), (  7.9350895241732666D-01,  6.0855857765177945D-01), &
(  7.9304196047944364D-01,  6.0916701233645321D-01), (  7.9257450201540769D-01,  6.0977508866386843D-01), &
(  7.9210657730021239D-01,  6.1038280627630948D-01), (  7.9163818660912588D-01,  6.1099016481627166D-01), &
(  7.9116933021769009D-01,  6.1159716392646191D-01), (  7.9070000840172161D-01,  6.1220380324979795D-01), &
(  7.9023022143731003D-01,  6.1281008242940971D-01), (  7.8975996960081907D-01,  6.1341600110863859D-01), &
(  7.8928925316888565D-01,  6.1402155893103849D-01), (  7.8881807241842028D-01,  6.1462675554037505D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.8787431907090022D-01,  6.1583606369598509D-01), &
(  7.8740174702903132D-01,  6.1644017453085365D-01), (  7.8692871177900181D-01,  6.1704392272984976D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.8598125276783015D-01,  6.1825032979976025D-01), &
(  7.8550682956405393D-01,  6.1885298796097632D-01), (  7.8503194426684808D-01,  6.1945528206692402D-01), &
(  7.8455659715557524D-01,  6.2005721176328910D-01), (  7.8408078850986995D-01,  6.2065877669597214D-01), &
(  7.8360451860963831D-01,  6.2125997651108755D-01), (  7.8312778773505731D-01,  6.2186081085496536D-01), &
(  7.8265059616657573D-01,  6.2246127937414997D-01), (  7.8217294418491301D-01,  6.2306138171540126D-01), &
(  7.8169483207105950D-01,  6.2366111752569453D-01), (  7.8121626010627609D-01,  6.2426048645222065D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.8025773775031659D-01,  6.2545812224381436D-01), &
(  7.7977778792301455D-01,  6.2605638840434352D-01), (  7.7929737937253041D-01,  6.2665428627202935D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.7833518723273321D-01,  6.2784897572217657D-01), &
(  7.7785340420945315D-01,  6.2844576660183271D-01), (  7.7737116359505631D-01,  6.2904218778303600D-01), &
(  7.7688846567323244D-01,  6.2963823891492698D-01), (  7.7640531072794039D-01,  6.3023391964686437D-01), &
(  7.7592169904340769D-01,  6.3082922962842447D-01), (  7.7543763090413054D-01,  6.3142416850940186D-01), &
(  7.7495310659487382D-01,  6.3201873593980906D-01), (  7.7446812640067086D-01,  6.3261293156987752D-01), &
(  7.7398269060682290D-01,  6.3320675505005719D-01), (  7.7349679949889905D-01,  6.3380020603101728D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.7252365248444133D-01,  6.3498598909904946D-01), &
(  7.7203639715038452D-01,  6.3557832048855611D-01), (  7.7154868764720630D-01,  6.3617027798371217D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.7057190728138081D-01,  6.3735306989825913D-01), &
(  7.7008283699334790D-01,  6.3794390362184406D-01), (  7.6959331368542294D-01,  6.3853436205946679D-01)/
data (mpuu1(i), i =  5001,  5100) / &
(  7.6910333764557970D-01,  6.3912444486377573D-01), (  7.6861290916205838D-01,  6.3971415168764045D-01), &
(  7.6812202852336542D-01,  6.4030348218415167D-01), (  7.6763069601827338D-01,  6.4089243600662138D-01), &
(  7.6713891193582040D-01,  6.4148101280858316D-01), (  7.6664667656531038D-01,  6.4206921224379254D-01), &
(  7.6615399019631292D-01,  6.4265703396622686D-01), (  7.6566085311866250D-01,  6.4324447763008585D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.6467322799806714D-01,  6.4441822939998838D-01), &
(  7.6417874053611667D-01,  6.4500453681554393D-01), (  7.6368380352750187D-01,  6.4559046479154869D-01), &
(  7.6318841726338138D-01,  6.4617601298331628D-01), (  7.6269258203517798D-01,  6.4676118104638392D-01), &
(  7.6219629813457890D-01,  6.4734596863651206D-01), (  7.6169956585353527D-01,  6.4793037540968534D-01), &
(  7.6120238548426178D-01,  6.4851440102211244D-01), (  7.6070475731923692D-01,  6.4909804513022595D-01), &
(  7.6020668165120242D-01,  6.4968130739068319D-01), (  7.5970815877316344D-01,  6.5026418746036585D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.5870977256040739D-01,  6.5142879965605982D-01), &
(  7.5820990981301528D-01,  6.5201053109695950D-01), (  7.5770960103026819D-01,  6.5259187897686244D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.5670764653624567D-01,  6.5375342268593606D-01), &
(  7.5620600141439454D-01,  6.5433361783180044D-01), (  7.5570391143603599D-01,  6.5491342805005615D-01), &
(  7.5520137689653655D-01,  6.5549285299961535D-01), (  7.5469839809152450D-01,  6.5607189233961760D-01), &
(  7.5419497531688917D-01,  6.5665054572942905D-01), (  7.5369110886878132D-01,  6.5722881282864254D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.5268204613805534D-01,  6.5838418679478505D-01), &
(  7.5217685044904270D-01,  6.5896129298203732D-01), (  7.5167121227376843D-01,  6.5953801151933866D-01), &
(  7.5116513190968637D-01,  6.6011434206742048D-01), (  7.5065860965451070D-01,  6.6069028428724230D-01), &
(  7.5015164580621507D-01,  6.6126583783999227D-01), (  7.4964424066303348D-01,  6.6184100238708687D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4862810768624533D-01,  6.6299016311112147D-01), &
(  7.4811938045040360D-01,  6.6356415861203977D-01), (  7.4761021311520515D-01,  6.6413776375526001D-01), &
(  7.4710060598018013D-01,  6.6471097820334479D-01), (  7.4659055934511731D-01,  6.6528380161908718D-01), &
(  7.4608007351006378D-01,  6.6585623366550972D-01), (  7.4556914877532543D-01,  6.6642827400586535D-01), &
(  7.4505778544146595D-01,  6.6699992230363747D-01), (  7.4454598380930737D-01,  6.6757117822254031D-01), &
(  7.4403374417992929D-01,  6.6814204142651845D-01), (  7.4352106685466923D-01,  6.6871251157974809D-01), &
(  7.4300795213512172D-01,  6.6928258834663601D-01), (  7.4249440032313929D-01,  6.6985227139182102D-01), &
(  7.4198041172083107D-01,  6.7042156038017309D-01), (  7.4146598663056329D-01,  6.7099045497679422D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.4043582819689802D-01,  6.7212705965641173D-01), &
(  7.3992009545951620D-01,  6.7269476907077286D-01), (  7.3940392744620576D-01,  6.7326208275613297D-01), &
(  7.3888732446061511D-01,  6.7382900037875604D-01), (  7.3837028680664862D-01,  6.7439552160513905D-01), &
(  7.3785281478846598D-01,  6.7496164610201204D-01), (  7.3733490871048291D-01,  6.7552737353633852D-01), &
(  7.3681656887736979D-01,  6.7609270357531592D-01), (  7.3629779559405306D-01,  6.7665763588637495D-01), &
(  7.3577858916571359D-01,  6.7722217013718033D-01), (  7.3525894989778684D-01,  6.7778630599563150D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  7.3421837406618828D-01,  6.7891338120823841D-01), &
(  7.3369743811466037D-01,  6.7947631989936497D-01), (  7.3317607054783274D-01,  6.8003885887207893D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.3213204179536140D-01,  6.8116273633879543D-01), &
(  7.3160938122389263D-01,  6.8172407417164971D-01), (  7.3108629026547423D-01,  6.8228501096379557D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.3003881841892615D-01,  6.8340568010625868D-01), &
(  7.2951443814699701D-01,  6.8396541179731551D-01), (  7.2898962872051931D-01,  6.8452474112914230D-01), &
(  7.2846439044822520D-01,  6.8508366777270036D-01), (  7.2793872363909862D-01,  6.8564219139918747D-01), &
(  7.2741262860237577D-01,  6.8620031168003859D-01), (  7.2688610564754486D-01,  6.8675802828692589D-01), &
(  7.2635915508434601D-01,  6.8731534089175905D-01), (  7.2583177722277037D-01,  6.8787224916668555D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  7.2477574084571128D-01,  6.8898485141659704D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.2371799900132339D-01,  6.9009583241859995D-01), &
(  7.2318848930652746D-01,  6.9065071413453460D-01), (  7.2265855417857572D-01,  6.9120518955844845D-01), &
(  7.2212819392921535D-01,  6.9175925836415775D-01), (  7.2159740887044377D-01,  6.9231292022571822D-01), &
(  7.2106619931450811D-01,  6.9286617481742463D-01), (  7.2053456557390527D-01,  6.9341902181381176D-01), &
(  7.2000250796138165D-01,  6.9397146088965389D-01), (  7.1947002678993299D-01,  6.9452349171996552D-01), &
(  7.1893712237280449D-01,  6.9507511398000088D-01), (  7.1840379502348983D-01,  6.9562632734525487D-01)/
data (mpuu1(i), i =  5101,  5200) / &
(  7.1787004505573171D-01,  6.9617713149146299D-01), (  7.1733587278352173D-01,  6.9672752609460109D-01), &
(  7.1680127852109954D-01,  6.9727751083088652D-01), (  7.1626626258295323D-01,  6.9782708537677729D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  7.1519496693868012D-01,  6.9892500260441415D-01), &
(  7.1465868786276909D-01,  6.9947334464028377D-01), (  7.1412198837156482D-01,  7.0002127519400625D-01), &
(  7.1358486878079352D-01,  7.0056879394324834D-01), (  7.1304732940642923D-01,  7.0111590056591866D-01), &
(  7.1250937056469232D-01,  7.0166259474016845D-01), (  7.1197099257205010D-01,  7.0220887614439187D-01), &
(  7.1143219574521643D-01,  7.0275474445722530D-01), (  7.1089298040115168D-01,  7.0330019935754873D-01), &
(  7.1035334685706242D-01,  7.0384524052448494D-01), (  7.0981329543040084D-01,  7.0438986763740041D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  7.0873194020040065D-01,  7.0547787841985210D-01), &
(  7.0819063703319540D-01,  7.0602126144933974D-01), (  7.0764891725568435D-01,  7.0656422914470951D-01), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  7.0656422914470962D-01,  7.0764891725568435D-01), &
(  7.0602126144933985D-01,  7.0819063703319529D-01), (  7.0547787841985221D-01,  7.0873194020040065D-01), &
(  7.0493408037590499D-01,  7.0927282643886558D-01), (  7.0438986763740052D-01,  7.0981329543040084D-01), &
(  7.0384524052448505D-01,  7.1035334685706231D-01), (  7.0330019935754873D-01,  7.1089298040115168D-01), &
(  7.0275474445722541D-01,  7.1143219574521632D-01), (  7.0220887614439187D-01,  7.1197099257204999D-01), &
(  7.0166259474016857D-01,  7.1250937056469232D-01), (  7.0111590056591877D-01,  7.1304732940642923D-01), &
(  7.0056879394324845D-01,  7.1358486878079352D-01), (  7.0002127519400636D-01,  7.1412198837156471D-01), &
(  6.9947334464028388D-01,  7.1465868786276898D-01), (  6.9892500260441426D-01,  7.1519496693868012D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.9782708537677740D-01,  7.1626626258295301D-01), &
(  6.9727751083088663D-01,  7.1680127852109943D-01), (  6.9672752609460120D-01,  7.1733587278352162D-01), &
(  6.9617713149146310D-01,  7.1787004505573160D-01), (  6.9562632734525498D-01,  7.1840379502348972D-01), &
(  6.9507511398000088D-01,  7.1893712237280438D-01), (  6.9452349171996564D-01,  7.1947002678993299D-01), &
(  6.9397146088965400D-01,  7.2000250796138165D-01), (  6.9341902181381188D-01,  7.2053456557390527D-01), &
(  6.9286617481742474D-01,  7.2106619931450799D-01), (  6.9231292022571833D-01,  7.2159740887044366D-01), &
(  6.9175925836415786D-01,  7.2212819392921523D-01), (  6.9120518955844856D-01,  7.2265855417857561D-01), &
(  6.9065071413453472D-01,  7.2318848930652724D-01), (  6.9009583241860006D-01,  7.2371799900132339D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.8898485141659715D-01,  7.2477574084571117D-01), &
(  6.8842875278409055D-01,  7.2530397237306066D-01), (  6.8787224916668555D-01,  7.2583177722277026D-01), &
(  6.8731534089175916D-01,  7.2635915508434590D-01), (  6.8675802828692600D-01,  7.2688610564754486D-01), &
(  6.8620031168003870D-01,  7.2741262860237565D-01), (  6.8564219139918758D-01,  7.2793872363909862D-01), &
(  6.8508366777270047D-01,  7.2846439044822520D-01), (  6.8452474112914241D-01,  7.2898962872051931D-01), &
(  6.8396541179731551D-01,  7.2951443814699690D-01), (  6.8340568010625879D-01,  7.3003881841892615D-01), &
(  6.8284554638524808D-01,  7.3056276922782759D-01), (  6.8228501096379568D-01,  7.3108629026547423D-01), &
(  6.8172407417164982D-01,  7.3160938122389252D-01), (  6.8116273633879543D-01,  7.3213204179536129D-01), &
(  6.8060099779545313D-01,  7.3265427167241270D-01), (  6.8003885887207904D-01,  7.3317607054783274D-01), &
(  6.7947631989936508D-01,  7.3369743811466026D-01), (  6.7891338120823852D-01,  7.3421837406618817D-01), &
(  6.7835004312986158D-01,  7.3473887809596339D-01), (  6.7778630599563161D-01,  7.3525894989778684D-01), &
(  6.7722217013718045D-01,  7.3577858916571348D-01), (  6.7665763588637495D-01,  7.3629779559405306D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.7552737353633863D-01,  7.3733490871048279D-01), &
(  6.7496164610201204D-01,  7.3785281478846598D-01), (  6.7439552160513905D-01,  7.3837028680664851D-01), &
(  6.7382900037875615D-01,  7.3888732446061511D-01), (  6.7326208275613308D-01,  7.3940392744620564D-01), &
(  6.7269476907077297D-01,  7.3992009545951609D-01), (  6.7212705965641184D-01,  7.4043582819689802D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.7099045497679433D-01,  7.4146598663056329D-01), &
(  6.7042156038017320D-01,  7.4198041172083096D-01), (  6.6985227139182113D-01,  7.4249440032313907D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.6871251157974809D-01,  7.4352106685466901D-01), &
(  6.6814204142651856D-01,  7.4403374417992918D-01), (  6.6757117822254042D-01,  7.4454598380930725D-01), &
(  6.6699992230363758D-01,  7.4505778544146595D-01), (  6.6642827400586535D-01,  7.4556914877532532D-01), &
(  6.6585623366550972D-01,  7.4608007351006367D-01), (  6.6528380161908718D-01,  7.4659055934511720D-01), &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.6413776375526001D-01,  7.4761021311520515D-01), &
(  6.6356415861203988D-01,  7.4811938045040349D-01), (  6.6299016311112147D-01,  7.4862810768624533D-01)/
data (mpuu1(i), i =  5201,  5300) / &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.6184100238708687D-01,  7.4964424066303348D-01), &
(  6.6126583783999227D-01,  7.5015164580621496D-01), (  6.6069028428724230D-01,  7.5065860965451059D-01), &
(  6.6011434206742059D-01,  7.5116513190968637D-01), (  6.5953801151933877D-01,  7.5167121227376843D-01), &
(  6.5896129298203732D-01,  7.5217685044904270D-01), (  6.5838418679478516D-01,  7.5268204613805523D-01), &
(  6.5780669329707875D-01,  7.5318679904361241D-01), (  6.5722881282864265D-01,  7.5369110886878121D-01), &
(  6.5665054572942905D-01,  7.5419497531688917D-01), (  6.5607189233961771D-01,  7.5469839809152439D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  6.5491342805005615D-01,  7.5570391143603577D-01), &
(  6.5433361783180055D-01,  7.5620600141439454D-01), (  6.5375342268593617D-01,  7.5670764653624567D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.5259187897686255D-01,  7.5770960103026808D-01), &
(  6.5201053109695961D-01,  7.5820990981301528D-01), (  6.5142879965605993D-01,  7.5870977256040728D-01), &
(  6.5084668499638099D-01,  7.5920918897838796D-01), (  6.5026418746036596D-01,  7.5970815877316333D-01), &
(  6.4968130739068330D-01,  7.6020668165120231D-01), (  6.4909804513022606D-01,  7.6070475731923681D-01), &
(  6.4851440102211255D-01,  7.6120238548426178D-01), (  6.4793037540968546D-01,  7.6169956585353527D-01), &
(  6.4734596863651217D-01,  7.6219629813457890D-01), (  6.4676118104638403D-01,  7.6269258203517787D-01), &
(  6.4617601298331639D-01,  7.6318841726338127D-01), (  6.4559046479154880D-01,  7.6368380352750176D-01), &
(  6.4500453681554404D-01,  7.6417874053611667D-01), (  6.4441822939998850D-01,  7.6467322799806703D-01), &
(  6.4383154288979150D-01,  7.6516726562245885D-01), (  6.4324447763008585D-01,  7.6566085311866239D-01), &
(  6.4265703396622698D-01,  7.6615399019631281D-01), (  6.4206921224379265D-01,  7.6664667656531038D-01), &
(  6.4148101280858316D-01,  7.6713891193582029D-01), (  6.4089243600662138D-01,  7.6763069601827327D-01), &
(  6.4030348218415178D-01,  7.6812202852336531D-01), (  6.3971415168764056D-01,  7.6861290916205827D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  6.3853436205946679D-01,  7.6959331368542294D-01), &
(  6.3794390362184417D-01,  7.7008283699334790D-01), (  6.3735306989825913D-01,  7.7057190728138070D-01), &
(  6.3676186123628431D-01,  7.7106052426181371D-01), (  6.3617027798371228D-01,  7.7154868764720619D-01), &
(  6.3557832048855623D-01,  7.7203639715038441D-01), (  6.3498598909904957D-01,  7.7252365248444121D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  6.3380020603101728D-01,  7.7349679949889905D-01), &
(  6.3320675505005730D-01,  7.7398269060682279D-01), (  6.3261293156987752D-01,  7.7446812640067075D-01), &
(  6.3201873593980906D-01,  7.7495310659487382D-01), (  6.3142416850940186D-01,  7.7543763090413043D-01), &
(  6.3082922962842458D-01,  7.7592169904340758D-01), (  6.3023391964686448D-01,  7.7640531072794028D-01), &
(  6.2963823891492710D-01,  7.7688846567323244D-01), (  6.2904218778303611D-01,  7.7737116359505620D-01), &
(  6.2844576660183271D-01,  7.7785340420945304D-01), (  6.2784897572217657D-01,  7.7833518723273309D-01), &
(  6.2725181549514419D-01,  7.7881651238147587D-01), (  6.2665428627202946D-01,  7.7929737937253030D-01), &
(  6.2605638840434363D-01,  7.7977778792301444D-01), (  6.2545812224381436D-01,  7.8025773775031659D-01), &
(  6.2485948814238645D-01,  7.8073722857209438D-01), (  6.2426048645222076D-01,  7.8121626010627598D-01), &
(  6.2366111752569464D-01,  7.8169483207105939D-01), (  6.2306138171540137D-01,  7.8217294418491290D-01), &
(  6.2246127937415008D-01,  7.8265059616657562D-01), (  6.2186081085496536D-01,  7.8312778773505731D-01), &
(  6.2125997651108766D-01,  7.8360451860963820D-01), (  6.2065877669597225D-01,  7.8408078850986995D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  6.1945528206692402D-01,  7.8503194426684797D-01), &
(  6.1885298796097643D-01,  7.8550682956405393D-01), (  6.1825032979976025D-01,  7.8598125276783004D-01), &
(  6.1764730793780398D-01,  7.8645521359908577D-01), (  6.1704392272984987D-01,  7.8692871177900170D-01), &
(  6.1644017453085365D-01,  7.8740174702903132D-01), (  6.1583606369598509D-01,  7.8787431907090011D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  6.1462675554037505D-01,  7.8881807241842017D-01), &
(  6.1402155893103849D-01,  7.8928925316888554D-01), (  6.1341600110863870D-01,  7.8975996960081907D-01), &
(  6.1281008242940982D-01,  7.9023022143731003D-01), (  6.1220380324979806D-01,  7.9070000840172161D-01), &
(  6.1159716392646202D-01,  7.9116933021769009D-01), (  6.1099016481627177D-01,  7.9163818660912577D-01), &
(  6.1038280627630948D-01,  7.9210657730021228D-01), (  6.0977508866386843D-01,  7.9257450201540758D-01), &
(  6.0916701233645332D-01,  7.9304196047944364D-01), (  6.0855857765177945D-01,  7.9350895241732655D-01), &
(  6.0794978496777374D-01,  7.9397547755433706D-01), (  6.0734063464257293D-01,  7.9444153561603059D-01), &
(  6.0673112703452459D-01,  7.9490712632823701D-01), (  6.0612126250218623D-01,  7.9537224941706119D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  6.0490046409991993D-01,  7.9630109163035900D-01), &
(  6.0428953094815607D-01,  7.9676481020841872D-01), (  6.0367824230843048D-01,  7.9722806007026870D-01)/
data (mpuu1(i), i =  5301,  5400) / &
(  6.0306659854034828D-01,  7.9769084094339104D-01), (  6.0245460000372386D-01,  7.9815315255554375D-01), &
(  6.0184224705858014D-01,  7.9861499463476082D-01), (  6.0122954006514862D-01,  7.9907636690935235D-01), &
(  6.0061647938386897D-01,  7.9953726910790501D-01), (  6.0000306537538906D-01,  7.9999770095928191D-01), &
(  5.9938929840056465D-01,  8.0045766219262271D-01), (  5.9877517882045883D-01,  8.0091715253734430D-01), &
(  5.9816070699634238D-01,  8.0137617172314013D-01), (  5.9754588328969327D-01,  8.0183471947998131D-01), &
(  5.9693070806219650D-01,  8.0229279553811561D-01), (  5.9631518167574382D-01,  8.0275039962806904D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.9508307687457007D-01,  8.0366419082692409D-01), &
(  5.9446649918466454D-01,  8.0412037739826570D-01), (  5.9384957178543363D-01,  8.0457609092630700D-01), &
(  5.9323229503979991D-01,  8.0503133114296355D-01), (  5.9261466931089124D-01,  8.0548609778042912D-01), &
(  5.9199669496204099D-01,  8.0594039057117628D-01), (  5.9137837235678770D-01,  8.0639420924795624D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.9014068383224894D-01,  8.0730042319201445D-01), &
(  5.8952131864106394D-01,  8.0775281792619025D-01), (  5.8890160664967584D-01,  8.0820473748019472D-01), &
(  5.8828154822264533D-01,  8.0865618158817498D-01), (  5.8766114372473677D-01,  8.0910714998455813D-01), &
(  5.8704039352091808D-01,  8.0955764240405115D-01), (  5.8641929797636061D-01,  8.1000765858164114D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  5.8517607232673052D-01,  8.1090626115245967D-01), &
(  5.8455394295301544D-01,  8.1135484701706373D-01), (  5.8393146970127630D-01,  8.1180295558251536D-01), &
(  5.8330865293769840D-01,  8.1225058658520388D-01), (  5.8268549302866846D-01,  8.1269773976179949D-01), &
(  5.8206199034077555D-01,  8.1314441484925348D-01), (  5.8143814524081028D-01,  8.1359061158479840D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  5.8018942927283179D-01,  8.1448156895049861D-01), &
(  5.7956455913940574D-01,  8.1492632905652651D-01), (  5.7893934806308189D-01,  8.1537060976239117D-01), &
(  5.7831379641165570D-01,  8.1581441080673378D-01), (  5.7768790455312291D-01,  8.1625773192847739D-01), &
(  5.7706167285567955D-01,  8.1670057286682773D-01), (  5.7643510168772183D-01,  8.1714293336127297D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.7518094241484519D-01,  8.1802621197781344D-01), &
(  5.7455335504771587D-01,  8.1846712958029866D-01), (  5.7392542968565086D-01,  8.1890756569965895D-01), &
(  5.7329716669804232D-01,  8.1934752007679690D-01), (  5.7266856645448128D-01,  8.1978699245289888D-01), &
(  5.7203962932475716D-01,  8.2022598256943469D-01), (  5.7141035567885734D-01,  8.2066449016815746D-01), &
(  5.7078074588696737D-01,  8.2110251499110465D-01), (  5.7015080031947041D-01,  8.2154005678059749D-01), &
(  5.6952051934694725D-01,  8.2197711527924144D-01), (  5.6888990334017597D-01,  8.2241369022992639D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.6762766770798634D-01,  8.2328538846040011D-01), &
(  5.6699604882510868D-01,  8.2372051122739132D-01), (  5.6636409639306395D-01,  8.2415514942082857D-01), &
(  5.6573181078361323D-01,  8.2458930278502529D-01), (  5.6509919236871409D-01,  8.2502297106458022D-01), &
(  5.6446624152051950D-01,  8.2545615400437744D-01), (  5.6383295861137828D-01,  8.2588885134958678D-01), &
(  5.6319934401383420D-01,  8.2632106284566342D-01), (  5.6256539810062656D-01,  8.2675278823834852D-01), &
(  5.6193112124468947D-01,  8.2718402727366902D-01), (  5.6129651381915158D-01,  8.2761477969793829D-01), &
(  5.6066157619733603D-01,  8.2804504525775569D-01), (  5.6002630875276049D-01,  8.2847482370000702D-01), &
(  5.5939071185913614D-01,  8.2890411477186476D-01), (  5.5875478589036842D-01,  8.2933291822078825D-01), &
(  5.5811853122055621D-01,  8.2976123379452305D-01), (  5.5748194822399166D-01,  8.3018906124110226D-01), &
(  5.5684503727516022D-01,  8.3061640030884620D-01), (  5.5620779874874005D-01,  8.3104325074636232D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  5.5493234046281048D-01,  8.3189548472657759D-01), &
(  5.5429412145362011D-01,  8.3232086776792968D-01), (  5.5365557636747931D-01,  8.3274576117635946D-01), &
(  5.5301670558002758D-01,  8.3317016470191319D-01), (  5.5237750946709618D-01,  8.3359407809492514D-01), &
(  5.5173798840470745D-01,  8.3401750110601802D-01), (  5.5109814276907554D-01,  8.3444043348610308D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.4981747928389102D-01,  8.3528482535833726D-01), &
(  5.4917666218771977D-01,  8.3570628435375249D-01), (  5.4853552202506750D-01,  8.3612725172469216D-01), &
(  5.4789405917310030D-01,  8.3654772722351189D-01), (  5.4725227400917409D-01,  8.3696771060285702D-01), &
(  5.4661016691083497D-01,  8.3738720161566182D-01), (  5.4596773825581768D-01,  8.3780620001515083D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.4468191778763464D-01,  8.3864271798852730D-01), &
(  5.4403852673088393D-01,  8.3906023707031263D-01), (  5.4339481563028491D-01,  8.3947726255457844D-01), &
(  5.4275078486451600D-01,  8.3989379419599941D-01), (  5.4210643481244403D-01,  8.4030983174954066D-01), &
(  5.4146176585312356D-01,  8.4072537497045796D-01), (  5.4081677836579678D-01,  8.4114042361429808D-01)/
data (mpuu1(i), i =  5401,  5500) / &
(  5.4017147272989297D-01,  8.4155497743689833D-01), (  5.3952584932502901D-01,  8.4196903619438768D-01), &
(  5.3887990853100842D-01,  8.4238259964318585D-01), (  5.3823365072782181D-01,  8.4279566754000412D-01), &
(  5.3758707629564551D-01,  8.4320823964184544D-01), (  5.3694018561484314D-01,  8.4362031570600404D-01), &
(  5.3629297906596318D-01,  8.4403189549006641D-01), (  5.3564545702974109D-01,  8.4444297875191066D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.3434946801913763D-01,  8.4526365474191822D-01), &
(  5.3370100180715296D-01,  8.4567324698729907D-01), (  5.3305222163261967D-01,  8.4608234174489683D-01), &
(  5.3240312787719801D-01,  8.4649093877405202D-01), (  5.3175372092273332D-01,  8.4689903783439724D-01), &
(  5.3110400115125511D-01,  8.4730663868585832D-01), (  5.3045396894497643D-01,  8.4771374108865427D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  5.2915296875779072D-01,  8.4852644959059265D-01), &
(  5.2850200154222848D-01,  8.4893205521163961D-01), (  5.2785072342255546D-01,  8.4933716142783067D-01), &
(  5.2719913478190139D-01,  8.4974176800085244D-01), (  5.2654723600357944D-01,  8.5014587469268521D-01), &
(  5.2589502747108485D-01,  8.5054948126560337D-01), (  5.2524250956809471D-01,  8.5095258748217573D-01), &
(  5.2458968267846895D-01,  8.5135519310526520D-01), (  5.2393654718624871D-01,  8.5175729789802901D-01), &
(  5.2328310347565643D-01,  8.5215890162391983D-01), (  5.2262935193109683D-01,  8.5256000404668397D-01), &
(  5.2197529293715439D-01,  8.5296060493036363D-01), (  5.2132092687859566D-01,  8.5336070403929543D-01), &
(  5.2066625414036727D-01,  8.5376030113811130D-01), (  5.2001127510759615D-01,  8.5415939599173873D-01), &
(  5.1935599016558964D-01,  8.5455798836540053D-01), (  5.1870039969983517D-01,  8.5495607802461482D-01), &
(  5.1804450409599945D-01,  8.5535366473519603D-01), (  5.1738830373992906D-01,  8.5575074826325381D-01), &
(  5.1673179901764998D-01,  8.5614732837519436D-01), (  5.1607499031536674D-01,  8.5654340483771996D-01), &
(  5.1541787801946315D-01,  8.5693897741782865D-01), (  5.1476046251650120D-01,  8.5733404588281559D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  5.1344472343654357D-01,  8.5812266953808602D-01), &
(  5.1278640063356307D-01,  8.5851622426444274D-01), (  5.1212777617155469D-01,  8.5890927394782390D-01), &
(  5.1146885043797052D-01,  8.5930181835700825D-01), (  5.1080962382043915D-01,  8.5969385726107261D-01), &
(  5.1015009670676681D-01,  8.6008539042939014D-01), (  5.0949026948493648D-01,  8.6047641763163207D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  5.0816971626961482D-01,  8.6125695321806206D-01), &
(  5.0750899105297098D-01,  8.6164646114308130D-01), (  5.0684796728186332D-01,  8.6203546218368721D-01), &
(  5.0618664534515545D-01,  8.6242395611104050D-01), (  5.0552502563188551D-01,  8.6281194269660033D-01), &
(  5.0486310853126759D-01,  8.6319942171212416D-01), (  5.0420089443269056D-01,  8.6358639292966799D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  5.0287557680008699D-01,  8.6435881106053403D-01), &
(  5.0221247404571090D-01,  8.6474425751946238D-01), (  5.0154907585267539D-01,  8.6512919527162369D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  5.0022139471184068D-01,  8.6589754375014882D-01), &
(  4.9955711254508189D-01,  8.6628095402451299D-01), (  4.9889253650174481D-01,  8.6666385468811102D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.9756250434931915D-01,  8.6742812628230692D-01), &
(  4.9689704902265469D-01,  8.6780949676330321D-01), (  4.9623130138425836D-01,  8.6819035673433120D-01), &
(  4.9556526182577254D-01,  8.6857070597134090D-01), (  4.9489893073901137D-01,  8.6895054425058238D-01), &
(  4.9423230851595978D-01,  8.6932987134860673D-01), (  4.9356539554877493D-01,  8.6970868704226556D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.9223069895148608D-01,  8.7046478332539756D-01), &
(  4.9156291610655012D-01,  8.7084206347007886D-01), (  4.9089484408781520D-01,  8.7121883132081090D-01), &
(  4.9022648328829116D-01,  8.7159508665595098D-01), (  4.8955783410115761D-01,  8.7197082925415770D-01), &
(  4.8888889691976323D-01,  8.7234605889439143D-01), (  4.8821967213762679D-01,  8.7272077535591430D-01), &
(  4.8755016014843611D-01,  8.7309497841828998D-01), (  4.8688036134604745D-01,  8.7346866786138488D-01), &
(  4.8621027612448658D-01,  8.7384184346536675D-01), (  4.8553990487794707D-01,  8.7421450501070619D-01), &
(  4.8486924800079112D-01,  8.7458665227817611D-01), (  4.8419830588754920D-01,  8.7495828504885154D-01), &
(  4.8352707893291880D-01,  8.7532940310411078D-01), (  4.8285556753176567D-01,  8.7570000622563460D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.8151169297018998D-01,  8.7643966679571361D-01), &
(  4.8083933060033396D-01,  8.7680872380914565D-01), (  4.8016668536508850D-01,  8.7717726501859594D-01), &
(  4.7949375766015306D-01,  8.7754529020726124D-01), (  4.7882054788139405D-01,  8.7791279915864173D-01), &
(  4.7814705642484312D-01,  8.7827979165654146D-01), (  4.7747328368669806D-01,  8.7864626748506813D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  4.7612489595124363D-01,  8.7937766827195318D-01), &
(  4.7545028174715587D-01,  8.7974259280004741D-01), (  4.7477538784791723D-01,  8.8010699979824036D-01)/
data (mpuu1(i), i =  5501,  5600) / &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.7342476255224153D-01,  8.8083426034774204D-01), &
(  4.7274903195034290D-01,  8.8119711347122198D-01), (  4.7207302324236866D-01,  8.8155944820914378D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  4.7072017309907171D-01,  8.8228256167600860D-01), &
(  4.7004333245959562D-01,  8.8264333997956279D-01), (  4.6936621530573763D-01,  8.8300359904678072D-01), &
(  4.6868882203582796D-01,  8.8336333866573158D-01), (  4.6801115304835983D-01,  8.8372255862478966D-01), &
(  4.6733320874198853D-01,  8.8408125871263499D-01), (  4.6665498951553097D-01,  8.8443943871825370D-01), &
(  4.6597649576796613D-01,  8.8479709843093779D-01), (  4.6529772789843465D-01,  8.8515423764028511D-01), &
(  4.6461868630623782D-01,  8.8551085613619995D-01), (  4.6393937139083846D-01,  8.8586695370889279D-01), &
(  4.6325978355186026D-01,  8.8622253014888064D-01), (  4.6257992318908681D-01,  8.8657758524698704D-01), &
(  4.6189979070246284D-01,  8.8693211879434208D-01), (  4.6121938649209243D-01,  8.8728613058238315D-01), &
(  4.6053871095824001D-01,  8.8763962040285393D-01), (  4.5985776450132959D-01,  8.8799258804780556D-01), &
(  4.5917654752194415D-01,  8.8834503330959635D-01), (  4.5849506042082622D-01,  8.8869695598089171D-01), &
(  4.5781330359887729D-01,  8.8904835585466446D-01), (  4.5713127745715698D-01,  8.8939923272419552D-01), &
(  4.5644898239688386D-01,  8.8974958638307289D-01), (  4.5576641881943475D-01,  8.9009941662519221D-01), &
(  4.5508358712634384D-01,  8.9044872324475788D-01), (  4.5440048771930375D-01,  8.9079750603628149D-01), &
(  4.5371712100016393D-01,  8.9114576479458318D-01), (  4.5303348737093158D-01,  8.9149349931479138D-01), &
(  4.5234958723377100D-01,  8.9184070939234272D-01), (  4.5166542099100254D-01,  8.9218739482298248D-01), &
(  4.5098098904510381D-01,  8.9253355540276469D-01), (  4.5029629179870873D-01,  8.9287919092805168D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.4892610301574321D-01,  8.9356888600213602D-01), &
(  4.4824061228522000D-01,  8.9391294514520325D-01), (  4.4755485786629301D-01,  8.9425647842231615D-01), &
(  4.4686884016237433D-01,  8.9459948563138258D-01), (  4.4618255957703012D-01,  8.9494196657062064D-01), &
(  4.4549601651398174D-01,  8.9528392103855758D-01), (  4.4480921137710500D-01,  8.9562534883403000D-01), &
(  4.4412214457042926D-01,  8.9596624975618511D-01), (  4.4343481649813843D-01,  8.9630662360447966D-01), &
(  4.4274722756457013D-01,  8.9664647017868015D-01), (  4.4205937817421476D-01,  8.9698578927886397D-01), &
(  4.4137126873171662D-01,  8.9732458070541832D-01), (  4.4068289964187302D-01,  8.9766284425904075D-01), &
(  4.3999427130963326D-01,  8.9800057974073988D-01), (  4.3930538414010006D-01,  8.9833778695183419D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  4.3792683491032286D-01,  8.9901061576903907D-01), &
(  4.3723717366104420D-01,  8.9934623697934146D-01), (  4.3654725519640125D-01,  8.9968132912742393D-01), &
(  4.3585707992225547D-01,  9.0001589201616028D-01), (  4.3516664824461937D-01,  9.0034992544873560D-01), &
(  4.3447596056965571D-01,  9.0068342922864686D-01), (  4.3378501730367852D-01,  9.0101640315970233D-01), &
(  4.3309381885315201D-01,  9.0134884704602203D-01), (  4.3240236562469014D-01,  9.0168076069203773D-01), &
(  4.3171065802505737D-01,  9.0201214390249307D-01), (  4.3101869646116708D-01,  9.0234299648244420D-01), &
(  4.3032648134008261D-01,  9.0267331823725883D-01), (  4.2963401306901650D-01,  9.0300310897261715D-01), &
(  4.2894129205532955D-01,  9.0333236849451182D-01), (  4.2824831870653191D-01,  9.0366109660924798D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  4.2686161663438649D-01,  9.0431695784402832D-01), &
(  4.2616788872679956D-01,  9.0464409057824624D-01), (  4.2547391011562391D-01,  9.0497069113365325D-01), &
(  4.2477968120910881D-01,  9.0529675931811882D-01), (  4.2408520241565167D-01,  9.0562229493982516D-01), &
(  4.2339047414379610D-01,  9.0594729780726846D-01), (  4.2269549680223295D-01,  9.0627176772925766D-01), &
(  4.2200027079979979D-01,  9.0659570451491533D-01), (  4.2130479654547970D-01,  9.0691910797367803D-01), &
(  4.2060907444840251D-01,  9.0724197791529582D-01), (  4.1991310491784373D-01,  9.0756431414983252D-01), &
(  4.1921688836322396D-01,  9.0788611648766615D-01), (  4.1852042519410970D-01,  9.0820738473948870D-01), &
(  4.1782371582021238D-01,  9.0852811871630612D-01), (  4.1712676065138787D-01,  9.0884831822943912D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  4.1573211456910542D-01,  9.0948711311150543D-01), &
(  4.1503442447608163D-01,  9.0980570810465222D-01), (  4.1433649022899921D-01,  9.1012376788254157D-01), &
(  4.1363831223843456D-01,  9.1044129225806714D-01), (  4.1293989091510802D-01,  9.1075828104443757D-01), &
(  4.1224122666988300D-01,  9.1107473405517625D-01), (  4.1154231991376528D-01,  9.1139065110412232D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  4.1014378051359035D-01,  9.1202087657356823D-01), &
(  4.0944414869225759D-01,  9.1233518462332275D-01), (  4.0874427600548152D-01,  9.1264895596979390D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  4.0734380968260797D-01,  9.1327488781486776D-01), &
(  4.0664321687036914D-01,  9.1358704794525081D-01), (  4.0594238484040251D-01,  9.1389867063591168D-01)/
data (mpuu1(i), i =  5601,  5700) / &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  4.0454000477655311D-01,  9.1452030296510445D-01), &
(  4.0383845756765413D-01,  9.1483031223794620D-01), (  4.0313667279099524D-01,  9.1513978333968526D-01), &
(  4.0243465085941854D-01,  9.1544871608826783D-01), (  4.0173239218590501D-01,  9.1575711030195672D-01), &
(  4.0102989718357579D-01,  9.1606496579933161D-01), (  4.0032716626569015D-01,  9.1637228239928914D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.9892099833698302D-01,  9.1698529818412289D-01), &
(  3.9821756215337362D-01,  9.1729099700837791D-01), (  3.9751389170863233D-01,  9.1759615621397295D-01), &
(  3.9680998741671042D-01,  9.1790077562139039D-01), (  3.9610584969169632D-01,  9.1820485505143090D-01), &
(  3.9540147894781630D-01,  9.1850839432521225D-01), (  3.9469687559943367D-01,  9.1881139326416994D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.9328697274729657D-01,  9.1941576942494696D-01), &
(  3.9258167407295153D-01,  9.1971714629122736D-01), (  3.9187614445292235D-01,  9.2001798211160657D-01), &
(  3.9117038430225398D-01,  9.2031827670911048D-01), (  3.9046439403612665D-01,  9.2061802990708386D-01), &
(  3.8975817406985641D-01,  9.2091724152918952D-01), (  3.8905172481889450D-01,  9.2121591139940873D-01), &
(  3.8834504669882630D-01,  9.2151403934204190D-01), (  3.8763814012537268D-01,  9.2181162518170812D-01), &
(  3.8693100551438869D-01,  9.2210866874334507D-01), (  3.8622364328186298D-01,  9.2240516985220999D-01), &
(  3.8551605384391902D-01,  9.2270112833387852D-01), (  3.8480823761681293D-01,  9.2299654401424625D-01), &
(  3.8410019501693504D-01,  9.2329141671952764D-01), (  3.8339192646080877D-01,  9.2358574627625656D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  3.8197471314656722D-01,  9.2417277525179120D-01), &
(  3.8126576922216249D-01,  9.2446547432526260D-01), (  3.8055660100892857D-01,  9.2475762955951391D-01), &
(  3.7984720892405111D-01,  9.2504924078267758D-01), (  3.7913759338484743D-01,  9.2534030782320631D-01), &
(  3.7842775480876556D-01,  9.2563083050987272D-01), (  3.7771769361338581D-01,  9.2592080867176996D-01), &
(  3.7700741021641831D-01,  9.2621024213831138D-01), (  3.7629690503570479D-01,  9.2649913073923051D-01), &
(  3.7558617848921733D-01,  9.2678747430458175D-01), (  3.7487523099505760D-01,  9.2707527266474010D-01), &
(  3.7416406297145793D-01,  9.2736252565040111D-01), (  3.7345267483678041D-01,  9.2764923309258118D-01), &
(  3.7274106700951581D-01,  9.2793539482261789D-01), (  3.7202923990828496D-01,  9.2822101067216944D-01), &
(  3.7131719395183760D-01,  9.2850608047321548D-01), (  3.7060492955905167D-01,  9.2879060405805702D-01), &
(  3.6989244714893421D-01,  9.2907458125931575D-01), (  3.6917974714062002D-01,  9.2935801190993550D-01), &
(  3.6846682995337232D-01,  9.2964089584318121D-01), (  3.6775369600658209D-01,  9.2992323289263956D-01), &
(  3.6704034571976724D-01,  9.3020502289221907D-01), (  3.6632677951257359D-01,  9.3048626567614967D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  3.6489900101626732D-01,  9.3104710893559528D-01), &
(  3.6418478956707984D-01,  9.3132670908118054D-01), (  3.6347036387736387D-01,  9.3160576135125783D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  3.6204087145758435D-01,  9.3216222160857432D-01), &
(  3.6132580556845434D-01,  9.3243962926846236D-01), (  3.6061052712066227D-01,  9.3271648839814025D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.5917933423233656D-01,  9.3326856041571205D-01), &
(  3.5846342063373654D-01,  9.3354377297883617D-01), (  3.5774729616034195D-01,  9.3381843636221096D-01), &
(  3.5703096123343003D-01,  9.3409255040425887D-01), (  3.5631441627440236D-01,  9.3436611494372590D-01), &
(  3.5559766170478396D-01,  9.3463912981968078D-01), (  3.5488069794622279D-01,  9.3491159487151609D-01), &
(  3.5416352542049051D-01,  9.3518350993894750D-01), (  3.5344614454948087D-01,  9.3545487486201462D-01), &
(  3.5272855575521073D-01,  9.3572568948108037D-01), (  3.5201075945981924D-01,  9.3599595363683130D-01), &
(  3.5129275608556715D-01,  9.3626566717027826D-01), (  3.5057454605483751D-01,  9.3653482992275550D-01), &
(  3.4985612979013503D-01,  9.3680344173592156D-01), (  3.4913750771408503D-01,  9.3707150245175919D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.4769964781905144D-01,  9.3760596996099999D-01), &
(  3.4698041084592368D-01,  9.3787237643998989D-01), (  3.4626096975316012D-01,  9.3813823119282436D-01), &
(  3.4554132496398915D-01,  9.3840353406310806D-01), (  3.4482147690175929D-01,  9.3866828489477017D-01), &
(  3.4410142598993898D-01,  9.3893248353206449D-01), (  3.4338117265211510D-01,  9.3919612981956990D-01), &
(  3.4266071731199438D-01,  9.3945922360218992D-01), (  3.4194006039340230D-01,  9.3972176472515334D-01), &
(  3.4121920232028241D-01,  9.3998375303401394D-01), (  3.4049814351669710D-01,  9.4024518837465088D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  3.3905542541496964D-01,  9.4076639953639607D-01), &
(  3.3833376696554129D-01,  9.4102617505088926D-01), (  3.3761190948307468D-01,  9.4128539698392866D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  3.3616759911774463D-01,  9.4180217949599765D-01), &
(  3.3544514708453166D-01,  9.4205973977101731D-01), (  3.3472249771758122D-01,  9.4231674585656378D-01)/
data (mpuu1(i), i =  5701,  5800) / &
(  3.3399965144200949D-01,  9.4257319760144687D-01), (  3.3327660868304793D-01,  9.4282909485480271D-01), &
(  3.3255336986604417D-01,  9.4308443746609349D-01), (  3.3182993541646122D-01,  9.4333922528510772D-01), &
(  3.3110630575987643D-01,  9.4359345816196039D-01), (  3.3038248132198289D-01,  9.4384713594709269D-01), &
(  3.2965846252858755D-01,  9.4410025849127266D-01), (  3.2893424980561220D-01,  9.4435282564559475D-01), &
(  3.2820984357909266D-01,  9.4460483726148026D-01), (  3.2748524427517806D-01,  9.4485629319067721D-01), &
(  3.2676045232013173D-01,  9.4510719328526061D-01), (  3.2603546814033035D-01,  9.4535753739763229D-01), &
(  3.2531029216226298D-01,  9.4560732538052128D-01), (  3.2458492481253209D-01,  9.4585655708698391D-01), &
(  3.2385936651785296D-01,  9.4610523237040334D-01), (  3.2313361770505233D-01,  9.4635335108449059D-01), &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  3.2168155023295664D-01,  9.4684791822114800D-01), &
(  3.2095523242787521D-01,  9.4709436635277722D-01), (  3.2022872581310002D-01,  9.4734025733319194D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  3.1877514786411848D-01,  9.4783036726210101D-01), &
(  3.1804807738501506D-01,  9.4807458592227623D-01), (  3.1732081980642179D-01,  9.4831824685459909D-01), &
(  3.1659337555616585D-01,  9.4856134991573027D-01), (  3.1586574506218407D-01,  9.4880389496265838D-01), &
(  3.1513792875252244D-01,  9.4904588185270056D-01), (  3.1440992705533682D-01,  9.4928731044350201D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  3.1295336921156020D-01,  9.4976849215960668D-01), &
(  3.1222481392182505D-01,  9.5000824500184300D-01), (  3.1149607495827597D-01,  9.5024743897870523D-01), &
(  3.1076715274961147D-01,  9.5048607394948170D-01), (  3.1003804772463800D-01,  9.5072414977378961D-01), &
(  3.0930876031226873D-01,  9.5096166631157508D-01), (  3.0857929094152503D-01,  9.5119862342311323D-01), &
(  3.0784964004153498D-01,  9.5143502096900834D-01), (  3.0711980804153310D-01,  9.5167085881019386D-01), &
(  3.0638979537086108D-01,  9.5190613680793223D-01), (  3.0565960245896623D-01,  9.5214085482381583D-01), &
(  3.0492922973540237D-01,  9.5237501271976588D-01), (  3.0419867762982927D-01,  9.5260861035803324D-01), &
(  3.0346794657201137D-01,  9.5284164760119872D-01), (  3.0273703699181914D-01,  9.5307412431217220D-01), &
(  3.0200594931922820D-01,  9.5330604035419375D-01), (  3.0127468398431800D-01,  9.5353739559083328D-01), &
(  3.0054324141727340D-01,  9.5376818988599033D-01), (  2.9981162204838346D-01,  9.5399842310389449D-01), &
(  2.9907982630804048D-01,  9.5422809510910567D-01), (  2.9834785462674157D-01,  9.5445720576651349D-01), &
(  2.9761570743508631D-01,  9.5468575494133834D-01), (  2.9688338516377827D-01,  9.5491374249913052D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.9541821710553207D-01,  9.5536803222747024D-01), &
(  2.9468537218051433D-01,  9.5559433413077111D-01), (  2.9395235389968477D-01,  9.5582007388254542D-01), &
(  2.9321916269425868D-01,  9.5604525134999641D-01), (  2.9248579899555383D-01,  9.5626986640065814D-01), &
(  2.9175226323498937D-01,  9.5649391890239510D-01), (  2.9101855584408509D-01,  9.5671740872340305D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  2.8955062789784314D-01,  9.5716269979767010D-01), &
(  2.8881640820604948D-01,  9.5738450078897586D-01), (  2.8808201861100430D-01,  9.5760573857564624D-01), &
(  2.8734745954472957D-01,  9.5782641302753291D-01), (  2.8661273143934779D-01,  9.5804652401481860D-01), &
(  2.8587783472708073D-01,  9.5826607140801767D-01), (  2.8514276984024872D-01,  9.5848505507797610D-01), &
(  2.8440753721127182D-01,  9.5870347489587160D-01), (  2.8367213727266855D-01,  9.5892133073321317D-01), &
(  2.8293657045705539D-01,  9.5913862246184189D-01), (  2.8220083719714750D-01,  9.5935534995393079D-01), &
(  2.8146493792575805D-01,  9.5957151308198452D-01), (  2.8072887307579719D-01,  9.5978711171883990D-01), &
(  2.7999264308027338D-01,  9.6000214573766585D-01), (  2.7925624837229124D-01,  9.6021661501196343D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.7778296655185775D-01,  9.6064385882263847D-01), &
(  2.7704608030609995D-01,  9.6085663310767966D-01), (  2.7630903108127103D-01,  9.6106884214551935D-01), &
(  2.7557181931095825D-01,  9.6128048581132064D-01), (  2.7483444542884394D-01,  9.6149156398057900D-01), &
(  2.7409690986870633D-01,  9.6170207652912254D-01), (  2.7335921306441879D-01,  9.6191202333311210D-01), &
(  2.7262135544994898D-01,  9.6212140426904158D-01), (  2.7188333745935989D-01,  9.6233021921373740D-01), &
(  2.7114515952680807D-01,  9.6253846804435916D-01), (  2.7040682208654482D-01,  9.6274615063839941D-01), &
(  2.6966832557291520D-01,  9.6295326687368388D-01), (  2.6892967042035731D-01,  9.6315981662837136D-01), &
(  2.6819085706340312D-01,  9.6336579978095405D-01), (  2.6745188593667774D-01,  9.6357121621025721D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.6597347211287553D-01,  9.6398034841599411D-01), &
(  2.6523403028551190D-01,  9.6418406395174572D-01), (  2.6449443242780163D-01,  9.6438721228285429D-01), &
(  2.6375467897483151D-01,  9.6458979328981265D-01), (  2.6301477036177906D-01,  9.6479180685344790D-01), &
(  2.6227470702391359D-01,  9.6499325285492032D-01), (  2.6153448939659563D-01,  9.6519413117572472D-01)/
data (mpuu1(i), i =  5801,  5900) / &
(  2.6079411791527557D-01,  9.6539444169768940D-01), (  2.6005359301549513D-01,  9.6559418430297683D-01), &
(  2.5931291513288635D-01,  9.6579335887408368D-01), (  2.5857208470317039D-01,  9.6599196529384057D-01), &
(  2.5783110216215893D-01,  9.6619000344541262D-01), (  2.5708996794575323D-01,  9.6638747321229879D-01), &
(  2.5634868248994291D-01,  9.6658437447833312D-01), (  2.5560724623080755D-01,  9.6678070712768327D-01), &
(  2.5486565960451463D-01,  9.6697647104485207D-01), (  2.5412392304732062D-01,  9.6717166611467664D-01), &
(  2.5338203699557027D-01,  9.6736629222232851D-01), (  2.5264000188569558D-01,  9.6756034925331436D-01), &
(  2.5189781815421691D-01,  9.6775383709347551D-01), (  2.5115548623774203D-01,  9.6794675562898780D-01), &
(  2.5041300657296528D-01,  9.6813910474636244D-01), (  2.4967037959666852D-01,  9.6833088433244519D-01), &
(  2.4892760574572026D-01,  9.6852209427441727D-01), (  2.4818468545707478D-01,  9.6871273445979478D-01), &
(  2.4744161916777344D-01,  9.6890280477642887D-01), (  2.4669840731494250D-01,  9.6909230511250610D-01), &
(  2.4595505033579459D-01,  9.6928123535654853D-01), (  2.4521154866762768D-01,  9.6946959539741295D-01), &
(  2.4446790274782421D-01,  9.6965738512429245D-01), (  2.4372411301385213D-01,  9.6984460442671483D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  2.4223610385369604D-01,  9.7021733131797916D-01), &
(  2.4149188530286927D-01,  9.7040283868755550D-01), (  2.4074752468858851D-01,  9.7058777519414363D-01), &
(  2.4000302244874150D-01,  9.7077214072895035D-01), (  2.3925837902130012D-01,  9.7095593518351797D-01), &
(  2.3851359484431850D-01,  9.7113915844972509D-01), (  2.3776867035593419D-01,  9.7132181041978616D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  2.3627840219791962D-01,  9.7168540004200854D-01), &
(  2.3553305940497546D-01,  9.7186633748027940D-01), (  2.3478757805400105D-01,  9.7204670319462338D-01), &
(  2.3404195858354346D-01,  9.7222649707893627D-01), (  2.3329620143223156D-01,  9.7240571902744977D-01), &
(  2.3255030703877533D-01,  9.7258436893473221D-01), (  2.3180427584196478D-01,  9.7276244669568857D-01), &
(  2.3105810828067125D-01,  9.7293995220556007D-01), (  2.3031180479384553D-01,  9.7311688535992513D-01), &
(  2.2956536582051887D-01,  9.7329324605469825D-01), (  2.2881879179980236D-01,  9.7346903418613095D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  2.2732524037303883D-01,  9.7381889234566610D-01), &
(  2.2657826384561011D-01,  9.7399296216795583D-01), (  2.2583115402802620D-01,  9.7416645901528032D-01), &
(  2.2508391135979278D-01,  9.7433938278557586D-01), (  2.2433653628049369D-01,  9.7451173337711572D-01), &
(  2.2358902922978999D-01,  9.7468351068851067D-01), (  2.2284139064742128D-01,  9.7485471461870843D-01), &
(  2.2209362097320359D-01,  9.7502534506699412D-01), (  2.2134572064703081D-01,  9.7519540193299037D-01), &
(  2.2059769010887365D-01,  9.7536488511665687D-01), (  2.1984952979877875D-01,  9.7553379451829136D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  2.1835282162334643D-01,  9.7586989157834103D-01), &
(  2.1760427463848367D-01,  9.7603707903903902D-01), (  2.1685559964263257D-01,  9.7620369232227056D-01), &
(  2.1610679707621960D-01,  9.7636973133002114D-01), (  2.1535786737974555D-01,  9.7653519596461447D-01), &
(  2.1460881099378692D-01,  9.7670008612871184D-01), (  2.1385962835899383D-01,  9.7686440172531264D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  2.1236088610587855D-01,  9.7719130882971228D-01), &
(  2.1161132736922761D-01,  9.7735390014519996D-01), (  2.1086164414708483D-01,  9.7751591650856928D-01), &
(  2.1011183688046972D-01,  9.7767735782450993D-01), (  2.0936190601047419D-01,  9.7783822399805043D-01), &
(  2.0861185197826343D-01,  9.7799851493455714D-01), (  2.0786167522507515D-01,  9.7815823053973505D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  2.0636095532107568D-01,  9.7847593538061683D-01), &
(  2.0561041305309932D-01,  9.7863392442942310D-01), (  2.0485974982981442D-01,  9.7879133777310567D-01), &
(  2.0410896609281701D-01,  9.7894817531906220D-01), (  2.0335806228377337D-01,  9.7910443697502925D-01), &
(  2.0260703884442111D-01,  9.7926012264908202D-01), (  2.0185589621656813D-01,  9.7941523224963478D-01), &
(  2.0110463484209193D-01,  9.7956976568544052D-01), (  2.0035325516294039D-01,  9.7972372286559117D-01), &
(  1.9960175762113105D-01,  9.7987710369951764D-01), (  1.9885014265875012D-01,  9.8002990809699009D-01), &
(  1.9809841071795373D-01,  9.8018213596811732D-01), (  1.9734656224096600D-01,  9.8033378722334796D-01), &
(  1.9659459767008022D-01,  9.8048486177346938D-01), (  1.9584251744765799D-01,  9.8063535952960812D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.9433801181798860D-01,  9.8093462430614164D-01), &
(  1.9358558729580372D-01,  9.8108339115048659D-01), (  1.9283304889220526D-01,  9.8123158084874973D-01), &
(  1.9208039704989238D-01,  9.8137919331375456D-01), (  1.9132763221163099D-01,  9.8152622845866466D-01), &
(  1.9057475482025277D-01,  9.8167268619698311D-01), (  1.8982176531865658D-01,  9.8181856644255250D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.8831545175673212D-01,  9.8210859411251361D-01), &
(  1.8756212858252974D-01,  9.8225274136628937D-01), (  1.8680869507035933D-01,  9.8239631078608469D-01)/
data (mpuu1(i), i =  5901,  6000) / &
(  1.8605515166344661D-01,  9.8253930228744124D-01), (  1.8530149880508201D-01,  9.8268171578624086D-01), &
(  1.8454773693861964D-01,  9.8282355119870524D-01), (  1.8379386650747839D-01,  9.8296480844139644D-01), &
(  1.8303988795514103D-01,  9.8310548743121629D-01), (  1.8228580172515332D-01,  9.8324558808540707D-01), &
(  1.8153160826112513D-01,  9.8338511032155118D-01), (  1.8077730800672867D-01,  9.8352405405757126D-01), &
(  1.8002290140569951D-01,  9.8366241921173025D-01), (  1.7926838890183588D-01,  9.8380020570263149D-01), &
(  1.7851377093899756D-01,  9.8393741344921892D-01), (  1.7775904796110714D-01,  9.8407404237077645D-01), &
(  1.7700422041214886D-01,  9.8421009238692903D-01), (  1.7624928873616794D-01,  9.8434556341764190D-01), &
(  1.7549425337727137D-01,  9.8448045538322093D-01), (  1.7473911477962731D-01,  9.8461476820431260D-01), &
(  1.7398387338746385D-01,  9.8474850180190421D-01), (  1.7322852964507049D-01,  9.8488165609732370D-01), &
(  1.7247308399679603D-01,  9.8501423101223984D-01), (  1.7171753688704997D-01,  9.8514622646866223D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.7020614006107812D-01,  9.8540847869576842D-01), &
(  1.6945029123396793D-01,  9.8553873531217606D-01), (  1.6869434272361744D-01,  9.8566841216153755D-01), &
(  1.6793829497473120D-01,  9.8579750916756737D-01), (  1.6718214843207288D-01,  9.8592602625432113D-01), &
(  1.6642590354046422D-01,  9.8605396334619544D-01), (  1.6566956074478414D-01,  9.8618132036792827D-01), &
(  1.6491312048997006D-01,  9.8630809724459867D-01), (  1.6415658322101589D-01,  9.8643429390162707D-01), &
(  1.6339994938297323D-01,  9.8655991026477541D-01), (  1.6264321942095045D-01,  9.8668494626014669D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.6112947290567878D-01,  9.8693327685367771D-01), &
(  1.6037245724292840D-01,  9.8705657130575097D-01), (  1.5961534723719309D-01,  9.8717928509787434D-01), &
(  1.5885814333386139D-01,  9.8730141815785843D-01), (  1.5810084597837709D-01,  9.8742297041385541D-01), &
(  1.5734345561623828D-01,  9.8754394179435923D-01), (  1.5658597269299859D-01,  9.8766433222820571D-01), &
(  1.5582839765426532D-01,  9.8778414164457218D-01), (  1.5507073094570051D-01,  9.8790336997297779D-01), &
(  1.5431297301302024D-01,  9.8802201714328353D-01), (  1.5355512430199350D-01,  9.8814008308569257D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  1.5203915632824616D-01,  9.8837447100934128D-01), &
(  1.5128103795733025D-01,  9.8849079285269659D-01), (  1.5052283059167737D-01,  9.8860653319238645D-01), &
(  1.4976453467732162D-01,  9.8872169196032378D-01), (  1.4900615066034847D-01,  9.8883626908876354D-01), &
(  1.4824767898689620D-01,  9.8895026451030299D-01), (  1.4748912010315365D-01,  9.8906367815788154D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  1.4597174248981235D-01,  9.8928875986462517D-01), &
(  1.4521292465284752D-01,  9.8940042779138038D-01), (  1.4445402139086044D-01,  9.8951151367935519D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  1.4293596037764270D-01,  9.8973193907791057D-01), &
(  1.4217680351944800D-01,  9.8984127845882053D-01), (  1.4141756302230313D-01,  9.8995003554160899D-01), &
(  1.4065823933284924D-01,  9.9005821026229712D-01), (  1.3989883289777735D-01,  9.9016580255724840D-01), &
(  1.3913934416382628D-01,  9.9027281236316911D-01), (  1.3837977357778389D-01,  9.9037923961710816D-01), &
(  1.3762012158648618D-01,  9.9048508425645698D-01), (  1.3686038863681643D-01,  9.9059034621895015D-01), &
(  1.3610057517570617D-01,  9.9069502544266463D-01), (  1.3534068165013433D-01,  9.9079912186602037D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  1.3382065619375469D-01,  9.9100556606704937D-01), &
(  1.3306052515713918D-01,  9.9110791372327678D-01), (  1.3230031584444468D-01,  9.9120967833625406D-01), &
(  1.3154002870288325D-01,  9.9131085984611544D-01), (  1.3077966417971179D-01,  9.9141145819333854D-01), &
(  1.3001922272223335D-01,  9.9151147331874390D-01), (  1.2925870477779627D-01,  9.9161090516349537D-01), &
(  1.2849811079379322D-01,  9.9170975366909953D-01), (  1.2773744121766228D-01,  9.9180801877740643D-01), &
(  1.2697669649688598D-01,  9.9190570043060933D-01), (  1.2621587707899040D-01,  9.9200279857124452D-01), &
(  1.2545498341154621D-01,  9.9209931314219180D-01), (  1.2469401594216775D-01,  9.9219524408667392D-01), &
(  1.2393297511851219D-01,  9.9229059134825737D-01), (  1.2317186138828064D-01,  9.9238535487085167D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  1.2164941699910553D-01,  9.9257313047642881D-01), &
(  1.2088808723577722D-01,  9.9266614244894802D-01), (  1.2012668635710157D-01,  9.9275857046155114D-01), &
(  1.1936521481099134D-01,  9.9285041445986510D-01), (  1.1860367304540084D-01,  9.9294167438986047D-01), &
(  1.1784206150832502D-01,  9.9303235019785141D-01), (  1.1708038064780055D-01,  9.9312244183049558D-01), &
(  1.1631863091190486D-01,  9.9321194923479450D-01), (  1.1555681274875529D-01,  9.9330087235809328D-01), &
(  1.1479492660651025D-01,  9.9338921114808065D-01), (  1.1403297293336728D-01,  9.9347696555278919D-01), &
(  1.1327095217756435D-01,  9.9356413552059530D-01), (  1.1250886478737883D-01,  9.9365072100021912D-01), &
(  1.1174671121112666D-01,  9.9373672194072460D-01), (  1.1098449189716338D-01,  9.9382213829151966D-01)/
data (mpuu1(i), i =  6001,  6100) / &
(  1.1022220729388318D-01,  9.9390697000235606D-01), (  1.0945985784971803D-01,  9.9399121702332938D-01), &
(  1.0869744401313867D-01,  9.9407487930487937D-01), (  1.0793496623265376D-01,  9.9415795679778973D-01), &
(  1.0717242495680887D-01,  9.9424044945318790D-01), (  1.0640982063418784D-01,  9.9432235722254581D-01), &
(  1.0564715371341070D-01,  9.9440368005767910D-01), (  1.0488442464313497D-01,  9.9448441791074760D-01), &
(  1.0412163387205473D-01,  9.9456457073425542D-01), (  1.0335878184889968D-01,  9.9464413848105071D-01), &
(  1.0259586902243627D-01,  9.9472312110432570D-01), (  1.0183289584146665D-01,  9.9480151855761711D-01), &
(  1.0106986275482786D-01,  9.9487933079480562D-01), (  1.0030677021139282D-01,  9.9495655777011638D-01), &
(  9.9543618660069430D-02,  9.9503319943811863D-01), (  9.8780408549799650D-02,  9.9510925575372611D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  9.7253814448363354D-02,  9.9525961214913339D-01), &
(  9.6490431355252593D-02,  9.9533391214048228D-01), (  9.5726991499307315D-02,  9.9540762660253490D-01), &
(  9.4963495329639061D-02,  9.9548075549192694D-01), (  9.4199943295393190D-02,  9.9555329876563847D-01), &
(  9.3436335845747912D-02,  9.9562525638099431D-01), (  9.2672673429913352D-02,  9.9569662829566352D-01), &
(  9.1908956497132696D-02,  9.9576741446765982D-01), (  9.1145185496681116D-02,  9.9583761485534161D-01), &
(  9.0381360877865011D-02,  9.9590722941741172D-01), (  8.9617483090022917D-02,  9.9597625811291779D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  8.8089569804770507D-02,  9.9611255774215113D-01), &
(  8.7325535206192212D-02,  9.9617982859569687D-01), (  8.6561449236251239D-02,  9.9624651342231552D-01), &
(  8.5797312344439880D-02,  9.9631261218277800D-01), (  8.5033124980280400D-02,  9.9637812483820021D-01), &
(  8.4268887593324113D-02,  9.9644305135004263D-01), (  8.3504600633152404D-02,  9.9650739168011082D-01), &
(  8.2740264549375803D-02,  9.9657114579055484D-01), (  8.1975879791633094D-02,  9.9663431364386990D-01), &
(  8.1211446809592386D-02,  9.9669689520289606D-01), (  8.0446966052950097D-02,  9.9675889043081800D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  7.8917863014785095D-02,  9.9688112174781385D-01), &
(  7.8153241632794301D-02,  9.9694135776498216D-01), (  7.7388574275265035D-02,  9.9700100730723529D-01), &
(  7.6623861392031617D-02,  9.9706007033948296D-01), (  7.5859103432954489D-02,  9.9711854682697998D-01), &
(  7.5094300847921278D-02,  9.9717643673532619D-01), (  7.4329454086845867D-02,  9.9723374003046616D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  7.2799629836351618D-02,  9.9734658664663323D-01), &
(  7.2034653246889416D-02,  9.9740212990127530D-01), (  7.1269634281296415D-02,  9.9745708640994191D-01), &
(  7.0504573389614009D-02,  9.9751145614030345D-01), (  6.9739471021907376D-02,  9.9756523906037575D-01), &
(  6.8974327628266732D-02,  9.9761843513851955D-01), (  6.8209143658806454D-02,  9.9767104434344100D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  6.6678655793001529D-02,  9.9777450201016782D-01), &
(  6.5913352797003916D-02,  9.9782535041111164D-01), (  6.5148011025878860D-02,  9.9787561181711015D-01), &
(  6.4382630929857410D-02,  9.9792528619859600D-01), (  6.3617212959193190D-02,  9.9797437352634699D-01), &
(  6.2851757564161420D-02,  9.9802287377148624D-01), (  6.2086265195060247D-02,  9.9807078690548234D-01), &
(  6.1320736302208655D-02,  9.9811811290014918D-01), (  6.0555171335947781D-02,  9.9816485172764624D-01), &
(  5.9789570746640007D-02,  9.9821100336047819D-01), (  5.9023934984667986D-02,  9.9825656777149518D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), (  5.7492559744367684D-02,  9.9834593482121237D-01), &
(  5.6726821166907783D-02,  9.9838973740734016D-01), (  5.5961049218520527D-02,  9.9843295266650844D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), (  5.4429407010919147D-02,  9.9851762110262221D-01), &
(  5.3663537652730679D-02,  9.9855907422975931D-01), (  5.2897636725665401D-02,  9.9859993993032037D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  5.1365741967162731D-02,  9.9867990895589909D-01), &
(  5.0599749036899337D-02,  9.9871901223387294D-01), (  4.9833726340107257D-02,  9.9875752799118334D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  4.8301593449480179D-02,  9.9883279685352799D-01), &
(  4.7535484156959261D-02,  9.9886954991428356D-01), (  4.6769346900537960D-02,  9.9890571536581829D-01), &
(  4.6003182130914644D-02,  9.9894129318685687D-01), (  4.5236990298804750D-02,  9.9897628335646982D-01), &
(  4.4470771854938744D-02,  9.9901068585407338D-01), (  4.3704527250063421D-02,  9.9904450065942929D-01), &
(  4.2938256934940959D-02,  9.9907772775264536D-01), (  4.2171961360348002D-02,  9.9911036711417489D-01), &
(  4.1405640977076719D-02,  9.9914241872481691D-01), (  4.0639296235933854D-02,  9.9917388256571638D-01), &
(  3.9872927587739845D-02,  9.9920475861836389D-01), (  3.9106535483329846D-02,  9.9923504686459585D-01), &
(  3.8340120373552791D-02,  9.9926474728659442D-01), (  3.7573682709270514D-02,  9.9929385986688779D-01), &
(  3.6807222941358991D-02,  9.9932238458834954D-01), (  3.6040741520706306D-02,  9.9935032143419944D-01), &
(  3.5274238898213947D-02,  9.9937767038800285D-01), (  3.4507715524795889D-02,  9.9940443143367130D-01)/
data (mpuu1(i), i =  6101,  6200) / &
(  3.3741171851377642D-02,  9.9943060455546173D-01), (  3.2974608328897315D-02,  9.9945618973797734D-01), &
(  3.2208025408304704D-02,  9.9948118696616695D-01), (  3.1441423540560343D-02,  9.9950559622532531D-01), &
(  3.0674803176636584D-02,  9.9952941750109314D-01), (  2.9908164767516655D-02,  9.9955265077945699D-01), &
(  2.9141508764193743D-02,  9.9957529604674922D-01), (  2.8374835617672258D-02,  9.9959735328964838D-01), &
(  2.7608145778965820D-02,  9.9961882249517864D-01), (  2.6841439699098531D-02,  9.9963970365071020D-01), &
(  2.6074717829104040D-02,  9.9965999674395922D-01), (  2.5307980620024630D-02,  9.9967970176298793D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  2.3774461988827676D-02,  9.9971734753236219D-01), &
(  2.3007681468839410D-02,  9.9973528826056168D-01), (  2.2240887414024919D-02,  9.9975264087024884D-01), &
(  2.1474080275469608D-02,  9.9976940535121528D-01), (  2.0707260504265915D-02,  9.9978558169359921D-01), &
(  1.9940428551514601D-02,  9.9980116988788426D-01), (  1.9173584868322702D-02,  9.9981616992490041D-01), &
(  1.8406729905804820D-02,  9.9983058179582340D-01), (  1.7639864115082195D-02,  9.9984440549217524D-01), &
(  1.6872987947281773D-02,  9.9985764100582386D-01), (  1.6106101853537266D-02,  9.9987028832898295D-01), &
(  1.5339206284988220D-02,  9.9988234745421256D-01), (  1.4572301692779104D-02,  9.9989381837441849D-01), &
(  1.3805388528060349D-02,  9.9990470108285290D-01), (  1.3038467241987433D-02,  9.9991499557311347D-01), &
(  1.2271538285719944D-02,  9.9992470183914450D-01), (  1.1504602110422875D-02,  9.9993381987523600D-01), &
(  1.0737659167264570D-02,  9.9994234967602391D-01), (  9.9707099074180291D-03,  9.9995029123649048D-01), &
(  9.2037547820599599D-03,  9.9995764455196390D-01), (  8.4367942423698595D-03,  9.9996440961811828D-01), &
(  7.6698287395310771D-03,  9.9997058643097414D-01), (  6.9028587247298772D-03,  9.9997617498689761D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), (  5.3689069639963026D-03,  9.9998558731514320D-01), &
(  4.6019261204486720D-03,  9.9998941108192840D-01), (  3.8349425697062479D-03,  9.9999264658070719D-01), &
(  3.0679567629661379D-03,  9.9999529380957619D-01), (  2.3009691514258861D-03,  9.9999735276697821D-01), &
(  1.5339801862847659D-03,  9.9999882345170188D-01), (  7.6699031874284641D-04,  9.9999970586288223D-01), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), ( -7.6699031874272389D-04,  9.9999970586288223D-01), &
( -1.5339801862846436D-03,  9.9999882345170188D-01), ( -2.3009691514257638D-03,  9.9999735276697821D-01), &
( -3.0679567629660156D-03,  9.9999529380957619D-01), ( -3.8349425697061256D-03,  9.9999264658070719D-01), &
( -4.6019261204485488D-03,  9.9998941108192840D-01), ( -5.3689069639961794D-03,  9.9998558731514320D-01), &
( -6.1358846491543929D-03,  9.9998117528260111D-01), ( -6.9028587247297541D-03,  9.9997617498689761D-01), &
( -7.6698287395309539D-03,  9.9997058643097414D-01), ( -8.4367942423697381D-03,  9.9996440961811828D-01), &
( -9.2037547820598385D-03,  9.9995764455196390D-01), ( -9.9707099074179076D-03,  9.9995029123649048D-01), &
( -1.0737659167264449D-02,  9.9994234967602391D-01), ( -1.1504602110422753D-02,  9.9993381987523600D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -1.3038467241987312D-02,  9.9991499557311347D-01), &
( -1.3805388528060228D-02,  9.9990470108285290D-01), ( -1.4572301692778983D-02,  9.9989381837441849D-01), &
( -1.5339206284988098D-02,  9.9988234745421256D-01), ( -1.6106101853537141D-02,  9.9987028832898295D-01), &
( -1.6872987947281648D-02,  9.9985764100582386D-01), ( -1.7639864115082071D-02,  9.9984440549217524D-01), &
( -1.8406729905804695D-02,  9.9983058179582340D-01), ( -1.9173584868322577D-02,  9.9981616992490041D-01), &
( -1.9940428551514476D-02,  9.9980116988788426D-01), ( -2.0707260504265790D-02,  9.9978558169359921D-01), &
( -2.1474080275469484D-02,  9.9976940535121528D-01), ( -2.2240887414024794D-02,  9.9975264087024884D-01), &
( -2.3007681468839285D-02,  9.9973528826056168D-01), ( -2.3774461988827551D-02,  9.9971734753236219D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -2.5307980620024505D-02,  9.9967970176298793D-01), &
( -2.6074717829103915D-02,  9.9965999674395922D-01), ( -2.6841439699098406D-02,  9.9963970365071020D-01), &
( -2.7608145778965695D-02,  9.9961882249517864D-01), ( -2.8374835617672133D-02,  9.9959735328964838D-01), &
( -2.9141508764193618D-02,  9.9957529604674922D-01), ( -2.9908164767516530D-02,  9.9955265077945699D-01), &
( -3.0674803176636459D-02,  9.9952941750109314D-01), ( -3.1441423540560218D-02,  9.9950559622532531D-01), &
( -3.2208025408304579D-02,  9.9948118696616695D-01), ( -3.2974608328897190D-02,  9.9945618973797734D-01), &
( -3.3741171851377517D-02,  9.9943060455546173D-01), ( -3.4507715524795764D-02,  9.9940443143367130D-01), &
( -3.5274238898213822D-02,  9.9937767038800285D-01), ( -3.6040741520706181D-02,  9.9935032143419944D-01), &
( -3.6807222941358866D-02,  9.9932238458834954D-01), ( -3.7573682709270390D-02,  9.9929385986688779D-01), &
( -3.8340120373552666D-02,  9.9926474728659442D-01), ( -3.9106535483329721D-02,  9.9923504686459585D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -4.0639296235933729D-02,  9.9917388256571638D-01), &
( -4.1405640977076594D-02,  9.9914241872481691D-01), ( -4.2171961360347877D-02,  9.9911036711417489D-01)/
data (mpuu1(i), i =  6201,  6300) / &
( -4.2938256934940834D-02,  9.9907772775264536D-01), ( -4.3704527250063296D-02,  9.9904450065942929D-01), &
( -4.4470771854938619D-02,  9.9901068585407338D-01), ( -4.5236990298804625D-02,  9.9897628335646982D-01), &
( -4.6003182130914519D-02,  9.9894129318685687D-01), ( -4.6769346900537835D-02,  9.9890571536581829D-01), &
( -4.7535484156959136D-02,  9.9886954991428356D-01), ( -4.8301593449480054D-02,  9.9883279685352799D-01), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -4.9833726340107132D-02,  9.9875752799118334D-01), &
( -5.0599749036899212D-02,  9.9871901223387294D-01), ( -5.1365741967162606D-02,  9.9867990895589909D-01), &
( -5.2131704680283192D-02,  9.9864021818026527D-01), ( -5.2897636725665276D-02,  9.9859993993032037D-01), &
( -5.3663537652730554D-02,  9.9855907422975931D-01), ( -5.4429407010919022D-02,  9.9851762110262221D-01), &
( -5.5195244349689913D-02,  9.9847558057329477D-01), ( -5.5961049218520402D-02,  9.9843295266650844D-01), &
( -5.6726821166907658D-02,  9.9838973740734016D-01), ( -5.7492559744367559D-02,  9.9834593482121237D-01), &
( -5.8258264500435607D-02,  9.9830154493389289D-01), ( -5.9023934984667861D-02,  9.9825656777149518D-01), &
( -5.9789570746639882D-02,  9.9821100336047819D-01), ( -6.0555171335947656D-02,  9.9816485172764624D-01), &
( -6.1320736302208530D-02,  9.9811811290014918D-01), ( -6.2086265195060122D-02,  9.9807078690548234D-01), &
( -6.2851757564161309D-02,  9.9802287377148624D-01), ( -6.3617212959193079D-02,  9.9797437352634699D-01), &
( -6.4382630929857299D-02,  9.9792528619859600D-01), ( -6.5148011025878749D-02,  9.9787561181711015D-01), &
( -6.5913352797003805D-02,  9.9782535041111164D-01), ( -6.6678655793001418D-02,  9.9777450201016782D-01), &
( -6.7443919563663995D-02,  9.9772306664419164D-01), ( -6.8209143658806343D-02,  9.9767104434344100D-01), &
( -6.8974327628266621D-02,  9.9761843513851955D-01), ( -6.9739471021907265D-02,  9.9756523906037575D-01), &
( -7.0504573389613898D-02,  9.9751145614030345D-01), ( -7.1269634281296304D-02,  9.9745708640994191D-01), &
( -7.2034653246889305D-02,  9.9740212990127530D-01), ( -7.2799629836351507D-02,  9.9734658664663323D-01), &
( -7.3564563599667343D-02,  9.9729045667869021D-01), ( -7.4329454086845756D-02,  9.9723374003046628D-01), &
( -7.5094300847921167D-02,  9.9717643673532619D-01), ( -7.5859103432954378D-02,  9.9711854682697998D-01), &
( -7.6623861392031506D-02,  9.9706007033948296D-01), ( -7.7388574275264924D-02,  9.9700100730723529D-01), &
( -7.8153241632794190D-02,  9.9694135776498216D-01), ( -7.8917863014784984D-02,  9.9688112174781385D-01), &
( -7.9682437971430015D-02,  9.9682029929116567D-01), ( -8.0446966052949986D-02,  9.9675889043081800D-01), &
( -8.1211446809592275D-02,  9.9669689520289606D-01), ( -8.1975879791632983D-02,  9.9663431364386990D-01), &
( -8.2740264549375692D-02,  9.9657114579055484D-01), ( -8.3504600633152293D-02,  9.9650739168011082D-01), &
( -8.4268887593324002D-02,  9.9644305135004263D-01), ( -8.5033124980280289D-02,  9.9637812483820021D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -8.6561449236251128D-02,  9.9624651342231552D-01), &
( -8.7325535206192101D-02,  9.9617982859569687D-01), ( -8.8089569804770396D-02,  9.9611255774215124D-01), &
( -8.8853552582524573D-02,  9.9604470090125197D-01), ( -8.9617483090022806D-02,  9.9597625811291779D-01), &
( -9.0381360877864900D-02,  9.9590722941741172D-01), ( -9.1145185496681005D-02,  9.9583761485534161D-01), &
( -9.1908956497132585D-02,  9.9576741446765982D-01), ( -9.2672673429913241D-02,  9.9569662829566352D-01), &
( -9.3436335845747800D-02,  9.9562525638099431D-01), ( -9.4199943295393079D-02,  9.9555329876563858D-01), &
( -9.4963495329638950D-02,  9.9548075549192694D-01), ( -9.5726991499307204D-02,  9.9540762660253490D-01), &
( -9.6490431355252482D-02,  9.9533391214048228D-01), ( -9.7253814448363243D-02,  9.9525961214913339D-01), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -9.8780408549799539D-02,  9.9510925575372611D-01), &
( -9.9543618660069319D-02,  9.9503319943811863D-01), ( -1.0030677021139271D-01,  9.9495655777011638D-01), &
( -1.0106986275482775D-01,  9.9487933079480562D-01), ( -1.0183289584146654D-01,  9.9480151855761711D-01), &
( -1.0259586902243616D-01,  9.9472312110432570D-01), ( -1.0335878184889957D-01,  9.9464413848105071D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.0488442464313485D-01,  9.9448441791074760D-01), &
( -1.0564715371341059D-01,  9.9440368005767910D-01), ( -1.0640982063418773D-01,  9.9432235722254581D-01), &
( -1.0717242495680876D-01,  9.9424044945318790D-01), ( -1.0793496623265365D-01,  9.9415795679778973D-01), &
( -1.0869744401313856D-01,  9.9407487930487948D-01), ( -1.0945985784971791D-01,  9.9399121702332938D-01), &
( -1.1022220729388307D-01,  9.9390697000235606D-01), ( -1.1098449189716326D-01,  9.9382213829151966D-01), &
( -1.1174671121112655D-01,  9.9373672194072460D-01), ( -1.1250886478737872D-01,  9.9365072100021912D-01), &
( -1.1327095217756424D-01,  9.9356413552059530D-01), ( -1.1403297293336717D-01,  9.9347696555278919D-01), &
( -1.1479492660651014D-01,  9.9338921114808065D-01), ( -1.1555681274875518D-01,  9.9330087235809328D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.1708038064780044D-01,  9.9312244183049558D-01), &
( -1.1784206150832491D-01,  9.9303235019785141D-01), ( -1.1860367304540073D-01,  9.9294167438986047D-01)/
data (mpuu1(i), i =  6301,  6400) / &
( -1.1936521481099123D-01,  9.9285041445986510D-01), ( -1.2012668635710147D-01,  9.9275857046155114D-01), &
( -1.2088808723577711D-01,  9.9266614244894802D-01), ( -1.2164941699910542D-01,  9.9257313047642881D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.2317186138828054D-01,  9.9238535487085167D-01), &
( -1.2393297511851208D-01,  9.9229059134825737D-01), ( -1.2469401594216764D-01,  9.9219524408667392D-01), &
( -1.2545498341154609D-01,  9.9209931314219180D-01), ( -1.2621587707899029D-01,  9.9200279857124452D-01), &
( -1.2697669649688587D-01,  9.9190570043060933D-01), ( -1.2773744121766217D-01,  9.9180801877740654D-01), &
( -1.2849811079379311D-01,  9.9170975366909953D-01), ( -1.2925870477779616D-01,  9.9161090516349537D-01), &
( -1.3001922272223324D-01,  9.9151147331874401D-01), ( -1.3077966417971168D-01,  9.9141145819333854D-01), &
( -1.3154002870288317D-01,  9.9131085984611544D-01), ( -1.3230031584444457D-01,  9.9120967833625406D-01), &
( -1.3306052515713906D-01,  9.9110791372327689D-01), ( -1.3382065619375458D-01,  9.9100556606704937D-01), &
( -1.3458070850712611D-01,  9.9090263542778001D-01), ( -1.3534068165013421D-01,  9.9079912186602037D-01), &
( -1.3610057517570606D-01,  9.9069502544266463D-01), ( -1.3686038863681632D-01,  9.9059034621895015D-01), &
( -1.3762012158648607D-01,  9.9048508425645698D-01), ( -1.3837977357778378D-01,  9.9037923961710816D-01), &
( -1.3913934416382617D-01,  9.9027281236316911D-01), ( -1.3989883289777727D-01,  9.9016580255724840D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -1.4141756302230302D-01,  9.8995003554160899D-01), &
( -1.4217680351944789D-01,  9.8984127845882053D-01), ( -1.4293596037764258D-01,  9.8973193907791057D-01), &
( -1.4369503315029447D-01,  9.8962201746320089D-01), ( -1.4445402139086033D-01,  9.8951151367935530D-01), &
( -1.4521292465284741D-01,  9.8940042779138038D-01), ( -1.4597174248981223D-01,  9.8928875986462517D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.4748912010315354D-01,  9.8906367815788154D-01), &
( -1.4824767898689609D-01,  9.8895026451030299D-01), ( -1.4900615066034836D-01,  9.8883626908876354D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -1.5052283059167726D-01,  9.8860653319238656D-01), &
( -1.5128103795733014D-01,  9.8849079285269670D-01), ( -1.5203915632824605D-01,  9.8837447100934128D-01), &
( -1.5279718525844330D-01,  9.8825756773074946D-01), ( -1.5355512430199339D-01,  9.8814008308569257D-01), &
( -1.5431297301302013D-01,  9.8802201714328353D-01), ( -1.5507073094570040D-01,  9.8790336997297779D-01), &
( -1.5582839765426520D-01,  9.8778414164457218D-01), ( -1.5658597269299848D-01,  9.8766433222820571D-01), &
( -1.5734345561623816D-01,  9.8754394179435934D-01), ( -1.5810084597837698D-01,  9.8742297041385541D-01), &
( -1.5885814333386128D-01,  9.8730141815785843D-01), ( -1.5961534723719298D-01,  9.8717928509787434D-01), &
( -1.6037245724292828D-01,  9.8705657130575097D-01), ( -1.6112947290567867D-01,  9.8693327685367782D-01), &
( -1.6188639378011177D-01,  9.8680940181418553D-01), ( -1.6264321942095034D-01,  9.8668494626014669D-01), &
( -1.6339994938297311D-01,  9.8655991026477552D-01), ( -1.6415658322101578D-01,  9.8643429390162718D-01), &
( -1.6491312048996995D-01,  9.8630809724459867D-01), ( -1.6566956074478403D-01,  9.8618132036792827D-01), &
( -1.6642590354046410D-01,  9.8605396334619544D-01), ( -1.6718214843207277D-01,  9.8592602625432113D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -1.6869434272361733D-01,  9.8566841216153755D-01), &
( -1.6945029123396782D-01,  9.8553873531217606D-01), ( -1.7020614006107801D-01,  9.8540847869576842D-01), &
( -1.7096188876030124D-01,  9.8527764238894122D-01), ( -1.7171753688704985D-01,  9.8514622646866223D-01), &
( -1.7247308399679592D-01,  9.8501423101223984D-01), ( -1.7322852964507038D-01,  9.8488165609732370D-01), &
( -1.7398387338746374D-01,  9.8474850180190421D-01), ( -1.7473911477962720D-01,  9.8461476820431260D-01), &
( -1.7549425337727126D-01,  9.8448045538322093D-01), ( -1.7624928873616783D-01,  9.8434556341764190D-01), &
( -1.7700422041214875D-01,  9.8421009238692903D-01), ( -1.7775904796110703D-01,  9.8407404237077656D-01), &
( -1.7851377093899745D-01,  9.8393741344921892D-01), ( -1.7926838890183577D-01,  9.8380020570263160D-01), &
( -1.8002290140569940D-01,  9.8366241921173025D-01), ( -1.8077730800672856D-01,  9.8352405405757126D-01), &
( -1.8153160826112502D-01,  9.8338511032155118D-01), ( -1.8228580172515321D-01,  9.8324558808540719D-01), &
( -1.8303988795514095D-01,  9.8310548743121629D-01), ( -1.8379386650747828D-01,  9.8296480844139644D-01), &
( -1.8454773693861953D-01,  9.8282355119870535D-01), ( -1.8530149880508190D-01,  9.8268171578624086D-01), &
( -1.8605515166344652D-01,  9.8253930228744124D-01), ( -1.8680869507035922D-01,  9.8239631078608469D-01), &
( -1.8756212858252963D-01,  9.8225274136628937D-01), ( -1.8831545175673201D-01,  9.8210859411251361D-01), &
( -1.8906866414980616D-01,  9.8196386910955524D-01), ( -1.8982176531865647D-01,  9.8181856644255250D-01), &
( -1.9057475482025266D-01,  9.8167268619698311D-01), ( -1.9132763221163088D-01,  9.8152622845866477D-01), &
( -1.9208039704989227D-01,  9.8137919331375456D-01), ( -1.9283304889220518D-01,  9.8123158084874973D-01), &
( -1.9358558729580361D-01,  9.8108339115048671D-01), ( -1.9433801181798849D-01,  9.8093462430614176D-01)/
data (mpuu1(i), i =  6401,  6500) / &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -1.9584251744765788D-01,  9.8063535952960812D-01), &
( -1.9659459767008011D-01,  9.8048486177346938D-01), ( -1.9734656224096589D-01,  9.8033378722334796D-01), &
( -1.9809841071795362D-01,  9.8018213596811743D-01), ( -1.9885014265875001D-01,  9.8002990809699009D-01), &
( -1.9960175762113094D-01,  9.7987710369951764D-01), ( -2.0035325516294028D-01,  9.7972372286559117D-01), &
( -2.0110463484209182D-01,  9.7956976568544052D-01), ( -2.0185589621656805D-01,  9.7941523224963478D-01), &
( -2.0260703884442099D-01,  9.7926012264908213D-01), ( -2.0335806228377326D-01,  9.7910443697502925D-01), &
( -2.0410896609281690D-01,  9.7894817531906220D-01), ( -2.0485974982981431D-01,  9.7879133777310567D-01), &
( -2.0561041305309921D-01,  9.7863392442942321D-01), ( -2.0636095532107557D-01,  9.7847593538061683D-01), &
( -2.0711137619221845D-01,  9.7831737071962765D-01), ( -2.0786167522507504D-01,  9.7815823053973505D-01), &
( -2.0861185197826332D-01,  9.7799851493455714D-01), ( -2.0936190601047408D-01,  9.7783822399805043D-01), &
( -2.1011183688046961D-01,  9.7767735782450993D-01), ( -2.1086164414708472D-01,  9.7751591650856928D-01), &
( -2.1161132736922750D-01,  9.7735390014520007D-01), ( -2.1236088610587844D-01,  9.7719130882971228D-01), &
( -2.1311031991609125D-01,  9.7702814265775439D-01), ( -2.1385962835899372D-01,  9.7686440172531264D-01), &
( -2.1460881099378681D-01,  9.7670008612871184D-01), ( -2.1535786737974544D-01,  9.7653519596461447D-01), &
( -2.1610679707621949D-01,  9.7636973133002114D-01), ( -2.1685559964263246D-01,  9.7620369232227056D-01), &
( -2.1760427463848356D-01,  9.7603707903903913D-01), ( -2.1835282162334632D-01,  9.7586989157834103D-01), &
( -2.1910124015686966D-01,  9.7570213003852857D-01), ( -2.1984952979877864D-01,  9.7553379451829136D-01), &
( -2.2059769010887353D-01,  9.7536488511665698D-01), ( -2.2134572064703070D-01,  9.7519540193299037D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.2284139064742117D-01,  9.7485471461870843D-01), &
( -2.2358902922978990D-01,  9.7468351068851067D-01), ( -2.2433653628049358D-01,  9.7451173337711583D-01), &
( -2.2508391135979267D-01,  9.7433938278557586D-01), ( -2.2583115402802609D-01,  9.7416645901528043D-01), &
( -2.2657826384561000D-01,  9.7399296216795583D-01), ( -2.2732524037303872D-01,  9.7381889234566621D-01), &
( -2.2807208317088568D-01,  9.7364424965081198D-01), ( -2.2881879179980225D-01,  9.7346903418613107D-01), &
( -2.2956536582051876D-01,  9.7329324605469825D-01), ( -2.3031180479384541D-01,  9.7311688535992513D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -2.3180427584196467D-01,  9.7276244669568857D-01), &
( -2.3255030703877522D-01,  9.7258436893473221D-01), ( -2.3329620143223145D-01,  9.7240571902744977D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -2.3478757805400097D-01,  9.7204670319462350D-01), &
( -2.3553305940497535D-01,  9.7186633748027940D-01), ( -2.3627840219791951D-01,  9.7168540004200854D-01), &
( -2.3702360599436723D-01,  9.7150389098625178D-01), ( -2.3776867035593410D-01,  9.7132181041978627D-01), &
( -2.3851359484431839D-01,  9.7113915844972509D-01), ( -2.3925837902130001D-01,  9.7095593518351797D-01), &
( -2.4000302244874139D-01,  9.7077214072895035D-01), ( -2.4074752468858840D-01,  9.7058777519414363D-01), &
( -2.4149188530286919D-01,  9.7040283868755550D-01), ( -2.4223610385369593D-01,  9.7021733131797916D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.4372411301385202D-01,  9.6984460442671494D-01), &
( -2.4446790274782410D-01,  9.6965738512429245D-01), ( -2.4521154866762757D-01,  9.6946959539741306D-01), &
( -2.4595505033579448D-01,  9.6928123535654853D-01), ( -2.4669840731494239D-01,  9.6909230511250621D-01), &
( -2.4744161916777332D-01,  9.6890280477642887D-01), ( -2.4818468545707467D-01,  9.6871273445979478D-01), &
( -2.4892760574572015D-01,  9.6852209427441727D-01), ( -2.4967037959666841D-01,  9.6833088433244530D-01), &
( -2.5041300657296517D-01,  9.6813910474636244D-01), ( -2.5115548623774192D-01,  9.6794675562898780D-01), &
( -2.5189781815421680D-01,  9.6775383709347551D-01), ( -2.5264000188569546D-01,  9.6756034925331447D-01), &
( -2.5338203699557016D-01,  9.6736629222232851D-01), ( -2.5412392304732051D-01,  9.6717166611467664D-01), &
( -2.5486565960451452D-01,  9.6697647104485207D-01), ( -2.5560724623080744D-01,  9.6678070712768327D-01), &
( -2.5634868248994280D-01,  9.6658437447833312D-01), ( -2.5708996794575312D-01,  9.6638747321229890D-01), &
( -2.5783110216215882D-01,  9.6619000344541262D-01), ( -2.5857208470317028D-01,  9.6599196529384057D-01), &
( -2.5931291513288623D-01,  9.6579335887408368D-01), ( -2.6005359301549502D-01,  9.6559418430297683D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -2.6153448939659552D-01,  9.6519413117572472D-01), &
( -2.6227470702391348D-01,  9.6499325285492044D-01), ( -2.6301477036177895D-01,  9.6479180685344790D-01), &
( -2.6375467897483140D-01,  9.6458979328981276D-01), ( -2.6449443242780152D-01,  9.6438721228285429D-01), &
( -2.6523403028551179D-01,  9.6418406395174583D-01), ( -2.6597347211287542D-01,  9.6398034841599411D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -2.6745188593667762D-01,  9.6357121621025732D-01), &
( -2.6819085706340307D-01,  9.6336579978095405D-01), ( -2.6892967042035720D-01,  9.6315981662837147D-01)/
data (mpuu1(i), i =  6501,  6600) / &
( -2.6966832557291509D-01,  9.6295326687368388D-01), ( -2.7040682208654471D-01,  9.6274615063839941D-01), &
( -2.7114515952680796D-01,  9.6253846804435916D-01), ( -2.7188333745935978D-01,  9.6233021921373740D-01), &
( -2.7262135544994887D-01,  9.6212140426904158D-01), ( -2.7335921306441868D-01,  9.6191202333311221D-01), &
( -2.7409690986870622D-01,  9.6170207652912254D-01), ( -2.7483444542884383D-01,  9.6149156398057900D-01), &
( -2.7557181931095814D-01,  9.6128048581132064D-01), ( -2.7630903108127092D-01,  9.6106884214551935D-01), &
( -2.7704608030609984D-01,  9.6085663310767966D-01), ( -2.7778296655185769D-01,  9.6064385882263859D-01), &
( -2.7851968938505295D-01,  9.6043051941556590D-01), ( -2.7925624837229113D-01,  9.6021661501196343D-01), &
( -2.7999264308027327D-01,  9.6000214573766585D-01), ( -2.8072887307579708D-01,  9.5978711171884001D-01), &
( -2.8146493792575794D-01,  9.5957151308198452D-01), ( -2.8220083719714739D-01,  9.5935534995393079D-01), &
( -2.8293657045705528D-01,  9.5913862246184201D-01), ( -2.8367213727266843D-01,  9.5892133073321317D-01), &
( -2.8440753721127171D-01,  9.5870347489587160D-01), ( -2.8514276984024861D-01,  9.5848505507797621D-01), &
( -2.8587783472708062D-01,  9.5826607140801767D-01), ( -2.8661273143934768D-01,  9.5804652401481860D-01), &
( -2.8734745954472946D-01,  9.5782641302753291D-01), ( -2.8808201861100419D-01,  9.5760573857564635D-01), &
( -2.8881640820604937D-01,  9.5738450078897597D-01), ( -2.8955062789784303D-01,  9.5716269979767010D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -2.9101855584408498D-01,  9.5671740872340316D-01), &
( -2.9175226323498926D-01,  9.5649391890239510D-01), ( -2.9248579899555371D-01,  9.5626986640065814D-01), &
( -2.9321916269425857D-01,  9.5604525134999652D-01), ( -2.9395235389968466D-01,  9.5582007388254542D-01), &
( -2.9468537218051422D-01,  9.5559433413077111D-01), ( -2.9541821710553196D-01,  9.5536803222747035D-01), &
( -2.9615088824362384D-01,  9.5514116830577067D-01), ( -2.9688338516377816D-01,  9.5491374249913052D-01), &
( -2.9761570743508620D-01,  9.5468575494133834D-01), ( -2.9834785462674146D-01,  9.5445720576651349D-01), &
( -2.9907982630804036D-01,  9.5422809510910567D-01), ( -2.9981162204838335D-01,  9.5399842310389449D-01), &
( -3.0054324141727329D-01,  9.5376818988599033D-01), ( -3.0127468398431789D-01,  9.5353739559083328D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -3.0273703699181903D-01,  9.5307412431217231D-01), &
( -3.0346794657201126D-01,  9.5284164760119872D-01), ( -3.0419867762982916D-01,  9.5260861035803324D-01), &
( -3.0492922973540232D-01,  9.5237501271976588D-01), ( -3.0565960245896612D-01,  9.5214085482381583D-01), &
( -3.0638979537086097D-01,  9.5190613680793235D-01), ( -3.0711980804153299D-01,  9.5167085881019386D-01), &
( -3.0784964004153487D-01,  9.5143502096900834D-01), ( -3.0857929094152492D-01,  9.5119862342311334D-01), &
( -3.0930876031226867D-01,  9.5096166631157508D-01), ( -3.1003804772463789D-01,  9.5072414977378961D-01), &
( -3.1076715274961136D-01,  9.5048607394948181D-01), ( -3.1149607495827586D-01,  9.5024743897870523D-01), &
( -3.1222481392182494D-01,  9.5000824500184300D-01), ( -3.1295336921156008D-01,  9.4976849215960668D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -3.1440992705533671D-01,  9.4928731044350201D-01), &
( -3.1513792875252233D-01,  9.4904588185270056D-01), ( -3.1586574506218396D-01,  9.4880389496265849D-01), &
( -3.1659337555616573D-01,  9.4856134991573038D-01), ( -3.1732081980642168D-01,  9.4831824685459920D-01), &
( -3.1804807738501495D-01,  9.4807458592227623D-01), ( -3.1877514786411837D-01,  9.4783036726210113D-01), &
( -3.1950203081601564D-01,  9.4758559101774120D-01), ( -3.2022872581309991D-01,  9.4734025733319205D-01), &
( -3.2095523242787510D-01,  9.4709436635277722D-01), ( -3.2168155023295653D-01,  9.4684791822114800D-01), &
( -3.2240767880106991D-01,  9.4660091308328353D-01), ( -3.2313361770505222D-01,  9.4635335108449059D-01), &
( -3.2385936651785285D-01,  9.4610523237040345D-01), ( -3.2458492481253204D-01,  9.4585655708698391D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.2603546814033024D-01,  9.4535753739763229D-01), &
( -3.2676045232013168D-01,  9.4510719328526061D-01), ( -3.2748524427517794D-01,  9.4485629319067721D-01), &
( -3.2820984357909255D-01,  9.4460483726148026D-01), ( -3.2893424980561209D-01,  9.4435282564559486D-01), &
( -3.2965846252858744D-01,  9.4410025849127266D-01), ( -3.3038248132198283D-01,  9.4384713594709269D-01), &
( -3.3110630575987632D-01,  9.4359345816196039D-01), ( -3.3182993541646111D-01,  9.4333922528510772D-01), &
( -3.3255336986604411D-01,  9.4308443746609349D-01), ( -3.3327660868304787D-01,  9.4282909485480271D-01), &
( -3.3399965144200938D-01,  9.4257319760144687D-01), ( -3.3472249771758111D-01,  9.4231674585656378D-01), &
( -3.3544514708453155D-01,  9.4205973977101742D-01), ( -3.3616759911774458D-01,  9.4180217949599765D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.3761190948307457D-01,  9.4128539698392877D-01), &
( -3.3833376696554118D-01,  9.4102617505088926D-01), ( -3.3905542541496952D-01,  9.4076639953639607D-01), &
( -3.3977688440682685D-01,  9.4050607059326830D-01), ( -3.4049814351669699D-01,  9.4024518837465088D-01), &
( -3.4121920232028230D-01,  9.3998375303401405D-01), ( -3.4194006039340219D-01,  9.3972176472515334D-01)/
data (mpuu1(i), i =  6601,  6700) / &
( -3.4266071731199427D-01,  9.3945922360218992D-01), ( -3.4338117265211499D-01,  9.3919612981956990D-01), &
( -3.4410142598993887D-01,  9.3893248353206449D-01), ( -3.4482147690175918D-01,  9.3866828489477028D-01), &
( -3.4554132496398904D-01,  9.3840353406310817D-01), ( -3.4626096975316006D-01,  9.3813823119282436D-01), &
( -3.4698041084592357D-01,  9.3787237643998989D-01), ( -3.4769964781905138D-01,  9.3760596996099999D-01), &
( -3.4841868024943440D-01,  9.3733901191257496D-01), ( -3.4913750771408492D-01,  9.3707150245175919D-01), &
( -3.4985612979013492D-01,  9.3680344173592156D-01), ( -3.5057454605483745D-01,  9.3653482992275561D-01), &
( -3.5129275608556704D-01,  9.3626566717027826D-01), ( -3.5201075945981913D-01,  9.3599595363683141D-01), &
( -3.5272855575521062D-01,  9.3572568948108037D-01), ( -3.5344614454948076D-01,  9.3545487486201462D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -3.5488069794622268D-01,  9.3491159487151609D-01), &
( -3.5559766170478385D-01,  9.3463912981968078D-01), ( -3.5631441627440225D-01,  9.3436611494372590D-01), &
( -3.5703096123342992D-01,  9.3409255040425898D-01), ( -3.5774729616034190D-01,  9.3381843636221096D-01), &
( -3.5846342063373643D-01,  9.3354377297883628D-01), ( -3.5917933423233644D-01,  9.3326856041571205D-01), &
( -3.5989503653498817D-01,  9.3299279883473885D-01), ( -3.6061052712066216D-01,  9.3271648839814025D-01), &
( -3.6132580556845423D-01,  9.3243962926846247D-01), ( -3.6204087145758423D-01,  9.3216222160857443D-01), &
( -3.6275572436739711D-01,  9.3188426558166815D-01), ( -3.6347036387736376D-01,  9.3160576135125783D-01), &
( -3.6418478956707973D-01,  9.3132670908118054D-01), ( -3.6489900101626727D-01,  9.3104710893559528D-01), &
( -3.6561299780477385D-01,  9.3076696107898371D-01), ( -3.6632677951257347D-01,  9.3048626567614978D-01), &
( -3.6704034571976712D-01,  9.3020502289221907D-01), ( -3.6775369600658198D-01,  9.2992323289263967D-01), &
( -3.6846682995337221D-01,  9.2964089584318133D-01), ( -3.6917974714061996D-01,  9.2935801190993561D-01), &
( -3.6989244714893416D-01,  9.2907458125931575D-01), ( -3.7060492955905155D-01,  9.2879060405805702D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -3.7202923990828485D-01,  9.2822101067216956D-01), &
( -3.7274106700951570D-01,  9.2793539482261789D-01), ( -3.7345267483678030D-01,  9.2764923309258118D-01), &
( -3.7416406297145788D-01,  9.2736252565040111D-01), ( -3.7487523099505754D-01,  9.2707527266474010D-01), &
( -3.7558617848921722D-01,  9.2678747430458175D-01), ( -3.7629690503570468D-01,  9.2649913073923051D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -3.7771769361338570D-01,  9.2592080867176996D-01), &
( -3.7842775480876550D-01,  9.2563083050987283D-01), ( -3.7913759338484732D-01,  9.2534030782320631D-01), &
( -3.7984720892405099D-01,  9.2504924078267770D-01), ( -3.8055660100892846D-01,  9.2475762955951391D-01), &
( -3.8126576922216238D-01,  9.2446547432526260D-01), ( -3.8197471314656711D-01,  9.2417277525179120D-01), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -3.8339192646080866D-01,  9.2358574627625667D-01), &
( -3.8410019501693493D-01,  9.2329141671952764D-01), ( -3.8480823761681282D-01,  9.2299654401424625D-01), &
( -3.8551605384391890D-01,  9.2270112833387852D-01), ( -3.8622364328186287D-01,  9.2240516985220999D-01), &
( -3.8693100551438858D-01,  9.2210866874334507D-01), ( -3.8763814012537257D-01,  9.2181162518170812D-01), &
( -3.8834504669882619D-01,  9.2151403934204201D-01), ( -3.8905172481889438D-01,  9.2121591139940873D-01), &
( -3.8975817406985630D-01,  9.2091724152918952D-01), ( -3.9046439403612654D-01,  9.2061802990708397D-01), &
( -3.9117038430225387D-01,  9.2031827670911059D-01), ( -3.9187614445292224D-01,  9.2001798211160657D-01), &
( -3.9258167407295147D-01,  9.1971714629122736D-01), ( -3.9328697274729646D-01,  9.1941576942494696D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -3.9469687559943356D-01,  9.1881139326416994D-01), &
( -3.9540147894781619D-01,  9.1850839432521225D-01), ( -3.9610584969169621D-01,  9.1820485505143101D-01), &
( -3.9680998741671031D-01,  9.1790077562139050D-01), ( -3.9751389170863222D-01,  9.1759615621397295D-01), &
( -3.9821756215337356D-01,  9.1729099700837802D-01), ( -3.9892099833698291D-01,  9.1698529818412300D-01), &
( -3.9962419984564673D-01,  9.1667905992104270D-01), ( -4.0032716626569004D-01,  9.1637228239928914D-01), &
( -4.0102989718357568D-01,  9.1606496579933172D-01), ( -4.0173239218590490D-01,  9.1575711030195683D-01), &
( -4.0243465085941843D-01,  9.1544871608826783D-01), ( -4.0313667279099513D-01,  9.1513978333968526D-01), &
( -4.0383845756765402D-01,  9.1483031223794620D-01), ( -4.0454000477655300D-01,  9.1452030296510445D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.0594238484040246D-01,  9.1389867063591168D-01), &
( -4.0664321687036903D-01,  9.1358704794525081D-01), ( -4.0734380968260786D-01,  9.1327488781486776D-01), &
( -4.0804416286497863D-01,  9.1296219042839821D-01), ( -4.0874427600548141D-01,  9.1264895596979390D-01), &
( -4.0944414869225754D-01,  9.1233518462332286D-01), ( -4.1014378051359024D-01,  9.1202087657356834D-01), &
( -4.1084317105790380D-01,  9.1170603200542988D-01), ( -4.1154231991376516D-01,  9.1139065110412243D-01), &
( -4.1224122666988289D-01,  9.1107473405517636D-01), ( -4.1293989091510791D-01,  9.1075828104443757D-01)/
data (mpuu1(i), i =  6701,  6800) / &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.1433649022899910D-01,  9.1012376788254168D-01), &
( -4.1503442447608152D-01,  9.0980570810465233D-01), ( -4.1573211456910530D-01,  9.0948711311150543D-01), &
( -4.1642956009763699D-01,  9.0916798309052249D-01), ( -4.1712676065138776D-01,  9.0884831822943912D-01), &
( -4.1782371582021227D-01,  9.0852811871630612D-01), ( -4.1852042519410976D-01,  9.0820738473948870D-01), &
( -4.1921688836322407D-01,  9.0788611648766615D-01), ( -4.1991310491784345D-01,  9.0756431414983274D-01), &
( -4.2060907444840240D-01,  9.0724197791529593D-01), ( -4.2130479654547959D-01,  9.0691910797367814D-01), &
( -4.2200027079979968D-01,  9.0659570451491533D-01), ( -4.2269549680223306D-01,  9.0627176772925755D-01), &
( -4.2339047414379577D-01,  9.0594729780726857D-01), ( -4.2408520241565140D-01,  9.0562229493982538D-01), &
( -4.2477968120910875D-01,  9.0529675931811882D-01), ( -4.2547391011562380D-01,  9.0497069113365325D-01), &
( -4.2616788872679967D-01,  9.0464409057824624D-01), ( -4.2686161663438660D-01,  9.0431695784402821D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.2824831870653179D-01,  9.0366109660924809D-01), &
( -4.2894129205532944D-01,  9.0333236849451182D-01), ( -4.2963401306901638D-01,  9.0300310897261715D-01), &
( -4.3032648134008272D-01,  9.0267331823725883D-01), ( -4.3101869646116681D-01,  9.0234299648244432D-01), &
( -4.3171065802505709D-01,  9.0201214390249329D-01), ( -4.3240236562469003D-01,  9.0168076069203773D-01), &
( -4.3309381885315196D-01,  9.0134884704602203D-01), ( -4.3378501730367858D-01,  9.0101640315970233D-01), &
( -4.3447596056965582D-01,  9.0068342922864686D-01), ( -4.3516664824461904D-01,  9.0034992544873571D-01), &
( -4.3585707992225536D-01,  9.0001589201616028D-01), ( -4.3654725519640114D-01,  8.9968132912742393D-01), &
( -4.3723717366104409D-01,  8.9934623697934157D-01), ( -4.3792683491032297D-01,  8.9901061576903907D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -4.3930538414009979D-01,  8.9833778695183442D-01), &
( -4.3999427130963314D-01,  8.9800057974073988D-01), ( -4.4068289964187290D-01,  8.9766284425904086D-01), &
( -4.4137126873171673D-01,  8.9732458070541821D-01), ( -4.4205937817421487D-01,  8.9698578927886397D-01), &
( -4.4274722756456980D-01,  8.9664647017868027D-01), ( -4.4343481649813832D-01,  8.9630662360447966D-01), &
( -4.4412214457042914D-01,  8.9596624975618522D-01), ( -4.4480921137710488D-01,  8.9562534883403000D-01), &
( -4.4549601651398185D-01,  8.9528392103855747D-01), ( -4.4618255957702979D-01,  8.9494196657062086D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.4755485786629290D-01,  8.9425647842231615D-01), &
( -4.4824061228521989D-01,  8.9391294514520325D-01), ( -4.4892610301574332D-01,  8.9356888600213591D-01), &
( -4.4961132965460671D-01,  8.9322430119551521D-01), ( -4.5029629179870845D-01,  8.9287919092805179D-01), &
( -4.5098098904510375D-01,  8.9253355540276469D-01), ( -4.5166542099100243D-01,  8.9218739482298259D-01), &
( -4.5234958723377089D-01,  8.9184070939234272D-01), ( -4.5303348737093169D-01,  8.9149349931479138D-01), &
( -4.5371712100016365D-01,  8.9114576479458341D-01), ( -4.5440048771930347D-01,  8.9079750603628161D-01), &
( -4.5508358712634372D-01,  8.9044872324475799D-01), ( -4.5576641881943464D-01,  8.9009941662519232D-01), &
( -4.5644898239688397D-01,  8.8974958638307278D-01), ( -4.5713127745715709D-01,  8.8939923272419552D-01), &
( -4.5781330359887701D-01,  8.8904835585466468D-01), ( -4.5849506042082611D-01,  8.8869695598089171D-01), &
( -4.5917654752194403D-01,  8.8834503330959635D-01), ( -4.5985776450132954D-01,  8.8799258804780556D-01), &
( -4.6053871095824012D-01,  8.8763962040285393D-01), ( -4.6121938649209215D-01,  8.8728613058238326D-01), &
( -4.6189979070246256D-01,  8.8693211879434231D-01), ( -4.6257992318908669D-01,  8.8657758524698704D-01), &
( -4.6325978355186015D-01,  8.8622253014888064D-01), ( -4.6393937139083857D-01,  8.8586695370889279D-01), &
( -4.6461868630623793D-01,  8.8551085613619984D-01), ( -4.6529772789843438D-01,  8.8515423764028522D-01), &
( -4.6597649576796601D-01,  8.8479709843093790D-01), ( -4.6665498951553086D-01,  8.8443943871825381D-01), &
( -4.6733320874198847D-01,  8.8408125871263499D-01), ( -4.6801115304835988D-01,  8.8372255862478954D-01), &
( -4.6868882203582768D-01,  8.8336333866573169D-01), ( -4.6936621530573736D-01,  8.8300359904678094D-01), &
( -4.7004333245959551D-01,  8.8264333997956279D-01), ( -4.7072017309907160D-01,  8.8228256167600871D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -4.7207302324236877D-01,  8.8155944820914378D-01), &
( -4.7274903195034257D-01,  8.8119711347122220D-01), ( -4.7342476255224142D-01,  8.8083426034774204D-01), &
( -4.7410021465054997D-01,  8.8047088905216087D-01), ( -4.7477538784791712D-01,  8.8010699979824036D-01), &
( -4.7545028174715598D-01,  8.7974259280004741D-01), ( -4.7612489595124335D-01,  8.7937766827195341D-01), &
( -4.7679923006332198D-01,  8.7901222642863353D-01), ( -4.7747328368669795D-01,  8.7864626748506824D-01), &
( -4.7814705642484301D-01,  8.7827979165654158D-01), ( -4.7882054788139394D-01,  8.7791279915864173D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -4.8016668536508811D-01,  8.7717726501859616D-01), &
( -4.8083933060033379D-01,  8.7680872380914576D-01), ( -4.8151169297018975D-01,  8.7643966679571372D-01)/
data (mpuu1(i), i =  6801,  6900) / &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -4.8285556753176567D-01,  8.7570000622563460D-01), &
( -4.8352707893291841D-01,  8.7532940310411100D-01), ( -4.8419830588754881D-01,  8.7495828504885176D-01), &
( -4.8486924800079095D-01,  8.7458665227817622D-01), ( -4.8553990487794685D-01,  8.7421450501070630D-01), &
( -4.8621027612448642D-01,  8.7384184346536686D-01), ( -4.8688036134604745D-01,  8.7346866786138488D-01), &
( -4.8755016014843572D-01,  8.7309497841829020D-01), ( -4.8821967213762657D-01,  8.7272077535591441D-01), &
( -4.8888889691976306D-01,  8.7234605889439154D-01), ( -4.8955783410115744D-01,  8.7197082925415781D-01), &
( -4.9022648328829116D-01,  8.7159508665595098D-01), ( -4.9089484408781481D-01,  8.7121883132081113D-01), &
( -4.9156291610654973D-01,  8.7084206347007909D-01), ( -4.9223069895148591D-01,  8.7046478332539778D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -4.9356539554877477D-01,  8.6970868704226567D-01), &
( -4.9423230851595978D-01,  8.6932987134860673D-01), ( -4.9489893073901092D-01,  8.6895054425058249D-01), &
( -4.9556526182577232D-01,  8.6857070597134101D-01), ( -4.9623130138425814D-01,  8.6819035673433143D-01), &
( -4.9689704902265447D-01,  8.6780949676330332D-01), ( -4.9756250434931915D-01,  8.6742812628230692D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -4.9889253650174442D-01,  8.6666385468811125D-01), &
( -4.9955711254508173D-01,  8.6628095402451311D-01), ( -5.0022139471184057D-01,  8.6589754375014893D-01), &
( -5.0088538261124071D-01,  8.6551362409056909D-01), ( -5.0154907585267539D-01,  8.6512919527162369D-01), &
( -5.0221247404571057D-01,  8.6474425751946249D-01), ( -5.0287557680008677D-01,  8.6435881106053403D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.0420089443269034D-01,  8.6358639292966810D-01), &
( -5.0486310853126759D-01,  8.6319942171212416D-01), ( -5.0552502563188517D-01,  8.6281194269660055D-01), &
( -5.0618664534515512D-01,  8.6242395611104072D-01), ( -5.0684796728186321D-01,  8.6203546218368732D-01), &
( -5.0750899105297076D-01,  8.6164646114308141D-01), ( -5.0816971626961460D-01,  8.6125695321806217D-01), &
( -5.0883014254310710D-01,  8.6086693863776720D-01), ( -5.0949026948493603D-01,  8.6047641763163230D-01), &
( -5.1015009670676659D-01,  8.6008539042939025D-01), ( -5.1080962382043893D-01,  8.5969385726107272D-01), &
( -5.1146885043797030D-01,  8.5930181835700847D-01), ( -5.1212777617155469D-01,  8.5890927394782390D-01), &
( -5.1278640063356273D-01,  8.5851622426444296D-01), ( -5.1344472343654324D-01,  8.5812266953808625D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.1476046251650109D-01,  8.5733404588281570D-01), &
( -5.1541787801946293D-01,  8.5693897741782876D-01), ( -5.1607499031536674D-01,  8.5654340483771996D-01), &
( -5.1673179901764965D-01,  8.5614732837519458D-01), ( -5.1738830373992883D-01,  8.5575074826325404D-01), &
( -5.1804450409599923D-01,  8.5535366473519603D-01), ( -5.1870039969983495D-01,  8.5495607802461493D-01), &
( -5.1935599016558964D-01,  8.5455798836540053D-01), ( -5.2001127510759571D-01,  8.5415939599173896D-01), &
( -5.2066625414036694D-01,  8.5376030113811152D-01), ( -5.2132092687859544D-01,  8.5336070403929554D-01), &
( -5.2197529293715428D-01,  8.5296060493036374D-01), ( -5.2262935193109661D-01,  8.5256000404668408D-01), &
( -5.2328310347565643D-01,  8.5215890162391983D-01), ( -5.2393654718624827D-01,  8.5175729789802923D-01), &
( -5.2458968267846873D-01,  8.5135519310526520D-01), ( -5.2524250956809460D-01,  8.5095258748217584D-01), &
( -5.2589502747108463D-01,  8.5054948126560348D-01), ( -5.2654723600357944D-01,  8.5014587469268521D-01), &
( -5.2719913478190106D-01,  8.4974176800085266D-01), ( -5.2785072342255512D-01,  8.4933716142783089D-01), &
( -5.2850200154222826D-01,  8.4893205521163972D-01), ( -5.2915296875779061D-01,  8.4852644959059276D-01), &
( -5.2980362468629461D-01,  8.4812034480329723D-01), ( -5.3045396894497643D-01,  8.4771374108865427D-01), &
( -5.3110400115125467D-01,  8.4730663868585854D-01), ( -5.3175372092273310D-01,  8.4689903783439735D-01), &
( -5.3240312787719779D-01,  8.4649093877405213D-01), ( -5.3305222163261945D-01,  8.4608234174489705D-01), &
( -5.3370100180715296D-01,  8.4567324698729907D-01), ( -5.3434946801913719D-01,  8.4526365474191845D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.3564545702974087D-01,  8.4444297875191077D-01), &
( -5.3629297906596307D-01,  8.4403189549006652D-01), ( -5.3694018561484291D-01,  8.4362031570600415D-01), &
( -5.3758707629564551D-01,  8.4320823964184544D-01), ( -5.3823365072782137D-01,  8.4279566754000435D-01), &
( -5.3887990853100820D-01,  8.4238259964318596D-01), ( -5.3952584932502878D-01,  8.4196903619438779D-01), &
( -5.4017147272989285D-01,  8.4155497743689844D-01), ( -5.4081677836579667D-01,  8.4114042361429808D-01), &
( -5.4146176585312322D-01,  8.4072537497045818D-01), ( -5.4210643481244369D-01,  8.4030983174954088D-01), &
( -5.4275078486451578D-01,  8.3989379419599963D-01), ( -5.4339481563028469D-01,  8.3947726255457855D-01), &
( -5.4403852673088382D-01,  8.3906023707031274D-01), ( -5.4468191778763464D-01,  8.3864271798852730D-01), &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.4596773825581735D-01,  8.3780620001515105D-01), &
( -5.4661016691083475D-01,  8.3738720161566205D-01), ( -5.4725227400917409D-01,  8.3696771060285702D-01)/
data (mpuu1(i), i =  6901,  7000) / &
( -5.4789405917310019D-01,  8.3654772722351201D-01), ( -5.4853552202506706D-01,  8.3612725172469238D-01), &
( -5.4917666218771954D-01,  8.3570628435375272D-01), ( -5.4981747928389080D-01,  8.3528482535833748D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -5.5109814276907543D-01,  8.3444043348610319D-01), &
( -5.5173798840470745D-01,  8.3401750110601802D-01), ( -5.5237750946709574D-01,  8.3359407809492536D-01), &
( -5.5301670558002736D-01,  8.3317016470191330D-01), ( -5.5365557636747920D-01,  8.3274576117635957D-01), &
( -5.5429412145362000D-01,  8.3232086776792968D-01), ( -5.5493234046281037D-01,  8.3189548472657759D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -5.5620779874873971D-01,  8.3104325074636243D-01), &
( -5.5684503727515988D-01,  8.3061640030884643D-01), ( -5.5748194822399144D-01,  8.3018906124110248D-01), &
( -5.5811853122055610D-01,  8.2976123379452305D-01), ( -5.5875478589036842D-01,  8.2933291822078825D-01), &
( -5.5939071185913580D-01,  8.2890411477186510D-01), ( -5.6002630875276016D-01,  8.2847482370000725D-01), &
( -5.6066157619733592D-01,  8.2804504525775591D-01), ( -5.6129651381915147D-01,  8.2761477969793840D-01), &
( -5.6193112124468947D-01,  8.2718402727366913D-01), ( -5.6256539810062656D-01,  8.2675278823834852D-01), &
( -5.6319934401383387D-01,  8.2632106284566365D-01), ( -5.6383295861137794D-01,  8.2588885134958701D-01), &
( -5.6446624152051939D-01,  8.2545615400437755D-01), ( -5.6509919236871398D-01,  8.2502297106458022D-01), &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.6636409639306362D-01,  8.2415514942082879D-01), &
( -5.6699604882510846D-01,  8.2372051122739154D-01), ( -5.6762766770798612D-01,  8.2328538846040022D-01), &
( -5.6825895267013149D-01,  8.2284978137582643D-01), ( -5.6888990334017586D-01,  8.2241369022992639D-01), &
( -5.6952051934694725D-01,  8.2197711527924144D-01), ( -5.7015080031947007D-01,  8.2154005678059772D-01), &
( -5.7078074588696714D-01,  8.2110251499110476D-01), ( -5.7141035567885723D-01,  8.2066449016815757D-01), &
( -5.7203962932475705D-01,  8.2022598256943469D-01), ( -5.7266856645448128D-01,  8.1978699245289888D-01), &
( -5.7329716669804198D-01,  8.1934752007679712D-01), ( -5.7392542968565052D-01,  8.1890756569965906D-01), &
( -5.7455335504771565D-01,  8.1846712958029877D-01), ( -5.7518094241484508D-01,  8.1802621197781344D-01), &
( -5.7580819141784534D-01,  8.1758481315158371D-01), ( -5.7643510168772183D-01,  8.1714293336127297D-01), &
( -5.7706167285567933D-01,  8.1670057286682796D-01), ( -5.7768790455312258D-01,  8.1625773192847761D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -5.7893934806308178D-01,  8.1537060976239129D-01), &
( -5.7956455913940574D-01,  8.1492632905652651D-01), ( -5.8018942927283135D-01,  8.1448156895049884D-01), &
( -5.8081395809576430D-01,  8.1403632970594852D-01), ( -5.8143814524081017D-01,  8.1359061158479862D-01), &
( -5.8206199034077544D-01,  8.1314441484925359D-01), ( -5.8268549302866846D-01,  8.1269773976179960D-01), &
( -5.8330865293769840D-01,  8.1225058658520388D-01), ( -5.8393146970127607D-01,  8.1180295558251558D-01), &
( -5.8455394295301510D-01,  8.1135484701706395D-01), ( -5.8517607232673030D-01,  8.1090626115245978D-01), &
( -5.8579785745643886D-01,  8.1045719825259477D-01), ( -5.8641929797636061D-01,  8.1000765858164114D-01), &
( -5.8704039352091775D-01,  8.0955764240405148D-01), ( -5.8766114372473655D-01,  8.0910714998455835D-01), &
( -5.8828154822264522D-01,  8.0865618158817509D-01), ( -5.8890160664967572D-01,  8.0820473748019483D-01), &
( -5.8952131864106394D-01,  8.0775281792619036D-01), ( -5.9014068383224894D-01,  8.0730042319201445D-01), &
( -5.9075970185887405D-01,  8.0684755354379945D-01), ( -5.9137837235678736D-01,  8.0639420924795635D-01), &
( -5.9199669496204088D-01,  8.0594039057117639D-01), ( -5.9261466931089113D-01,  8.0548609778042923D-01), &
( -5.9323229503979991D-01,  8.0503133114296355D-01), ( -5.9384957178543329D-01,  8.0457609092630733D-01), &
( -5.9446649918466432D-01,  8.0412037739826592D-01), ( -5.9508307687456985D-01,  8.0366419082692420D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -5.9631518167574371D-01,  8.0275039962806916D-01), &
( -5.9693070806219650D-01,  8.0229279553811561D-01), ( -5.9754588328969305D-01,  8.0183471947998153D-01), &
( -5.9816070699634216D-01,  8.0137617172314035D-01), ( -5.9877517882045861D-01,  8.0091715253734441D-01), &
( -5.9938929840056454D-01,  8.0045766219262282D-01), ( -6.0000306537538906D-01,  7.9999770095928191D-01), &
( -6.0061647938386864D-01,  7.9953726910790524D-01), ( -6.0122954006514839D-01,  7.9907636690935258D-01), &
( -6.0184224705857992D-01,  7.9861499463476093D-01), ( -6.0245460000372375D-01,  7.9815315255554387D-01), &
( -6.0306659854034816D-01,  7.9769084094339116D-01), ( -6.0367824230843048D-01,  7.9722806007026870D-01), &
( -6.0428953094815585D-01,  7.9676481020841894D-01), ( -6.0490046409991971D-01,  7.9630109163035923D-01), &
( -6.0551104140432543D-01,  7.9583690460888357D-01), ( -6.0612126250218612D-01,  7.9537224941706131D-01), &
( -6.0673112703452459D-01,  7.9490712632823701D-01), ( -6.0734063464257260D-01,  7.9444153561603081D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.0855857765177934D-01,  7.9350895241732666D-01), &
( -6.0916701233645310D-01,  7.9304196047944375D-01), ( -6.0977508866386843D-01,  7.9257450201540769D-01)/
data (mpuu1(i), i =  7001,  7100) / &
( -6.1038280627630948D-01,  7.9210657730021228D-01), ( -6.1099016481627155D-01,  7.9163818660912599D-01), &
( -6.1159716392646180D-01,  7.9116933021769031D-01), ( -6.1220380324979795D-01,  7.9070000840172172D-01), &
( -6.1281008242940971D-01,  7.9023022143731003D-01), ( -6.1341600110863870D-01,  7.8975996960081907D-01), &
( -6.1402155893103816D-01,  7.8928925316888587D-01), ( -6.1462675554037483D-01,  7.8881807241842039D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -6.1583606369598498D-01,  7.8787431907090022D-01), &
( -6.1644017453085365D-01,  7.8740174702903132D-01), ( -6.1704392272984987D-01,  7.8692871177900170D-01), &
( -6.1764730793780376D-01,  7.8645521359908588D-01), ( -6.1825032979976002D-01,  7.8598125276783026D-01), &
( -6.1885298796097621D-01,  7.8550682956405404D-01), ( -6.1945528206692402D-01,  7.8503194426684808D-01), &
( -6.2005721176328921D-01,  7.8455659715557524D-01), ( -6.2065877669597180D-01,  7.8408078850987017D-01), &
( -6.2125997651108744D-01,  7.8360451860963831D-01), ( -6.2186081085496525D-01,  7.8312778773505742D-01), &
( -6.2246127937414997D-01,  7.8265059616657573D-01), ( -6.2306138171540126D-01,  7.8217294418491301D-01), &
( -6.2366111752569464D-01,  7.8169483207105939D-01), ( -6.2426048645222043D-01,  7.8121626010627621D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.2545812224381425D-01,  7.8025773775031670D-01), &
( -6.2605638840434352D-01,  7.7977778792301455D-01), ( -6.2665428627202946D-01,  7.7929737937253030D-01), &
( -6.2725181549514386D-01,  7.7881651238147620D-01), ( -6.2784897572217635D-01,  7.7833518723273332D-01), &
( -6.2844576660183260D-01,  7.7785340420945315D-01), ( -6.2904218778303589D-01,  7.7737116359505631D-01), &
( -6.2963823891492698D-01,  7.7688846567323244D-01), ( -6.3023391964686448D-01,  7.7640531072794028D-01), &
( -6.3082922962842436D-01,  7.7592169904340780D-01), ( -6.3142416850940164D-01,  7.7543763090413065D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.3261293156987752D-01,  7.7446812640067086D-01), &
( -6.3320675505005730D-01,  7.7398269060682279D-01), ( -6.3380020603101694D-01,  7.7349679949889927D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -6.3498598909904935D-01,  7.7252365248444144D-01), &
( -6.3557832048855611D-01,  7.7203639715038452D-01), ( -6.3617027798371217D-01,  7.7154868764720630D-01), &
( -6.3676186123628431D-01,  7.7106052426181371D-01), ( -6.3735306989825891D-01,  7.7057190728138092D-01), &
( -6.3794390362184394D-01,  7.7008283699334812D-01), ( -6.3853436205946668D-01,  7.6959331368542305D-01), &
( -6.3912444486377573D-01,  7.6910333764557970D-01), ( -6.3971415168764056D-01,  7.6861290916205827D-01), &
( -6.4030348218415145D-01,  7.6812202852336564D-01), ( -6.4089243600662116D-01,  7.6763069601827350D-01), &
( -6.4148101280858305D-01,  7.6713891193582051D-01), ( -6.4206921224379243D-01,  7.6664667656531049D-01), &
( -6.4265703396622686D-01,  7.6615399019631292D-01), ( -6.4324447763008585D-01,  7.6566085311866239D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.4441822939998816D-01,  7.6467322799806725D-01), &
( -6.4500453681554393D-01,  7.6417874053611679D-01), ( -6.4559046479154869D-01,  7.6368380352750187D-01), &
( -6.4617601298331639D-01,  7.6318841726338127D-01), ( -6.4676118104638369D-01,  7.6269258203517820D-01), &
( -6.4734596863651195D-01,  7.6219629813457912D-01), ( -6.4793037540968523D-01,  7.6169956585353538D-01), &
( -6.4851440102211244D-01,  7.6120238548426189D-01), ( -6.4909804513022595D-01,  7.6070475731923692D-01), &
( -6.4968130739068330D-01,  7.6020668165120231D-01), ( -6.5026418746036574D-01,  7.5970815877316356D-01), &
( -6.5084668499638076D-01,  7.5920918897838818D-01), ( -6.5142879965605971D-01,  7.5870977256040750D-01), &
( -6.5201053109695950D-01,  7.5820990981301528D-01), ( -6.5259187897686255D-01,  7.5770960103026808D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -6.5375342268593595D-01,  7.5670764653624589D-01), &
( -6.5433361783180044D-01,  7.5620600141439454D-01), ( -6.5491342805005603D-01,  7.5570391143603599D-01), &
( -6.5549285299961535D-01,  7.5520137689653655D-01), ( -6.5607189233961771D-01,  7.5469839809152439D-01), &
( -6.5665054572942883D-01,  7.5419497531688928D-01), ( -6.5722881282864243D-01,  7.5369110886878143D-01), &
( -6.5780669329707853D-01,  7.5318679904361252D-01), ( -6.5838418679478505D-01,  7.5268204613805534D-01), &
( -6.5896129298203732D-01,  7.5217685044904270D-01), ( -6.5953801151933844D-01,  7.5167121227376865D-01), &
( -6.6011434206742026D-01,  7.5116513190968659D-01), ( -6.6069028428724219D-01,  7.5065860965451070D-01), &
( -6.6126583783999215D-01,  7.5015164580621507D-01), ( -6.6184100238708687D-01,  7.4964424066303348D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -6.6299016311112124D-01,  7.4862810768624555D-01), &
( -6.6356415861203966D-01,  7.4811938045040371D-01), ( -6.6413776375525990D-01,  7.4761021311520515D-01), &
( -6.6471097820334479D-01,  7.4710060598018013D-01), ( -6.6528380161908718D-01,  7.4659055934511720D-01), &
( -6.6585623366550939D-01,  7.4608007351006400D-01), ( -6.6642827400586513D-01,  7.4556914877532554D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -6.6757117822254020D-01,  7.4454598380930737D-01), &
( -6.6814204142651845D-01,  7.4403374417992929D-01), ( -6.6871251157974809D-01,  7.4352106685466901D-01)/
data (mpuu1(i), i =  7101,  7200) / &
( -6.6928258834663579D-01,  7.4300795213512183D-01), ( -6.6985227139182091D-01,  7.4249440032313940D-01), &
( -6.7042156038017298D-01,  7.4198041172083107D-01), ( -6.7099045497679422D-01,  7.4146598663056329D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -6.7212705965641151D-01,  7.4043582819689824D-01), &
( -6.7269476907077275D-01,  7.3992009545951631D-01), ( -6.7326208275613286D-01,  7.3940392744620587D-01), &
( -6.7382900037875604D-01,  7.3888732446061522D-01), ( -6.7439552160513905D-01,  7.3837028680664862D-01), &
( -6.7496164610201204D-01,  7.3785281478846598D-01), ( -6.7552737353633840D-01,  7.3733490871048302D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -6.7665763588637484D-01,  7.3629779559405317D-01), &
( -6.7722217013718033D-01,  7.3577858916571359D-01), ( -6.7778630599563150D-01,  7.3525894989778684D-01), &
( -6.7835004312986125D-01,  7.3473887809596372D-01), ( -6.7891338120823830D-01,  7.3421837406618851D-01), &
( -6.7947631989936497D-01,  7.3369743811466037D-01), ( -6.8003885887207893D-01,  7.3317607054783285D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -6.8116273633879543D-01,  7.3213204179536129D-01), &
( -6.8172407417164960D-01,  7.3160938122389274D-01), ( -6.8228501096379546D-01,  7.3108629026547445D-01), &
( -6.8284554638524797D-01,  7.3056276922782759D-01), ( -6.8340568010625868D-01,  7.3003881841892615D-01), &
( -6.8396541179731551D-01,  7.2951443814699701D-01), ( -6.8452474112914208D-01,  7.2898962872051964D-01), &
( -6.8508366777270024D-01,  7.2846439044822531D-01), ( -6.8564219139918736D-01,  7.2793872363909873D-01), &
( -6.8620031168003859D-01,  7.2741262860237588D-01), ( -6.8675802828692589D-01,  7.2688610564754486D-01), &
( -6.8731534089175916D-01,  7.2635915508434590D-01), ( -6.8787224916668532D-01,  7.2583177722277048D-01), &
( -6.8842875278409033D-01,  7.2530397237306088D-01), ( -6.8898485141659704D-01,  7.2477574084571139D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -6.9009583241859995D-01,  7.2371799900132339D-01), &
( -6.9065071413453438D-01,  7.2318848930652768D-01), ( -6.9120518955844823D-01,  7.2265855417857583D-01), &
( -6.9175925836415764D-01,  7.2212819392921546D-01), ( -6.9231292022571811D-01,  7.2159740887044377D-01), &
( -6.9286617481742463D-01,  7.2106619931450811D-01), ( -6.9341902181381188D-01,  7.2053456557390527D-01), &
( -6.9397146088965378D-01,  7.2000250796138188D-01), ( -6.9452349171996541D-01,  7.1947002678993321D-01), &
( -6.9507511398000077D-01,  7.1893712237280449D-01), ( -6.9562632734525487D-01,  7.1840379502348983D-01), &
( -6.9617713149146299D-01,  7.1787004505573171D-01), ( -6.9672752609460087D-01,  7.1733587278352196D-01), &
( -6.9727751083088640D-01,  7.1680127852109965D-01), ( -6.9782708537677718D-01,  7.1626626258295323D-01), &
( -6.9837624940897280D-01,  7.1573082528381871D-01), ( -6.9892500260441415D-01,  7.1519496693868012D-01), &
( -6.9947334464028388D-01,  7.1465868786276898D-01), ( -7.0002127519400614D-01,  7.1412198837156493D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.0111590056591855D-01,  7.1304732940642945D-01), &
( -7.0166259474016845D-01,  7.1250937056469232D-01), ( -7.0220887614439187D-01,  7.1197099257205010D-01), &
( -7.0275474445722508D-01,  7.1143219574521677D-01), ( -7.0330019935754851D-01,  7.1089298040115190D-01), &
( -7.0384524052448483D-01,  7.1035334685706242D-01), ( -7.0438986763740030D-01,  7.0981329543040095D-01), &
( -7.0493408037590488D-01,  7.0927282643886569D-01), ( -7.0547787841985221D-01,  7.0873194020040065D-01), &
( -7.0602126144933952D-01,  7.0819063703319551D-01), ( -7.0656422914470940D-01,  7.0764891725568457D-01), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), ( -7.0764891725568435D-01,  7.0656422914470951D-01), &
( -7.0819063703319540D-01,  7.0602126144933974D-01), ( -7.0873194020040042D-01,  7.0547787841985232D-01), &
( -7.0927282643886547D-01,  7.0493408037590510D-01), ( -7.0981329543040084D-01,  7.0438986763740052D-01), &
( -7.1035334685706231D-01,  7.0384524052448505D-01), ( -7.1089298040115168D-01,  7.0330019935754873D-01), &
( -7.1143219574521654D-01,  7.0275474445722519D-01), ( -7.1197099257204988D-01,  7.0220887614439198D-01), &
( -7.1250937056469232D-01,  7.0166259474016868D-01), ( -7.1304732940642923D-01,  7.0111590056591877D-01), &
( -7.1358486878079352D-01,  7.0056879394324834D-01), ( -7.1412198837156482D-01,  7.0002127519400625D-01), &
( -7.1465868786276887D-01,  6.9947334464028399D-01), ( -7.1519496693867990D-01,  6.9892500260441426D-01), &
( -7.1573082528381859D-01,  6.9837624940897292D-01), ( -7.1626626258295301D-01,  6.9782708537677740D-01), &
( -7.1680127852109954D-01,  6.9727751083088652D-01), ( -7.1733587278352173D-01,  6.9672752609460109D-01), &
( -7.1787004505573160D-01,  6.9617713149146310D-01), ( -7.1840379502348961D-01,  6.9562632734525498D-01), &
( -7.1893712237280438D-01,  6.9507511398000088D-01), ( -7.1947002678993299D-01,  6.9452349171996552D-01), &
( -7.2000250796138165D-01,  6.9397146088965389D-01), ( -7.2053456557390505D-01,  6.9341902181381210D-01), &
( -7.2106619931450799D-01,  6.9286617481742485D-01), ( -7.2159740887044366D-01,  6.9231292022571833D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.2265855417857572D-01,  6.9120518955844845D-01), &
( -7.2318848930652746D-01,  6.9065071413453460D-01), ( -7.2371799900132339D-01,  6.9009583241860006D-01)/
data (mpuu1(i), i =  7201,  7300) / &
( -7.2424708295146689D-01,  6.8954054473706705D-01), ( -7.2477574084571117D-01,  6.8898485141659715D-01), &
( -7.2530397237306077D-01,  6.8842875278409044D-01), ( -7.2583177722277037D-01,  6.8787224916668555D-01), &
( -7.2635915508434579D-01,  6.8731534089175927D-01), ( -7.2688610564754486D-01,  6.8675802828692600D-01), &
( -7.2741262860237565D-01,  6.8620031168003870D-01), ( -7.2793872363909862D-01,  6.8564219139918758D-01), &
( -7.2846439044822520D-01,  6.8508366777270036D-01), ( -7.2898962872051953D-01,  6.8452474112914219D-01), &
( -7.2951443814699690D-01,  6.8396541179731563D-01), ( -7.3003881841892615D-01,  6.8340568010625891D-01), &
( -7.3056276922782759D-01,  6.8284554638524808D-01), ( -7.3108629026547423D-01,  6.8228501096379557D-01), &
( -7.3160938122389263D-01,  6.8172407417164971D-01), ( -7.3213204179536118D-01,  6.8116273633879565D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.3317607054783274D-01,  6.8003885887207904D-01), &
( -7.3369743811466026D-01,  6.7947631989936508D-01), ( -7.3421837406618828D-01,  6.7891338120823841D-01), &
( -7.3473887809596361D-01,  6.7835004312986147D-01), ( -7.3525894989778662D-01,  6.7778630599563161D-01), &
( -7.3577858916571337D-01,  6.7722217013718056D-01), ( -7.3629779559405306D-01,  6.7665763588637495D-01), &
( -7.3681656887736979D-01,  6.7609270357531592D-01), ( -7.3733490871048291D-01,  6.7552737353633852D-01), &
( -7.3785281478846576D-01,  6.7496164610201226D-01), ( -7.3837028680664840D-01,  6.7439552160513916D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.3940392744620564D-01,  6.7326208275613308D-01), &
( -7.3992009545951620D-01,  6.7269476907077286D-01), ( -7.4043582819689813D-01,  6.7212705965641173D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.4146598663056318D-01,  6.7099045497679433D-01), &
( -7.4198041172083096D-01,  6.7042156038017320D-01), ( -7.4249440032313929D-01,  6.6985227139182102D-01), &
( -7.4300795213512172D-01,  6.6928258834663601D-01), ( -7.4352106685466890D-01,  6.6871251157974831D-01), &
( -7.4403374417992918D-01,  6.6814204142651867D-01), ( -7.4454598380930725D-01,  6.6757117822254042D-01), &
( -7.4505778544146595D-01,  6.6699992230363758D-01), ( -7.4556914877532543D-01,  6.6642827400586535D-01), &
( -7.4608007351006389D-01,  6.6585623366550961D-01), ( -7.4659055934511709D-01,  6.6528380161908740D-01), &
( -7.4710060598018002D-01,  6.6471097820334502D-01), ( -7.4761021311520515D-01,  6.6413776375526001D-01), &
( -7.4811938045040360D-01,  6.6356415861203977D-01), ( -7.4862810768624533D-01,  6.6299016311112147D-01), &
( -7.4913639452345904D-01,  6.6241577759017201D-01), ( -7.4964424066303337D-01,  6.6184100238708699D-01), &
( -7.5015164580621496D-01,  6.6126583783999227D-01), ( -7.5065860965451059D-01,  6.6069028428724230D-01), &
( -7.5116513190968637D-01,  6.6011434206742048D-01), ( -7.5167121227376854D-01,  6.5953801151933855D-01), &
( -7.5217685044904259D-01,  6.5896129298203754D-01), ( -7.5268204613805523D-01,  6.5838418679478528D-01), &
( -7.5318679904361241D-01,  6.5780669329707875D-01), ( -7.5369110886878132D-01,  6.5722881282864254D-01), &
( -7.5419497531688917D-01,  6.5665054572942905D-01), ( -7.5469839809152428D-01,  6.5607189233961793D-01), &
( -7.5520137689653644D-01,  6.5549285299961557D-01), ( -7.5570391143603577D-01,  6.5491342805005615D-01), &
( -7.5620600141439454D-01,  6.5433361783180055D-01), ( -7.5670764653624567D-01,  6.5375342268593606D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -7.5770960103026797D-01,  6.5259187897686277D-01), &
( -7.5820990981301517D-01,  6.5201053109695972D-01), ( -7.5870977256040728D-01,  6.5142879965605993D-01), &
( -7.5920918897838796D-01,  6.5084668499638099D-01), ( -7.5970815877316344D-01,  6.5026418746036585D-01), &
( -7.6020668165120220D-01,  6.4968130739068342D-01), ( -7.6070475731923681D-01,  6.4909804513022618D-01), &
( -7.6120238548426178D-01,  6.4851440102211255D-01), ( -7.6169956585353527D-01,  6.4793037540968546D-01), &
( -7.6219629813457890D-01,  6.4734596863651206D-01), ( -7.6269258203517798D-01,  6.4676118104638380D-01), &
( -7.6318841726338116D-01,  6.4617601298331651D-01), ( -7.6368380352750176D-01,  6.4559046479154891D-01), &
( -7.6417874053611667D-01,  6.4500453681554404D-01), ( -7.6467322799806714D-01,  6.4441822939998838D-01), &
( -7.6516726562245896D-01,  6.4383154288979139D-01), ( -7.6566085311866228D-01,  6.4324447763008608D-01), &
( -7.6615399019631281D-01,  6.4265703396622709D-01), ( -7.6664667656531038D-01,  6.4206921224379265D-01), &
( -7.6713891193582029D-01,  6.4148101280858316D-01), ( -7.6763069601827338D-01,  6.4089243600662138D-01), &
( -7.6812202852336542D-01,  6.4030348218415156D-01), ( -7.6861290916205816D-01,  6.3971415168764068D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -7.6959331368542294D-01,  6.3853436205946679D-01), &
( -7.7008283699334790D-01,  6.3794390362184406D-01), ( -7.7057190728138081D-01,  6.3735306989825913D-01), &
( -7.7106052426181360D-01,  6.3676186123628442D-01), ( -7.7154868764720619D-01,  6.3617027798371228D-01), &
( -7.7203639715038441D-01,  6.3557832048855623D-01), ( -7.7252365248444121D-01,  6.3498598909904957D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -7.7349679949889916D-01,  6.3380020603101717D-01), &
( -7.7398269060682257D-01,  6.3320675505005741D-01), ( -7.7446812640067075D-01,  6.3261293156987763D-01)/
data (mpuu1(i), i =  7301,  7400) / &
( -7.7495310659487382D-01,  6.3201873593980906D-01), ( -7.7543763090413054D-01,  6.3142416850940186D-01), &
( -7.7592169904340769D-01,  6.3082922962842447D-01), ( -7.7640531072794017D-01,  6.3023391964686470D-01), &
( -7.7688846567323233D-01,  6.2963823891492721D-01), ( -7.7737116359505620D-01,  6.2904218778303611D-01), &
( -7.7785340420945304D-01,  6.2844576660183271D-01), ( -7.7833518723273321D-01,  6.2784897572217657D-01), &
( -7.7881651238147609D-01,  6.2725181549514408D-01), ( -7.7929737937253007D-01,  6.2665428627202968D-01), &
( -7.7977778792301433D-01,  6.2605638840434363D-01), ( -7.8025773775031659D-01,  6.2545812224381436D-01), &
( -7.8073722857209449D-01,  6.2485948814238634D-01), ( -7.8121626010627609D-01,  6.2426048645222065D-01), &
( -7.8169483207105928D-01,  6.2366111752569486D-01), ( -7.8217294418491279D-01,  6.2306138171540149D-01), &
( -7.8265059616657562D-01,  6.2246127937415008D-01), ( -7.8312778773505731D-01,  6.2186081085496536D-01), &
( -7.8360451860963831D-01,  6.2125997651108755D-01), ( -7.8408078850987006D-01,  6.2065877669597203D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), ( -7.8503194426684797D-01,  6.1945528206692413D-01), &
( -7.8550682956405393D-01,  6.1885298796097643D-01), ( -7.8598125276783015D-01,  6.1825032979976025D-01), &
( -7.8645521359908577D-01,  6.1764730793780387D-01), ( -7.8692871177900159D-01,  6.1704392272984998D-01), &
( -7.8740174702903132D-01,  6.1644017453085376D-01), ( -7.8787431907090011D-01,  6.1583606369598509D-01), &
( -7.8834642762660623D-01,  6.1523159058062693D-01), ( -7.8881807241842028D-01,  6.1462675554037505D-01), &
( -7.8928925316888576D-01,  6.1402155893103838D-01), ( -7.8975996960081885D-01,  6.1341600110863881D-01), &
( -7.9023022143730992D-01,  6.1281008242940982D-01), ( -7.9070000840172161D-01,  6.1220380324979806D-01), &
( -7.9116933021769009D-01,  6.1159716392646191D-01), ( -7.9163818660912588D-01,  6.1099016481627166D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -7.9257450201540758D-01,  6.0977508866386854D-01), &
( -7.9304196047944364D-01,  6.0916701233645332D-01), ( -7.9350895241732655D-01,  6.0855857765177945D-01), &
( -7.9397547755433717D-01,  6.0794978496777363D-01), ( -7.9444153561603059D-01,  6.0734063464257282D-01), &
( -7.9490712632823679D-01,  6.0673112703452470D-01), ( -7.9537224941706119D-01,  6.0612126250218634D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -7.9630109163035911D-01,  6.0490046409991982D-01), &
( -7.9676481020841883D-01,  6.0428953094815596D-01), ( -7.9722806007026858D-01,  6.0367824230843059D-01), &
( -7.9769084094339093D-01,  6.0306659854034839D-01), ( -7.9815315255554375D-01,  6.0245460000372386D-01), &
( -7.9861499463476082D-01,  6.0184224705858014D-01), ( -7.9907636690935235D-01,  6.0122954006514850D-01), &
( -7.9953726910790501D-01,  6.0061647938386886D-01), ( -7.9999770095928180D-01,  6.0000306537538928D-01), &
( -8.0045766219262271D-01,  5.9938929840056465D-01), ( -8.0091715253734430D-01,  5.9877517882045883D-01), &
( -8.0137617172314024D-01,  5.9816070699634238D-01), ( -8.0183471947998131D-01,  5.9754588328969316D-01), &
( -8.0229279553811561D-01,  5.9693070806219672D-01), ( -8.0275039962806904D-01,  5.9631518167574393D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.0366419082692409D-01,  5.9508307687457007D-01), &
( -8.0412037739826570D-01,  5.9446649918466443D-01), ( -8.0457609092630711D-01,  5.9384957178543352D-01), &
( -8.0503133114296344D-01,  5.9323229503980002D-01), ( -8.0548609778042901D-01,  5.9261466931089135D-01), &
( -8.0594039057117628D-01,  5.9199669496204099D-01), ( -8.0639420924795635D-01,  5.9137837235678758D-01), &
( -8.0684755354379933D-01,  5.9075970185887416D-01), ( -8.0730042319201423D-01,  5.9014068383224916D-01), &
( -8.0775281792619025D-01,  5.8952131864106405D-01), ( -8.0820473748019461D-01,  5.8890160664967595D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), ( -8.0910714998455824D-01,  5.8766114372473666D-01), &
( -8.0955764240405137D-01,  5.8704039352091786D-01), ( -8.1000765858164092D-01,  5.8641929797636072D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.1090626115245967D-01,  5.8517607232673052D-01), &
( -8.1135484701706373D-01,  5.8455394295301533D-01), ( -8.1180295558251547D-01,  5.8393146970127618D-01), &
( -8.1225058658520366D-01,  5.8330865293769851D-01), ( -8.1269773976179938D-01,  5.8268549302866857D-01), &
( -8.1314441484925348D-01,  5.8206199034077566D-01), ( -8.1359061158479840D-01,  5.8143814524081028D-01), &
( -8.1403632970594841D-01,  5.8081395809576453D-01), ( -8.1448156895049872D-01,  5.8018942927283157D-01), &
( -8.1492632905652640D-01,  5.7956455913940597D-01), ( -8.1537060976239117D-01,  5.7893934806308200D-01), &
( -8.1581441080673378D-01,  5.7831379641165570D-01), ( -8.1625773192847739D-01,  5.7768790455312280D-01), &
( -8.1670057286682785D-01,  5.7706167285567944D-01), ( -8.1714293336127275D-01,  5.7643510168772205D-01), &
( -8.1758481315158360D-01,  5.7580819141784545D-01), ( -8.1802621197781344D-01,  5.7518094241484530D-01), &
( -8.1846712958029866D-01,  5.7455335504771587D-01), ( -8.1890756569965895D-01,  5.7392542968565075D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.1978699245289888D-01,  5.7266856645448150D-01), &
( -8.2022598256943458D-01,  5.7203962932475727D-01), ( -8.2066449016815746D-01,  5.7141035567885734D-01)/
data (mpuu1(i), i =  7401,  7500) / &
( -8.2110251499110465D-01,  5.7078074588696726D-01), ( -8.2154005678059761D-01,  5.7015080031947030D-01), &
( -8.2197711527924144D-01,  5.6952051934694747D-01), ( -8.2241369022992628D-01,  5.6888990334017608D-01), &
( -8.2284978137582621D-01,  5.6825895267013171D-01), ( -8.2328538846040011D-01,  5.6762766770798634D-01), &
( -8.2372051122739143D-01,  5.6699604882510868D-01), ( -8.2415514942082857D-01,  5.6636409639306373D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.2502297106458011D-01,  5.6509919236871420D-01), &
( -8.2545615400437744D-01,  5.6446624152051950D-01), ( -8.2588885134958678D-01,  5.6383295861137817D-01), &
( -8.2632106284566353D-01,  5.6319934401383409D-01), ( -8.2675278823834841D-01,  5.6256539810062678D-01), &
( -8.2718402727366902D-01,  5.6193112124468958D-01), ( -8.2761477969793829D-01,  5.6129651381915169D-01), &
( -8.2804504525775569D-01,  5.6066157619733603D-01), ( -8.2847482370000713D-01,  5.6002630875276038D-01), &
( -8.2890411477186499D-01,  5.5939071185913603D-01), ( -8.2933291822078803D-01,  5.5875478589036853D-01), &
( -8.2976123379452293D-01,  5.5811853122055632D-01), ( -8.3018906124110226D-01,  5.5748194822399166D-01), &
( -8.3061640030884631D-01,  5.5684503727516010D-01), ( -8.3104325074636232D-01,  5.5620779874873993D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -8.3189548472657748D-01,  5.5493234046281059D-01), &
( -8.3232086776792957D-01,  5.5429412145362023D-01), ( -8.3274576117635946D-01,  5.5365557636747931D-01), &
( -8.3317016470191319D-01,  5.5301670558002747D-01), ( -8.3359407809492525D-01,  5.5237750946709596D-01), &
( -8.3401750110601802D-01,  5.5173798840470767D-01), ( -8.3444043348610308D-01,  5.5109814276907554D-01), &
( -8.3486287498638001D-01,  5.5045797293660492D-01), ( -8.3528482535833737D-01,  5.4981747928389091D-01), &
( -8.3570628435375260D-01,  5.4917666218771966D-01), ( -8.3612725172469227D-01,  5.4853552202506728D-01), &
( -8.3654772722351189D-01,  5.4789405917310030D-01), ( -8.3696771060285691D-01,  5.4725227400917420D-01), &
( -8.3738720161566182D-01,  5.4661016691083497D-01), ( -8.3780620001515094D-01,  5.4596773825581757D-01), &
( -8.3822470555483808D-01,  5.4532498842204635D-01), ( -8.3864271798852719D-01,  5.4468191778763475D-01), &
( -8.3906023707031263D-01,  5.4403852673088404D-01), ( -8.3947726255457844D-01,  5.4339481563028491D-01), &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.4030983174954077D-01,  5.4210643481244392D-01), &
( -8.4072537497045818D-01,  5.4146176585312333D-01), ( -8.4114042361429797D-01,  5.4081677836579678D-01), &
( -8.4155497743689833D-01,  5.4017147272989297D-01), ( -8.4196903619438768D-01,  5.3952584932502901D-01), &
( -8.4238259964318585D-01,  5.3887990853100842D-01), ( -8.4279566754000423D-01,  5.3823365072782159D-01), &
( -8.4320823964184533D-01,  5.3758707629564573D-01), ( -8.4362031570600404D-01,  5.3694018561484314D-01), &
( -8.4403189549006641D-01,  5.3629297906596318D-01), ( -8.4444297875191066D-01,  5.3564545702974109D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.4526365474191834D-01,  5.3434946801913741D-01), &
( -8.4567324698729895D-01,  5.3370100180715319D-01), ( -8.4608234174489683D-01,  5.3305222163261967D-01), &
( -8.4649093877405202D-01,  5.3240312787719801D-01), ( -8.4689903783439724D-01,  5.3175372092273332D-01), &
( -8.4730663868585843D-01,  5.3110400115125489D-01), ( -8.4771374108865416D-01,  5.3045396894497665D-01), &
( -8.4812034480329712D-01,  5.2980362468629483D-01), ( -8.4852644959059265D-01,  5.2915296875779072D-01), &
( -8.4893205521163961D-01,  5.2850200154222848D-01), ( -8.4933716142783078D-01,  5.2785072342255523D-01), &
( -8.4974176800085255D-01,  5.2719913478190128D-01), ( -8.5014587469268510D-01,  5.2654723600357956D-01), &
( -8.5054948126560337D-01,  5.2589502747108485D-01), ( -8.5095258748217573D-01,  5.2524250956809471D-01), &
( -8.5135519310526520D-01,  5.2458968267846895D-01), ( -8.5175729789802923D-01,  5.2393654718624849D-01), &
( -8.5215890162391972D-01,  5.2328310347565665D-01), ( -8.5256000404668397D-01,  5.2262935193109683D-01), &
( -8.5296060493036363D-01,  5.2197529293715439D-01), ( -8.5336070403929543D-01,  5.2132092687859566D-01), &
( -8.5376030113811141D-01,  5.2066625414036716D-01), ( -8.5415939599173885D-01,  5.2001127510759593D-01), &
( -8.5455798836540042D-01,  5.1935599016558975D-01), ( -8.5495607802461482D-01,  5.1870039969983517D-01), &
( -8.5535366473519603D-01,  5.1804450409599945D-01), ( -8.5575074826325381D-01,  5.1738830373992906D-01), &
( -8.5614732837519458D-01,  5.1673179901764976D-01), ( -8.5654340483771985D-01,  5.1607499031536685D-01), &
( -8.5693897741782865D-01,  5.1541787801946315D-01), ( -8.5733404588281559D-01,  5.1476046251650120D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.5812266953808614D-01,  5.1344472343654346D-01), &
( -8.5851622426444285D-01,  5.1278640063356296D-01), ( -8.5890927394782368D-01,  5.1212777617155492D-01), &
( -8.5930181835700825D-01,  5.1146885043797052D-01), ( -8.5969385726107261D-01,  5.1080962382043915D-01), &
( -8.6008539042939014D-01,  5.1015009670676681D-01), ( -8.6047641763163218D-01,  5.0949026948493625D-01), &
( -8.6086693863776720D-01,  5.0883014254310732D-01), ( -8.6125695321806206D-01,  5.0816971626961482D-01), &
( -8.6164646114308130D-01,  5.0750899105297098D-01), ( -8.6203546218368721D-01,  5.0684796728186332D-01)/
data (mpuu1(i), i =  7501,  7600) / &
( -8.6242395611104050D-01,  5.0618664534515523D-01), ( -8.6281194269660044D-01,  5.0552502563188528D-01), &
( -8.6319942171212405D-01,  5.0486310853126770D-01), ( -8.6358639292966799D-01,  5.0420089443269056D-01), &
( -8.6397285612158670D-01,  5.0353838372571758D-01), ( -8.6435881106053403D-01,  5.0287557680008699D-01), &
( -8.6474425751946238D-01,  5.0221247404571068D-01), ( -8.6512919527162357D-01,  5.0154907585267561D-01), &
( -8.6551362409056898D-01,  5.0088538261124094D-01), ( -8.6589754375014882D-01,  5.0022139471184068D-01), &
( -8.6628095402451299D-01,  4.9955711254508189D-01), ( -8.6666385468811113D-01,  4.9889253650174459D-01), &
( -8.6704624551569265D-01,  4.9822766697278176D-01), ( -8.6742812628230681D-01,  4.9756250434931937D-01), &
( -8.6780949676330321D-01,  4.9689704902265469D-01), ( -8.6819035673433120D-01,  4.9623130138425836D-01), &
( -8.6857070597134090D-01,  4.9556526182577254D-01), ( -8.6895054425058249D-01,  4.9489893073901114D-01), &
( -8.6932987134860662D-01,  4.9423230851595995D-01), ( -8.6970868704226556D-01,  4.9356539554877493D-01), &
( -8.7008699110871135D-01,  4.9289819222978415D-01), ( -8.7046478332539756D-01,  4.9223069895148608D-01), &
( -8.7084206347007886D-01,  4.9156291610654990D-01), ( -8.7121883132081102D-01,  4.9089484408781503D-01), &
( -8.7159508665595098D-01,  4.9022648328829138D-01), ( -8.7197082925415770D-01,  4.8955783410115761D-01), &
( -8.7234605889439143D-01,  4.8888889691976323D-01), ( -8.7272077535591430D-01,  4.8821967213762679D-01), &
( -8.7309497841829020D-01,  4.8755016014843588D-01), ( -8.7346866786138477D-01,  4.8688036134604762D-01), &
( -8.7384184346536675D-01,  4.8621027612448658D-01), ( -8.7421450501070619D-01,  4.8553990487794707D-01), &
( -8.7458665227817611D-01,  4.8486924800079112D-01), ( -8.7495828504885165D-01,  4.8419830588754903D-01), &
( -8.7532940310411089D-01,  4.8352707893291863D-01), ( -8.7570000622563449D-01,  4.8285556753176589D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -8.7643966679571361D-01,  4.8151169297018998D-01), &
( -8.7680872380914565D-01,  4.8083933060033396D-01), ( -8.7717726501859605D-01,  4.8016668536508833D-01), &
( -8.7754529020726113D-01,  4.7949375766015329D-01), ( -8.7791279915864173D-01,  4.7882054788139411D-01), &
( -8.7827979165654146D-01,  4.7814705642484318D-01), ( -8.7864626748506813D-01,  4.7747328368669811D-01), &
( -8.7901222642863353D-01,  4.7679923006332209D-01), ( -8.7937766827195329D-01,  4.7612489595124352D-01), &
( -8.7974259280004730D-01,  4.7545028174715609D-01), ( -8.8010699979824025D-01,  4.7477538784791729D-01), &
( -8.8047088905216075D-01,  4.7410021465055008D-01), ( -8.8083426034774193D-01,  4.7342476255224153D-01), &
( -8.8119711347122209D-01,  4.7274903195034274D-01), ( -8.8155944820914367D-01,  4.7207302324236894D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -8.8228256167600860D-01,  4.7072017309907177D-01), &
( -8.8264333997956279D-01,  4.7004333245959568D-01), ( -8.8300359904678083D-01,  4.6936621530573752D-01), &
( -8.8336333866573169D-01,  4.6868882203582785D-01), ( -8.8372255862478943D-01,  4.6801115304836005D-01), &
( -8.8408125871263488D-01,  4.6733320874198858D-01), ( -8.8443943871825370D-01,  4.6665498951553103D-01), &
( -8.8479709843093779D-01,  4.6597649576796618D-01), ( -8.8515423764028511D-01,  4.6529772789843454D-01), &
( -8.8551085613619984D-01,  4.6461868630623809D-01), ( -8.8586695370889268D-01,  4.6393937139083874D-01), &
( -8.8622253014888053D-01,  4.6325978355186032D-01), ( -8.8657758524698704D-01,  4.6257992318908686D-01), &
( -8.8693211879434219D-01,  4.6189979070246273D-01), ( -8.8728613058238326D-01,  4.6121938649209226D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -8.8799258804780545D-01,  4.5985776450132965D-01), &
( -8.8834503330959624D-01,  4.5917654752194420D-01), ( -8.8869695598089160D-01,  4.5849506042082627D-01), &
( -8.8904835585466457D-01,  4.5781330359887717D-01), ( -8.8939923272419541D-01,  4.5713127745715720D-01), &
( -8.8974958638307267D-01,  4.5644898239688414D-01), ( -8.9009941662519221D-01,  4.5576641881943480D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -8.9079750603628149D-01,  4.5440048771930358D-01), &
( -8.9114576479458329D-01,  4.5371712100016376D-01), ( -8.9149349931479127D-01,  4.5303348737093185D-01), &
( -8.9184070939234261D-01,  4.5234958723377100D-01), ( -8.9218739482298248D-01,  4.5166542099100260D-01), &
( -8.9253355540276458D-01,  4.5098098904510386D-01), ( -8.9287919092805179D-01,  4.5029629179870856D-01), &
( -8.9322430119551521D-01,  4.4961132965460687D-01), ( -8.9356888600213591D-01,  4.4892610301574348D-01), &
( -8.9391294514520325D-01,  4.4824061228522005D-01), ( -8.9425647842231604D-01,  4.4755485786629307D-01), &
( -8.9459948563138270D-01,  4.4686884016237416D-01), ( -8.9494196657062075D-01,  4.4618255957702996D-01), &
( -8.9528392103855747D-01,  4.4549601651398196D-01), ( -8.9562534883403000D-01,  4.4480921137710505D-01), &
( -8.9596624975618511D-01,  4.4412214457042931D-01), ( -8.9630662360447955D-01,  4.4343481649813848D-01), &
( -8.9664647017868027D-01,  4.4274722756456997D-01), ( -8.9698578927886385D-01,  4.4205937817421503D-01), &
( -8.9732458070541821D-01,  4.4137126873171689D-01), ( -8.9766284425904075D-01,  4.4068289964187302D-01), &
( -8.9800057974073977D-01,  4.3999427130963331D-01), ( -8.9833778695183431D-01,  4.3930538414009995D-01)/
data (mpuu1(i), i =  7601,  7700) / &
( -8.9867446569395393D-01,  4.3861623853852755D-01), ( -8.9901061576903896D-01,  4.3792683491032314D-01), &
( -8.9934623697934146D-01,  4.3723717366104425D-01), ( -8.9968132912742393D-01,  4.3654725519640131D-01), &
( -9.0001589201616028D-01,  4.3585707992225547D-01), ( -9.0034992544873571D-01,  4.3516664824461920D-01), &
( -9.0068342922864675D-01,  4.3447596056965598D-01), ( -9.0101640315970222D-01,  4.3378501730367874D-01), &
( -9.0134884704602192D-01,  4.3309381885315207D-01), ( -9.0168076069203773D-01,  4.3240236562469020D-01), &
( -9.0201214390249318D-01,  4.3171065802505726D-01), ( -9.0234299648244432D-01,  4.3101869646116692D-01), &
( -9.0267331823725871D-01,  4.3032648134008289D-01), ( -9.0300310897261704D-01,  4.2963401306901655D-01), &
( -9.0333236849451182D-01,  4.2894129205532960D-01), ( -9.0366109660924798D-01,  4.2824831870653196D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.0431695784402821D-01,  4.2686161663438676D-01), &
( -9.0464409057824613D-01,  4.2616788872679984D-01), ( -9.0497069113365325D-01,  4.2547391011562397D-01), &
( -9.0529675931811870D-01,  4.2477968120910886D-01), ( -9.0562229493982527D-01,  4.2408520241565156D-01), &
( -9.0594729780726846D-01,  4.2339047414379594D-01), ( -9.0627176772925755D-01,  4.2269549680223323D-01), &
( -9.0659570451491533D-01,  4.2200027079979985D-01), ( -9.0691910797367803D-01,  4.2130479654547975D-01), &
( -9.0724197791529582D-01,  4.2060907444840251D-01), ( -9.0756431414983263D-01,  4.1991310491784356D-01), &
( -9.0788611648766604D-01,  4.1921688836322424D-01), ( -9.0820738473948859D-01,  4.1852042519410992D-01), &
( -9.0852811871630612D-01,  4.1782371582021244D-01), ( -9.0884831822943901D-01,  4.1712676065138793D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.0948711311150543D-01,  4.1573211456910525D-01), &
( -9.0980570810465211D-01,  4.1503442447608185D-01), ( -9.1012376788254157D-01,  4.1433649022899927D-01), &
( -9.1044129225806714D-01,  4.1363831223843461D-01), ( -9.1075828104443757D-01,  4.1293989091510808D-01), &
( -9.1107473405517636D-01,  4.1224122666988283D-01), ( -9.1139065110412221D-01,  4.1154231991376550D-01), &
( -9.1170603200542977D-01,  4.1084317105790413D-01), ( -9.1202087657356823D-01,  4.1014378051359035D-01), &
( -9.1233518462332275D-01,  4.0944414869225765D-01), ( -9.1264895596979390D-01,  4.0874427600548136D-01), &
( -9.1296219042839821D-01,  4.0804416286497858D-01), ( -9.1327488781486765D-01,  4.0734380968260819D-01), &
( -9.1358704794525081D-01,  4.0664321687036920D-01), ( -9.1389867063591157D-01,  4.0594238484040257D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.1452030296510456D-01,  4.0454000477655294D-01), &
( -9.1483031223794598D-01,  4.0383845756765441D-01), ( -9.1513978333968515D-01,  4.0313667279099547D-01), &
( -9.1544871608826772D-01,  4.0243465085941854D-01), ( -9.1575711030195672D-01,  4.0173239218590506D-01), &
( -9.1606496579933172D-01,  4.0102989718357562D-01), ( -9.1637228239928914D-01,  4.0032716626568998D-01), &
( -9.1667905992104259D-01,  3.9962419984564707D-01), ( -9.1698529818412289D-01,  3.9892099833698302D-01), &
( -9.1729099700837791D-01,  3.9821756215337367D-01), ( -9.1759615621397284D-01,  3.9751389170863238D-01), &
( -9.1790077562139050D-01,  3.9680998741671025D-01), ( -9.1820485505143079D-01,  3.9610584969169654D-01), &
( -9.1850839432521214D-01,  3.9540147894781652D-01), ( -9.1881139326416994D-01,  3.9469687559943373D-01), &
( -9.1911385169005777D-01,  3.9399204006104815D-01), ( -9.1941576942494707D-01,  3.9328697274729640D-01), &
( -9.1971714629122736D-01,  3.9258167407295141D-01), ( -9.2001798211160646D-01,  3.9187614445292257D-01), &
( -9.2031827670911048D-01,  3.9117038430225404D-01), ( -9.2061802990708386D-01,  3.9046439403612671D-01), &
( -9.2091724152918941D-01,  3.8975817406985647D-01), ( -9.2121591139940873D-01,  3.8905172481889433D-01), &
( -9.2151403934204179D-01,  3.8834504669882658D-01), ( -9.2181162518170801D-01,  3.8763814012537290D-01), &
( -9.2210866874334507D-01,  3.8693100551438869D-01), ( -9.2240516985220988D-01,  3.8622364328186304D-01), &
( -9.2270112833387863D-01,  3.8551605384391885D-01), ( -9.2299654401424636D-01,  3.8480823761681276D-01), &
( -9.2329141671952752D-01,  3.8410019501693532D-01), ( -9.2358574627625656D-01,  3.8339192646080883D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), ( -9.2417277525179109D-01,  3.8197471314656728D-01), &
( -9.2446547432526271D-01,  3.8126576922216232D-01), ( -9.2475762955951379D-01,  3.8055660100892880D-01), &
( -9.2504924078267747D-01,  3.7984720892405138D-01), ( -9.2534030782320620D-01,  3.7913759338484748D-01), &
( -9.2563083050987272D-01,  3.7842775480876562D-01), ( -9.2592080867177007D-01,  3.7771769361338564D-01), &
( -9.2621024213831138D-01,  3.7700741021641815D-01), ( -9.2649913073923040D-01,  3.7629690503570506D-01), &
( -9.2678747430458175D-01,  3.7558617848921738D-01), ( -9.2707527266474010D-01,  3.7487523099505765D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.2764923309258118D-01,  3.7345267483678024D-01), &
( -9.2793539482261778D-01,  3.7274106700951604D-01), ( -9.2822101067216933D-01,  3.7202923990828524D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.2879060405805691D-01,  3.7060492955905167D-01), &
( -9.2907458125931575D-01,  3.6989244714893410D-01), ( -9.2935801190993561D-01,  3.6917974714061991D-01)/
data (mpuu1(i), i =  7701,  7800) / &
( -9.2964089584318121D-01,  3.6846682995337260D-01), ( -9.2992323289263956D-01,  3.6775369600658214D-01), &
( -9.3020502289221896D-01,  3.6704034571976729D-01), ( -9.3048626567614967D-01,  3.6632677951257364D-01), &
( -9.3076696107898371D-01,  3.6561299780477380D-01), ( -9.3104710893559517D-01,  3.6489900101626760D-01), &
( -9.3132670908118032D-01,  3.6418478956708011D-01), ( -9.3160576135125783D-01,  3.6347036387736392D-01), &
( -9.3188426558166815D-01,  3.6275572436739728D-01), ( -9.3216222160857443D-01,  3.6204087145758418D-01), &
( -9.3243962926846247D-01,  3.6132580556845417D-01), ( -9.3271648839814014D-01,  3.6061052712066255D-01), &
( -9.3299279883473885D-01,  3.5989503653498833D-01), ( -9.3326856041571205D-01,  3.5917933423233661D-01), &
( -9.3354377297883617D-01,  3.5846342063373660D-01), ( -9.3381843636221096D-01,  3.5774729616034184D-01), &
( -9.3409255040425876D-01,  3.5703096123343031D-01), ( -9.3436611494372579D-01,  3.5631441627440258D-01), &
( -9.3463912981968067D-01,  3.5559766170478402D-01), ( -9.3491159487151609D-01,  3.5488069794622285D-01), &
( -9.3518350993894761D-01,  3.5416352542049034D-01), ( -9.3545487486201473D-01,  3.5344614454948070D-01), &
( -9.3572568948108026D-01,  3.5272855575521095D-01), ( -9.3599595363683130D-01,  3.5201075945981930D-01), &
( -9.3626566717027826D-01,  3.5129275608556720D-01), ( -9.3653482992275550D-01,  3.5057454605483757D-01), &
( -9.3680344173592167D-01,  3.4985612979013486D-01), ( -9.3707150245175908D-01,  3.4913750771408525D-01), &
( -9.3733901191257485D-01,  3.4841868024943479D-01), ( -9.3760596996099999D-01,  3.4769964781905149D-01), &
( -9.3787237643998977D-01,  3.4698041084592374D-01), ( -9.3813823119282436D-01,  3.4626096975316001D-01), &
( -9.3840353406310817D-01,  3.4554132496398898D-01), ( -9.3866828489477006D-01,  3.4482147690175957D-01), &
( -9.3893248353206449D-01,  3.4410142598993904D-01), ( -9.3919612981956990D-01,  3.4338117265211515D-01), &
( -9.3945922360218992D-01,  3.4266071731199443D-01), ( -9.3972176472515334D-01,  3.4194006039340213D-01), &
( -9.3998375303401382D-01,  3.4121920232028269D-01), ( -9.4024518837465076D-01,  3.4049814351669738D-01), &
( -9.4050607059326830D-01,  3.3977688440682702D-01), ( -9.4076639953639607D-01,  3.3905542541496969D-01), &
( -9.4102617505088926D-01,  3.3833376696554113D-01), ( -9.4128539698392877D-01,  3.3761190948307451D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.4180217949599765D-01,  3.3616759911774469D-01), &
( -9.4205973977101731D-01,  3.3544514708453171D-01), ( -9.4231674585656378D-01,  3.3472249771758128D-01), &
( -9.4257319760144687D-01,  3.3399965144200933D-01), ( -9.4282909485480260D-01,  3.3327660868304820D-01), &
( -9.4308443746609338D-01,  3.3255336986604445D-01), ( -9.4333922528510772D-01,  3.3182993541646127D-01), &
( -9.4359345816196039D-01,  3.3110630575987648D-01), ( -9.4384713594709269D-01,  3.3038248132198278D-01), &
( -9.4410025849127266D-01,  3.2965846252858744D-01), ( -9.4435282564559464D-01,  3.2893424980561242D-01), &
( -9.4460483726148015D-01,  3.2820984357909272D-01), ( -9.4485629319067721D-01,  3.2748524427517811D-01), &
( -9.4510719328526061D-01,  3.2676045232013179D-01), ( -9.4535753739763229D-01,  3.2603546814033019D-01), &
( -9.4560732538052128D-01,  3.2531029216226320D-01), ( -9.4585655708698380D-01,  3.2458492481253237D-01), &
( -9.4610523237040334D-01,  3.2385936651785302D-01), ( -9.4635335108449059D-01,  3.2313361770505239D-01), &
( -9.4660091308328353D-01,  3.2240767880106985D-01), ( -9.4684791822114811D-01,  3.2168155023295647D-01), &
( -9.4709436635277711D-01,  3.2095523242787549D-01), ( -9.4734025733319194D-01,  3.2022872581310008D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.4783036726210101D-01,  3.1877514786411854D-01), &
( -9.4807458592227623D-01,  3.1804807738501489D-01), ( -9.4831824685459898D-01,  3.1732081980642202D-01), &
( -9.4856134991573027D-01,  3.1659337555616607D-01), ( -9.4880389496265838D-01,  3.1586574506218412D-01), &
( -9.4904588185270056D-01,  3.1513792875252244D-01), ( -9.4928731044350212D-01,  3.1440992705533666D-01), &
( -9.4952818059303667D-01,  3.1368174039889141D-01), ( -9.4976849215960657D-01,  3.1295336921156047D-01), &
( -9.5000824500184300D-01,  3.1222481392182511D-01), ( -9.5024743897870523D-01,  3.1149607495827603D-01), &
( -9.5048607394948170D-01,  3.1076715274961153D-01), ( -9.5072414977378961D-01,  3.1003804772463783D-01), &
( -9.5096166631157497D-01,  3.0930876031226900D-01), ( -9.5119862342311323D-01,  3.0857929094152525D-01), &
( -9.5143502096900834D-01,  3.0784964004153503D-01), ( -9.5167085881019386D-01,  3.0711980804153316D-01), &
( -9.5190613680793235D-01,  3.0638979537086092D-01), ( -9.5214085482381583D-01,  3.0565960245896606D-01), &
( -9.5237501271976577D-01,  3.0492922973540265D-01), ( -9.5260861035803324D-01,  3.0419867762982933D-01), &
( -9.5284164760119860D-01,  3.0346794657201143D-01), ( -9.5307412431217220D-01,  3.0273703699181920D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.5353739559083317D-01,  3.0127468398431828D-01), &
( -9.5376818988599021D-01,  3.0054324141727368D-01), ( -9.5399842310389449D-01,  2.9981162204838352D-01), &
( -9.5422809510910556D-01,  2.9907982630804053D-01), ( -9.5445720576651349D-01,  2.9834785462674140D-01), &
( -9.5468575494133834D-01,  2.9761570743508614D-01), ( -9.5491374249913041D-01,  2.9688338516377849D-01)/
data (mpuu1(i), i =  7801,  7900) / &
( -9.5514116830577067D-01,  2.9615088824362401D-01), ( -9.5536803222747024D-01,  2.9541821710553212D-01), &
( -9.5559433413077111D-01,  2.9468537218051438D-01), ( -9.5582007388254542D-01,  2.9395235389968460D-01), &
( -9.5604525134999641D-01,  2.9321916269425896D-01), ( -9.5626986640065803D-01,  2.9248579899555410D-01), &
( -9.5649391890239499D-01,  2.9175226323498943D-01), ( -9.5671740872340305D-01,  2.9101855584408515D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.5716269979767021D-01,  2.8955062789784297D-01), &
( -9.5738450078897586D-01,  2.8881640820604976D-01), ( -9.5760573857564624D-01,  2.8808201861100430D-01), &
( -9.5782641302753291D-01,  2.8734745954472962D-01), ( -9.5804652401481849D-01,  2.8661273143934785D-01), &
( -9.5826607140801767D-01,  2.8587783472708056D-01), ( -9.5848505507797610D-01,  2.8514276984024900D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.5892133073321306D-01,  2.8367213727266860D-01), &
( -9.5913862246184189D-01,  2.8293657045705545D-01), ( -9.5935534995393079D-01,  2.8220083719714756D-01), &
( -9.5957151308198452D-01,  2.8146493792575789D-01), ( -9.5978711171883990D-01,  2.8072887307579747D-01), &
( -9.6000214573766585D-01,  2.7999264308027344D-01), ( -9.6021661501196343D-01,  2.7925624837229129D-01), &
( -9.6043051941556579D-01,  2.7851968938505312D-01), ( -9.6064385882263859D-01,  2.7778296655185764D-01), &
( -9.6085663310767955D-01,  2.7704608030610023D-01), ( -9.6106884214551924D-01,  2.7630903108127131D-01), &
( -9.6128048581132064D-01,  2.7557181931095831D-01), ( -9.6149156398057900D-01,  2.7483444542884400D-01), &
( -9.6170207652912254D-01,  2.7409690986870638D-01), ( -9.6191202333311221D-01,  2.7335921306441863D-01), &
( -9.6212140426904158D-01,  2.7262135544994925D-01), ( -9.6233021921373740D-01,  2.7188333745935994D-01), &
( -9.6253846804435916D-01,  2.7114515952680812D-01), ( -9.6274615063839941D-01,  2.7040682208654487D-01), &
( -9.6295326687368388D-01,  2.6966832557291504D-01), ( -9.6315981662837136D-01,  2.6892967042035759D-01), &
( -9.6336579978095394D-01,  2.6819085706340340D-01), ( -9.6357121621025721D-01,  2.6745188593667779D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.6398034841599411D-01,  2.6597347211287559D-01), &
( -9.6418406395174583D-01,  2.6523403028551173D-01), ( -9.6438721228285418D-01,  2.6449443242780191D-01), &
( -9.6458979328981265D-01,  2.6375467897483157D-01), ( -9.6479180685344779D-01,  2.6301477036177912D-01), &
( -9.6499325285492032D-01,  2.6227470702391364D-01), ( -9.6519413117572472D-01,  2.6153448939659546D-01), &
( -9.6539444169768929D-01,  2.6079411791527585D-01), ( -9.6559418430297672D-01,  2.6005359301549541D-01), &
( -9.6579335887408357D-01,  2.5931291513288640D-01), ( -9.6599196529384057D-01,  2.5857208470317045D-01), &
( -9.6619000344541250D-01,  2.5783110216215899D-01), ( -9.6638747321229890D-01,  2.5708996794575306D-01), &
( -9.6658437447833301D-01,  2.5634868248994314D-01), ( -9.6678070712768327D-01,  2.5560724623080761D-01), &
( -9.6697647104485207D-01,  2.5486565960451468D-01), ( -9.6717166611467653D-01,  2.5412392304732068D-01), &
( -9.6736629222232851D-01,  2.5338203699557010D-01), ( -9.6756034925331436D-01,  2.5264000188569585D-01), &
( -9.6775383709347540D-01,  2.5189781815421719D-01), ( -9.6794675562898780D-01,  2.5115548623774209D-01), &
( -9.6813910474636233D-01,  2.5041300657296534D-01), ( -9.6833088433244519D-01,  2.4967037959666855D-01), &
( -9.6852209427441738D-01,  2.4892760574572009D-01), ( -9.6871273445979467D-01,  2.4818468545707506D-01), &
( -9.6890280477642887D-01,  2.4744161916777349D-01), ( -9.6909230511250610D-01,  2.4669840731494255D-01), &
( -9.6928123535654853D-01,  2.4595505033579465D-01), ( -9.6946959539741306D-01,  2.4521154866762751D-01), &
( -9.6965738512429234D-01,  2.4446790274782448D-01), ( -9.6984460442671483D-01,  2.4372411301385238D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.7021733131797916D-01,  2.4223610385369609D-01), &
( -9.7040283868755550D-01,  2.4149188530286933D-01), ( -9.7058777519414363D-01,  2.4074752468858837D-01), &
( -9.7077214072895024D-01,  2.4000302244874175D-01), ( -9.7095593518351797D-01,  2.3925837902130015D-01), &
( -9.7113915844972509D-01,  2.3851359484431855D-01), ( -9.7132181041978616D-01,  2.3776867035593424D-01), &
( -9.7150389098625178D-01,  2.3702360599436717D-01), ( -9.7168540004200843D-01,  2.3627840219791987D-01), &
( -9.7186633748027929D-01,  2.3553305940497574D-01), ( -9.7204670319462338D-01,  2.3478757805400111D-01), &
( -9.7222649707893627D-01,  2.3404195858354349D-01), ( -9.7240571902744977D-01,  2.3329620143223162D-01), &
( -9.7258436893473221D-01,  2.3255030703877516D-01), ( -9.7276244669568845D-01,  2.3180427584196503D-01), &
( -9.7293995220556007D-01,  2.3105810828067130D-01), ( -9.7311688535992513D-01,  2.3031180479384558D-01), &
( -9.7329324605469825D-01,  2.2956536582051892D-01), ( -9.7346903418613107D-01,  2.2881879179980219D-01), &
( -9.7364424965081187D-01,  2.2807208317088606D-01), ( -9.7381889234566610D-01,  2.2732524037303911D-01), &
( -9.7399296216795583D-01,  2.2657826384561017D-01), ( -9.7416645901528032D-01,  2.2583115402802625D-01), &
( -9.7433938278557586D-01,  2.2508391135979283D-01), ( -9.7451173337711583D-01,  2.2433653628049352D-01), &
( -9.7468351068851067D-01,  2.2358902922979026D-01), ( -9.7485471461870843D-01,  2.2284139064742134D-01)/
data (mpuu1(i), i =  7901,  8000) / &
( -9.7502534506699412D-01,  2.2209362097320365D-01), ( -9.7519540193299037D-01,  2.2134572064703087D-01), &
( -9.7536488511665698D-01,  2.2059769010887348D-01), ( -9.7553379451829125D-01,  2.1984952979877900D-01), &
( -9.7570213003852846D-01,  2.1910124015687002D-01), ( -9.7586989157834103D-01,  2.1835282162334649D-01), &
( -9.7603707903903902D-01,  2.1760427463848372D-01), ( -9.7620369232227056D-01,  2.1685559964263262D-01), &
( -9.7636973133002114D-01,  2.1610679707621944D-01), ( -9.7653519596461436D-01,  2.1535786737974583D-01), &
( -9.7670008612871173D-01,  2.1460881099378698D-01), ( -9.7686440172531264D-01,  2.1385962835899389D-01), &
( -9.7702814265775439D-01,  2.1311031991609142D-01), ( -9.7719130882971228D-01,  2.1236088610587839D-01), &
( -9.7735390014519996D-01,  2.1161132736922789D-01), ( -9.7751591650856917D-01,  2.1086164414708508D-01), &
( -9.7767735782450993D-01,  2.1011183688046978D-01), ( -9.7783822399805043D-01,  2.0936190601047425D-01), &
( -9.7799851493455714D-01,  2.0861185197826349D-01), ( -9.7815823053973505D-01,  2.0786167522507498D-01), &
( -9.7831737071962754D-01,  2.0711137619221884D-01), ( -9.7847593538061683D-01,  2.0636095532107573D-01), &
( -9.7863392442942310D-01,  2.0561041305309938D-01), ( -9.7879133777310567D-01,  2.0485974982981447D-01), &
( -9.7894817531906220D-01,  2.0410896609281684D-01), ( -9.7910443697502914D-01,  2.0335806228377362D-01), &
( -9.7926012264908202D-01,  2.0260703884442136D-01), ( -9.7941523224963478D-01,  2.0185589621656819D-01), &
( -9.7956976568544052D-01,  2.0110463484209198D-01), ( -9.7972372286559117D-01,  2.0035325516294045D-01), &
( -9.7987710369951764D-01,  1.9960175762113089D-01), ( -9.8002990809698998D-01,  1.9885014265875040D-01), &
( -9.8018213596811732D-01,  1.9809841071795378D-01), ( -9.8033378722334796D-01,  1.9734656224096606D-01), &
( -9.8048486177346938D-01,  1.9659459767008028D-01), ( -9.8063535952960812D-01,  1.9584251744765782D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.8093462430614164D-01,  1.9433801181798885D-01), &
( -9.8108339115048659D-01,  1.9358558729580377D-01), ( -9.8123158084874962D-01,  1.9283304889220532D-01), &
( -9.8137919331375456D-01,  1.9208039704989244D-01), ( -9.8152622845866477D-01,  1.9132763221163082D-01), &
( -9.8167268619698311D-01,  1.9057475482025305D-01), ( -9.8181856644255250D-01,  1.8982176531865663D-01), &
( -9.8196386910955524D-01,  1.8906866414980633D-01), ( -9.8210859411251350D-01,  1.8831545175673217D-01), &
( -9.8225274136628937D-01,  1.8756212858252957D-01), ( -9.8239631078608469D-01,  1.8680869507035916D-01), &
( -9.8253930228744124D-01,  1.8605515166344688D-01), ( -9.8268171578624086D-01,  1.8530149880508207D-01), &
( -9.8282355119870524D-01,  1.8454773693861970D-01), ( -9.8296480844139644D-01,  1.8379386650747845D-01), &
( -9.8310548743121640D-01,  1.8303988795514090D-01), ( -9.8324558808540707D-01,  1.8228580172515360D-01), &
( -9.8338511032155118D-01,  1.8153160826112519D-01), ( -9.8352405405757126D-01,  1.8077730800672873D-01), &
( -9.8366241921173025D-01,  1.8002290140569957D-01), ( -9.8380020570263160D-01,  1.7926838890183572D-01), &
( -9.8393741344921892D-01,  1.7851377093899740D-01), ( -9.8407404237077645D-01,  1.7775904796110742D-01), &
( -9.8421009238692903D-01,  1.7700422041214892D-01), ( -9.8434556341764190D-01,  1.7624928873616796D-01), &
( -9.8448045538322093D-01,  1.7549425337727143D-01), ( -9.8461476820431260D-01,  1.7473911477962714D-01), &
( -9.8474850180190421D-01,  1.7398387338746410D-01), ( -9.8488165609732370D-01,  1.7322852964507054D-01), &
( -9.8501423101223984D-01,  1.7247308399679609D-01), ( -9.8514622646866212D-01,  1.7171753688705002D-01), &
( -9.8527764238894122D-01,  1.7096188876030119D-01), ( -9.8540847869576842D-01,  1.7020614006107795D-01), &
( -9.8553873531217606D-01,  1.6945029123396821D-01), ( -9.8566841216153755D-01,  1.6869434272361750D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.8592602625432113D-01,  1.6718214843207294D-01), &
( -9.8605396334619544D-01,  1.6642590354046405D-01), ( -9.8618132036792816D-01,  1.6566956074478439D-01), &
( -9.8630809724459856D-01,  1.6491312048997012D-01), ( -9.8643429390162707D-01,  1.6415658322101595D-01), &
( -9.8655991026477541D-01,  1.6339994938297328D-01), ( -9.8668494626014669D-01,  1.6264321942095028D-01), &
( -9.8680940181418553D-01,  1.6188639378011171D-01), ( -9.8693327685367771D-01,  1.6112947290567906D-01), &
( -9.8705657130575097D-01,  1.6037245724292842D-01), ( -9.8717928509787434D-01,  1.5961534723719314D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.8742297041385541D-01,  1.5810084597837692D-01), &
( -9.8754394179435923D-01,  1.5734345561623855D-01), ( -9.8766433222820571D-01,  1.5658597269299865D-01), &
( -9.8778414164457218D-01,  1.5582839765426537D-01), ( -9.8790336997297779D-01,  1.5507073094570056D-01), &
( -9.8802201714328353D-01,  1.5431297301302008D-01), ( -9.8814008308569257D-01,  1.5355512430199333D-01), &
( -9.8825756773074946D-01,  1.5279718525844369D-01), ( -9.8837447100934128D-01,  1.5203915632824622D-01), &
( -9.8849079285269659D-01,  1.5128103795733031D-01), ( -9.8860653319238645D-01,  1.5052283059167743D-01), &
( -9.8872169196032378D-01,  1.4976453467732145D-01), ( -9.8883626908876343D-01,  1.4900615066034875D-01), &
( -9.8895026451030299D-01,  1.4824767898689625D-01), ( -9.8906367815788154D-01,  1.4748912010315371D-01)/
data (mpuu1(i), i =  8001,  8100) / &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.8928875986462517D-01,  1.4597174248981218D-01), &
( -9.8940042779138038D-01,  1.4521292465284735D-01), ( -9.8951151367935519D-01,  1.4445402139086072D-01), &
( -9.8962201746320078D-01,  1.4369503315029464D-01), ( -9.8973193907791057D-01,  1.4293596037764275D-01), &
( -9.8984127845882053D-01,  1.4217680351944806D-01), ( -9.8995003554160899D-01,  1.4141756302230296D-01), &
( -9.9005821026229701D-01,  1.4065823933284952D-01), ( -9.9016580255724840D-01,  1.3989883289777741D-01), &
( -9.9027281236316911D-01,  1.3913934416382634D-01), ( -9.9037923961710816D-01,  1.3837977357778394D-01), &
( -9.9048508425645709D-01,  1.3762012158648601D-01), ( -9.9059034621895015D-01,  1.3686038863681627D-01), &
( -9.9069502544266463D-01,  1.3610057517570645D-01), ( -9.9079912186602037D-01,  1.3534068165013438D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9100556606704937D-01,  1.3382065619375474D-01), &
( -9.9110791372327689D-01,  1.3306052515713901D-01), ( -9.9120967833625395D-01,  1.3230031584444496D-01), &
( -9.9131085984611544D-01,  1.3154002870288331D-01), ( -9.9141145819333854D-01,  1.3077966417971185D-01), &
( -9.9151147331874390D-01,  1.3001922272223340D-01), ( -9.9161090516349537D-01,  1.2925870477779611D-01), &
( -9.9170975366909953D-01,  1.2849811079379306D-01), ( -9.9180801877740643D-01,  1.2773744121766256D-01), &
( -9.9190570043060933D-01,  1.2697669649688603D-01), ( -9.9200279857124452D-01,  1.2621587707899046D-01), &
( -9.9209931314219180D-01,  1.2545498341154626D-01), ( -9.9219524408667392D-01,  1.2469401594216759D-01), &
( -9.9229059134825726D-01,  1.2393297511851248D-01), ( -9.9238535487085167D-01,  1.2317186138828071D-01), &
( -9.9247953459870997D-01,  1.2241067519921635D-01), ( -9.9257313047642881D-01,  1.2164941699910560D-01), &
( -9.9266614244894802D-01,  1.2088808723577707D-01), ( -9.9275857046155114D-01,  1.2012668635710143D-01), &
( -9.9285041445986510D-01,  1.1936521481099163D-01), ( -9.9294167438986047D-01,  1.1860367304540091D-01), &
( -9.9303235019785141D-01,  1.1784206150832509D-01), ( -9.9312244183049558D-01,  1.1708038064780062D-01), &
( -9.9321194923479450D-01,  1.1631863091190471D-01), ( -9.9330087235809328D-01,  1.1555681274875558D-01), &
( -9.9338921114808065D-01,  1.1479492660651032D-01), ( -9.9347696555278919D-01,  1.1403297293336735D-01), &
( -9.9356413552059530D-01,  1.1327095217756442D-01), ( -9.9365072100021912D-01,  1.1250886478737868D-01), &
( -9.9373672194072460D-01,  1.1174671121112650D-01), ( -9.9382213829151966D-01,  1.1098449189716367D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9399121702332938D-01,  1.0945985784971810D-01), &
( -9.9407487930487937D-01,  1.0869744401313874D-01), ( -9.9415795679778973D-01,  1.0793496623265361D-01), &
( -9.9424044945318790D-01,  1.0717242495680916D-01), ( -9.9432235722254581D-01,  1.0640982063418791D-01), &
( -9.9440368005767910D-01,  1.0564715371341077D-01), ( -9.9448441791074760D-01,  1.0488442464313504D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9464413848105071D-01,  1.0335878184889953D-01), &
( -9.9472312110432570D-01,  1.0259586902243656D-01), ( -9.9480151855761711D-01,  1.0183289584146672D-01), &
( -9.9487933079480562D-01,  1.0106986275482793D-01), ( -9.9495655777011638D-01,  1.0030677021139289D-01), &
( -9.9503319943811863D-01,  9.9543618660069277D-02), ( -9.9510925575372611D-01,  9.8780408549799942D-02), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), ( -9.9525961214913328D-01,  9.7253814448363424D-02), &
( -9.9533391214048228D-01,  9.6490431355252662D-02), ( -9.9540762660253490D-01,  9.5726991499307162D-02), &
( -9.9548075549192694D-01,  9.4963495329638908D-02), ( -9.9555329876563847D-01,  9.4199943295393482D-02), &
( -9.9562525638099431D-01,  9.3436335845747981D-02), ( -9.9569662829566352D-01,  9.2672673429913421D-02), &
( -9.9576741446765982D-01,  9.1908956497132765D-02), ( -9.9583761485534161D-01,  9.1145185496680964D-02), &
( -9.9590722941741172D-01,  9.0381360877865302D-02), ( -9.9597625811291779D-01,  8.9617483090023195D-02), &
( -9.9604470090125197D-01,  8.8853552582524753D-02), ( -9.9611255774215113D-01,  8.8089569804770576D-02), &
( -9.9617982859569698D-01,  8.7325535206192059D-02), ( -9.9624651342231552D-01,  8.6561449236251087D-02), &
( -9.9631261218277800D-01,  8.5797312344440158D-02), ( -9.9637812483820021D-01,  8.5033124980280470D-02), &
( -9.9644305135004263D-01,  8.4268887593324182D-02), ( -9.9650739168011082D-01,  8.3504600633152473D-02), &
( -9.9657114579055484D-01,  8.2740264549375650D-02), ( -9.9663431364386990D-01,  8.1975879791633385D-02), &
( -9.9669689520289606D-01,  8.1211446809592663D-02), ( -9.9675889043081800D-01,  8.0446966052950167D-02), &
( -9.9682029929116567D-01,  7.9682437971430195D-02), ( -9.9688112174781385D-01,  7.8917863014784942D-02), &
( -9.9694135776498216D-01,  7.8153241632794149D-02), ( -9.9700100730723529D-01,  7.7388574275265326D-02), &
( -9.9706007033948296D-01,  7.6623861392031686D-02), ( -9.9711854682697998D-01,  7.5859103432954558D-02), &
( -9.9717643673532608D-01,  7.5094300847921347D-02), ( -9.9723374003046628D-01,  7.4329454086845714D-02), &
( -9.9729045667869021D-01,  7.3564563599667745D-02), ( -9.9734658664663312D-01,  7.2799629836351909D-02), &
( -9.9740212990127530D-01,  7.2034653246889485D-02), ( -9.9745708640994191D-01,  7.1269634281296484D-02)/
data (mpuu1(i), i =  8101,  8200) / &
( -9.9751145614030345D-01,  7.0504573389613856D-02), ( -9.9756523906037575D-01,  6.9739471021907223D-02), &
( -9.9761843513851955D-01,  6.8974327628267024D-02), ( -9.9767104434344100D-01,  6.8209143658806523D-02), &
( -9.9772306664419164D-01,  6.7443919563664176D-02), ( -9.9777450201016782D-01,  6.6678655793001598D-02), &
( -9.9782535041111164D-01,  6.5913352797003763D-02), ( -9.9787561181711015D-01,  6.5148011025879152D-02), &
( -9.9792528619859600D-01,  6.4382630929857701D-02), ( -9.9797437352634699D-01,  6.3617212959193259D-02), &
( -9.9802287377148624D-01,  6.2851757564161490D-02), ( -9.9807078690548234D-01,  6.2086265195060088D-02), &
( -9.9811811290014918D-01,  6.1320736302208495D-02), ( -9.9816485172764624D-01,  6.0555171335948066D-02), &
( -9.9821100336047819D-01,  5.9789570746640069D-02), ( -9.9825656777149518D-01,  5.9023934984668049D-02), &
( -9.9830154493389289D-01,  5.8258264500435794D-02), ( -9.9834593482121237D-01,  5.7492559744367525D-02), &
( -9.9838973740734016D-01,  5.6726821166908067D-02), ( -9.9843295266650844D-01,  5.5961049218520804D-02), &
( -9.9847558057329477D-01,  5.5195244349690094D-02), ( -9.9851762110262210D-01,  5.4429407010919209D-02), &
( -9.9855907422975931D-01,  5.3663537652730520D-02), ( -9.9859993993032037D-01,  5.2897636725665241D-02), &
( -9.9864021818026516D-01,  5.2131704680283601D-02), ( -9.9867990895589909D-01,  5.1365741967162794D-02), &
( -9.9871901223387294D-01,  5.0599749036899400D-02), ( -9.9875752799118334D-01,  4.9833726340107319D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9883279685352799D-01,  4.8301593449480464D-02), &
( -9.9886954991428356D-01,  4.7535484156959545D-02), ( -9.9890571536581829D-01,  4.6769346900538022D-02), &
( -9.9894129318685687D-01,  4.6003182130914706D-02), ( -9.9897628335646982D-01,  4.5236990298804590D-02), &
( -9.9901068585407338D-01,  4.4470771854938584D-02), ( -9.9904450065942929D-01,  4.3704527250063706D-02), &
( -9.9907772775264536D-01,  4.2938256934941021D-02), ( -9.9911036711417489D-01,  4.2171961360348065D-02), &
( -9.9914241872481691D-01,  4.1405640977076781D-02), ( -9.9917388256571638D-01,  4.0639296235933695D-02), &
( -9.9920475861836389D-01,  3.9872927587740130D-02), ( -9.9923504686459585D-01,  3.9106535483330131D-02), &
( -9.9926474728659442D-01,  3.8340120373552854D-02), ( -9.9929385986688768D-01,  3.7573682709270577D-02), &
( -9.9932238458834954D-01,  3.6807222941358832D-02), ( -9.9935032143419944D-01,  3.6040741520706146D-02), &
( -9.9937767038800285D-01,  3.5274238898214232D-02), ( -9.9940443143367130D-01,  3.4507715524795951D-02), &
( -9.9943060455546173D-01,  3.3741171851377705D-02), ( -9.9945618973797734D-01,  3.2974608328897377D-02), &
( -9.9948118696616695D-01,  3.2208025408304544D-02), ( -9.9950559622532531D-01,  3.1441423540560627D-02), &
( -9.9952941750109314D-01,  3.0674803176636865D-02), ( -9.9955265077945699D-01,  2.9908164767516714D-02), &
( -9.9957529604674922D-01,  2.9141508764193802D-02), ( -9.9959735328964838D-01,  2.8374835617672095D-02), &
( -9.9961882249517864D-01,  2.7608145778965656D-02), ( -9.9963970365071020D-01,  2.6841439699098808D-02), &
( -9.9965999674395922D-01,  2.6074717829104099D-02), ( -9.9967970176298793D-01,  2.5307980620024689D-02), &
( -9.9969881869620425D-01,  2.4541228522912326D-02), ( -9.9971734753236219D-01,  2.3774461988827513D-02), &
( -9.9973528826056168D-01,  2.3007681468839691D-02), ( -9.9975264087024884D-01,  2.2240887414025200D-02), &
( -9.9976940535121528D-01,  2.1474080275469667D-02), ( -9.9978558169359921D-01,  2.0707260504265974D-02), &
( -9.9980116988788426D-01,  1.9940428551514438D-02), ( -9.9981616992490041D-01,  1.9173584868322539D-02), &
( -9.9983058179582340D-01,  1.8406729905805101D-02), ( -9.9984440549217524D-01,  1.7639864115082254D-02), &
( -9.9985764100582386D-01,  1.6872987947281832D-02), ( -9.9987028832898295D-01,  1.6106101853537325D-02), &
( -9.9988234745421256D-01,  1.5339206284988060D-02), ( -9.9989381837441849D-01,  1.4572301692779389D-02), &
( -9.9990470108285279D-01,  1.3805388528060633D-02), ( -9.9991499557311347D-01,  1.3038467241987496D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9993381987523600D-01,  1.1504602110422715D-02), &
( -9.9994234967602391D-01,  1.0737659167264411D-02), ( -9.9995029123649048D-01,  9.9707099074183136D-03), &
( -9.9995764455196390D-01,  9.2037547820600224D-03), ( -9.9996440961811828D-01,  8.4367942423699219D-03), &
( -9.9997058643097414D-01,  7.6698287395311378D-03), ( -9.9997617498689761D-01,  6.9028587247297159D-03), &
( -9.9998117528260111D-01,  6.1358846491547988D-03), ( -9.9998558731514320D-01,  5.3689069639965854D-03), &
( -9.9998941108192840D-01,  4.6019261204487327D-03), ( -9.9999264658070719D-01,  3.8349425697063091D-03), &
( -9.9999529380957619D-01,  3.0679567629659770D-03), ( -9.9999735276697821D-01,  2.3009691514257252D-03), &
( -9.9999882345170188D-01,  1.5339801862850493D-03), ( -9.9999970586288223D-01,  7.6699031874290766D-04), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00)/
data (mpuu1(i), i =  8201,  8205) / &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00)/
data (mpuu2(i), i =     1,   100) / &
(  1.3000000000000000D+01,  0.0000000000000000D+00), (  1.4000000000000000D+01,  0.0000000000000000D+00), &
(  1.8000000000000000D+01,  0.0000000000000000D+00), (  2.6000000000000000D+01,  0.0000000000000000D+00), &
(  4.2000000000000000D+01,  0.0000000000000000D+00), (  7.4000000000000000D+01,  0.0000000000000000D+00), &
(  1.3800000000000000D+02,  0.0000000000000000D+00), (  2.6600000000000000D+02,  0.0000000000000000D+00), &
(  5.2200000000000000D+02,  0.0000000000000000D+00), (  1.0340000000000000D+03,  0.0000000000000000D+00), &
(  2.0580000000000000D+03,  0.0000000000000000D+00), (  4.1060000000000000D+03,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  6.1232339957367660D-17,  1.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  7.0710678118654757D-01,  7.0710678118654746D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -7.0710678118654746D-01,  7.0710678118654757D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -9.2387953251128674D-01, -3.8268343236508967D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -5.5557023301960218D-01, -8.3146961230254524D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01)/
data (mpuu2(i), i =   101,   200) / &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.2387953251128674D-01,  3.8268343236508978D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  3.8268343236508984D-01,  9.2387953251128674D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -3.8268343236508973D-01,  9.2387953251128674D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -9.2387953251128674D-01,  3.8268343236508984D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.5694033573220894D-01, -2.9028467725446216D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -5.5557023301960218D-01, -8.3146961230254524D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.5694033573220894D-01, -2.9028467725446216D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
(  9.8017140329560090D-02, -9.9518472667219693D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -4.9067674327417786D-02,  9.9879545620517241D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.3688985339222016D-01,  9.4154406518302070D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01)/
data (mpuu2(i), i =   201,   300) / &
( -5.9569930449243291D-01,  8.0320753148064516D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -9.0398929312344323D-01,  4.2755509343028242D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9879545620517241D-01, -4.9067674327418168D-02), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -8.5772861000027212D-01, -5.1410274419322155D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9518472667219693D-01, -9.8017140329560146D-02), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -7.7301045336273688D-01, -6.3439328416364571D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -2.9028467725446327D-01, -9.5694033573220860D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -8.0320753148064516D-01, -5.9569930449243291D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -2.4298017990326326D-01, -9.7003125319454420D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  4.2755509343028136D-01, -9.0398929312344367D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02)/
data (mpuu2(i), i =   301,   400) / &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.8954054473706705D-01,  7.2424708295146689D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.7580819141784534D-01,  8.1758481315158371D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.4961132965460682D-01,  8.9322430119551521D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.1910124015686999D-01,  9.7570213003852846D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -2.4541228522912364D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -4.9067674327417786D-02,  9.9879545620517241D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.3688985339222016D-01,  9.4154406518302070D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.9569930449243291D-01,  8.0320753148064516D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -3.1368174039889124D-01,  9.4952818059303679D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -6.1523159058062704D-01,  7.8834642762660612D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -8.4485356524970689D-01,  5.3499761988709760D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8078528040323043D-01,  1.9509032201612825D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.3146961230254524D-01,  5.5557023301960218D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  5.5557023301960229D-01,  8.3146961230254512D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01)/
data (mpuu2(i), i =   401,   500) / &
(  1.9509032201612830D-01,  9.8078528040323043D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -1.9509032201612819D-01,  9.8078528040323043D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -5.5557023301960196D-01,  8.3146961230254546D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.3146961230254535D-01,  5.5557023301960218D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.8078528040323043D-01,  1.9509032201612858D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -7.5720884650648435D-01,  6.5317284295377698D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.8527764238894133D-01, -1.7096188876030097D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -9.0398929312344323D-01,  4.2755509343028242D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9879545620517241D-01, -4.9067674327418168D-02), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -8.5772861000027212D-01, -5.1410274419322155D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -3.1368174039889146D-01,  9.4952818059303667D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.8527764238894122D-01,  1.7096188876030163D-01), ( -9.9518472667219693D-01, -9.8017140329560590D-02), &
( -9.3299279883473873D-01, -3.5989503653498850D-01), ( -8.0320753148064494D-01, -5.9569930449243325D-01), &
( -6.1523159058062737D-01, -7.8834642762660589D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9518472667219693D-01, -9.8017140329560146D-02), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -7.7301045336273688D-01, -6.3439328416364571D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -2.9028467725446327D-01, -9.5694033573220860D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
( -2.4541228522912142D-02,  9.9969881869620425D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -6.1523159058062671D-01,  7.8834642762660634D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.9879545620517241D-01, -4.9067674327417724D-02), &
( -9.3299279883473907D-01, -3.5989503653498767D-01), ( -7.7301045336273710D-01, -6.3439328416364527D-01), &
( -5.3499761988709726D-01, -8.4485356524970712D-01), ( -2.4298017990326412D-01, -9.7003125319454397D-01), &
(  7.3564563599666996D-02, -9.9729045667869021D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.5694033573220894D-01, -2.9028467725446216D-01)/
data (mpuu2(i), i =   501,   600) / &
( -8.0320753148064516D-01, -5.9569930449243291D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -2.4298017990326326D-01, -9.7003125319454420D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  4.2755509343028136D-01, -9.0398929312344367D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.8527764238894133D-01, -1.7096188876030097D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -6.1523159058062737D-01, -7.8834642762660589D-01), ( -2.9028467725446239D-01, -9.5694033573220882D-01), &
(  7.3564563599667884D-02, -9.9729045667869021D-01), (  4.2755509343028220D-01, -9.0398929312344334D-01), &
(  7.2424708295146667D-01, -6.8954054473706716D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01)/
data (mpuu2(i), i =   601,   700) / &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1911385169005777D-01,  3.9399204006104804D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.8763962040285393D-01,  4.6053871095824006D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5135519310526520D-01,  5.2458968267846884D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01)/
data (mpuu2(i), i =   701,   800) / &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.5885814333386161D-01,  9.8730141815785832D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  3.6807222941358769D-02,  9.9932238458834954D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.0711137619221867D-01,  9.7831737071962765D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.8954054473706705D-01,  7.2424708295146689D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.7580819141784534D-01,  8.1758481315158371D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.4961132965460682D-01,  8.9322430119551521D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.1368174039889135D-01,  9.4952818059303667D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  5.8579785745643898D-01,  8.1045719825259466D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.3861623853852749D-01,  8.9867446569395393D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  2.7851968938505328D-01,  9.6043051941556579D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.1022220729388296D-01,  9.9390697000235606D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -6.1320736302208308D-02,  9.9811811290014918D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.4532498842204657D-01,  8.3822470555483797D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.8060099779545269D-01,  7.3265427167241315D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01)/
data (mpuu2(i), i =   801,   900) / &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.4841868024943473D-01,  9.3733901191257485D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -7.5720884650648435D-01,  6.5317284295377698D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9811811290014918D-01, -6.1320736302208689D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6043051941556590D-01, -2.7851968938505289D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.1910124015686999D-01,  9.7570213003852846D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -2.4541228522912364D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -9.0398929312344323D-01,  4.2755509343028242D-01), &
( -9.4952818059303656D-01,  3.1368174039889180D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9729045667869021D-01,  7.3564563599667301D-02), ( -9.9879545620517241D-01, -4.9067674327418168D-02), &
( -9.8527764238894133D-01, -1.7096188876030097D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.1420975570353058D-01, -4.0524131400499008D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -7.8834642762660634D-01, -6.1523159058062671D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  8.5797312344440088D-02,  9.9631261218277800D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -1.8303988795514115D-01,  9.8310548743121629D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -8.3822470555483786D-01,  5.4532498842204669D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.8527764238894122D-01,  1.7096188876030163D-01), &
( -9.9932238458834943D-01,  3.6807222941359276D-02), ( -9.9518472667219693D-01, -9.8017140329560590D-02), &
( -9.7293995220556018D-01, -2.3105810828067111D-01), ( -9.3299279883473873D-01, -3.5989503653498850D-01)/
data (mpuu2(i), i =   901,  1000) / &
( -8.7607009419540682D-01, -4.8218377207912233D-01), ( -8.0320753148064494D-01, -5.9569930449243325D-01), &
( -7.1573082528381871D-01, -6.9837624940897280D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.0353838372571813D-01, -8.6397285612158647D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -4.9067674327417786D-02,  9.9879545620517241D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.3688985339222016D-01,  9.4154406518302070D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.9569930449243291D-01,  8.0320753148064516D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.0320753148064505D-01,  5.9569930449243313D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9518472667219693D-01, -9.8017140329560146D-02), &
( -9.7003125319454397D-01, -2.4298017990326382D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -8.5772861000027212D-01, -5.1410274419322155D-01), ( -7.7301045336273688D-01, -6.3439328416364571D-01), &
( -6.7155895484701866D-01, -7.4095112535495877D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.2755509343028247D-01, -9.0398929312344312D-01), ( -2.9028467725446327D-01, -9.5694033573220860D-01), &
( -1.4673047445536233D-01, -9.8917650996478090D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -1.8303988795514073D-01,  9.8310548743121640D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9879545620517241D-01, -4.9067674327417724D-02), &
( -9.7831737071962765D-01, -2.0711137619221862D-01), ( -9.3299279883473907D-01, -3.5989503653498767D-01), &
( -8.6397285612158681D-01, -5.0353838372571746D-01), ( -7.7301045336273710D-01, -6.3439328416364527D-01), &
( -6.6241577759017178D-01, -7.4913639452345937D-01), ( -5.3499761988709726D-01, -8.4485356524970712D-01), &
( -3.9399204006104821D-01, -9.1911385169005766D-01), ( -2.4298017990326412D-01, -9.7003125319454397D-01), &
( -8.5797312344440213D-02, -9.9631261218277800D-01), (  7.3564563599666996D-02, -9.9729045667869021D-01), &
(  2.3105810828067058D-01, -9.7293995220556029D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -3.1368174039889124D-01,  9.4952818059303679D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -6.1523159058062704D-01,  7.8834642762660612D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -8.4485356524970689D-01,  5.3499761988709760D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.7570213003852857D-01,  2.1910124015686960D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9247953459871008D-01, -1.2241067519921565D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -8.9322430119551532D-01, -4.4961132965460665D-01), ( -8.0320753148064516D-01, -5.9569930449243291D-01), &
( -6.8954054473706716D-01, -7.2424708295146667D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.0524131400498953D-01, -9.1420975570353080D-01), ( -2.4298017990326326D-01, -9.7003125319454420D-01), &
( -7.3564563599668231D-02, -9.9729045667869021D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  2.6671275747489820D-01, -9.6377606579543995D-01), (  4.2755509343028136D-01, -9.0398929312344367D-01)/
data (mpuu2(i), i =  1001,  1100) / &
(  5.7580819141784489D-01, -8.1758481315158404D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -7.3265427167241293D-01,  6.8060099779545291D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.3733901191257507D-01, -3.4841868024943418D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -7.4913639452345926D-01, -6.6241577759017178D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -4.6053871095824067D-01, -8.8763962040285360D-01), ( -2.9028467725446239D-01, -9.5694033573220882D-01), &
( -1.1022220729388331D-01, -9.9390697000235606D-01), (  7.3564563599667884D-02, -9.9729045667869021D-01), &
(  2.5486565960451396D-01, -9.6697647104485229D-01), (  4.2755509343028220D-01, -9.0398929312344334D-01), &
(  5.8579785745643875D-01, -8.1045719825259488D-01), (  7.2424708295146667D-01, -6.8954054473706716D-01), &
(  8.3822470555483775D-01, -5.4532498842204680D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02)/
data (mpuu2(i), i =  1101,  1200) / &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7956976568544052D-01,  2.0110463484209187D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7150389098625178D-01,  2.3702360599436723D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6212140426904158D-01,  2.7262135544994892D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5143502096900834D-01,  3.0784964004153492D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.1911385169005777D-01,  3.9399204006104804D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8763962040285393D-01,  4.6053871095824006D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.5135519310526520D-01,  5.2458968267846884D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01)/
data (mpuu2(i), i =  1201,  1300) / &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4359345816196039D-01,  3.3110630575987637D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2151403934204190D-01,  3.8834504669882630D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.6120238548426189D-01,  6.4851440102211244D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2000250796138165D-01,  6.9397146088965400D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2963823891492698D-01,  7.7688846567323244D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1911385169005777D-01,  3.9399204006104804D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.8763962040285393D-01,  4.6053871095824006D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5135519310526520D-01,  5.2458968267846884D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.9044872324475799D-01,  4.5508358712634378D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.4812034480329723D-01,  5.2980362468629472D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  7.9953726910790501D-01,  6.0061647938386886D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4505778544146595D-01,  6.6699992230363758D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.8508366777270058D-01,  7.2846439044822509D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  5.8579785745643898D-01,  8.1045719825259466D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.7679923006332203D-01,  8.7901222642863353D-01), (  4.3861623853852749D-01,  8.9867446569395393D-01), &
(  3.9962419984564701D-01,  9.1667905992104259D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  2.7851968938505328D-01,  9.6043051941556579D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01)/
data (mpuu2(i), i =  1301,  1400) / &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.2110251499110476D-01,  5.7078074588696726D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.4841868024943473D-01,  9.3733901191257485D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.0674803176636681D-02,  9.9952941750109314D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.5885814333386161D-01,  9.8730141815785832D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  3.6807222941358769D-02,  9.9932238458834954D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.0711137619221867D-01,  9.7831737071962765D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.3681656887737002D-01,  6.7609270357531592D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.3912444486377573D-01,  7.6910333764557970D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01)/
data (mpuu2(i), i =  1401,  1500) / &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  2.8440753721127199D-01,  9.5870347489587149D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  8.5797312344440088D-02,  9.9631261218277800D-01), &
(  1.8406729905805042D-02,  9.9983058179582340D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.8303988795514115D-01,  9.8310548743121629D-01), &
( -2.4892760574571993D-01,  9.6852209427441738D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.8954054473706705D-01,  7.2424708295146689D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.7580819141784534D-01,  8.1758481315158371D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.4961132965460682D-01,  8.9322430119551521D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.1368174039889135D-01,  9.4952818059303667D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.8303988795514073D-01,  9.8310548743121640D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -4.1084317105790397D-01,  9.1170603200542977D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  5.8579785745643898D-01,  8.1045719825259466D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.3861623853852749D-01,  8.9867446569395393D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  2.7851968938505328D-01,  9.6043051941556579D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.1022220729388296D-01,  9.9390697000235606D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01)/
data (mpuu2(i), i =  1501,  1600) / &
( -6.1320736302208308D-02,  9.9811811290014918D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.4532498842204657D-01,  8.3822470555483797D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.8060099779545269D-01,  7.3265427167241315D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.6561299780477374D-01,  9.3076696107898371D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -5.1935599016558920D-01,  8.5455798836540076D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -7.3265427167241293D-01,  6.8060099779545291D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9518472667219693D-01,  9.8017140329560604D-02), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.5694033573220882D-01,  2.9028467725446233D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  8.8192126434835505D-01,  4.7139673682599764D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.7301045336273699D-01,  6.3439328416364549D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.3439328416364560D-01,  7.7301045336273688D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.7139673682599781D-01,  8.8192126434835494D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.9028467725446228D-01,  9.5694033573220894D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  9.8017140329560770D-02,  9.9518472667219682D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -9.8017140329560659D-02,  9.9518472667219693D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.9028467725446222D-01,  9.5694033573220894D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.7139673682599770D-01,  8.8192126434835505D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -6.3439328416364527D-01,  7.7301045336273710D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.7301045336273699D-01,  6.3439328416364549D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.8192126434835494D-01,  4.7139673682599781D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.5694033573220882D-01,  2.9028467725446233D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9518472667219682D-01,  9.8017140329560840D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.4505778544146595D-01,  6.6699992230363747D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.1084317105790408D-01,  9.1170603200542977D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  1.1022220729388318D-01,  9.9390697000235606D-01), &
(  6.1358846491547381D-03,  9.9998117528260111D-01), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -2.0110463484209204D-01,  9.7956976568544052D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.9962419984564673D-01,  9.1667905992104270D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01), &
( -5.8081395809576475D-01,  8.1403632970594830D-01), ( -6.6241577759017145D-01,  7.4913639452345959D-01)/
data (mpuu2(i), i =  1601,  1700) / &
( -7.3681656887736979D-01,  6.7609270357531592D-01), ( -8.0320753148064483D-01,  5.9569930449243347D-01), &
( -8.6086693863776742D-01,  5.0883014254310688D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.7570213003852846D-01,  2.1910124015687002D-01), &
( -9.9321194923479450D-01,  1.1631863091190471D-01), ( -9.9992470183914450D-01,  1.2271538285720451D-02), &
( -9.9576741446765982D-01, -9.1908956497132516D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.4841868024943473D-01,  9.3733901191257485D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.0200594931922808D-01,  9.5330604035419386D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), ( -7.5720884650648435D-01,  6.5317284295377698D-01), &
( -8.2458930278502507D-01,  5.6573181078361345D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.8730141815785843D-01,  1.5885814333386145D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9811811290014918D-01, -6.1320736302208689D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6043051941556590D-01, -2.7851968938505289D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  6.8508366777270047D-01,  7.2846439044822520D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  2.8440753721127199D-01,  9.5870347489587149D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  5.5195244349689816D-02,  9.9847558057329477D-01), ( -6.1320736302208530D-02,  9.9811811290014918D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.9962419984564690D-01,  9.1667905992104259D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -6.0061647938386864D-01,  7.9953726910790524D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -8.3822470555483786D-01,  5.4532498842204669D-01), &
( -8.9596624975618511D-01,  4.4412214457042931D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.7433938278557586D-01,  2.2508391135979283D-01), ( -9.9390697000235606D-01,  1.1022220729388281D-01), &
( -9.9998117528260111D-01, -6.1358846491541101D-03), ( -9.9247953459870997D-01, -1.2241067519921610D-01), &
( -9.7150389098625178D-01, -2.3702360599436739D-01), ( -9.3733901191257507D-01, -3.4841868024943418D-01), &
( -8.9044872324475799D-01, -4.5508358712634367D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.1910124015686999D-01,  9.7570213003852846D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -2.4541228522912364D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.9289819222978393D-01,  8.7008699110871146D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.8954054473706683D-01,  7.2424708295146700D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -9.0398929312344323D-01,  4.2755509343028242D-01), &
( -9.4952818059303656D-01,  3.1368174039889180D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9729045667869021D-01,  7.3564563599667301D-02), ( -9.9879545620517241D-01, -4.9067674327418168D-02)/
data (mpuu2(i), i =  1701,  1800) / &
( -9.8527764238894133D-01, -1.7096188876030097D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.1420975570353058D-01, -4.0524131400499008D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -7.8834642762660634D-01, -6.1523159058062671D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  1.5279718525844363D-01,  9.8825756773074946D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -3.5416352542049023D-01,  9.3518350993894761D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.8081395809576475D-01,  8.1403632970594830D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -9.0659570451491545D-01,  4.2200027079979946D-01), ( -9.5330604035419375D-01,  3.0200594931922842D-01), &
( -9.8421009238692903D-01,  1.7700422041214892D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9682029929116578D-01, -7.9682437971429945D-02), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.4359345816196039D-01, -3.3110630575987626D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.2804504525775591D-01, -5.6066157619733592D-01), ( -7.4913639452345959D-01, -6.6241577759017145D-01), &
( -6.5780669329707886D-01, -7.5318679904361230D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  5.8579785745643886D-01,  8.1045719825259477D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  8.5797312344440088D-02,  9.9631261218277800D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -1.8303988795514115D-01,  9.8310548743121629D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -6.6241577759017178D-01,  7.4913639452345926D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -8.3822470555483786D-01,  5.4532498842204669D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.8527764238894122D-01,  1.7096188876030163D-01), &
( -9.9932238458834943D-01,  3.6807222941359276D-02), ( -9.9518472667219693D-01, -9.8017140329560590D-02), &
( -9.7293995220556018D-01, -2.3105810828067111D-01), ( -9.3299279883473873D-01, -3.5989503653498850D-01), &
( -8.7607009419540682D-01, -4.8218377207912233D-01), ( -8.0320753148064494D-01, -5.9569930449243325D-01), &
( -7.1573082528381871D-01, -6.9837624940897280D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.0353838372571813D-01, -8.6397285612158647D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  7.6120238548426178D-01,  6.4851440102211244D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  1.5885814333386139D-01,  9.8730141815785843D-01), &
(  1.8406729905805042D-02,  9.9983058179582340D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -2.6079411791527568D-01,  9.6539444169768929D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -5.1935599016558920D-01,  8.5455798836540076D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01), &
( -7.3681656887736979D-01,  6.7609270357531592D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.9596624975618511D-01,  4.4412214457042931D-01), ( -9.4952818059303667D-01,  3.1368174039889141D-01), &
( -9.8421009238692903D-01,  1.7700422041214892D-01), ( -9.9932238458834943D-01,  3.6807222941359276D-02), &
( -9.9456457073425553D-01, -1.0412163387205432D-01), ( -9.7003125319454397D-01, -2.4298017990326382D-01), &
( -9.2621024213831127D-01, -3.7700741021641837D-01), ( -8.6397285612158659D-01, -5.0353838372571780D-01), &
( -7.8455659715557546D-01, -6.2005721176328887D-01), ( -6.8954054473706716D-01, -7.2424708295146667D-01), &
( -5.8081395809576430D-01, -8.1403632970594852D-01), ( -4.6053871095824067D-01, -8.8763962040285360D-01)/
data (mpuu2(i), i =  1801,  1900) / &
( -3.3110630575987654D-01, -9.4359345816196027D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -4.9067674327417786D-02,  9.9879545620517241D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -3.3688985339222016D-01,  9.4154406518302070D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.9569930449243291D-01,  8.0320753148064516D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -8.0320753148064505D-01,  5.9569930449243313D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), ( -9.9518472667219693D-01, -9.8017140329560146D-02), &
( -9.7003125319454397D-01, -2.4298017990326382D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -8.5772861000027212D-01, -5.1410274419322155D-01), ( -7.7301045336273688D-01, -6.3439328416364571D-01), &
( -6.7155895484701866D-01, -7.4095112535495877D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.2755509343028247D-01, -9.0398929312344312D-01), ( -2.9028467725446327D-01, -9.5694033573220860D-01), &
( -1.4673047445536233D-01, -9.8917650996478090D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.2000250796138165D-01,  6.9397146088965389D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  3.6807222941358991D-02,  9.9932238458834954D-01), &
( -1.1631863091190453D-01,  9.9321194923479461D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -4.1084317105790397D-01,  9.1170603200542977D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.6086693863776742D-01,  5.0883014254310688D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.7433938278557575D-01,  2.2508391135979328D-01), ( -9.9729045667869021D-01,  7.3564563599667745D-02), &
( -9.9682029929116567D-01, -7.9682437971430389D-02), ( -9.7293995220556029D-01, -2.3105810828067067D-01), &
( -9.2621024213831149D-01, -3.7700741021641793D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -7.6910333764557970D-01, -6.3912444486377573D-01), ( -6.6241577759017178D-01, -7.4913639452345937D-01), &
( -5.4017147272989352D-01, -8.4155497743689800D-01), ( -4.0524131400499036D-01, -9.1420975570353047D-01), &
( -2.6079411791527590D-01, -9.6539444169768929D-01), ( -1.1022220729388331D-01, -9.9390697000235606D-01), &
(  4.2938256934940716D-02, -9.9907772775264536D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  4.3861623853852771D-01,  8.9867446569395382D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -1.8303988795514073D-01,  9.8310548743121640D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -4.8218377207912272D-01,  8.7607009419540660D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -9.0916798309052238D-01,  4.1642956009763715D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.9390697000235606D-01,  1.1022220729388325D-01), ( -9.9879545620517241D-01, -4.9067674327417724D-02), &
( -9.7831737071962765D-01, -2.0711137619221862D-01), ( -9.3299279883473907D-01, -3.5989503653498767D-01), &
( -8.6397285612158681D-01, -5.0353838372571746D-01), ( -7.7301045336273710D-01, -6.3439328416364527D-01), &
( -6.6241577759017178D-01, -7.4913639452345937D-01), ( -5.3499761988709726D-01, -8.4485356524970712D-01), &
( -3.9399204006104821D-01, -9.1911385169005766D-01), ( -2.4298017990326412D-01, -9.7003125319454397D-01), &
( -8.5797312344440213D-02, -9.9631261218277800D-01), (  7.3564563599666996D-02, -9.9729045667869021D-01), &
(  2.3105810828067058D-01, -9.7293995220556029D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01)/
data (mpuu2(i), i =  1901,  2000) / &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -2.4892760574571993D-01,  9.6852209427441738D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01), &
( -9.9998117528260111D-01, -6.1358846491541101D-03), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.4359345816196039D-01, -3.3110630575987626D-01), ( -8.7607009419540682D-01, -4.8218377207912233D-01), &
( -7.8455659715557546D-01, -6.2005721176328887D-01), ( -6.7155895484701866D-01, -7.4095112535495877D-01), &
( -5.4017147272989274D-01, -8.4155497743689855D-01), ( -3.9399204006104821D-01, -9.1911385169005766D-01), &
( -2.3702360599436767D-01, -9.7150389098625167D-01), ( -7.3564563599667357D-02, -9.9729045667869021D-01), &
(  9.1908956497132460D-02, -9.9576741446765982D-01), (  2.5486565960451396D-01, -9.6697647104485229D-01), &
(  4.1084317105790391D-01, -9.1170603200542988D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -3.1368174039889124D-01,  9.4952818059303679D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -6.1523159058062704D-01,  7.8834642762660612D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -8.4485356524970689D-01,  5.3499761988709760D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.7570213003852857D-01,  2.1910124015686960D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9247953459871008D-01, -1.2241067519921565D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -8.9322430119551532D-01, -4.4961132965460665D-01), ( -8.0320753148064516D-01, -5.9569930449243291D-01), &
( -6.8954054473706716D-01, -7.2424708295146667D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.0524131400498953D-01, -9.1420975570353080D-01), ( -2.4298017990326326D-01, -9.7003125319454420D-01), &
( -7.3564563599668231D-02, -9.9729045667869021D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  2.6671275747489820D-01, -9.6377606579543995D-01), (  4.2755509343028136D-01, -9.0398929312344367D-01), &
(  5.7580819141784489D-01, -8.1758481315158404D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  6.2963823891492710D-01,  7.7688846567323244D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
( -3.0674803176636459D-02,  9.9952941750109314D-01), ( -2.0711137619221845D-01,  9.7831737071962765D-01), &
( -3.7700741021641798D-01,  9.2621024213831149D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -6.7609270357531615D-01,  7.3681656887736968D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.9044872324475766D-01,  4.5508358712634428D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.9321194923479450D-01,  1.1631863091190471D-01), ( -9.9811811290014918D-01, -6.1320736302208245D-02), &
( -9.7150389098625189D-01, -2.3702360599436695D-01), ( -9.1420975570353069D-01, -4.0524131400498969D-01), &
( -8.2804504525775557D-01, -5.6066157619733625D-01), ( -7.1573082528381904D-01, -6.9837624940897247D-01), &
( -5.8081395809576497D-01, -8.1403632970594808D-01), ( -4.2755509343028247D-01, -9.0398929312344312D-01), &
( -2.6079411791527590D-01, -9.6539444169768929D-01), ( -8.5797312344439339D-02, -9.9631261218277811D-01), &
(  9.1908956497132460D-02, -9.9576741446765982D-01), (  2.6671275747489820D-01, -9.6377606579543995D-01), &
(  4.3309381885315185D-01, -9.0134884704602203D-01), (  5.8579785745643798D-01, -8.1045719825259543D-01), &
(  7.2000250796138165D-01, -6.9397146088965400D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01)/
data (mpuu2(i), i =  2001,  2100) / &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -4.3861623853852738D-01,  8.9867446569395393D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -7.3265427167241293D-01,  6.8060099779545291D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.3733901191257507D-01, -3.4841868024943418D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -7.4913639452345926D-01, -6.6241577759017178D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -4.6053871095824067D-01, -8.8763962040285360D-01), ( -2.9028467725446239D-01, -9.5694033573220882D-01), &
( -1.1022220729388331D-01, -9.9390697000235606D-01), (  7.3564563599667884D-02, -9.9729045667869021D-01), &
(  2.5486565960451396D-01, -9.6697647104485229D-01), (  4.2755509343028220D-01, -9.0398929312344334D-01), &
(  5.8579785745643875D-01, -8.1045719825259488D-01), (  7.2424708295146667D-01, -6.8954054473706716D-01), &
(  8.3822470555483775D-01, -5.4532498842204680D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -7.8455659715557535D-01,  6.2005721176328898D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
( -9.9576741446765982D-01, -9.1908956497132960D-02), ( -9.6043051941556590D-01, -2.7851968938505289D-01), &
( -8.9044872324475799D-01, -4.5508358712634367D-01), ( -7.8834642762660634D-01, -6.1523159058062671D-01), &
( -6.5780669329707886D-01, -7.5318679904361230D-01), ( -5.0353838372571813D-01, -8.6397285612158647D-01), &
( -3.3110630575987654D-01, -9.4359345816196027D-01), ( -1.4673047445536233D-01, -9.8917650996478090D-01), &
(  4.2938256934940716D-02, -9.9907772775264536D-01), (  2.3105810828067144D-01, -9.7293995220556007D-01), &
(  4.1084317105790391D-01, -9.1170603200542988D-01), (  5.7580819141784489D-01, -8.1758481315158404D-01), &
(  7.2000250796138165D-01, -6.9397146088965400D-01), (  8.3822470555483775D-01, -5.4532498842204680D-01), &
(  9.2621024213831138D-01, -3.7700741021641826D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00)/
data (mpuu2(i), i =  2101,  2200) / &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9999529380957619D-01,  3.0679567629659761D-03), (  9.9998117528260111D-01,  6.1358846491544753D-03), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9356413552059530D-01,  1.1327095217756435D-01), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9209931314219180D-01,  1.2545498341154623D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9131085984611544D-01,  1.3154002870288312D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.8962201746320089D-01,  1.4369503315029447D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8680940181418553D-01,  1.6188639378011183D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.8366241921173025D-01,  1.8002290140569951D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8253930228744124D-01,  1.8605515166344663D-01), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02)/
data (mpuu2(i), i =  2201,  2300) / &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7433938278557586D-01,  2.2508391135979283D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6852209427441727D-01,  2.4892760574572015D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6539444169768940D-01,  2.6079411791527551D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.5870347489587160D-01,  2.8440753721127188D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4758559101774109D-01,  3.1950203081601569D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.3518350993894761D-01,  3.5416352542049034D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.3076696107898371D-01,  3.6561299780477385D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9487933079480562D-01,  1.0106986275482781D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9285041445986510D-01,  1.1936521481099137D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9048508425645709D-01,  1.3762012158648601D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8778414164457218D-01,  1.5582839765426526D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7956976568544052D-01,  2.0110463484209187D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7150389098625178D-01,  2.3702360599436723D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.6212140426904158D-01,  2.7262135544994892D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.5143502096900834D-01,  3.0784964004153492D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4257319760144687D-01,  3.3399965144200938D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2964089584318133D-01,  3.6846682995337227D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.2270112833387863D-01,  3.8551605384391885D-01), (  9.1911385169005777D-01,  3.9399204006104804D-01), &
(  9.1544871608826783D-01,  4.0243465085941849D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  9.0788611648766615D-01,  4.1921688836322396D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01)/
data (mpuu2(i), i =  2301,  2400) / &
(  8.9184070939234272D-01,  4.5234958723377083D-01), (  8.8763962040285393D-01,  4.6053871095824006D-01), &
(  8.8336333866573158D-01,  4.6868882203582796D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.7458665227817611D-01,  4.8486924800079112D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01), &
(  8.5614732837519447D-01,  5.1673179901764987D-01), (  8.5135519310526520D-01,  5.2458968267846884D-01), &
(  8.4649093877405213D-01,  5.3240312787719790D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8579750916756748D-01,  1.6793829497473114D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8018213596811743D-01,  1.9809841071795359D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4359345816196039D-01,  3.3110630575987637D-01)/
data (mpuu2(i), i =  2401,  2500) / &
(  9.3840353406310817D-01,  3.4554132496398904D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2736252565040111D-01,  3.7416406297145799D-01), (  9.2151403934204190D-01,  3.8834504669882630D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0267331823725883D-01,  4.3032648134008267D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7458665227817611D-01,  4.8486924800079112D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.4320823964184544D-01,  5.3758707629564539D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  8.0865618158817498D-01,  5.8828154822264522D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.9023022143731003D-01,  6.1281008242940971D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.6120238548426189D-01,  6.4851440102211244D-01), &
(  7.5116513190968637D-01,  6.6011434206742059D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.2000250796138165D-01,  6.9397146088965400D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.8731534089175916D-01,  7.2635915508434590D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  6.2963823891492698D-01,  7.7688846567323244D-01), &
(  6.1764730793780409D-01,  7.8645521359908566D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.9323229503979991D-01,  8.0503133114296355D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7956976568544052D-01,  2.0110463484209187D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7150389098625178D-01,  2.3702360599436723D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6212140426904158D-01,  2.7262135544994892D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5143502096900834D-01,  3.0784964004153492D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.1911385169005777D-01,  3.9399204006104804D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8763962040285393D-01,  4.6053871095824006D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.5135519310526520D-01,  5.2458968267846884D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7688846567323244D-01,  6.2963823891492698D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2846439044822531D-01,  6.8508366777270024D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0275474445722541D-01,  7.1143219574521632D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.7609270357531592D-01,  7.3681656887736979D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.4851440102211244D-01,  7.6120238548426178D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.2005721176328932D-01,  7.8455659715557513D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.9075970185887439D-01,  8.0684755354379922D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.6066157619733603D-01,  8.2804504525775569D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.2980362468629461D-01,  8.4812034480329723D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01)/
data (mpuu2(i), i =  2501,  2600) / &
(  4.6597649576796613D-01,  8.8479709843093779D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.3309381885315201D-01,  9.0134884704602203D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7222649707893627D-01,  2.3404195858354340D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6128048581132064D-01,  2.7557181931095820D-01), (  9.5514116830577067D-01,  2.9615088824362379D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3409255040425887D-01,  3.5703096123343003D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.1790077562139050D-01,  3.9680998741671025D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9044872324475799D-01,  4.5508358712634378D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5930181835700836D-01,  5.1146885043797041D-01), (  8.4812034480329723D-01,  5.2980362468629472D-01), &
(  8.3654772722351201D-01,  5.4789405917310008D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  7.9953726910790501D-01,  6.0061647938386886D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.4505778544146595D-01,  6.6699992230363758D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0056879394324834D-01,  7.1358486878079352D-01), (  6.8508366777270058D-01,  7.2846439044822509D-01), &
(  6.6928258834663623D-01,  7.4300795213512161D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.3676186123628442D-01,  7.7106052426181360D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  6.0306659854034828D-01,  7.9769084094339104D-01), (  5.8579785745643898D-01,  8.1045719825259466D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  5.3240312787719801D-01,  8.4649093877405202D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9556526182577271D-01,  8.6857070597134078D-01), (  4.7679923006332203D-01,  8.7901222642863353D-01), &
(  4.5781330359887729D-01,  8.8904835585466446D-01), (  4.3861623853852749D-01,  8.9867446569395393D-01), &
(  4.1921688836322396D-01,  9.0788611648766615D-01), (  3.9962419984564701D-01,  9.1667905992104259D-01), &
(  3.7984720892405111D-01,  9.2504924078267758D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  2.9907982630804048D-01,  9.5422809510910567D-01), (  2.7851968938505328D-01,  9.6043051941556579D-01), &
(  2.5783110216215893D-01,  9.6619000344541262D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  2.1610679707621938D-01,  9.7636973133002114D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01)/
data (mpuu2(i), i =  2601,  2700) / &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5422809510910567D-01,  2.9907982630804042D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  8.2110251499110476D-01,  5.7078074588696726D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.9617713149146299D-01,  7.1787004505573171D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.1281008242940982D-01,  7.9023022143731003D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.6825895267013171D-01,  8.2284978137582621D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.2197529293715439D-01,  8.5296060493036363D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2477968120910903D-01,  9.0529675931811870D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.7416406297145793D-01,  9.2736252565040111D-01), (  3.4841868024943473D-01,  9.3733901191257485D-01), &
(  3.2240767880106980D-01,  9.4660091308328353D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.6966832557291498D-01,  9.6295326687368388D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.1610679707621960D-01,  9.7636973133002114D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  1.0717242495680887D-01,  9.9424044945318790D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -3.0674803176636681D-02,  9.9952941750109314D-01), &
( -5.8258264500435607D-02,  9.9830154493389289D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.1327095217756424D-01,  9.9356413552059530D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02)/
data (mpuu2(i), i =  2701,  2800) / &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4359345816196039D-01,  3.3110630575987637D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2151403934204190D-01,  3.8834504669882630D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.6120238548426189D-01,  6.4851440102211244D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2000250796138165D-01,  6.9397146088965400D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2963823891492698D-01,  7.7688846567323244D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.2980362468629461D-01,  8.4812034480329723D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2200027079979979D-01,  9.0659570451491533D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  3.0784964004153498D-01,  9.5143502096900834D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.4892760574572026D-01,  9.6852209427441727D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.5885814333386161D-01,  9.8730141815785832D-01), &
(  1.2849811079379300D-01,  9.9170975366909953D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  3.6807222941358769D-02,  9.9932238458834954D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -5.5195244349689913D-02,  9.9847558057329477D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.0711137619221867D-01,  9.7831737071962765D-01), &
( -2.3702360599436700D-01,  9.7150389098625178D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -2.9615088824362384D-01,  9.5514116830577067D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.7956976568544052D-01,  2.0110463484209190D-01), &
(  9.7222649707893627D-01,  2.3404195858354343D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.4359345816196039D-01,  3.3110630575987643D-01), &
(  9.3188426558166815D-01,  3.6275572436739717D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  9.0529675931811870D-01,  4.2477968120910886D-01), (  8.9044872324475788D-01,  4.5508358712634384D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.2110251499110465D-01,  5.7078074588696726D-01), &
(  8.0137617172314024D-01,  5.9816070699634227D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.3681656887737002D-01,  6.7609270357531592D-01), &
(  7.1358486878079375D-01,  7.0056879394324834D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.3912444486377573D-01,  7.6910333764557970D-01), &
(  6.1281008242940982D-01,  7.9023022143730992D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.5811853122055621D-01,  8.2976123379452305D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.4137126873171662D-01,  8.9732458070541832D-01), (  4.1084317105790391D-01,  9.1170603200542988D-01), &
(  3.7984720892405133D-01,  9.2504924078267758D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  3.1659337555616585D-01,  9.4856134991573027D-01), (  2.8440753721127199D-01,  9.5870347489587149D-01)/
data (mpuu2(i), i =  2801,  2900) / &
(  2.5189781815421713D-01,  9.6775383709347540D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.8605515166344683D-01,  9.8253930228744124D-01), (  1.5279718525844341D-01,  9.8825756773074946D-01), &
(  1.1936521481099156D-01,  9.9285041445986510D-01), (  8.5797312344440088D-02,  9.9631261218277800D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  1.8406729905805042D-02,  9.9983058179582340D-01), &
( -1.5339206284988098D-02,  9.9988234745421256D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -8.2740264549375470D-02,  9.9657114579055484D-01), ( -1.1631863091190475D-01,  9.9321194923479450D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -1.8303988795514115D-01,  9.8310548743121629D-01), &
( -2.1610679707621949D-01,  9.7636973133002114D-01), ( -2.4892760574571993D-01,  9.6852209427441738D-01), &
( -2.8146493792575794D-01,  9.5957151308198452D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.4554132496398882D-01,  9.3840353406310817D-01), ( -3.7700741021641820D-01,  9.2621024213831138D-01), &
( -4.0804416286497863D-01,  9.1296219042839821D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.6868882203582807D-01,  8.8336333866573158D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.2719913478190139D-01,  8.4974176800085244D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1911385169005777D-01,  3.9399204006104804D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.8763962040285393D-01,  4.6053871095824006D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5135519310526520D-01,  5.2458968267846884D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.1368174039889135D-01,  9.4952818059303667D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1320736302208877D-02,  9.9811811290014918D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01), &
( -8.5797312344439991D-02,  9.9631261218277800D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.5885814333386150D-01,  9.8730141815785832D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.3105810828067094D-01,  9.7293995220556018D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.0200594931922786D-01,  9.5330604035419386D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.3861623853852777D-01,  8.9867446569395382D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8018213596811743D-01,  1.9809841071795356D-01), (  9.7150389098625178D-01,  2.3702360599436720D-01), &
(  9.6128048581132064D-01,  2.7557181931095814D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.2151403934204190D-01,  3.8834504669882625D-01)/
data (mpuu2(i), i =  2901,  3000) / &
(  9.0529675931811882D-01,  4.2477968120910881D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.6857070597134090D-01,  4.9556526182577254D-01), (  8.4812034480329723D-01,  5.2980362468629461D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.2635915508434601D-01,  6.8731534089175905D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.3912444486377584D-01,  7.6910333764557959D-01), &
(  6.0794978496777374D-01,  7.9397547755433706D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.4275078486451589D-01,  8.3989379419599952D-01), (  5.0883014254310710D-01,  8.6086693863776720D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  4.0243465085941854D-01,  9.1544871608826783D-01), (  3.6561299780477396D-01,  9.3076696107898371D-01), &
(  3.2820984357909266D-01,  9.4460483726148026D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.5189781815421691D-01,  9.6775383709347551D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  1.7398387338746385D-01,  9.8474850180190421D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  9.4963495329639061D-02,  9.9548075549192694D-01), (  5.5195244349690031D-02,  9.9847558057329477D-01), &
(  1.5339206284988220D-02,  9.9988234745421256D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -6.4382630929857299D-02,  9.9792528619859600D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.4369503315029447D-01,  9.8962201746320089D-01), ( -1.8303988795514073D-01,  9.8310548743121640D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.6079411791527546D-01,  9.6539444169768940D-01), &
( -2.9907982630804059D-01,  9.5422809510910556D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -3.7416406297145788D-01,  9.2736252565040111D-01), ( -4.1084317105790397D-01,  9.1170603200542977D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -5.1673179901764998D-01,  8.5614732837519436D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -5.8330865293769840D-01,  8.1225058658520388D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.4617601298331606D-01,  7.6318841726338160D-01), ( -6.7609270357531581D-01,  7.3681656887737002D-01), &
( -7.0493408037590488D-01,  7.0927282643886569D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.5920918897838796D-01,  6.5084668499638099D-01), ( -7.8455659715557513D-01,  6.2005721176328943D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.9044872324475799D-01,  4.5508358712634378D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.4812034480329723D-01,  5.2980362468629472D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  7.9953726910790501D-01,  6.0061647938386886D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4505778544146595D-01,  6.6699992230363758D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.8508366777270058D-01,  7.2846439044822509D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  5.8579785745643898D-01,  8.1045719825259466D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.7679923006332203D-01,  8.7901222642863353D-01), (  4.3861623853852749D-01,  8.9867446569395393D-01), &
(  3.9962419984564701D-01,  9.1667905992104259D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  2.7851968938505328D-01,  9.6043051941556579D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  1.1022220729388296D-01,  9.9390697000235606D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -1.8406729905804917D-02,  9.9983058179582340D-01), ( -6.1320736302208308D-02,  9.9811811290014918D-01), &
( -1.0412163387205439D-01,  9.9456457073425553D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -1.8906866414980594D-01,  9.8196386910955535D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.7262135544994887D-01,  9.6212140426904158D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01)/
data (mpuu2(i), i =  3001,  3100) / &
( -4.3309381885315196D-01,  9.0134884704602203D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.0883014254310666D-01,  8.6086693863776742D-01), ( -5.4532498842204657D-01,  8.3822470555483797D-01), &
( -5.8081395809576430D-01,  8.1403632970594852D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.4851440102211244D-01,  7.6120238548426189D-01), ( -6.8060099779545269D-01,  7.3265427167241315D-01), &
( -7.1143219574521654D-01,  7.0275474445722519D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.2110251499110465D-01,  5.7078074588696726D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.6704624551569265D-01,  4.9822766697278176D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.0659570451491545D-01,  4.2200027079979946D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.2632106284566342D-01,  5.6319934401383420D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  4.9022648328829138D-01,  8.7159508665595098D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  3.6561299780477374D-01,  9.3076696107898371D-01), &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.3404195858354346D-01,  9.7222649707893627D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  6.1358846491545160D-03,  9.9998117528260111D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.3154002870288317D-01,  9.9131085984611544D-01), ( -1.7700422041214853D-01,  9.8421009238692914D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.1076715274961136D-01,  9.5048607394948181D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -3.9680998741671009D-01,  9.1790077562139061D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -5.1935599016558920D-01,  8.5455798836540076D-01), &
( -5.5811853122055610D-01,  8.2976123379452305D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.3265427167241293D-01,  6.8060099779545291D-01), &
( -7.6318841726338116D-01,  6.4617601298331651D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.6857070597134067D-01,  4.9556526182577293D-01), ( -8.9044872324475788D-01,  4.5508358712634389D-01), &
( -9.1044129225806714D-01,  4.1363831223843461D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.4460483726148015D-01,  3.2820984357909272D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.7077214072895035D-01,  2.4000302244874133D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01)/
data (mpuu2(i), i =  3101,  3200) / &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01), &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.5143502096900834D-01,  3.0784964004153487D-01), &
(  9.3409255040425898D-01,  3.5703096123342998D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.4505778544146595D-01,  6.6699992230363747D-01), &
(  7.0927282643886569D-01,  7.0493408037590477D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.3201873593980906D-01,  7.7495310659487382D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.4789405917310030D-01,  8.3654772722351189D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.5781330359887712D-01,  8.8904835585466468D-01), (  4.1084317105790408D-01,  9.1170603200542977D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.6375467897483129D-01,  9.6458979328981276D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.1022220729388318D-01,  9.9390697000235606D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), (  6.1358846491547381D-03,  9.9998117528260111D-01), &
( -4.6003182130914519D-02,  9.9894129318685687D-01), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -2.0110463484209204D-01,  9.7956976568544052D-01), &
( -2.5189781815421680D-01,  9.6775383709347551D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.5129275608556704D-01,  9.3626566717027826D-01), ( -3.9962419984564673D-01,  9.1667905992104270D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01), &
( -5.3758707629564517D-01,  8.4320823964184566D-01), ( -5.8081395809576475D-01,  8.1403632970594830D-01), &
( -6.2246127937414997D-01,  7.8265059616657573D-01), ( -6.6241577759017145D-01,  7.4913639452345959D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.3681656887736979D-01,  6.7609270357531592D-01), &
( -7.7106052426181382D-01,  6.3676186123628409D-01), ( -8.0320753148064483D-01,  5.9569930449243347D-01), &
( -8.3317016470191296D-01,  5.5301670558002791D-01), ( -8.6086693863776742D-01,  5.0883014254310688D-01), &
( -8.8622253014888053D-01,  4.6325978355186032D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.2964089584318133D-01,  3.6846682995337215D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01)/
data (mpuu2(i), i =  3201,  3300) / &
( -9.6295326687368388D-01,  2.6966832557291504D-01), ( -9.7570213003852846D-01,  2.1910124015687002D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.9321194923479450D-01,  1.1631863091190471D-01), &
( -9.9792528619859600D-01,  6.4382630929857701D-02), ( -9.9992470183914450D-01,  1.2271538285720451D-02), &
( -9.9920475861836389D-01, -3.9872927587739880D-02), ( -9.9576741446765982D-01, -9.1908956497132516D-02), &
( -9.8962201746320089D-01, -1.4369503315029442D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.2110251499110476D-01,  5.7078074588696726D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.4841868024943473D-01,  9.3733901191257485D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.0674803176636681D-02,  9.9952941750109314D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.4892760574572015D-01,  9.6852209427441727D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.5416352542049023D-01,  9.3518350993894761D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.5508358712634372D-01,  8.9044872324475799D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.3912444486377540D-01,  7.6910333764558003D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.2000250796138165D-01,  6.9397146088965389D-01), ( -7.5720884650648435D-01,  6.5317284295377698D-01), &
( -7.9210657730021250D-01,  6.1038280627630936D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.5455798836540064D-01,  5.1935599016558942D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.0659570451491533D-01,  4.2200027079979985D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.7702814265775439D-01,  2.1311031991609142D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9998117528260111D-01, -6.1358846491541101D-03), ( -9.9811811290014918D-01, -6.1320736302208689D-02), &
( -9.9321194923479461D-01, -1.1631863091190446D-01), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.7433938278557586D-01, -2.2508391135979261D-01), ( -9.6043051941556590D-01, -2.7851968938505289D-01), &
( -9.4359345816196039D-01, -3.3110630575987626D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.1790077562139050D-01,  3.9680998741671031D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.0137617172314024D-01,  5.9816070699634227D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.2635915508434590D-01,  6.8731534089175916D-01), (  6.8508366777270047D-01,  7.2846439044822520D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.4789405917310019D-01,  8.3654772722351201D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.4686884016237433D-01,  8.9459948563138258D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  2.8440753721127199D-01,  9.5870347489587149D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.1327095217756435D-01,  9.9356413552059530D-01), (  5.5195244349689816D-02,  9.9847558057329477D-01)/
data (mpuu2(i), i =  3301,  3400) / &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -6.1320736302208530D-02,  9.9811811290014918D-01), &
( -1.1936521481099145D-01,  9.9285041445986510D-01), ( -1.7700422041214853D-01,  9.8421009238692914D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.4554132496398904D-01,  9.3840353406310817D-01), ( -3.9962419984564690D-01,  9.1667905992104259D-01), &
( -4.5234958723377089D-01,  8.9184070939234272D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.5301670558002736D-01,  8.3317016470191330D-01), ( -6.0061647938386864D-01,  7.9953726910790524D-01), &
( -6.4617601298331606D-01,  7.6318841726338160D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.3056276922782759D-01,  6.8284554638524808D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -8.0503133114296344D-01,  5.9323229503980002D-01), ( -8.3822470555483786D-01,  5.4532498842204669D-01), &
( -8.6857070597134090D-01,  4.9556526182577254D-01), ( -8.9596624975618511D-01,  4.4412214457042931D-01), &
( -9.2031827670911071D-01,  3.9117038430225365D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.5957151308198441D-01,  2.8146493792575833D-01), ( -9.7433938278557586D-01,  2.2508391135979283D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.9390697000235606D-01,  1.1022220729388281D-01), &
( -9.9864021818026516D-01,  5.2131704680283601D-02), ( -9.9998117528260111D-01, -6.1358846491541101D-03), &
( -9.9792528619859600D-01, -6.4382630929857451D-02), ( -9.9247953459870997D-01, -1.2241067519921610D-01), &
( -9.8366241921173025D-01, -1.8002290140569935D-01), ( -9.7150389098625178D-01, -2.3702360599436739D-01), &
( -9.5604525134999652D-01, -2.9321916269425830D-01), ( -9.3733901191257507D-01, -3.4841868024943418D-01), &
( -9.1544871608826783D-01, -4.0243465085941837D-01), ( -8.9044872324475799D-01, -4.5508358712634367D-01), &
( -8.6242395611104050D-01, -5.0618664534515545D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.5885814333386161D-01,  9.8730141815785832D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  3.6807222941358769D-02,  9.9932238458834954D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.0711137619221867D-01,  9.7831737071962765D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.3861623853852777D-01,  8.9867446569395382D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01), &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -9.0398929312344323D-01,  4.2755509343028242D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.4952818059303656D-01,  3.1368174039889180D-01), &
( -9.6697647104485218D-01,  2.5486565960451424D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9729045667869021D-01,  7.3564563599667301D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9879545620517241D-01, -4.9067674327418168D-02), &
( -9.9390697000235606D-01, -1.1022220729388300D-01), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.7293995220556018D-01, -2.3105810828067111D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.3733901191257507D-01, -3.4841868024943418D-01), ( -9.1420975570353058D-01, -4.0524131400499008D-01), &
( -8.8763962040285416D-01, -4.6053871095823967D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.2458930278502529D-01, -5.6573181078361323D-01), ( -7.8834642762660634D-01, -6.1523159058062671D-01)/
data (mpuu2(i), i =  3401,  3500) / &
( -7.4913639452345926D-01, -6.6241577759017178D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.5920918897838807D-01,  6.5084668499638088D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  5.6825895267013171D-01,  8.2284978137582621D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.5781330359887712D-01,  8.8904835585466468D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.1610679707621938D-01,  9.7636973133002114D-01), (  1.5279718525844363D-01,  9.8825756773074946D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.9321916269425857D-01,  9.5604525134999652D-01), ( -3.5416352542049023D-01,  9.3518350993894761D-01), &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.2719913478190139D-01,  8.4974176800085244D-01), ( -5.8081395809576475D-01,  8.1403632970594830D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.2635915508434601D-01,  6.8731534089175894D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.7754529020726113D-01,  4.7949375766015329D-01), ( -9.0659570451491545D-01,  4.2200027079979946D-01), &
( -9.3188426558166815D-01,  3.6275572436739728D-01), ( -9.5330604035419375D-01,  3.0200594931922842D-01), &
( -9.7077214072895035D-01,  2.4000302244874133D-01), ( -9.8421009238692903D-01,  1.7700422041214892D-01), &
( -9.9356413552059530D-01,  1.1327095217756442D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9988234745421256D-01, -1.5339206284987814D-02), ( -9.9682029929116578D-01, -7.9682437971429945D-02), &
( -9.8962201746320089D-01, -1.4369503315029442D-01), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.6295326687368388D-01, -2.6966832557291526D-01), ( -9.4359345816196039D-01, -3.3110630575987626D-01), &
( -9.2031827670911059D-01, -3.9117038430225387D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.6242395611104072D-01, -5.0618664534515512D-01), ( -8.2804504525775591D-01, -5.6066157619733592D-01), &
( -7.9023022143731003D-01, -6.1281008242940971D-01), ( -7.4913639452345959D-01, -6.6241577759017145D-01), &
( -7.0493408037590510D-01, -7.0927282643886547D-01), ( -6.5780669329707886D-01, -7.5318679904361230D-01), &
( -6.0794978496777341D-01, -7.9397547755433739D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.3681656887737002D-01,  6.7609270357531592D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.3912444486377573D-01,  7.6910333764557970D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  2.8440753721127199D-01,  9.5870347489587149D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  8.5797312344440088D-02,  9.9631261218277800D-01), &
(  1.8406729905805042D-02,  9.9983058179582340D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.8303988795514115D-01,  9.8310548743121629D-01), &
( -2.4892760574571993D-01,  9.6852209427441738D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -6.1038280627630948D-01,  7.9210657730021228D-01), ( -6.6241577759017178D-01,  7.4913639452345926D-01)/
data (mpuu2(i), i =  3501,  3600) / &
( -7.1143219574521610D-01,  7.0275474445722552D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -7.9953726910790501D-01,  6.0061647938386886D-01), ( -8.3822470555483786D-01,  5.4532498842204669D-01), &
( -8.7309497841828998D-01,  4.8755016014843627D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.3076696107898360D-01,  3.6561299780477424D-01), ( -9.5330604035419386D-01,  3.0200594931922803D-01), &
( -9.7150389098625167D-01,  2.3702360599436759D-01), ( -9.8527764238894122D-01,  1.7096188876030163D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9932238458834943D-01,  3.6807222941359276D-02), &
( -9.9952941750109314D-01, -3.0674803176636622D-02), ( -9.9518472667219693D-01, -9.8017140329560590D-02), &
( -9.8630809724459867D-01, -1.6491312048996948D-01), ( -9.7293995220556018D-01, -2.3105810828067111D-01), &
( -9.5514116830577067D-01, -2.9615088824362379D-01), ( -9.3299279883473873D-01, -3.5989503653498850D-01), &
( -9.0659570451491533D-01, -4.2200027079979963D-01), ( -8.7607009419540682D-01, -4.8218377207912233D-01), &
( -8.4155497743689844D-01, -5.4017147272989285D-01), ( -8.0320753148064494D-01, -5.9569930449243325D-01), &
( -7.6120238548426222D-01, -6.4851440102211200D-01), ( -7.1573082528381871D-01, -6.9837624940897280D-01), &
( -6.6699992230363758D-01, -7.4505778544146584D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.6066157619733581D-01, -8.2804504525775591D-01), ( -5.0353838372571813D-01, -8.6397285612158647D-01), &
( -4.4412214457042898D-01, -8.9596624975618533D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.3840353406310806D-01,  3.4554132496398909D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  7.6120238548426178D-01,  6.4851440102211244D-01), &
(  7.1358486878079375D-01,  7.0056879394324834D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.0794978496777363D-01,  7.9397547755433717D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  4.9022648328829138D-01,  8.7159508665595098D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  1.5885814333386139D-01,  9.8730141815785843D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  1.8406729905805042D-02,  9.9983058179582340D-01), &
( -5.2131704680283192D-02,  9.9864021818026527D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.9208039704989249D-01,  9.8137919331375456D-01), ( -2.6079411791527568D-01,  9.6539444169768929D-01), &
( -3.2820984357909233D-01,  9.4460483726148037D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -4.5781330359887740D-01,  8.8904835585466446D-01), ( -5.1935599016558920D-01,  8.5455798836540076D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01), &
( -6.8731534089175916D-01,  7.2635915508434590D-01), ( -7.3681656887736979D-01,  6.7609270357531592D-01), &
( -7.8265059616657562D-01,  6.2246127937415008D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.6242395611104050D-01,  5.0618664534515523D-01), ( -8.9596624975618511D-01,  4.4412214457042931D-01), &
( -9.2504924078267747D-01,  3.7984720892405138D-01), ( -9.4952818059303667D-01,  3.1368174039889141D-01), &
( -9.6928123535654842D-01,  2.4595505033579507D-01), ( -9.8421009238692903D-01,  1.7700422041214892D-01), &
( -9.9424044945318790D-01,  1.0717242495680916D-01), ( -9.9932238458834943D-01,  3.6807222941359276D-02), &
( -9.9943060455546173D-01, -3.3741171851377455D-02), ( -9.9456457073425553D-01, -1.0412163387205432D-01), &
( -9.8474850180190421D-01, -1.7398387338746391D-01), ( -9.7003125319454397D-01, -2.4298017990326382D-01), &
( -9.5048607394948181D-01, -3.1076715274961131D-01), ( -9.2621024213831127D-01, -3.7700741021641837D-01), &
( -8.9732458070541832D-01, -4.4137126873171667D-01), ( -8.6397285612158659D-01, -5.0353838372571780D-01), &
( -8.2632106284566365D-01, -5.6319934401383387D-01), ( -7.8455659715557546D-01, -6.2005721176328887D-01), &
( -7.3888732446061522D-01, -6.7382900037875604D-01), ( -6.8954054473706716D-01, -7.2424708295146667D-01), &
( -6.3676186123628487D-01, -7.7106052426181326D-01), ( -5.8081395809576430D-01, -8.1403632970594852D-01), &
( -5.2197529293715450D-01, -8.5296060493036352D-01), ( -4.6053871095824067D-01, -8.8763962040285360D-01), &
( -3.9680998741671070D-01, -9.1790077562139027D-01), ( -3.3110630575987654D-01, -9.4359345816196027D-01), &
( -2.6375467897483118D-01, -9.6458979328981276D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01)/
data (mpuu2(i), i =  3601,  3700) / &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.8954054473706705D-01,  7.2424708295146689D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.7580819141784534D-01,  8.1758481315158371D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.4961132965460682D-01,  8.9322430119551521D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.1368174039889135D-01,  9.4952818059303667D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01), &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -8.0320753148064505D-01,  5.9569930449243313D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9247953459870997D-01,  1.2241067519921679D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9969881869620425D-01, -2.4541228522912083D-02), ( -9.9518472667219693D-01, -9.8017140329560146D-02), &
( -9.8527764238894122D-01, -1.7096188876030141D-01), ( -9.7003125319454397D-01, -2.4298017990326382D-01), &
( -9.4952818059303667D-01, -3.1368174039889157D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -8.9322430119551544D-01, -4.4961132965460626D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.1758481315158393D-01, -5.7580819141784489D-01), ( -7.7301045336273688D-01, -6.3439328416364571D-01), &
( -7.2424708295146700D-01, -6.8954054473706683D-01), ( -6.7155895484701866D-01, -7.4095112535495877D-01), &
( -6.1523159058062660D-01, -7.8834642762660645D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.9289819222978426D-01, -8.7008699110871135D-01), ( -4.2755509343028247D-01, -9.0398929312344312D-01), &
( -3.5989503653498794D-01, -9.3299279883473896D-01), ( -2.9028467725446327D-01, -9.5694033573220860D-01), &
( -2.1910124015687010D-01, -9.7570213003852846D-01), ( -1.4673047445536233D-01, -9.8917650996478090D-01), &
( -7.3564563599667357D-02, -9.9729045667869021D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.2736252565040111D-01,  3.7416406297145793D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.2000250796138165D-01,  6.9397146088965389D-01), &
(  6.6471097820334502D-01,  7.4710060598018002D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.4275078486451589D-01,  8.3989379419599952D-01), (  4.7679923006332225D-01,  8.7901222642863341D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.6375467897483129D-01,  9.6458979328981276D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.1327095217756457D-01,  9.9356413552059530D-01), (  3.6807222941358991D-02,  9.9932238458834954D-01), &
( -3.9872927587739943D-02,  9.9920475861836389D-01), ( -1.1631863091190453D-01,  9.9321194923479461D-01), &
( -1.9208039704989227D-01,  9.8137919331375456D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.3977688440682685D-01,  9.4050607059326830D-01), ( -4.1084317105790397D-01,  9.1170603200542977D-01), &
( -4.7949375766015268D-01,  8.7754529020726146D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.6086693863776742D-01,  5.0883014254310688D-01), &
( -8.9732458070541821D-01,  4.4137126873171689D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5422809510910556D-01,  2.9907982630804053D-01), ( -9.7433938278557575D-01,  2.2508391135979328D-01), &
( -9.8872169196032367D-01,  1.4976453467732190D-01), ( -9.9729045667869021D-01,  7.3564563599667745D-02), &
( -9.9999529380957619D-01, -3.0679567629657324D-03), ( -9.9682029929116567D-01, -7.9682437971430389D-02)/
data (mpuu2(i), i =  3701,  3800) / &
( -9.8778414164457218D-01, -1.5582839765426515D-01), ( -9.7293995220556029D-01, -2.3105810828067067D-01), &
( -9.5237501271976588D-01, -3.0492922973540243D-01), ( -9.2621024213831149D-01, -3.7700741021641793D-01), &
( -8.9459948563138258D-01, -4.4686884016237438D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.1581441080673411D-01, -5.7831379641165515D-01), ( -7.6910333764557970D-01, -6.3912444486377573D-01), &
( -7.1787004505573204D-01, -6.9617713149146265D-01), ( -6.6241577759017178D-01, -7.4913639452345937D-01), &
( -6.0306659854034805D-01, -7.9769084094339116D-01), ( -5.4017147272989352D-01, -8.4155497743689800D-01), &
( -4.7410021465054974D-01, -8.8047088905216087D-01), ( -4.0524131400499036D-01, -9.1420975570353047D-01), &
( -3.3399965144200983D-01, -9.4257319760144676D-01), ( -2.6079411791527590D-01, -9.6539444169768929D-01), &
( -1.8605515166344697D-01, -9.8253930228744124D-01), ( -1.1022220729388331D-01, -9.9390697000235606D-01), &
( -3.3741171851377760D-02, -9.9943060455546173D-01), (  4.2938256934940716D-02, -9.9907772775264536D-01), &
(  1.1936521481099133D-01, -9.9285041445986510D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.8303988795514073D-01,  9.8310548743121640D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -4.1084317105790397D-01,  9.1170603200542977D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.7309497841829020D-01,  4.8755016014843588D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.3945922360218992D-01,  3.4266071731199443D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.8196386910955524D-01,  1.8906866414980633D-01), ( -9.9390697000235606D-01,  1.1022220729388325D-01), &
( -9.9952941750109314D-01,  3.0674803176636865D-02), ( -9.9879545620517241D-01, -4.9067674327417724D-02), &
( -9.9170975366909953D-01, -1.2849811079379284D-01), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.5870347489587160D-01, -2.8440753721127188D-01), ( -9.3299279883473907D-01, -3.5989503653498767D-01), &
( -9.0134884704602203D-01, -4.3309381885315190D-01), ( -8.6397285612158681D-01, -5.0353838372571746D-01), &
( -8.2110251499110454D-01, -5.7078074588696748D-01), ( -7.7301045336273710D-01, -6.3439328416364527D-01), &
( -7.2000250796138188D-01, -6.9397146088965378D-01), ( -6.6241577759017178D-01, -7.4913639452345937D-01), &
( -6.0061647938386931D-01, -7.9953726910790479D-01), ( -5.3499761988709726D-01, -8.4485356524970712D-01), &
( -4.6597649576796585D-01, -8.8479709843093790D-01), ( -3.9399204006104821D-01, -9.1911385169005766D-01), &
( -3.1950203081601541D-01, -9.4758559101774120D-01), ( -2.4298017990326412D-01, -9.7003125319454397D-01), &
( -1.6491312048997064D-01, -9.8630809724459856D-01), ( -8.5797312344440213D-02, -9.9631261218277800D-01), &
( -6.1358846491544163D-03, -9.9998117528260111D-01), (  7.3564563599666996D-02, -9.9729045667869021D-01), &
(  1.5279718525844338D-01, -9.8825756773074946D-01), (  2.3105810828067058D-01, -9.7293995220556029D-01), &
(  3.0784964004153476D-01, -9.5143502096900845D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.1281008242940982D-01,  7.9023022143730992D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01)/
data (mpuu2(i), i =  3801,  3900) / &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -2.4892760574571993D-01,  9.6852209427441738D-01), &
( -3.2820984357909233D-01,  9.4460483726148037D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -6.1764730793780376D-01,  7.8645521359908588D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.1790077562139050D-01,  3.9680998741671025D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01), &
( -9.7077214072895024D-01,  2.4000302244874175D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01), &
( -9.9706007033948296D-01,  7.6623861392031686D-02), ( -9.9998117528260111D-01, -6.1358846491541101D-03), &
( -9.9604470090125197D-01, -8.8853552582524503D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6775383709347551D-01, -2.5189781815421652D-01), ( -9.4359345816196039D-01, -3.3110630575987626D-01), &
( -9.1296219042839832D-01, -4.0804416286497835D-01), ( -8.7607009419540682D-01, -4.8218377207912233D-01), &
( -8.3317016470191330D-01, -5.5301670558002736D-01), ( -7.8455659715557546D-01, -6.2005721176328887D-01), &
( -7.3056276922782737D-01, -6.8284554638524830D-01), ( -6.7155895484701866D-01, -7.4095112535495877D-01), &
( -6.0794978496777408D-01, -7.9397547755433684D-01), ( -5.4017147272989274D-01, -8.4155497743689855D-01), &
( -4.6868882203582790D-01, -8.8336333866573158D-01), ( -3.9399204006104821D-01, -9.1911385169005766D-01), &
( -3.1659337555616612D-01, -9.4856134991573016D-01), ( -2.3702360599436767D-01, -9.7150389098625167D-01), &
( -1.5582839765426501D-01, -9.8778414164457218D-01), ( -7.3564563599667357D-02, -9.9729045667869021D-01), &
(  9.2037547820597154D-03, -9.9995764455196390D-01), (  9.1908956497132460D-02, -9.9576741446765982D-01), &
(  1.7398387338746338D-01, -9.8474850180190432D-01), (  2.5486565960451396D-01, -9.6697647104485229D-01), &
(  3.3399965144200949D-01, -9.4257319760144687D-01), (  4.1084317105790391D-01, -9.1170603200542988D-01), &
(  4.8486924800079084D-01, -8.7458665227817622D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  5.8579785745643898D-01,  8.1045719825259466D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.3861623853852749D-01,  8.9867446569395393D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  2.7851968938505328D-01,  9.6043051941556579D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.1022220729388296D-01,  9.9390697000235606D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -6.1320736302208308D-02,  9.9811811290014918D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.4532498842204657D-01,  8.3822470555483797D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.8060099779545269D-01,  7.3265427167241315D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.7570213003852857D-01,  2.1910124015686960D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9932238458834954D-01, -3.6807222941359026D-02), ( -9.9247953459871008D-01, -1.2241067519921565D-01), &
( -9.7831737071962777D-01, -2.0711137619221817D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.2850608047321581D-01, -3.7131719395183704D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.5135519310526520D-01, -5.2458968267846873D-01), ( -8.0320753148064516D-01, -5.9569930449243291D-01), &
( -7.4913639452345926D-01, -6.6241577759017178D-01), ( -6.8954054473706716D-01, -7.2424708295146667D-01), &
( -6.2485948814238645D-01, -7.8073722857209438D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.8218377207912339D-01, -8.7607009419540627D-01), ( -4.0524131400498953D-01, -9.1420975570353080D-01)/
data (mpuu2(i), i =  3901,  4000) / &
( -3.2531029216226326D-01, -9.4560732538052117D-01), ( -2.4298017990326326D-01, -9.7003125319454420D-01), &
( -1.5885814333386153D-01, -9.8730141815785832D-01), ( -7.3564563599668231D-02, -9.9729045667869021D-01), &
(  1.2271538285720144D-02, -9.9992470183914450D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  1.8303988795514059D-01, -9.8310548743121640D-01), (  2.6671275747489820D-01, -9.6377606579543995D-01), &
(  3.4841868024943451D-01, -9.3733901191257496D-01), (  4.2755509343028136D-01, -9.0398929312344367D-01), &
(  5.0353838372571769D-01, -8.6397285612158670D-01), (  5.7580819141784489D-01, -8.1758481315158404D-01), &
(  6.4383154288979183D-01, -7.6516726562245863D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.0267331823725883D-01,  4.3032648134008261D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  6.9617713149146310D-01,  7.1787004505573160D-01), (  6.2963823891492710D-01,  7.7688846567323244D-01), &
(  5.5811853122055632D-01,  8.2976123379452293D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  4.0243465085941832D-01,  9.1544871608826783D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  2.3404195858354365D-01,  9.7222649707893627D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), ( -3.0674803176636459D-02,  9.9952941750109314D-01), &
( -1.1936521481099123D-01,  9.9285041445986510D-01), ( -2.0711137619221845D-01,  9.7831737071962765D-01), &
( -2.9321916269425879D-01,  9.5604525134999641D-01), ( -3.7700741021641798D-01,  9.2621024213831149D-01), &
( -4.5781330359887701D-01,  8.8904835585466468D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.7609270357531615D-01,  7.3681656887736968D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.4649093877405202D-01,  5.3240312787719801D-01), ( -8.9044872324475766D-01,  4.5508358712634428D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.7894817531906220D-01,  2.0410896609281684D-01), ( -9.9321194923479450D-01,  1.1631863091190471D-01), &
( -9.9961882249517864D-01,  2.7608145778966101D-02), ( -9.9811811290014918D-01, -6.1320736302208245D-02), &
( -9.8872169196032378D-01, -1.4976453467732168D-01), ( -9.7150389098625189D-01, -2.3702360599436695D-01), &
( -9.4660091308328365D-01, -3.2240767880106963D-01), ( -9.1420975570353069D-01, -4.0524131400498969D-01), &
( -8.7458665227817645D-01, -4.8486924800079056D-01), ( -8.2804504525775557D-01, -5.6066157619733625D-01), &
( -7.7495310659487393D-01, -6.3201873593980895D-01), ( -7.1573082528381904D-01, -6.9837624940897247D-01), &
( -6.5084668499638099D-01, -7.5920918897838796D-01), ( -5.8081395809576497D-01, -8.1403632970594808D-01), &
( -5.0618664534515534D-01, -8.6242395611104050D-01), ( -4.2755509343028247D-01, -9.0398929312344312D-01), &
( -3.4554132496398987D-01, -9.3840353406310784D-01), ( -2.6079411791527590D-01, -9.6539444169768929D-01), &
( -1.7398387338746377D-01, -9.8474850180190421D-01), ( -8.5797312344439339D-02, -9.9631261218277811D-01), &
(  3.0679567629661149D-03, -9.9999529380957619D-01), (  9.1908956497132460D-02, -9.9576741446765982D-01), &
(  1.8002290140569971D-01, -9.8366241921173025D-01), (  2.6671275747489820D-01, -9.6377606579543995D-01), &
(  3.5129275608556654D-01, -9.3626566717027848D-01), (  4.3309381885315185D-01, -9.0134884704602203D-01), &
(  5.1146885043796986D-01, -8.5930181835700870D-01), (  5.8579785745643798D-01, -8.1045719825259543D-01), &
(  6.5549285299961502D-01, -7.5520137689653688D-01), (  7.2000250796138165D-01, -6.9397146088965400D-01), &
(  7.7881651238147620D-01, -6.2725181549514375D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.6561299780477374D-01,  9.3076696107898371D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01)/
data (mpuu2(i), i =  4001,  4100) / &
( -5.1935599016558920D-01,  8.5455798836540076D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -7.3265427167241293D-01,  6.8060099779545291D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9992470183914450D-01,  1.2271538285720007D-02), &
( -9.9682029929116578D-01, -7.9682437971429945D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6539444169768940D-01, -2.6079411791527563D-01), ( -9.3733901191257507D-01, -3.4841868024943418D-01), &
( -9.0134884704602203D-01, -4.3309381885315190D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.0684755354379945D-01, -5.9075970185887405D-01), ( -7.4913639452345926D-01, -6.6241577759017178D-01), &
( -6.8508366777270080D-01, -7.2846439044822486D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.4017147272989274D-01, -8.4155497743689855D-01), ( -4.6053871095824067D-01, -8.8763962040285360D-01), &
( -3.7700741021641820D-01, -9.2621024213831138D-01), ( -2.9028467725446239D-01, -9.5694033573220882D-01), &
( -2.0110463484209207D-01, -9.7956976568544052D-01), ( -1.1022220729388331D-01, -9.9390697000235606D-01), &
( -1.8406729905805164D-02, -9.9983058179582340D-01), (  7.3564563599667884D-02, -9.9729045667869021D-01), &
(  1.6491312048996939D-01, -9.8630809724459878D-01), (  2.5486565960451396D-01, -9.6697647104485229D-01), &
(  3.4266071731199454D-01, -9.3945922360218981D-01), (  4.2755509343028220D-01, -9.0398929312344334D-01), &
(  5.0883014254310621D-01, -8.6086693863776775D-01), (  5.8579785745643875D-01, -8.1045719825259488D-01), &
(  6.5780669329707853D-01, -7.5318679904361263D-01), (  7.2424708295146667D-01, -6.8954054473706716D-01), &
(  7.8455659715557502D-01, -6.2005721176328943D-01), (  8.3822470555483775D-01, -5.4532498842204680D-01), &
(  8.8479709843093790D-01, -4.6597649576796590D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  3.2820984357909244D-01,  9.4460483726148026D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
( -4.6003182130914741D-02,  9.9894129318685687D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.8455659715557535D-01,  6.2005721176328898D-01), &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.8137919331375456D-01,  1.9208039704989244D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
( -9.9999529380957619D-01,  3.0679567629659770D-03), ( -9.9576741446765982D-01, -9.1908956497132960D-02), &
( -9.8253930228744135D-01, -1.8605515166344624D-01), ( -9.6043051941556590D-01, -2.7851968938505289D-01), &
( -9.2964089584318121D-01, -3.6846682995337238D-01), ( -8.9044872324475799D-01, -4.5508358712634367D-01), &
( -8.4320823964184566D-01, -5.3758707629564517D-01), ( -7.8834642762660634D-01, -6.1523159058062671D-01), &
( -7.2635915508434623D-01, -6.8731534089175883D-01), ( -6.5780669329707886D-01, -7.5318679904361230D-01), &
( -5.8330865293769829D-01, -8.1225058658520388D-01), ( -5.0353838372571813D-01, -8.6397285612158647D-01), &
( -4.1921688836322429D-01, -9.0788611648766604D-01), ( -3.3110630575987654D-01, -9.4359345816196027D-01), &
( -2.4000302244874142D-01, -9.7077214072895035D-01), ( -1.4673047445536233D-01, -9.8917650996478090D-01), &
( -5.2131704680283657D-02, -9.9864021818026516D-01), (  4.2938256934940716D-02, -9.9907772775264536D-01), &
(  1.3762012158648615D-01, -9.9048508425645698D-01), (  2.3105810828067144D-01, -9.7293995220556007D-01), &
(  3.2240767880106957D-01, -9.4660091308328365D-01), (  4.1084317105790391D-01, -9.1170603200542988D-01), &
(  4.9556526182577265D-01, -8.6857070597134078D-01), (  5.7580819141784489D-01, -8.1758481315158404D-01), &
(  6.5084668499638065D-01, -7.5920918897838829D-01), (  7.2000250796138165D-01, -6.9397146088965400D-01)/
data (mpuu2(i), i =  4101,  4200) / &
(  7.8265059616657529D-01, -6.2246127937415052D-01), (  8.3822470555483775D-01, -5.4532498842204680D-01), &
(  8.8622253014888053D-01, -4.6325978355186043D-01), (  9.2621024213831138D-01, -3.7700741021641826D-01), &
(  9.5782641302753291D-01, -2.8734745954472929D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  1.0000000000000000D+00,  0.0000000000000000D+00), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9999882345170188D-01,  1.5339801862847655D-03), (  9.9999529380957619D-01,  3.0679567629659761D-03), &
(  9.9998941108192840D-01,  4.6019261204485705D-03), (  9.9998117528260111D-01,  6.1358846491544753D-03), &
(  9.9997058643097414D-01,  7.6698287395310970D-03), (  9.9995764455196390D-01,  9.2037547820598194D-03), &
(  9.9994234967602391D-01,  1.0737659167264491D-02), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9990470108285290D-01,  1.3805388528060391D-02), (  9.9988234745421256D-01,  1.5339206284988100D-02), &
(  9.9985764100582386D-01,  1.6872987947281710D-02), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9980116988788426D-01,  1.9940428551514441D-02), (  9.9976940535121528D-01,  2.1474080275469508D-02), &
(  9.9973528826056168D-01,  2.3007681468839369D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9965999674395922D-01,  2.6074717829103901D-02), (  9.9961882249517864D-01,  2.7608145778965740D-02), &
(  9.9957529604674922D-01,  2.9141508764193722D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9948118696616695D-01,  3.2208025408304586D-02), (  9.9943060455546173D-01,  3.3741171851377580D-02), &
(  9.9937767038800285D-01,  3.5274238898213947D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9926474728659442D-01,  3.8340120373552694D-02), (  9.9920475861836389D-01,  3.9872927587739811D-02), &
(  9.9914241872481691D-01,  4.1405640977076739D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9901068585407338D-01,  4.4470771854938668D-02), (  9.9894129318685687D-01,  4.6003182130914623D-02)/
data (mpuu2(i), i =  4201,  4300) / &
(  9.9886954991428356D-01,  4.7535484156959303D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9871901223387294D-01,  5.0599749036899282D-02), (  9.9864021818026527D-01,  5.2131704680283324D-02), &
(  9.9855907422975931D-01,  5.3663537652730520D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9838973740734016D-01,  5.6726821166907748D-02), (  9.9830154493389289D-01,  5.8258264500435752D-02), &
(  9.9821100336047819D-01,  5.9789570746639868D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9802287377148624D-01,  6.2851757564161406D-02), (  9.9792528619859600D-01,  6.4382630929857465D-02), &
(  9.9782535041111164D-01,  6.5913352797003805D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9751145614030345D-01,  7.0504573389613856D-02), &
(  9.9740212990127530D-01,  7.2034653246889332D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9717643673532619D-01,  7.5094300847921305D-02), (  9.9706007033948296D-01,  7.6623861392031492D-02), &
(  9.9694135776498216D-01,  7.8153241632794232D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9669689520289606D-01,  8.1211446809592441D-02), (  9.9657114579055484D-01,  8.2740264549375692D-02), &
(  9.9644305135004263D-01,  8.4268887593324071D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9617982859569698D-01,  8.7325535206192059D-02), (  9.9604470090125197D-01,  8.8853552582524600D-02), &
(  9.9590722941741172D-01,  9.0381360877864983D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9562525638099431D-01,  9.3436335845747787D-02), (  9.9548075549192694D-01,  9.4963495329638992D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9999529380957619D-01,  3.0679567629659761D-03), (  9.9998117528260111D-01,  6.1358846491544753D-03), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9356413552059530D-01,  1.1327095217756435D-01), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9209931314219180D-01,  1.2545498341154623D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9131085984611544D-01,  1.3154002870288312D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.8962201746320089D-01,  1.4369503315029447D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8680940181418553D-01,  1.6188639378011183D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.8366241921173025D-01,  1.8002290140569951D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8253930228744124D-01,  1.8605515166344663D-01), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9998941108192840D-01,  4.6019261204485705D-03), (  9.9995764455196390D-01,  9.2037547820598194D-03)/
data (mpuu2(i), i =  4301,  4400) / &
(  9.9990470108285290D-01,  1.3805388528060391D-02), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9973528826056168D-01,  2.3007681468839369D-02), (  9.9961882249517864D-01,  2.7608145778965740D-02), &
(  9.9948118696616695D-01,  3.2208025408304586D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9914241872481691D-01,  4.1405640977076739D-02), (  9.9894129318685687D-01,  4.6003182130914623D-02), &
(  9.9871901223387294D-01,  5.0599749036899275D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9821100336047819D-01,  5.9789570746639875D-02), (  9.9792528619859600D-01,  6.4382630929857465D-02), &
(  9.9761843513851955D-01,  6.8974327628266732D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9694135776498216D-01,  7.8153241632794246D-02), (  9.9657114579055484D-01,  8.2740264549375692D-02), &
(  9.9617982859569698D-01,  8.7325535206192059D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.9487933079480562D-01,  1.0106986275482781D-01), &
(  9.9440368005767910D-01,  1.0564715371341062D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9338921114808065D-01,  1.1479492660651008D-01), (  9.9285041445986510D-01,  1.1936521481099137D-01), &
(  9.9229059134825737D-01,  1.2393297511851216D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9110791372327689D-01,  1.3306052515713906D-01), (  9.9048508425645709D-01,  1.3762012158648601D-01), &
(  9.8984127845882053D-01,  1.4217680351944803D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8849079285269659D-01,  1.5128103795733022D-01), (  9.8778414164457218D-01,  1.5582839765426526D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8553873531217606D-01,  1.6945029123396796D-01), (  9.8474850180190421D-01,  1.7398387338746382D-01), &
(  9.8393741344921892D-01,  1.7851377093899751D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8225274136628937D-01,  1.8756212858252957D-01), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.8048486177346938D-01,  1.9659459767008022D-01), (  9.7956976568544052D-01,  2.0110463484209187D-01), &
(  9.7863392442942310D-01,  2.0561041305309927D-01), (  9.7767735782450993D-01,  2.1011183688046961D-01), &
(  9.7670008612871184D-01,  2.1460881099378679D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7468351068851067D-01,  2.2358902922978999D-01), (  9.7364424965081198D-01,  2.2807208317088573D-01), &
(  9.7258436893473221D-01,  2.3255030703877522D-01), (  9.7150389098625178D-01,  2.3702360599436723D-01), &
(  9.7040283868755550D-01,  2.4149188530286933D-01), (  9.6928123535654853D-01,  2.4595505033579459D-01), &
(  9.6813910474636244D-01,  2.5041300657296528D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6579335887408368D-01,  2.5931291513288623D-01), (  9.6458979328981276D-01,  2.6375467897483135D-01), &
(  9.6336579978095405D-01,  2.6819085706340318D-01), (  9.6212140426904158D-01,  2.7262135544994892D-01), &
(  9.6085663310767966D-01,  2.7704608030609990D-01), (  9.5957151308198452D-01,  2.8146493792575794D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9998117528260111D-01,  6.1358846491544753D-03), (  9.9992470183914450D-01,  1.2271538285719925D-02), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9456457073425542D-01,  1.0412163387205459D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9321194923479450D-01,  1.1631863091190475D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.9005821026229712D-01,  1.4065823933284921D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8421009238692903D-01,  1.7700422041214875D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8196386910955524D-01,  1.8906866414980619D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7433938278557586D-01,  2.2508391135979283D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01)/
data (mpuu2(i), i =  4401,  4500) / &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6852209427441727D-01,  2.4892760574572015D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6539444169768940D-01,  2.6079411791527551D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.5870347489587160D-01,  2.8440753721127188D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.5143502096900834D-01,  3.0784964004153487D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4758559101774109D-01,  3.1950203081601569D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.3518350993894761D-01,  3.5416352542049034D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.3076696107898371D-01,  3.6561299780477385D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9997058643097414D-01,  7.6698287395310970D-03), (  9.9988234745421256D-01,  1.5339206284988100D-02), &
(  9.9973528826056168D-01,  2.3007681468839369D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9926474728659442D-01,  3.8340120373552694D-02), (  9.9894129318685687D-01,  4.6003182130914623D-02), &
(  9.9855907422975931D-01,  5.3663537652730520D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9706007033948296D-01,  7.6623861392031492D-02), &
(  9.9644305135004263D-01,  8.4268887593324057D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9503319943811863D-01,  9.9543618660069333D-02), (  9.9424044945318790D-01,  1.0717242495680884D-01), &
(  9.9338921114808065D-01,  1.1479492660651008D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9151147331874390D-01,  1.3001922272223335D-01), (  9.9048508425645709D-01,  1.3762012158648604D-01), &
(  9.8940042779138038D-01,  1.4521292465284746D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.8579750916756748D-01,  1.6793829497473114D-01), &
(  9.8448045538322093D-01,  1.7549425337727140D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8167268619698311D-01,  1.9057475482025277D-01), (  9.8018213596811743D-01,  1.9809841071795359D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7536488511665698D-01,  2.2059769010887353D-01), (  9.7364424965081198D-01,  2.2807208317088573D-01), &
(  9.7186633748027940D-01,  2.3553305940497549D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6813910474636244D-01,  2.5041300657296528D-01), (  9.6619000344541250D-01,  2.5783110216215899D-01), &
(  9.6418406395174583D-01,  2.6523403028551179D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.6000214573766596D-01,  2.7999264308027322D-01), (  9.5782641302753291D-01,  2.8734745954472951D-01), &
(  9.5559433413077111D-01,  2.9468537218051433D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.5096166631157508D-01,  3.0930876031226873D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.4610523237040345D-01,  3.2385936651785285D-01), (  9.4359345816196039D-01,  3.3110630575987637D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.3840353406310817D-01,  3.4554132496398904D-01), &
(  9.3572568948108037D-01,  3.5272855575521073D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.3020502289221907D-01,  3.6704034571976718D-01), (  9.2736252565040111D-01,  3.7416406297145799D-01), &
(  9.2446547432526260D-01,  3.8126576922216238D-01), (  9.2151403934204190D-01,  3.8834504669882630D-01), &
(  9.1850839432521225D-01,  3.9540147894781635D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  9.1233518462332275D-01,  4.0944414869225759D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0594729780726846D-01,  4.2339047414379599D-01), (  9.0267331823725883D-01,  4.3032648134008267D-01), &
(  8.9934623697934157D-01,  4.3723717366104403D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.9253355540276458D-01,  4.5098098904510386D-01), (  8.8904835585466457D-01,  4.5781330359887723D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9995764455196390D-01,  9.2037547820598194D-03), (  9.9983058179582340D-01,  1.8406729905804820D-02), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02)/
data (mpuu2(i), i =  4501,  4600) / &
(  9.9487933079480562D-01,  1.0106986275482781D-01), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9285041445986510D-01,  1.1936521481099137D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9048508425645709D-01,  1.3762012158648601D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8778414164457218D-01,  1.5582839765426526D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7956976568544052D-01,  2.0110463484209187D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7150389098625178D-01,  2.3702360599436723D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.6212140426904158D-01,  2.7262135544994892D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.5143502096900834D-01,  3.0784964004153492D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4257319760144687D-01,  3.3399965144200938D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2964089584318133D-01,  3.6846682995337227D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.2270112833387863D-01,  3.8551605384391885D-01), (  9.1911385169005777D-01,  3.9399204006104804D-01), &
(  9.1544871608826783D-01,  4.0243465085941849D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  9.0788611648766615D-01,  4.1921688836322396D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.9184070939234272D-01,  4.5234958723377083D-01), (  8.8763962040285393D-01,  4.6053871095824006D-01), &
(  8.8336333866573158D-01,  4.6868882203582796D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.7458665227817611D-01,  4.8486924800079112D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01), &
(  8.5614732837519447D-01,  5.1673179901764987D-01), (  8.5135519310526520D-01,  5.2458968267846884D-01), &
(  8.4649093877405213D-01,  5.3240312787719790D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9994234967602391D-01,  1.0737659167264491D-02), (  9.9976940535121528D-01,  2.1474080275469508D-02), &
(  9.9948118696616695D-01,  3.2208025408304586D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9855907422975931D-01,  5.3663537652730520D-02), (  9.9792528619859600D-01,  6.4382630929857465D-02), &
(  9.9717643673532619D-01,  7.5094300847921305D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.9424044945318790D-01,  1.0717242495680884D-01), &
(  9.9303235019785141D-01,  1.1784206150832496D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.9027281236316911D-01,  1.3913934416382623D-01), (  9.8872169196032378D-01,  1.4976453467732151D-01), &
(  9.8705657130575097D-01,  1.6037245724292826D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8338511032155118D-01,  1.8153160826112499D-01), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.7926012264908202D-01,  2.0260703884442111D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7468351068851067D-01,  2.2358902922978999D-01), (  9.7222649707893627D-01,  2.3404195858354340D-01), &
(  9.6965738512429245D-01,  2.4446790274782415D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6418406395174583D-01,  2.6523403028551185D-01), (  9.6128048581132064D-01,  2.7557181931095820D-01), &
(  9.5826607140801767D-01,  2.8587783472708056D-01), (  9.5514116830577067D-01,  2.9615088824362379D-01), &
(  9.5190613680793235D-01,  3.0638979537086092D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.4510719328526061D-01,  3.2676045232013173D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3787237643998989D-01,  3.4698041084592368D-01), (  9.3409255040425887D-01,  3.5703096123343003D-01), &
(  9.3020502289221907D-01,  3.6704034571976718D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.2210866874334507D-01,  3.8693100551438864D-01), (  9.1790077562139050D-01,  3.9680998741671025D-01), &
(  9.1358704794525081D-01,  4.0664321687036897D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0464409057824624D-01,  4.2616788872679956D-01), (  9.0001589201616028D-01,  4.3585707992225547D-01), &
(  8.9528392103855758D-01,  4.4549601651398174D-01), (  8.9044872324475799D-01,  4.5508358712634378D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.8047088905216075D-01,  4.7410021465054997D-01)/
data (mpuu2(i), i =  4601,  4700) / &
(  8.7532940310411089D-01,  4.8352707893291874D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6474425751946238D-01,  5.0221247404571068D-01), (  8.5930181835700836D-01,  5.1146885043797041D-01), &
(  8.5376030113811141D-01,  5.2066625414036716D-01), (  8.4812034480329723D-01,  5.2980362468629472D-01), &
(  8.4238259964318585D-01,  5.3887990853100842D-01), (  8.3654772722351201D-01,  5.4789405917310008D-01), &
(  8.3061640030884631D-01,  5.5684503727516010D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  8.1846712958029866D-01,  5.7455335504771576D-01), (  8.1225058658520388D-01,  5.8330865293769829D-01), &
(  8.0594039057117628D-01,  5.9199669496204099D-01), (  7.9953726910790501D-01,  6.0061647938386886D-01), &
(  7.9304196047944364D-01,  6.0916701233645321D-01), (  7.8645521359908577D-01,  6.1764730793780387D-01), &
(  7.7977778792301444D-01,  6.2605638840434363D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9992470183914450D-01,  1.2271538285719925D-02), (  9.9969881869620425D-01,  2.4541228522912288D-02), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9090263542778001D-01,  1.3458070850712617D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8730141815785843D-01,  1.5885814333386145D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7831737071962765D-01,  2.0711137619221856D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7293995220556018D-01,  2.3105810828067111D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.6043051941556579D-01,  2.7851968938505306D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3733901191257496D-01,  3.4841868024943456D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2850608047321559D-01,  3.7131719395183754D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1911385169005777D-01,  3.9399204006104810D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9867446569395382D-01,  4.3861623853852766D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.8763962040285393D-01,  4.6053871095824001D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7607009419540660D-01,  4.8218377207912272D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6397285612158670D-01,  5.0353838372571758D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.3822470555483797D-01,  5.4532498842204646D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.9583690460888357D-01,  6.0551104140432555D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  7.4913639452345937D-01,  6.6241577759017178D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.3265427167241282D-01,  6.8060099779545302D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9990470108285290D-01,  1.3805388528060391D-02), (  9.9961882249517864D-01,  2.7608145778965740D-02), &
(  9.9914241872481691D-01,  4.1405640977076739D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9657114579055484D-01,  8.2740264549375692D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9229059134825737D-01,  1.2393297511851216D-01), (  9.9048508425645709D-01,  1.3762012158648604D-01), &
(  9.8849079285269659D-01,  1.5128103795733019D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8393741344921892D-01,  1.7851377093899751D-01), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7258436893473221D-01,  2.3255030703877524D-01), (  9.6928123535654853D-01,  2.4595505033579459D-01)/
data (mpuu2(i), i =  4701,  4800) / &
(  9.6579335887408368D-01,  2.5931291513288623D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  9.5422809510910567D-01,  2.9907982630804042D-01), &
(  9.5000824500184300D-01,  3.1222481392182488D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.3626566717027826D-01,  3.5129275608556709D-01), &
(  9.3132670908118043D-01,  3.6418478956707989D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.2091724152918941D-01,  3.8975817406985647D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  9.0980570810465222D-01,  4.1503442447608163D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9800057974073988D-01,  4.3999427130963326D-01), (  8.9184070939234272D-01,  4.5234958723377089D-01), &
(  8.8551085613619995D-01,  4.6461868630623776D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.7234605889439154D-01,  4.8888889691976317D-01), (  8.6551362409056909D-01,  5.0088538261124071D-01), &
(  8.5851622426444285D-01,  5.1278640063356296D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.4403189549006652D-01,  5.3629297906596307D-01), (  8.3654772722351201D-01,  5.4789405917310019D-01), &
(  8.2890411477186487D-01,  5.5939071185913614D-01), (  8.2110251499110476D-01,  5.7078074588696726D-01), &
(  8.1314441484925348D-01,  5.8206199034077555D-01), (  8.0503133114296366D-01,  5.9323229503979980D-01), &
(  7.9676481020841872D-01,  6.0428953094815607D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7977778792301455D-01,  6.2605638840434352D-01), (  7.7106052426181382D-01,  6.3676186123628420D-01), &
(  7.6219629813457890D-01,  6.4734596863651206D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.4403374417992929D-01,  6.6814204142651845D-01), (  7.3473887809596339D-01,  6.7835004312986147D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0602126144933985D-01,  7.0819063703319518D-01), (  6.9617713149146299D-01,  7.1787004505573171D-01), &
(  6.8620031168003870D-01,  7.2741262860237565D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.6585623366550972D-01,  7.4608007351006367D-01), (  6.5549285299961546D-01,  7.5520137689653644D-01), &
(  6.4500453681554404D-01,  7.6417874053611667D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9988234745421256D-01,  1.5339206284988100D-02), (  9.9952941750109314D-01,  3.0674803176636626D-02), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8579750916756748D-01,  1.6793829497473114D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.8018213596811743D-01,  1.9809841071795359D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4359345816196039D-01,  3.3110630575987637D-01), &
(  9.3840353406310817D-01,  3.4554132496398904D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2736252565040111D-01,  3.7416406297145799D-01), (  9.2151403934204190D-01,  3.8834504669882630D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0267331823725883D-01,  4.3032648134008267D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7458665227817611D-01,  4.8486924800079112D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.4320823964184544D-01,  5.3758707629564539D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  8.0865618158817498D-01,  5.8828154822264522D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.9023022143731003D-01,  6.1281008242940971D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.6120238548426189D-01,  6.4851440102211244D-01), &
(  7.5116513190968637D-01,  6.6011434206742059D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.2000250796138165D-01,  6.9397146088965400D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.8731534089175916D-01,  7.2635915508434590D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01)/
data (mpuu2(i), i =  4801,  4900) / &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  6.2963823891492698D-01,  7.7688846567323244D-01), &
(  6.1764730793780409D-01,  7.8645521359908566D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.9323229503979991D-01,  8.0503133114296355D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9985764100582386D-01,  1.6872987947281710D-02), (  9.9943060455546173D-01,  3.3741171851377580D-02), &
(  9.9871901223387294D-01,  5.0599749036899282D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9644305135004263D-01,  8.4268887593324071D-02), (  9.9487933079480562D-01,  1.0106986275482782D-01), &
(  9.9303235019785141D-01,  1.1784206150832498D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.8849079285269659D-01,  1.5128103795733022D-01), (  9.8579750916756748D-01,  1.6793829497473117D-01), &
(  9.8282355119870524D-01,  1.8454773693861959D-01), (  9.7956976568544052D-01,  2.0110463484209190D-01), &
(  9.7603707903903902D-01,  2.1760427463848367D-01), (  9.7222649707893627D-01,  2.3404195858354343D-01), &
(  9.6813910474636244D-01,  2.5041300657296522D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.5913862246184189D-01,  2.8293657045705539D-01), (  9.5422809510910567D-01,  2.9907982630804048D-01), &
(  9.4904588185270056D-01,  3.1513792875252239D-01), (  9.4359345816196039D-01,  3.3110630575987643D-01), &
(  9.3787237643998989D-01,  3.4698041084592368D-01), (  9.3188426558166815D-01,  3.6275572436739717D-01), &
(  9.2563083050987283D-01,  3.7842775480876556D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  9.1233518462332275D-01,  4.0944414869225759D-01), (  9.0529675931811870D-01,  4.2477968120910886D-01), &
(  8.9800057974073988D-01,  4.3999427130963320D-01), (  8.9044872324475788D-01,  4.5508358712634384D-01), &
(  8.8264333997956279D-01,  4.7004333245959562D-01), (  8.7458665227817622D-01,  4.8486924800079106D-01), &
(  8.6628095402451299D-01,  4.9955711254508184D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.4893205521163961D-01,  5.2850200154222848D-01), (  8.3989379419599952D-01,  5.4275078486451589D-01), &
(  8.3061640030884631D-01,  5.5684503727515999D-01), (  8.2110251499110465D-01,  5.7078074588696726D-01), &
(  8.1135484701706373D-01,  5.8455394295301533D-01), (  8.0137617172314024D-01,  5.9816070699634227D-01), &
(  7.9116933021769020D-01,  6.1159716392646191D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.7008283699334801D-01,  6.3794390362184406D-01), (  7.5920918897838796D-01,  6.5084668499638099D-01), &
(  7.4811938045040360D-01,  6.6356415861203977D-01), (  7.3681656887737002D-01,  6.7609270357531592D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  7.1358486878079375D-01,  7.0056879394324834D-01), &
(  7.0166259474016857D-01,  7.1250937056469232D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.7722217013718056D-01,  7.3577858916571337D-01), (  6.6471097820334490D-01,  7.4710060598018013D-01), &
(  6.5201053109695961D-01,  7.5820990981301528D-01), (  6.3912444486377573D-01,  7.6910333764557970D-01), &
(  6.2605638840434363D-01,  7.7977778792301444D-01), (  6.1281008242940982D-01,  7.9023022143730992D-01), &
(  5.9938929840056465D-01,  8.0045766219262271D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.7203962932475727D-01,  8.2022598256943458D-01), (  5.5811853122055621D-01,  8.2976123379452305D-01), &
(  5.4403852673088393D-01,  8.3906023707031263D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  5.1541787801946293D-01,  8.5693897741782876D-01), (  5.0088538261124094D-01,  8.6551362409056898D-01), &
(  4.8621027612448642D-01,  8.7384184346536686D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9983058179582340D-01,  1.8406729905804820D-02), (  9.9932238458834954D-01,  3.6807222941358832D-02), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7956976568544052D-01,  2.0110463484209187D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.7150389098625178D-01,  2.3702360599436723D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6212140426904158D-01,  2.7262135544994892D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.5143502096900834D-01,  3.0784964004153492D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3945922360218992D-01,  3.4266071731199438D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.1911385169005777D-01,  3.9399204006104804D-01), &
(  9.1170603200542988D-01,  4.1084317105790391D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8763962040285393D-01,  4.6053871095824006D-01)/
data (mpuu2(i), i =  4901,  5000) / &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.6086693863776731D-01,  5.0883014254310699D-01), (  8.5135519310526520D-01,  5.2458968267846884D-01), &
(  8.4155497743689844D-01,  5.4017147272989285D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7688846567323244D-01,  6.2963823891492698D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2846439044822531D-01,  6.8508366777270024D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0275474445722541D-01,  7.1143219574521632D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.7609270357531592D-01,  7.3681656887736979D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.4851440102211244D-01,  7.6120238548426178D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.2005721176328932D-01,  7.8455659715557513D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.9075970185887439D-01,  8.0684755354379922D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.6066157619733603D-01,  8.2804504525775569D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.2980362468629461D-01,  8.4812034480329723D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  4.6597649576796613D-01,  8.8479709843093779D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.3309381885315201D-01,  9.0134884704602203D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9980116988788426D-01,  1.9940428551514441D-02), (  9.9920475861836389D-01,  3.9872927587739811D-02), &
(  9.9821100336047819D-01,  5.9789570746639868D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9503319943811863D-01,  9.9543618660069319D-02), (  9.9285041445986510D-01,  1.1936521481099135D-01), &
(  9.9027281236316911D-01,  1.3913934416382620D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8393741344921892D-01,  1.7851377093899751D-01), (  9.8018213596811743D-01,  1.9809841071795356D-01), &
(  9.7603707903903902D-01,  2.1760427463848361D-01), (  9.7150389098625178D-01,  2.3702360599436720D-01), &
(  9.6658437447833312D-01,  2.5634868248994291D-01), (  9.6128048581132064D-01,  2.7557181931095814D-01), &
(  9.5559433413077111D-01,  2.9468537218051433D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.4308443746609349D-01,  3.3255336986604422D-01), (  9.3626566717027826D-01,  3.5129275608556709D-01), &
(  9.2907458125931575D-01,  3.6989244714893410D-01), (  9.2151403934204190D-01,  3.8834504669882625D-01), &
(  9.1358704794525081D-01,  4.0664321687036903D-01), (  9.0529675931811882D-01,  4.2477968120910881D-01), &
(  8.9664647017868027D-01,  4.4274722756457002D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.7827979165654146D-01,  4.7814705642484306D-01), (  8.6857070597134090D-01,  4.9556526182577254D-01), &
(  8.5851622426444285D-01,  5.1278640063356296D-01), (  8.4812034480329723D-01,  5.2980362468629461D-01), &
(  8.3738720161566194D-01,  5.4661016691083486D-01), (  8.2632106284566353D-01,  5.6319934401383409D-01), &
(  8.1492632905652662D-01,  5.7956455913940563D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.9116933021769009D-01,  6.1159716392646191D-01), (  7.7881651238147598D-01,  6.2725181549514408D-01), &
(  7.6615399019631292D-01,  6.4265703396622686D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.3992009545951620D-01,  6.7269476907077286D-01), (  7.2635915508434601D-01,  6.8731534089175905D-01), &
(  7.1250937056469232D-01,  7.0166259474016845D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.8396541179731551D-01,  7.2951443814699690D-01), (  6.6928258834663612D-01,  7.4300795213512161D-01), &
(  6.5433361783180055D-01,  7.5620600141439454D-01), (  6.3912444486377584D-01,  7.6910333764557959D-01), &
(  6.2366111752569464D-01,  7.8169483207105939D-01), (  6.0794978496777374D-01,  7.9397547755433706D-01), &
(  5.9199669496204099D-01,  8.0594039057117628D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.5939071185913614D-01,  8.2890411477186476D-01), (  5.4275078486451589D-01,  8.3989379419599952D-01), &
(  5.2589502747108485D-01,  8.5054948126560337D-01), (  5.0883014254310710D-01,  8.6086693863776720D-01), &
(  4.9156291610654990D-01,  8.7084206347007886D-01), (  4.7410021465055002D-01,  8.8047088905216075D-01), &
(  4.5644898239688386D-01,  8.8974958638307289D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  4.2060907444840268D-01,  9.0724197791529582D-01), (  4.0243465085941854D-01,  9.1544871608826783D-01), &
(  3.8410019501693504D-01,  9.2329141671952764D-01), (  3.6561299780477396D-01,  9.3076696107898371D-01), &
(  3.4698041084592368D-01,  9.3787237643998989D-01), (  3.2820984357909266D-01,  9.4460483726148026D-01)/
data (mpuu2(i), i =  5001,  5100) / &
(  3.0930876031226873D-01,  9.5096166631157508D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9976940535121528D-01,  2.1474080275469508D-02), (  9.9907772775264536D-01,  4.2938256934940820D-02), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02), &
(  9.9424044945318790D-01,  1.0717242495680884D-01), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.8872169196032378D-01,  1.4976453467732151D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.7222649707893627D-01,  2.3404195858354340D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.6128048581132064D-01,  2.7557181931095820D-01), (  9.5514116830577067D-01,  2.9615088824362379D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3409255040425887D-01,  3.5703096123343003D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.1790077562139050D-01,  3.9680998741671025D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.9044872324475799D-01,  4.5508358712634378D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5930181835700836D-01,  5.1146885043797041D-01), (  8.4812034480329723D-01,  5.2980362468629472D-01), &
(  8.3654772722351201D-01,  5.4789405917310008D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  7.9953726910790501D-01,  6.0061647938386886D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.4505778544146595D-01,  6.6699992230363758D-01), &
(  7.3056276922782759D-01,  6.8284554638524808D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  7.0056879394324834D-01,  7.1358486878079352D-01), (  6.8508366777270058D-01,  7.2846439044822509D-01), &
(  6.6928258834663623D-01,  7.4300795213512161D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.3676186123628442D-01,  7.7106052426181360D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  6.0306659854034828D-01,  7.9769084094339104D-01), (  5.8579785745643898D-01,  8.1045719825259466D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  5.3240312787719801D-01,  8.4649093877405202D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9556526182577271D-01,  8.6857070597134078D-01), (  4.7679923006332203D-01,  8.7901222642863353D-01), &
(  4.5781330359887729D-01,  8.8904835585466446D-01), (  4.3861623853852749D-01,  8.9867446569395393D-01), &
(  4.1921688836322396D-01,  9.0788611648766615D-01), (  3.9962419984564701D-01,  9.1667905992104259D-01), &
(  3.7984720892405111D-01,  9.2504924078267758D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  2.9907982630804048D-01,  9.5422809510910567D-01), (  2.7851968938505328D-01,  9.6043051941556579D-01), &
(  2.5783110216215893D-01,  9.6619000344541262D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  2.1610679707621938D-01,  9.7636973133002114D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9973528826056168D-01,  2.3007681468839369D-02), (  9.9894129318685687D-01,  4.6003182130914623D-02), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9338921114808065D-01,  1.1479492660651008D-01), (  9.9048508425645709D-01,  1.3762012158648604D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.7364424965081198D-01,  2.2807208317088573D-01), &
(  9.6813910474636244D-01,  2.5041300657296522D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5559433413077111D-01,  2.9468537218051438D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2446547432526260D-01,  3.8126576922216238D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  9.0594729780726846D-01,  4.2339047414379599D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.7458665227817622D-01,  4.8486924800079106D-01), &
(  8.6319942171212416D-01,  5.0486310853126748D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3906023707031274D-01,  5.4403852673088382D-01), (  8.2632106284566342D-01,  5.6319934401383420D-01), &
(  8.1314441484925359D-01,  5.8206199034077544D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.8550682956405393D-01,  6.1885298796097632D-01), (  7.7106052426181382D-01,  6.3676186123628420D-01), &
(  7.5620600141439454D-01,  6.5433361783180044D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  7.0927282643886569D-01,  7.0493408037590488D-01)/
data (mpuu2(i), i =  5101,  5200) / &
(  6.9286617481742474D-01,  7.2106619931450799D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.5896129298203732D-01,  7.5217685044904270D-01), (  6.4148101280858327D-01,  7.6713891193582029D-01), &
(  6.2366111752569464D-01,  7.8169483207105939D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.8704039352091808D-01,  8.0955764240405115D-01), (  5.6825895267013160D-01,  8.2284978137582632D-01), &
(  5.4917666218771988D-01,  8.3570628435375249D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  5.1015009670676681D-01,  8.6008539042939014D-01), (  4.9022648328829138D-01,  8.7159508665595098D-01), &
(  4.7004333245959562D-01,  8.8264333997956279D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2894129205532955D-01,  9.0333236849451182D-01), (  4.0804416286497874D-01,  9.1296219042839810D-01), &
(  3.8693100551438869D-01,  9.2210866874334507D-01), (  3.6561299780477374D-01,  9.3076696107898371D-01), &
(  3.4410142598993898D-01,  9.3893248353206449D-01), (  3.2240767880106996D-01,  9.4660091308328353D-01), &
(  3.0054324141727340D-01,  9.5376818988599033D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.5634868248994308D-01,  9.6658437447833301D-01), (  2.3404195858354346D-01,  9.7222649707893627D-01), &
(  2.1161132736922761D-01,  9.7735390014519996D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.6642590354046422D-01,  9.8605396334619544D-01), (  1.4369503315029458D-01,  9.8962201746320078D-01), &
(  1.2088808723577700D-01,  9.9266614244894802D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9969881869620425D-01,  2.4541228522912288D-02), (  9.9879545620517241D-01,  4.9067674327418015D-02), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.9247953459870997D-01,  1.2241067519921620D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8527764238894122D-01,  1.7096188876030122D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6377606579543984D-01,  2.6671275747489837D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4952818059303667D-01,  3.1368174039889152D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.1420975570353069D-01,  4.0524131400498986D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9322430119551532D-01,  4.4961132965460654D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.4485356524970712D-01,  5.3499761988709715D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1758481315158371D-01,  5.7580819141784534D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.5720884650648457D-01,  6.5317284295377676D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2424708295146700D-01,  6.8954054473706683D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.8954054473706694D-01,  7.2424708295146689D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.5317284295377687D-01,  7.5720884650648446D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.1523159058062693D-01,  7.8834642762660623D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.7580819141784545D-01,  8.1758481315158371D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.3499761988709738D-01,  8.4485356524970701D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.9289819222978415D-01,  8.7008699110871135D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.4961132965460660D-01,  8.9322430119551532D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  4.0524131400498981D-01,  9.1420975570353069D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.5989503653498828D-01,  9.3299279883473885D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  3.1368174039889152D-01,  9.4952818059303667D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.6671275747489842D-01,  9.6377606579543984D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.1910124015686977D-01,  9.7570213003852857D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  1.2241067519921628D-01,  9.9247953459870997D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  7.3564563599667454D-02,  9.9729045667869021D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9965999674395922D-01,  2.6074717829103901D-02), (  9.9864021818026527D-01,  5.2131704680283324D-02), &
(  9.9694135776498216D-01,  7.8153241632794232D-02), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.9151147331874390D-01,  1.3001922272223335D-01), (  9.8778414164457218D-01,  1.5582839765426523D-01)/
data (mpuu2(i), i =  5201,  5300) / &
(  9.8338511032155118D-01,  1.8153160826112497D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.7258436893473221D-01,  2.3255030703877524D-01), (  9.6619000344541250D-01,  2.5783110216215899D-01), &
(  9.5913862246184189D-01,  2.8293657045705534D-01), (  9.5143502096900834D-01,  3.0784964004153487D-01), &
(  9.4308443746609349D-01,  3.3255336986604422D-01), (  9.3409255040425898D-01,  3.5703096123342998D-01), &
(  9.2446547432526271D-01,  3.8126576922216232D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  9.0333236849451182D-01,  4.2894129205532955D-01), (  8.9184070939234272D-01,  4.5234958723377089D-01), &
(  8.7974259280004741D-01,  4.7545028174715587D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.5376030113811130D-01,  5.2066625414036716D-01), (  8.3989379419599952D-01,  5.4275078486451589D-01), &
(  8.2545615400437755D-01,  5.6446624152051950D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.9490712632823701D-01,  6.0673112703452459D-01), (  7.7881651238147598D-01,  6.2725181549514408D-01), &
(  7.6219629813457890D-01,  6.4734596863651206D-01), (  7.4505778544146595D-01,  6.6699992230363747D-01), &
(  7.2741262860237577D-01,  6.8620031168003859D-01), (  7.0927282643886569D-01,  7.0493408037590477D-01), &
(  6.9065071413453472D-01,  7.2318848930652724D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.5201053109695961D-01,  7.5820990981301528D-01), (  6.3201873593980906D-01,  7.7495310659487382D-01), &
(  6.1159716392646202D-01,  7.9116933021769009D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.6952051934694725D-01,  8.2197711527924144D-01), (  5.4789405917310030D-01,  8.3654772722351189D-01), &
(  5.2589502747108485D-01,  8.5054948126560337D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.8083933060033418D-01,  8.7680872380914554D-01), (  4.5781330359887712D-01,  8.8904835585466468D-01), &
(  4.3447596056965571D-01,  9.0068342922864686D-01), (  4.1084317105790408D-01,  9.1170603200542977D-01), &
(  3.8693100551438869D-01,  9.2210866874334507D-01), (  3.6275572436739723D-01,  9.3188426558166815D-01), &
(  3.3833376696554107D-01,  9.4102617505088926D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.8881640820604970D-01,  9.5738450078897586D-01), (  2.6375467897483129D-01,  9.6458979328981276D-01), &
(  2.3851359484431850D-01,  9.7113915844972509D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  1.8756212858252952D-01,  9.8225274136628937D-01), (  1.6188639378011188D-01,  9.8680940181418542D-01), &
(  1.3610057517570617D-01,  9.9069502544266463D-01), (  1.1022220729388318D-01,  9.9390697000235606D-01), &
(  8.4268887593324113D-02,  9.9644305135004263D-01), (  5.8258264500435732D-02,  9.9830154493389289D-01), &
(  3.2208025408304704D-02,  9.9948118696616695D-01), (  6.1358846491547381D-03,  9.9998117528260111D-01), &
( -1.9940428551514476D-02,  9.9980116988788426D-01), ( -4.6003182130914519D-02,  9.9894129318685687D-01), &
( -7.2034653246889305D-02,  9.9740212990127530D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9961882249517864D-01,  2.7608145778965740D-02), (  9.9847558057329477D-01,  5.5195244349689941D-02), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.5422809510910567D-01,  2.9907982630804042D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  8.2110251499110476D-01,  5.7078074588696726D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.9617713149146299D-01,  7.1787004505573171D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.1281008242940982D-01,  7.9023022143731003D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.6825895267013171D-01,  8.2284978137582621D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.2197529293715439D-01,  8.5296060493036363D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2477968120910903D-01,  9.0529675931811870D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01)/
data (mpuu2(i), i =  5301,  5400) / &
(  3.7416406297145793D-01,  9.2736252565040111D-01), (  3.4841868024943473D-01,  9.3733901191257485D-01), &
(  3.2240767880106980D-01,  9.4660091308328353D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.6966832557291498D-01,  9.6295326687368388D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.1610679707621960D-01,  9.7636973133002114D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  1.0717242495680887D-01,  9.9424044945318790D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -3.0674803176636681D-02,  9.9952941750109314D-01), &
( -5.8258264500435607D-02,  9.9830154493389289D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.1327095217756424D-01,  9.9356413552059530D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9957529604674922D-01,  2.9141508764193722D-02), (  9.9830154493389289D-01,  5.8258264500435752D-02), &
(  9.9617982859569698D-01,  8.7325535206192059D-02), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.8940042779138038D-01,  1.4521292465284746D-01), (  9.8474850180190421D-01,  1.7398387338746382D-01), &
(  9.7926012264908202D-01,  2.0260703884442113D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.6579335887408368D-01,  2.5931291513288623D-01), (  9.5782641302753291D-01,  2.8734745954472951D-01), &
(  9.4904588185270056D-01,  3.1513792875252239D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.2907458125931575D-01,  3.6989244714893416D-01), (  9.1790077562139050D-01,  3.9680998741671031D-01), &
(  9.0594729780726846D-01,  4.2339047414379599D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.7974259280004741D-01,  4.7545028174715592D-01), (  8.6551362409056909D-01,  5.0088538261124071D-01), &
(  8.5054948126560348D-01,  5.2589502747108463D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.1846712958029866D-01,  5.7455335504771576D-01), (  8.0137617172314024D-01,  5.9816070699634227D-01), &
(  7.8360451860963831D-01,  6.2125997651108755D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.4608007351006378D-01,  6.6585623366550972D-01), (  7.2635915508434590D-01,  6.8731534089175916D-01), &
(  7.0602126144933985D-01,  7.0819063703319518D-01), (  6.8508366777270047D-01,  7.2846439044822520D-01), &
(  6.6356415861203977D-01,  7.4811938045040360D-01), (  6.4148101280858327D-01,  7.6713891193582029D-01), &
(  6.1885298796097643D-01,  7.8550682956405393D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.7203962932475716D-01,  8.2022598256943469D-01), (  5.4789405917310019D-01,  8.3654772722351201D-01), &
(  5.2328310347565643D-01,  8.5215890162391983D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.7274903195034290D-01,  8.8119711347122198D-01), (  4.4686884016237433D-01,  8.9459948563138258D-01), &
(  4.2060907444840268D-01,  9.0724197791529582D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.6704034571976724D-01,  9.3020502289221907D-01), (  3.3977688440682696D-01,  9.4050607059326830D-01), &
(  3.1222481392182505D-01,  9.5000824500184300D-01), (  2.8440753721127199D-01,  9.5870347489587149D-01), &
(  2.5634868248994291D-01,  9.6658437447833312D-01), (  2.2807208317088579D-01,  9.7364424965081187D-01), &
(  1.9960175762113083D-01,  9.7987710369951764D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.4217680351944822D-01,  9.8984127845882053D-01), (  1.1327095217756435D-01,  9.9356413552059530D-01), &
(  8.4268887593324113D-02,  9.9644305135004263D-01), (  5.5195244349689816D-02,  9.9847558057329477D-01), &
(  2.6074717829104040D-02,  9.9965999674395922D-01), ( -3.0679567629657936D-03,  9.9999529380957619D-01), &
( -3.2208025408304579D-02,  9.9948118696616695D-01), ( -6.1320736302208530D-02,  9.9811811290014918D-01), &
( -9.0381360877864900D-02,  9.9590722941741172D-01), ( -1.1936521481099145D-01,  9.9285041445986510D-01), &
( -1.4824767898689586D-01,  9.8895026451030299D-01), ( -1.7700422041214853D-01,  9.8421009238692914D-01), &
( -2.0561041305309921D-01,  9.7863392442942321D-01), ( -2.3404195858354335D-01,  9.7222649707893627D-01), &
( -2.6227470702391370D-01,  9.6499325285492032D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9952941750109314D-01,  3.0674803176636626D-02), (  9.9811811290014918D-01,  6.1320736302208578D-02), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8825756773074946D-01,  1.5279718525844344D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4359345816196039D-01,  3.3110630575987637D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.2151403934204190D-01,  3.8834504669882630D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01)/
data (mpuu2(i), i =  5401,  5500) / &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.6704624551569265D-01,  4.9822766697278187D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.3486287498638001D-01,  5.5045797293660481D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.6120238548426189D-01,  6.4851440102211244D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.2000250796138165D-01,  6.9397146088965400D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2963823891492698D-01,  7.7688846567323244D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.8081395809576464D-01,  8.1403632970594830D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.2980362468629461D-01,  8.4812034480329723D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.7679923006332225D-01,  8.7901222642863341D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.2200027079979979D-01,  9.0659570451491533D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  3.0784964004153498D-01,  9.5143502096900834D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.4892760574572026D-01,  9.6852209427441727D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.5885814333386161D-01,  9.8730141815785832D-01), &
(  1.2849811079379300D-01,  9.9170975366909953D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  3.6807222941358769D-02,  9.9932238458834954D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -5.5195244349689913D-02,  9.9847558057329477D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.0711137619221867D-01,  9.7831737071962765D-01), &
( -2.3702360599436700D-01,  9.7150389098625178D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -2.9615088824362384D-01,  9.5514116830577067D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9948118696616695D-01,  3.2208025408304586D-02), (  9.9792528619859600D-01,  6.4382630929857465D-02), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.7468351068851067D-01,  2.2358902922978999D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.3787237643998989D-01,  3.4698041084592363D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  9.1358704794525081D-01,  4.0664321687036903D-01), (  9.0001589201616028D-01,  4.3585707992225547D-01), &
(  8.8551085613619995D-01,  4.6461868630623776D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5376030113811130D-01,  5.2066625414036716D-01), (  8.3654772722351201D-01,  5.4789405917310019D-01), &
(  8.1846712958029866D-01,  5.7455335504771576D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.7977778792301444D-01,  6.2605638840434363D-01), (  7.5920918897838807D-01,  6.5084668499638088D-01), &
(  7.3785281478846598D-01,  6.7496164610201204D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.9286617481742474D-01,  7.2106619931450799D-01), (  6.6928258834663612D-01,  7.4300795213512161D-01), &
(  6.4500453681554404D-01,  7.6417874053611667D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  5.9446649918466454D-01,  8.0412037739826570D-01), (  5.6825895267013171D-01,  8.2284978137582621D-01), &
(  5.4146176585312356D-01,  8.4072537497045796D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.8621027612448642D-01,  8.7384184346536686D-01), (  4.5781330359887712D-01,  8.8904835585466468D-01), &
(  4.2894129205532955D-01,  9.0333236849451182D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.6989244714893404D-01,  9.2907458125931586D-01), (  3.3977688440682696D-01,  9.4050607059326830D-01), &
(  3.0930876031226873D-01,  9.5096166631157508D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.4744161916777344D-01,  9.6890280477642887D-01), (  2.1610679707621938D-01,  9.7636973133002114D-01), &
(  1.8454773693861964D-01,  9.8282355119870524D-01), (  1.5279718525844363D-01,  9.8825756773074946D-01), &
(  1.2088808723577700D-01,  9.9266614244894802D-01), (  8.8853552582524684D-02,  9.9604470090125197D-01), &
(  5.6726821166907783D-02,  9.9838973740734016D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -7.6698287395309539D-03,  9.9997058643097414D-01), ( -3.9872927587739720D-02,  9.9920475861836389D-01)/
data (mpuu2(i), i =  5501,  5600) / &
( -7.2034653246889305D-02,  9.9740212990127530D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.3610057517570628D-01,  9.9069502544266463D-01), ( -1.6793829497473109D-01,  9.8579750916756748D-01), &
( -1.9960175762113094D-01,  9.7987710369951764D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.6227470702391348D-01,  9.6499325285492044D-01), ( -2.9321916269425857D-01,  9.5604525134999652D-01), &
( -3.2385936651785285D-01,  9.4610523237040345D-01), ( -3.5416352542049023D-01,  9.3518350993894761D-01), &
( -3.8410019501693493D-01,  9.2329141671952764D-01), ( -4.1363831223843450D-01,  9.1044129225806725D-01), &
( -4.4274722756457024D-01,  8.9664647017868015D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9943060455546173D-01,  3.3741171851377580D-02), (  9.9772306664419164D-01,  6.7443919563664051D-02), &
(  9.9487933079480562D-01,  1.0106986275482782D-01), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.8579750916756748D-01,  1.6793829497473117D-01), (  9.7956976568544052D-01,  2.0110463484209190D-01), &
(  9.7222649707893627D-01,  2.3404195858354343D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.5422809510910567D-01,  2.9907982630804048D-01), (  9.4359345816196039D-01,  3.3110630575987643D-01), &
(  9.3188426558166815D-01,  3.6275572436739717D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  9.0529675931811870D-01,  4.2477968120910886D-01), (  8.9044872324475788D-01,  4.5508358712634384D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.2110251499110465D-01,  5.7078074588696726D-01), &
(  8.0137617172314024D-01,  5.9816070699634227D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.5920918897838796D-01,  6.5084668499638099D-01), (  7.3681656887737002D-01,  6.7609270357531592D-01), &
(  7.1358486878079375D-01,  7.0056879394324834D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.6471097820334490D-01,  7.4710060598018013D-01), (  6.3912444486377573D-01,  7.6910333764557970D-01), &
(  6.1281008242940982D-01,  7.9023022143730992D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.5811853122055621D-01,  8.2976123379452305D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.4137126873171662D-01,  8.9732458070541832D-01), (  4.1084317105790391D-01,  9.1170603200542988D-01), &
(  3.7984720892405133D-01,  9.2504924078267758D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  3.1659337555616585D-01,  9.4856134991573027D-01), (  2.8440753721127199D-01,  9.5870347489587149D-01), &
(  2.5189781815421713D-01,  9.6775383709347540D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.8605515166344683D-01,  9.8253930228744124D-01), (  1.5279718525844341D-01,  9.8825756773074946D-01), &
(  1.1936521481099156D-01,  9.9285041445986510D-01), (  8.5797312344440088D-02,  9.9631261218277800D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  1.8406729905805042D-02,  9.9983058179582340D-01), &
( -1.5339206284988098D-02,  9.9988234745421256D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -8.2740264549375470D-02,  9.9657114579055484D-01), ( -1.1631863091190475D-01,  9.9321194923479450D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -1.8303988795514115D-01,  9.8310548743121629D-01), &
( -2.1610679707621949D-01,  9.7636973133002114D-01), ( -2.4892760574571993D-01,  9.6852209427441738D-01), &
( -2.8146493792575794D-01,  9.5957151308198452D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.4554132496398882D-01,  9.3840353406310817D-01), ( -3.7700741021641820D-01,  9.2621024213831138D-01), &
( -4.0804416286497863D-01,  9.1296219042839821D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.6868882203582807D-01,  8.8336333866573158D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.2719913478190139D-01,  8.4974176800085244D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9937767038800285D-01,  3.5274238898213947D-02), (  9.9751145614030345D-01,  7.0504573389613856D-02), &
(  9.9440368005767910D-01,  1.0564715371341062D-01), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.8448045538322093D-01,  1.7549425337727143D-01), (  9.7767735782450993D-01,  2.1011183688046961D-01), &
(  9.6965738512429245D-01,  2.4446790274782415D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.5000824500184300D-01,  3.1222481392182488D-01), (  9.3840353406310806D-01,  3.4554132496398909D-01), &
(  9.2563083050987283D-01,  3.7842775480876556D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  8.9664647017868015D-01,  4.4274722756457008D-01), (  8.8047088905216075D-01,  4.7410021465054997D-01), &
(  8.6319942171212416D-01,  5.0486310853126748D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.2545615400437755D-01,  5.6446624152051950D-01), (  8.0503133114296366D-01,  5.9323229503979980D-01), &
(  7.8360451860963831D-01,  6.2125997651108755D-01), (  7.6120238548426178D-01,  6.4851440102211244D-01), &
(  7.3785281478846598D-01,  6.7496164610201204D-01), (  7.1358486878079375D-01,  7.0056879394324834D-01)/
data (mpuu2(i), i =  5601,  5700) / &
(  6.8842875278409055D-01,  7.2530397237306066D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.3557832048855611D-01,  7.7203639715038452D-01), (  6.0794978496777363D-01,  7.9397547755433717D-01), &
(  5.7956455913940585D-01,  8.1492632905652651D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  5.2066625414036716D-01,  8.5376030113811141D-01), (  4.9022648328829138D-01,  8.7159508665595098D-01), &
(  4.5917654752194415D-01,  8.8834503330959635D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  3.9540147894781630D-01,  9.1850839432521225D-01), (  3.6275572436739723D-01,  9.3188426558166815D-01), &
(  3.2965846252858755D-01,  9.4410025849127266D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.6227470702391359D-01,  9.6499325285492032D-01), (  2.2807208317088579D-01,  9.7364424965081187D-01), &
(  1.9358558729580372D-01,  9.8108339115048659D-01), (  1.5885814333386139D-01,  9.8730141815785843D-01), &
(  1.2393297511851241D-01,  9.9229059134825726D-01), (  8.8853552582524684D-02,  9.9604470090125197D-01), &
(  5.3663537652730679D-02,  9.9855907422975931D-01), (  1.8406729905805042D-02,  9.9983058179582340D-01), &
( -1.6872987947281648D-02,  9.9985764100582386D-01), ( -5.2131704680283192D-02,  9.9864021818026527D-01), &
( -8.7325535206192101D-02,  9.9617982859569687D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.5734345561623816D-01,  9.8754394179435934D-01), ( -1.9208039704989249D-01,  9.8137919331375456D-01), &
( -2.2657826384561000D-01,  9.7399296216795583D-01), ( -2.6079411791527568D-01,  9.6539444169768929D-01), &
( -2.9468537218051422D-01,  9.5559433413077111D-01), ( -3.2820984357909233D-01,  9.4460483726148037D-01), &
( -3.6132580556845423D-01,  9.3243962926846247D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -4.2616788872679928D-01,  9.0464409057824635D-01), ( -4.5781330359887740D-01,  8.8904835585466446D-01), &
( -4.8888889691976306D-01,  8.7234605889439154D-01), ( -5.1935599016558920D-01,  8.5455798836540076D-01), &
( -5.4917666218771954D-01,  8.3570628435375272D-01), ( -5.7831379641165548D-01,  8.1581441080673389D-01), &
( -6.0673112703452459D-01,  7.9490712632823701D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9932238458834954D-01,  3.6807222941358832D-02), (  9.9729045667869021D-01,  7.3564563599667426D-02), &
(  9.9390697000235606D-01,  1.1022220729388306D-01), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4560732538052128D-01,  3.2531029216226293D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1911385169005777D-01,  3.9399204006104804D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.8763962040285393D-01,  4.6053871095824006D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.5135519310526520D-01,  5.2458968267846884D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.1045719825259477D-01,  5.8579785745643886D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.6516726562245896D-01,  6.4383154288979139D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.8954054473706705D-01,  7.2424708295146689D-01), &
(  6.6241577759017178D-01,  7.4913639452345926D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.7580819141784534D-01,  8.1758481315158371D-01), &
(  5.4532498842204657D-01,  8.3822470555483797D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.8218377207912289D-01,  8.7607009419540649D-01), (  4.4961132965460682D-01,  8.9322430119551521D-01), &
(  4.1642956009763732D-01,  9.0916798309052238D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.4841868024943451D-01,  9.3733901191257496D-01), (  3.1368174039889135D-01,  9.4952818059303667D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.0711137619221856D-01,  9.7831737071962765D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.3458070850712622D-01,  9.9090263542778001D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1320736302208877D-02,  9.9811811290014918D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -1.2271538285719823D-02,  9.9992470183914450D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01), &
( -8.5797312344439991D-02,  9.9631261218277800D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.5885814333386150D-01,  9.8730141815785832D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.3105810828067094D-01,  9.7293995220556018D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.0200594931922786D-01,  9.5330604035419386D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -3.7131719395183754D-01,  9.2850608047321559D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.3861623853852777D-01,  8.9867446569395382D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.0353838372571746D-01,  8.6397285612158681D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01)/
data (mpuu2(i), i =  5701,  5800) / &
( -5.6573181078361323D-01,  8.2458930278502529D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.2485948814238623D-01,  7.8073722857209460D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -6.8060099779545302D-01,  7.3265427167241282D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9926474728659442D-01,  3.8340120373552694D-02), (  9.9706007033948296D-01,  7.6623861392031492D-02), &
(  9.9338921114808065D-01,  1.1479492660651008D-01), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.8167268619698311D-01,  1.9057475482025274D-01), (  9.7364424965081198D-01,  2.2807208317088573D-01), &
(  9.6418406395174583D-01,  2.6523403028551179D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.2736252565040111D-01,  3.7416406297145793D-01), &
(  9.1233518462332275D-01,  4.0944414869225754D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.7827979165654146D-01,  4.7814705642484306D-01), (  8.5930181835700847D-01,  5.1146885043797030D-01), &
(  8.3906023707031274D-01,  5.4403852673088382D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.9490712632823701D-01,  6.0673112703452459D-01), (  7.7106052426181382D-01,  6.3676186123628420D-01), &
(  7.4608007351006389D-01,  6.6585623366550961D-01), (  7.2000250796138165D-01,  6.9397146088965389D-01), &
(  6.9286617481742463D-01,  7.2106619931450811D-01), (  6.6471097820334502D-01,  7.4710060598018002D-01), &
(  6.3557832048855623D-01,  7.7203639715038441D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.7455335504771587D-01,  8.1846712958029866D-01), (  5.4275078486451589D-01,  8.3989379419599952D-01), &
(  5.1015009670676692D-01,  8.6008539042939003D-01), (  4.7679923006332225D-01,  8.7901222642863341D-01), &
(  4.4274722756457013D-01,  8.9664647017868015D-01), (  4.0804416286497874D-01,  9.1296219042839810D-01), &
(  3.7274106700951581D-01,  9.2793539482261789D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  3.0054324141727340D-01,  9.5376818988599033D-01), (  2.6375467897483129D-01,  9.6458979328981276D-01), &
(  2.2657826384561011D-01,  9.7399296216795583D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.5128103795733025D-01,  9.8849079285269659D-01), (  1.1327095217756457D-01,  9.9356413552059530D-01), &
(  7.5094300847921500D-02,  9.9717643673532608D-01), (  3.6807222941358991D-02,  9.9932238458834954D-01), &
( -1.5339801862846436D-03,  9.9999882345170188D-01), ( -3.9872927587739943D-02,  9.9920475861836389D-01), &
( -7.8153241632794190D-02,  9.9694135776498216D-01), ( -1.1631863091190453D-01,  9.9321194923479461D-01), &
( -1.5431297301302013D-01,  9.8802201714328353D-01), ( -1.9208039704989227D-01,  9.8137919331375456D-01), &
( -2.2956536582051898D-01,  9.7329324605469825D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.0346794657201104D-01,  9.5284164760119872D-01), ( -3.3977688440682685D-01,  9.4050607059326830D-01), &
( -3.7558617848921699D-01,  9.2678747430458186D-01), ( -4.1084317105790397D-01,  9.1170603200542977D-01), &
( -4.4549601651398185D-01,  8.9528392103855747D-01), ( -4.7949375766015268D-01,  8.7754529020726146D-01), &
( -5.1278640063356307D-01,  8.5851622426444274D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -5.7706167285567933D-01,  8.1670057286682796D-01), ( -6.0794978496777352D-01,  7.9397547755433728D-01), &
( -6.3794390362184394D-01,  7.7008283699334812D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -6.9507511398000077D-01,  7.1893712237280449D-01), ( -7.2212819392921523D-01,  6.9175925836415786D-01), &
( -7.4811938045040360D-01,  6.6356415861203977D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9920475861836389D-01,  3.9872927587739811D-02), (  9.9682029929116567D-01,  7.9682437971430126D-02), &
(  9.9285041445986510D-01,  1.1936521481099135D-01), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.8018213596811743D-01,  1.9809841071795356D-01), (  9.7150389098625178D-01,  2.3702360599436720D-01), &
(  9.6128048581132064D-01,  2.7557181931095814D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.3626566717027826D-01,  3.5129275608556709D-01), (  9.2151403934204190D-01,  3.8834504669882625D-01), &
(  9.0529675931811882D-01,  4.2477968120910881D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.6857070597134090D-01,  4.9556526182577254D-01), (  8.4812034480329723D-01,  5.2980362468629461D-01), &
(  8.2632106284566353D-01,  5.6319934401383409D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.2635915508434601D-01,  6.8731534089175905D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.3912444486377584D-01,  7.6910333764557959D-01), &
(  6.0794978496777374D-01,  7.9397547755433706D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.4275078486451589D-01,  8.3989379419599952D-01), (  5.0883014254310710D-01,  8.6086693863776720D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  4.0243465085941854D-01,  9.1544871608826783D-01), (  3.6561299780477396D-01,  9.3076696107898371D-01)/
data (mpuu2(i), i =  5801,  5900) / &
(  3.2820984357909266D-01,  9.4460483726148026D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.5189781815421691D-01,  9.6775383709347551D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  1.7398387338746385D-01,  9.8474850180190421D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  9.4963495329639061D-02,  9.9548075549192694D-01), (  5.5195244349690031D-02,  9.9847558057329477D-01), &
(  1.5339206284988220D-02,  9.9988234745421256D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -6.4382630929857299D-02,  9.9792528619859600D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.4369503315029447D-01,  9.8962201746320089D-01), ( -1.8303988795514073D-01,  9.8310548743121640D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.6079411791527546D-01,  9.6539444169768940D-01), &
( -2.9907982630804059D-01,  9.5422809510910556D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -3.7416406297145788D-01,  9.2736252565040111D-01), ( -4.1084317105790397D-01,  9.1170603200542977D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -5.1673179901764998D-01,  8.5614732837519436D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -5.8330865293769840D-01,  8.1225058658520388D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.4617601298331606D-01,  7.6318841726338160D-01), ( -6.7609270357531581D-01,  7.3681656887737002D-01), &
( -7.0493408037590488D-01,  7.0927282643886569D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.5920918897838796D-01,  6.5084668499638099D-01), ( -7.8455659715557513D-01,  6.2005721176328943D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9914241872481691D-01,  4.1405640977076739D-02), (  9.9657114579055484D-01,  8.2740264549375692D-02), &
(  9.9229059134825737D-01,  1.2393297511851216D-01), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.6928123535654853D-01,  2.4595505033579459D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.3132670908118043D-01,  3.6418478956707989D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  8.9800057974073988D-01,  4.3999427130963320D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.5851622426444285D-01,  5.1278640063356296D-01), (  8.3654772722351201D-01,  5.4789405917310019D-01), &
(  8.1314441484925359D-01,  5.8206199034077544D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.6219629813457890D-01,  6.4734596863651206D-01), (  7.3473887809596339D-01,  6.7835004312986147D-01), &
(  7.0602126144933985D-01,  7.0819063703319518D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.4500453681554404D-01,  7.6417874053611667D-01), (  6.1281008242940982D-01,  7.9023022143730992D-01), &
(  5.7956455913940585D-01,  8.1492632905652651D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  5.1015009670676681D-01,  8.6008539042939014D-01), (  4.7410021465055002D-01,  8.8047088905216075D-01), &
(  4.3723717366104420D-01,  8.9934623697934146D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.6132580556845434D-01,  9.3243962926846236D-01), (  3.2240767880106996D-01,  9.4660091308328353D-01), &
(  2.8293657045705539D-01,  9.5913862246184189D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  2.0260703884442111D-01,  9.7926012264908202D-01), (  1.6188639378011188D-01,  9.8680940181418542D-01), &
(  1.2088808723577722D-01,  9.9266614244894802D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
(  3.8340120373552791D-02,  9.9926474728659442D-01), ( -3.0679567629657936D-03,  9.9999529380957619D-01), &
( -4.4470771854938619D-02,  9.9901068585407338D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.2697669649688564D-01,  9.9190570043060933D-01), ( -1.6793829497473109D-01,  9.8579750916756748D-01), &
( -2.0861185197826332D-01,  9.7799851493455714D-01), ( -2.4892760574571993D-01,  9.6852209427441738D-01), &
( -2.8881640820604937D-01,  9.5738450078897597D-01), ( -3.2820984357909233D-01,  9.4460483726148037D-01), &
( -3.6704034571976735D-01,  9.3020502289221896D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.4274722756456980D-01,  8.9664647017868027D-01), ( -4.7949375766015306D-01,  8.7754529020726124D-01), &
( -5.1541787801946293D-01,  8.5693897741782876D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -5.8455394295301510D-01,  8.1135484701706395D-01), ( -6.1764730793780376D-01,  7.8645521359908588D-01), &
( -6.4968130739068330D-01,  7.6020668165120231D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.1035334685706231D-01,  7.0384524052448505D-01), ( -7.3888732446061511D-01,  6.7382900037875615D-01), &
( -7.6615399019631281D-01,  6.4265703396622709D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.1670057286682785D-01,  5.7706167285567944D-01), ( -8.3989379419599952D-01,  5.4275078486451589D-01), &
( -8.6164646114308130D-01,  5.0750899105297098D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9907772775264536D-01,  4.2938256934940820D-02), (  9.9631261218277800D-01,  8.5797312344439894D-02)/
data (mpuu2(i), i =  5901,  6000) / &
(  9.9170975366909953D-01,  1.2849811079379317D-01), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.7702814265775439D-01,  2.1311031991609136D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.5514116830577067D-01,  2.9615088824362379D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.9044872324475799D-01,  4.5508358712634378D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.4812034480329723D-01,  5.2980362468629472D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  7.9953726910790501D-01,  6.0061647938386886D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4505778544146595D-01,  6.6699992230363758D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.8508366777270058D-01,  7.2846439044822509D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.2005721176328921D-01,  7.8455659715557524D-01), (  5.8579785745643898D-01,  8.1045719825259466D-01), &
(  5.5045797293660492D-01,  8.3486287498638001D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.7679923006332203D-01,  8.7901222642863353D-01), (  4.3861623853852749D-01,  8.9867446569395393D-01), &
(  3.9962419984564701D-01,  9.1667905992104259D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  3.1950203081601575D-01,  9.4758559101774109D-01), (  2.7851968938505328D-01,  9.6043051941556579D-01), &
(  2.3702360599436734D-01,  9.7150389098625178D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  1.1022220729388296D-01,  9.9390697000235606D-01), &
(  6.7443919563664106D-02,  9.9772306664419164D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -1.8406729905804917D-02,  9.9983058179582340D-01), ( -6.1320736302208308D-02,  9.9811811290014918D-01), &
( -1.0412163387205439D-01,  9.9456457073425553D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -1.8906866414980594D-01,  9.8196386910955535D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.7262135544994887D-01,  9.6212140426904158D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -4.3309381885315196D-01,  9.0134884704602203D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.0883014254310666D-01,  8.6086693863776742D-01), ( -5.4532498842204657D-01,  8.3822470555483797D-01), &
( -5.8081395809576430D-01,  8.1403632970594852D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.4851440102211244D-01,  7.6120238548426189D-01), ( -6.8060099779545269D-01,  7.3265427167241315D-01), &
( -7.1143219574521654D-01,  7.0275474445722519D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.6910333764557959D-01,  6.3912444486377584D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.2110251499110465D-01,  5.7078074588696726D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.6704624551569265D-01,  4.9822766697278176D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.0659570451491545D-01,  4.2200027079979946D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9901068585407338D-01,  4.4470771854938668D-02), (  9.9604470090125197D-01,  8.8853552582524600D-02), &
(  9.9110791372327689D-01,  1.3306052515713906D-01), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.7536488511665698D-01,  2.2059769010887351D-01), (  9.6458979328981276D-01,  2.6375467897483135D-01), &
(  9.5190613680793235D-01,  3.0638979537086092D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.2091724152918952D-01,  3.8975817406985641D-01), (  9.0267331823725883D-01,  4.3032648134008261D-01), &
(  8.8264333997956279D-01,  4.7004333245959556D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01), &
(  8.3738720161566182D-01,  5.4661016691083497D-01), (  8.1225058658520388D-01,  5.8330865293769829D-01), &
(  7.8550682956405404D-01,  6.1885298796097621D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  7.2741262860237577D-01,  6.8620031168003859D-01), (  6.9617713149146310D-01,  7.1787004505573160D-01), &
(  6.6356415861203988D-01,  7.4811938045040349D-01), (  6.2963823891492710D-01,  7.7688846567323244D-01), &
(  5.9446649918466443D-01,  8.0412037739826570D-01), (  5.5811853122055632D-01,  8.2976123379452293D-01), &
(  5.2066625414036727D-01,  8.5376030113811130D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  4.4274722756457013D-01,  8.9664647017868015D-01), (  4.0243465085941832D-01,  9.1544871608826783D-01), &
(  3.6132580556845434D-01,  9.3243962926846236D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  2.7704608030609995D-01,  9.6085663310767966D-01), (  2.3404195858354365D-01,  9.7222649707893627D-01), &
(  1.9057475482025277D-01,  9.8167268619698311D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  1.0259586902243627D-01,  9.9472312110432570D-01), (  5.8258264500435732D-02,  9.9830154493389289D-01), &
(  1.3805388528060571D-02,  9.9990470108285279D-01), ( -3.0674803176636459D-02,  9.9952941750109314D-01), &
( -7.5094300847921389D-02,  9.9717643673532608D-01), ( -1.1936521481099123D-01,  9.9285041445986510D-01)/
data (mpuu2(i), i =  6001,  6100) / &
( -1.6339994938297311D-01,  9.8655991026477552D-01), ( -2.0711137619221845D-01,  9.7831737071962765D-01), &
( -2.5041300657296495D-01,  9.6813910474636244D-01), ( -2.9321916269425879D-01,  9.5604525134999641D-01), &
( -3.3544514708453155D-01,  9.4205973977101742D-01), ( -3.7700741021641798D-01,  9.2621024213831149D-01), &
( -4.1782371582021227D-01,  9.0852811871630612D-01), ( -4.5781330359887701D-01,  8.8904835585466468D-01), &
( -4.9689704902265447D-01,  8.6780949676330332D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -5.7203962932475672D-01,  8.2022598256943491D-01), ( -6.0794978496777352D-01,  7.9397547755433728D-01), &
( -6.4265703396622686D-01,  7.6615399019631292D-01), ( -6.7609270357531615D-01,  7.3681656887736968D-01), &
( -7.0819063703319540D-01,  7.0602126144933974D-01), ( -7.3888732446061511D-01,  6.7382900037875615D-01), &
( -7.6812202852336542D-01,  6.4030348218415156D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.2197711527924144D-01,  5.6952051934694747D-01), ( -8.4649093877405202D-01,  5.3240312787719801D-01), &
( -8.6932987134860662D-01,  4.9423230851595995D-01), ( -8.9044872324475766D-01,  4.5508358712634428D-01), &
( -9.0980570810465211D-01,  4.1503442447608185D-01), ( -9.2736252565040111D-01,  3.7416406297145799D-01), &
( -9.4308443746609361D-01,  3.3255336986604406D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9894129318685687D-01,  4.6003182130914623D-02), (  9.9576741446765982D-01,  9.1908956497132724D-02), &
(  9.9048508425645709D-01,  1.3762012158648604D-01), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.7458665227817622D-01,  4.8486924800079106D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.2632106284566342D-01,  5.6319934401383420D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  7.0927282643886569D-01,  7.0493408037590488D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.6825895267013160D-01,  8.2284978137582632D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  4.9022648328829138D-01,  8.7159508665595098D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  3.6561299780477374D-01,  9.3076696107898371D-01), &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.3404195858354346D-01,  9.7222649707893627D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  5.2131704680283317D-02,  9.9864021818026527D-01), (  6.1358846491545160D-03,  9.9998117528260111D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.3154002870288317D-01,  9.9131085984611544D-01), ( -1.7700422041214853D-01,  9.8421009238692914D-01), &
( -2.2209362097320348D-01,  9.7502534506699412D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.1076715274961136D-01,  9.5048607394948181D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -3.9680998741671009D-01,  9.1790077562139061D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -5.1935599016558920D-01,  8.5455798836540076D-01), &
( -5.5811853122055610D-01,  8.2976123379452305D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.3265427167241293D-01,  6.8060099779545291D-01), &
( -7.6318841726338116D-01,  6.4617601298331651D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.6857070597134067D-01,  4.9556526182577293D-01), ( -8.9044872324475788D-01,  4.5508358712634389D-01), &
( -9.1044129225806714D-01,  4.1363831223843461D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.4460483726148015D-01,  3.2820984357909272D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.7077214072895035D-01,  2.4000302244874133D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9886954991428356D-01,  4.7535484156959303D-02), (  9.9548075549192694D-01,  9.4963495329638992D-02), &
(  9.8984127845882053D-01,  1.4217680351944803D-01), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.7186633748027940D-01,  2.3553305940497549D-01), (  9.5957151308198452D-01,  2.8146493792575794D-01), &
(  9.4510719328526061D-01,  3.2676045232013173D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  9.0980570810465222D-01,  4.1503442447608163D-01), (  8.8904835585466457D-01,  4.5781330359887723D-01)/
data (mpuu2(i), i =  6101,  6200) / &
(  8.6628095402451299D-01,  4.9955711254508184D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  8.1492632905652651D-01,  5.7956455913940574D-01), (  7.8645521359908577D-01,  6.1764730793780387D-01), &
(  7.5620600141439454D-01,  6.5433361783180044D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  6.9065071413453460D-01,  7.2318848930652746D-01), (  6.5549285299961546D-01,  7.5520137689653644D-01), &
(  6.1885298796097643D-01,  7.8550682956405393D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.4146176585312356D-01,  8.4072537497045796D-01), (  5.0088538261124094D-01,  8.6551362409056898D-01), &
(  4.5917654752194415D-01,  8.8834503330959635D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  3.7274106700951581D-01,  9.2793539482261789D-01), (  3.2820984357909244D-01,  9.4460483726148026D-01), &
(  2.8293657045705539D-01,  9.5913862246184189D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  1.9057475482025277D-01,  9.8167268619698311D-01), (  1.4369503315029458D-01,  9.8962201746320078D-01), &
(  9.6490431355252593D-02,  9.9533391214048228D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
(  1.5339801862847659D-03,  9.9999882345170188D-01), ( -4.6003182130914741D-02,  9.9894129318685687D-01), &
( -9.3436335845747578D-02,  9.9562525638099431D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -1.8756212858252963D-01,  9.8225274136628937D-01), ( -2.3404195858354335D-01,  9.7222649707893627D-01), &
( -2.7999264308027305D-01,  9.6000214573766596D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -3.6989244714893393D-01,  9.2907458125931586D-01), ( -4.1363831223843450D-01,  9.1044129225806725D-01), &
( -4.5644898239688397D-01,  8.8974958638307278D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.3887990853100820D-01,  8.4238259964318596D-01), ( -5.7831379641165548D-01,  8.1581441080673389D-01), &
( -6.1644017453085365D-01,  7.8740174702903132D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -6.8842875278409033D-01,  7.2530397237306088D-01), ( -7.2212819392921523D-01,  6.9175925836415786D-01), &
( -7.5419497531688917D-01,  6.5665054572942905D-01), ( -7.8455659715557535D-01,  6.2005721176328898D-01), &
( -8.1314441484925348D-01,  5.8206199034077566D-01), ( -8.3989379419599952D-01,  5.4275078486451589D-01), &
( -8.6474425751946238D-01,  5.0221247404571068D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.0852811871630612D-01,  4.1782371582021244D-01), ( -9.2736252565040111D-01,  3.7416406297145799D-01), &
( -9.4410025849127255D-01,  3.2965846252858783D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.7113915844972509D-01,  2.3851359484431855D-01), ( -9.8137919331375456D-01,  1.9208039704989244D-01), &
( -9.8940042779138038D-01,  1.4521292465284735D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9879545620517241D-01,  4.9067674327418015D-02), (  9.9518472667219693D-01,  9.8017140329560604D-02), &
(  9.8917650996478101D-01,  1.4673047445536175D-01), (  9.8078528040323043D-01,  1.9509032201612825D-01), &
(  9.7003125319454397D-01,  2.4298017990326387D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.4154406518302081D-01,  3.3688985339222005D-01), (  9.2387953251128674D-01,  3.8268343236508978D-01), &
(  9.0398929312344334D-01,  4.2755509343028208D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5772861000027212D-01,  5.1410274419322166D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  8.0320753148064494D-01,  5.9569930449243336D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.4095112535495922D-01,  6.7155895484701833D-01), (  7.0710678118654757D-01,  7.0710678118654746D-01), &
(  6.7155895484701844D-01,  7.4095112535495899D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9569930449243347D-01,  8.0320753148064483D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.1410274419322177D-01,  8.5772861000027212D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.2755509343028220D-01,  9.0398929312344334D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.3688985339222005D-01,  9.4154406518302081D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.4298017990326398D-01,  9.7003125319454397D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.4673047445536175D-01,  9.8917650996478101D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  4.9067674327418133D-02,  9.9879545620517241D-01), (  6.1232339957367660D-17,  1.0000000000000000D+00), &
( -4.9067674327418008D-02,  9.9879545620517241D-01), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -1.4673047445536164D-01,  9.8917650996478101D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.4298017990326387D-01,  9.7003125319454397D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.3688985339221994D-01,  9.4154406518302081D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.2755509343028186D-01,  9.0398929312344345D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.1410274419322155D-01,  8.5772861000027212D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -5.9569930449243325D-01,  8.0320753148064494D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01)/
data (mpuu2(i), i =  6201,  6300) / &
( -6.7155895484701844D-01,  7.4095112535495899D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.4095112535495888D-01,  6.7155895484701855D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.0320753148064483D-01,  5.9569930449243347D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.5772861000027212D-01,  5.1410274419322177D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.0398929312344334D-01,  4.2755509343028203D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.4154406518302070D-01,  3.3688985339222027D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.7003125319454397D-01,  2.4298017990326404D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.8917650996478101D-01,  1.4673047445536180D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
( -9.9879545620517241D-01,  4.9067674327417973D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9871901223387294D-01,  5.0599749036899282D-02), (  9.9487933079480562D-01,  1.0106986275482782D-01), &
(  9.8849079285269659D-01,  1.5128103795733022D-01), (  9.7956976568544052D-01,  2.0110463484209190D-01), &
(  9.6813910474636244D-01,  2.5041300657296522D-01), (  9.5422809510910567D-01,  2.9907982630804048D-01), &
(  9.3787237643998989D-01,  3.4698041084592368D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  8.9800057974073988D-01,  4.3999427130963326D-01), (  8.7458665227817622D-01,  4.8486924800079106D-01), &
(  8.4893205521163972D-01,  5.2850200154222837D-01), (  8.2110251499110465D-01,  5.7078074588696726D-01), &
(  7.9116933021769009D-01,  6.1159716392646191D-01), (  7.5920918897838796D-01,  6.5084668499638099D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.5201053109695961D-01,  7.5820990981301528D-01), (  6.1281008242940982D-01,  7.9023022143731003D-01), &
(  5.7203962932475727D-01,  8.2022598256943458D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  4.8621027612448642D-01,  8.7384184346536686D-01), (  4.4137126873171684D-01,  8.9732458070541821D-01), &
(  3.9540147894781646D-01,  9.1850839432521214D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  3.0054324141727340D-01,  9.5376818988599033D-01), (  2.5189781815421691D-01,  9.6775383709347551D-01), &
(  2.0260703884442130D-01,  9.7926012264908202D-01), (  1.5279718525844341D-01,  9.8825756773074946D-01), &
(  1.0259586902243627D-01,  9.9472312110432570D-01), (  5.2131704680283539D-02,  9.9864021818026516D-01), &
(  1.5339801862849880D-03,  9.9999882345170188D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -9.9543618660069319D-02,  9.9503319943811863D-01), ( -1.4976453467732151D-01,  9.8872169196032378D-01), &
( -1.9960175762113094D-01,  9.7987710369951764D-01), ( -2.4892760574572015D-01,  9.6852209427441727D-01), &
( -2.9761570743508620D-01,  9.5468575494133834D-01), ( -3.4554132496398882D-01,  9.3840353406310817D-01), &
( -3.9258167407295147D-01,  9.1971714629122736D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.8352707893291841D-01,  8.7532940310411100D-01), ( -5.2719913478190139D-01,  8.4974176800085244D-01), &
( -5.6952051934694692D-01,  8.2197711527924178D-01), ( -6.1038280627630914D-01,  7.9210657730021261D-01), &
( -6.4968130739068330D-01,  7.6020668165120231D-01), ( -6.8731534089175883D-01,  7.2635915508434623D-01), &
( -7.2318848930652746D-01,  6.9065071413453460D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -7.8928925316888554D-01,  6.1402155893103871D-01), ( -8.1934752007679701D-01,  5.7329716669804209D-01), &
( -8.4730663868585820D-01,  5.3110400115125533D-01), ( -8.7309497841829020D-01,  4.8755016014843588D-01), &
( -8.9664647017868027D-01,  4.4274722756456997D-01), ( -9.1790077562139027D-01,  3.9680998741671070D-01), &
( -9.3680344173592167D-01,  3.4985612979013486D-01), ( -9.5330604035419386D-01,  3.0200594931922803D-01), &
( -9.6736629222232839D-01,  2.5338203699557055D-01), ( -9.7894817531906220D-01,  2.0410896609281684D-01), &
( -9.8802201714328353D-01,  1.5431297301302008D-01), ( -9.9456457073425542D-01,  1.0412163387205502D-01), &
( -9.9855907422975931D-01,  5.3663537652730520D-02), ( -9.9999529380957619D-01,  3.0679567629664211D-03), &
( -9.9886954991428356D-01, -4.7535484156959296D-02), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9864021818026527D-01,  5.2131704680283324D-02), (  9.9456457073425542D-01,  1.0412163387205459D-01), &
(  9.8778414164457218D-01,  1.5582839765426523D-01), (  9.7831737071962765D-01,  2.0711137619221856D-01), &
(  9.6619000344541250D-01,  2.5783110216215899D-01), (  9.5143502096900834D-01,  3.0784964004153487D-01), &
(  9.3409255040425898D-01,  3.5703096123342998D-01), (  9.1420975570353069D-01,  4.0524131400498986D-01), &
(  8.9184070939234272D-01,  4.5234958723377089D-01), (  8.6704624551569265D-01,  4.9822766697278187D-01), &
(  8.3989379419599952D-01,  5.4275078486451589D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.7881651238147598D-01,  6.2725181549514408D-01), (  7.4505778544146595D-01,  6.6699992230363747D-01), &
(  7.0927282643886569D-01,  7.0493408037590477D-01), (  6.7155895484701844D-01,  7.4095112535495899D-01), &
(  6.3201873593980906D-01,  7.7495310659487382D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01)/
data (mpuu2(i), i =  6301,  6400) / &
(  5.4789405917310030D-01,  8.3654772722351189D-01), (  5.0353838372571758D-01,  8.6397285612158670D-01), &
(  4.5781330359887712D-01,  8.8904835585466468D-01), (  4.1084317105790408D-01,  9.1170603200542977D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.6375467897483129D-01,  9.6458979328981276D-01), (  2.1311031991609136D-01,  9.7702814265775439D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  1.1022220729388318D-01,  9.9390697000235606D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), (  6.1358846491547381D-03,  9.9998117528260111D-01), &
( -4.6003182130914519D-02,  9.9894129318685687D-01), ( -9.8017140329560659D-02,  9.9518472667219693D-01), &
( -1.4976453467732151D-01,  9.8872169196032378D-01), ( -2.0110463484209204D-01,  9.7956976568544052D-01), &
( -2.5189781815421680D-01,  9.6775383709347551D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.5129275608556704D-01,  9.3626566717027826D-01), ( -3.9962419984564673D-01,  9.1667905992104270D-01), &
( -4.4686884016237399D-01,  8.9459948563138281D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01), &
( -5.3758707629564517D-01,  8.4320823964184566D-01), ( -5.8081395809576475D-01,  8.1403632970594830D-01), &
( -6.2246127937414997D-01,  7.8265059616657573D-01), ( -6.6241577759017145D-01,  7.4913639452345959D-01), &
( -7.0056879394324822D-01,  7.1358486878079375D-01), ( -7.3681656887736979D-01,  6.7609270357531592D-01), &
( -7.7106052426181382D-01,  6.3676186123628409D-01), ( -8.0320753148064483D-01,  5.9569930449243347D-01), &
( -8.3317016470191296D-01,  5.5301670558002791D-01), ( -8.6086693863776742D-01,  5.0883014254310688D-01), &
( -8.8622253014888053D-01,  4.6325978355186032D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.2964089584318133D-01,  3.6846682995337215D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01), &
( -9.6295326687368388D-01,  2.6966832557291504D-01), ( -9.7570213003852846D-01,  2.1910124015687002D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.9321194923479450D-01,  1.1631863091190471D-01), &
( -9.9792528619859600D-01,  6.4382630929857701D-02), ( -9.9992470183914450D-01,  1.2271538285720451D-02), &
( -9.9920475861836389D-01, -3.9872927587739880D-02), ( -9.9576741446765982D-01, -9.1908956497132516D-02), &
( -9.8962201746320089D-01, -1.4369503315029442D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9855907422975931D-01,  5.3663537652730520D-02), (  9.9424044945318790D-01,  1.0717242495680884D-01), &
(  9.8705657130575097D-01,  1.6037245724292828D-01), (  9.7702814265775439D-01,  2.1311031991609136D-01), &
(  9.6418406395174583D-01,  2.6523403028551179D-01), (  9.4856134991573027D-01,  3.1659337555616585D-01), &
(  9.3020502289221907D-01,  3.6704034571976718D-01), (  9.0916798309052238D-01,  4.1642956009763715D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.5930181835700847D-01,  5.1146885043797030D-01), &
(  8.3061640030884631D-01,  5.5684503727515999D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.6615399019631292D-01,  6.4265703396622686D-01), (  7.3056276922782759D-01,  6.8284554638524808D-01), &
(  6.9286617481742474D-01,  7.2106619931450799D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.1159716392646191D-01,  7.9116933021769009D-01), (  5.6825895267013160D-01,  8.2284978137582632D-01), &
(  5.2328310347565643D-01,  8.5215890162391983D-01), (  4.7679923006332225D-01,  8.7901222642863341D-01), &
(  4.2894129205532955D-01,  9.0333236849451182D-01), (  3.7984720892405133D-01,  9.2504924078267758D-01), &
(  3.2965846252858755D-01,  9.4410025849127266D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.2657826384560989D-01,  9.7399296216795594D-01), (  1.7398387338746385D-01,  9.8474850180190421D-01), &
(  1.2088808723577722D-01,  9.9266614244894802D-01), (  6.7443919563664106D-02,  9.9772306664419164D-01), &
(  1.3805388528060349D-02,  9.9990470108285290D-01), ( -3.9872927587739720D-02,  9.9920475861836389D-01), &
( -9.3436335845747578D-02,  9.9562525638099431D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -1.9960175762113094D-01,  9.7987710369951764D-01), ( -2.5189781815421702D-01,  9.6775383709347540D-01), &
( -3.0346794657201126D-01,  9.5284164760119872D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -4.0383845756765402D-01,  9.1483031223794620D-01), ( -4.5234958723377089D-01,  8.9184070939234272D-01), &
( -4.9955711254508173D-01,  8.6628095402451311D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -5.8952131864106350D-01,  8.0775281792619058D-01), ( -6.3201873593980895D-01,  7.7495310659487393D-01), &
( -6.7269476907077275D-01,  7.3992009545951631D-01), ( -7.1143219574521610D-01,  7.0275474445722552D-01), &
( -7.4811938045040360D-01,  6.6356415861203977D-01), ( -7.8265059616657562D-01,  6.2246127937415008D-01), &
( -8.1492632905652673D-01,  5.7956455913940563D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.7234605889439143D-01,  4.8888889691976323D-01), ( -8.9732458070541843D-01,  4.4137126873171650D-01), &
( -9.1971714629122725D-01,  3.9258167407295180D-01), ( -9.3945922360218992D-01,  3.4266071731199443D-01), &
( -9.5649391890239499D-01,  2.9175226323498943D-01), ( -9.7077214072895024D-01,  2.4000302244874175D-01)/
data (mpuu2(i), i =  6401,  6500) / &
( -9.8225274136628937D-01,  1.8756212858252957D-01), ( -9.9090263542778001D-01,  1.3458070850712628D-01), &
( -9.9669689520289606D-01,  8.1211446809592663D-02), ( -9.9961882249517864D-01,  2.7608145778965656D-02), &
( -9.9965999674395922D-01, -2.6074717829103856D-02), ( -9.9682029929116578D-01, -7.9682437971429945D-02), &
( -9.9110791372327678D-01, -1.3306052515713920D-01), ( -9.8253930228744135D-01, -1.8605515166344624D-01), &
( -9.7113915844972509D-01, -2.3851359484431833D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9847558057329477D-01,  5.5195244349689941D-02), (  9.9390697000235606D-01,  1.1022220729388306D-01), &
(  9.8630809724459867D-01,  1.6491312048996992D-01), (  9.7570213003852857D-01,  2.1910124015686980D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.2621024213831138D-01,  3.7700741021641826D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7901222642863353D-01,  4.7679923006332209D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.2110251499110476D-01,  5.7078074588696726D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.9075970185887428D-01,  8.0684755354379922D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  4.9822766697278192D-01,  8.6704624551569265D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9962419984564679D-01,  9.1667905992104270D-01), (  3.4841868024943473D-01,  9.3733901191257485D-01), &
(  2.9615088824362396D-01,  9.5514116830577067D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  7.9682437971430126D-02,  9.9682029929116567D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.0674803176636681D-02,  9.9952941750109314D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.4065823933284913D-01,  9.9005821026229712D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.4892760574572015D-01,  9.6852209427441727D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.5416352542049023D-01,  9.3518350993894761D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.5508358712634372D-01,  8.9044872324475799D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.3912444486377540D-01,  7.6910333764558003D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.2000250796138165D-01,  6.9397146088965389D-01), ( -7.5720884650648435D-01,  6.5317284295377698D-01), &
( -7.9210657730021250D-01,  6.1038280627630936D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.5455798836540064D-01,  5.1935599016558942D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.0659570451491533D-01,  4.2200027079979985D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.4758559101774109D-01,  3.1950203081601580D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.7702814265775439D-01,  2.1311031991609142D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9998117528260111D-01, -6.1358846491541101D-03), ( -9.9811811290014918D-01, -6.1320736302208689D-02), &
( -9.9321194923479461D-01, -1.1631863091190446D-01), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.7433938278557586D-01, -2.2508391135979261D-01), ( -9.6043051941556590D-01, -2.7851968938505289D-01), &
( -9.4359345816196039D-01, -3.3110630575987626D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9838973740734016D-01,  5.6726821166907748D-02), (  9.9356413552059530D-01,  1.1327095217756435D-01), &
(  9.8553873531217606D-01,  1.6945029123396796D-01), (  9.7433938278557586D-01,  2.2508391135979283D-01), &
(  9.6000214573766596D-01,  2.7999264308027322D-01), (  9.4257319760144687D-01,  3.3399965144200938D-01), &
(  9.2210866874334507D-01,  3.8693100551438858D-01), (  8.9867446569395382D-01,  4.3861623853852766D-01), &
(  8.7234605889439154D-01,  4.8888889691976317D-01), (  8.4320823964184544D-01,  5.3758707629564539D-01), &
(  8.1135484701706384D-01,  5.8455394295301522D-01), (  7.7688846567323244D-01,  6.2963823891492698D-01), &
(  7.3992009545951609D-01,  6.7269476907077297D-01), (  7.0056879394324845D-01,  7.1358486878079352D-01), &
(  6.5896129298203743D-01,  7.5217685044904259D-01), (  6.1523159058062693D-01,  7.8834642762660623D-01), &
(  5.6952051934694714D-01,  8.2197711527924155D-01), (  5.2197529293715439D-01,  8.5296060493036363D-01), &
(  4.7274903195034290D-01,  8.8119711347122198D-01), (  4.2200027079979979D-01,  9.0659570451491533D-01), &
(  3.6989244714893404D-01,  9.2907458125931586D-01), (  3.1659337555616601D-01,  9.4856134991573027D-01), &
(  2.6227470702391381D-01,  9.6499325285492032D-01), (  2.0711137619221856D-01,  9.7831737071962765D-01), &
(  1.5128103795733025D-01,  9.8849079285269659D-01), (  9.4963495329638839D-02,  9.9548075549192694D-01)/
data (mpuu2(i), i =  6501,  6600) / &
(  3.8340120373552791D-02,  9.9926474728659442D-01), ( -1.8406729905804695D-02,  9.9983058179582340D-01), &
( -7.5094300847921389D-02,  9.9717643673532608D-01), ( -1.3154002870288295D-01,  9.9131085984611544D-01), &
( -1.8756212858252941D-01,  9.8225274136628948D-01), ( -2.4298017990326387D-01,  9.7003125319454397D-01), &
( -2.9761570743508620D-01,  9.5468575494133834D-01), ( -3.5129275608556726D-01,  9.3626566717027815D-01), &
( -4.0383845756765402D-01,  9.1483031223794620D-01), ( -4.5508358712634372D-01,  8.9044872324475799D-01), &
( -5.0486310853126759D-01,  8.6319942171212416D-01), ( -5.5301670558002736D-01,  8.3317016470191330D-01), &
( -5.9938929840056454D-01,  8.0045766219262282D-01), ( -6.4383154288979128D-01,  7.6516726562245907D-01), &
( -6.8620031168003826D-01,  7.2741262860237610D-01), ( -7.2635915508434601D-01,  6.8731534089175894D-01), &
( -7.6417874053611667D-01,  6.4500453681554404D-01), ( -7.9953726910790479D-01,  6.0061647938386920D-01), &
( -8.3232086776792957D-01,  5.5429412145362023D-01), ( -8.6242395611104028D-01,  5.0618664534515567D-01), &
( -8.8974958638307289D-01,  4.5644898239688370D-01), ( -9.1420975570353069D-01,  4.0524131400498986D-01), &
( -9.3572568948108026D-01,  3.5272855575521095D-01), ( -9.5422809510910556D-01,  2.9907982630804053D-01), &
( -9.6965738512429234D-01,  2.4446790274782448D-01), ( -9.8196386910955535D-01,  1.8906866414980589D-01), &
( -9.9110791372327689D-01,  1.3306052515713901D-01), ( -9.9706007033948296D-01,  7.6623861392031686D-02), &
( -9.9980116988788426D-01,  1.9940428551514438D-02), ( -9.9932238458834954D-01, -3.6807222941358582D-02), &
( -9.9562525638099431D-01, -9.3436335845747287D-02), ( -9.8872169196032378D-01, -1.4976453467732168D-01), &
( -9.7863392442942321D-01, -2.0561041305309916D-01), ( -9.6539444169768951D-01, -2.6079411791527518D-01), &
( -9.4904588185270067D-01, -3.1513792875252228D-01), ( -9.2964089584318144D-01, -3.6846682995337193D-01), &
( -9.0724197791529582D-01, -4.2060907444840273D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9830154493389289D-01,  5.8258264500435752D-02), (  9.9321194923479450D-01,  1.1631863091190475D-01), &
(  9.8474850180190421D-01,  1.7398387338746382D-01), (  9.7293995220556018D-01,  2.3105810828067111D-01), &
(  9.5782641302753291D-01,  2.8734745954472951D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.1790077562139050D-01,  3.9680998741671031D-01), (  8.9322430119551532D-01,  4.4961132965460654D-01), &
(  8.6551362409056909D-01,  5.0088538261124071D-01), (  8.3486287498638001D-01,  5.5045797293660481D-01), &
(  8.0137617172314024D-01,  5.9816070699634227D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.2635915508434590D-01,  6.8731534089175916D-01), (  6.8508366777270047D-01,  7.2846439044822520D-01), &
(  6.4148101280858327D-01,  7.6713891193582029D-01), (  5.9569930449243347D-01,  8.0320753148064483D-01), &
(  5.4789405917310019D-01,  8.3654772722351201D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.4686884016237433D-01,  8.9459948563138258D-01), (  3.9399204006104810D-01,  9.1911385169005777D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  2.8440753721127199D-01,  9.5870347489587149D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  1.1327095217756435D-01,  9.9356413552059530D-01), (  5.5195244349689816D-02,  9.9847558057329477D-01), &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -6.1320736302208530D-02,  9.9811811290014918D-01), &
( -1.1936521481099145D-01,  9.9285041445986510D-01), ( -1.7700422041214853D-01,  9.8421009238692914D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -2.9028467725446222D-01,  9.5694033573220894D-01), &
( -3.4554132496398904D-01,  9.3840353406310817D-01), ( -3.9962419984564690D-01,  9.1667905992104259D-01), &
( -4.5234958723377089D-01,  8.9184070939234272D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.5301670558002736D-01,  8.3317016470191330D-01), ( -6.0061647938386864D-01,  7.9953726910790524D-01), &
( -6.4617601298331606D-01,  7.6318841726338160D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.3056276922782759D-01,  6.8284554638524808D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -8.0503133114296344D-01,  5.9323229503980002D-01), ( -8.3822470555483786D-01,  5.4532498842204669D-01), &
( -8.6857070597134090D-01,  4.9556526182577254D-01), ( -8.9596624975618511D-01,  4.4412214457042931D-01), &
( -9.2031827670911071D-01,  3.9117038430225365D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.5957151308198441D-01,  2.8146493792575833D-01), ( -9.7433938278557586D-01,  2.2508391135979283D-01), &
( -9.8579750916756737D-01,  1.6793829497473126D-01), ( -9.9390697000235606D-01,  1.1022220729388281D-01), &
( -9.9864021818026516D-01,  5.2131704680283601D-02), ( -9.9998117528260111D-01, -6.1358846491541101D-03), &
( -9.9792528619859600D-01, -6.4382630929857451D-02), ( -9.9247953459870997D-01, -1.2241067519921610D-01), &
( -9.8366241921173025D-01, -1.8002290140569935D-01), ( -9.7150389098625178D-01, -2.3702360599436739D-01), &
( -9.5604525134999652D-01, -2.9321916269425830D-01), ( -9.3733901191257507D-01, -3.4841868024943418D-01), &
( -9.1544871608826783D-01, -4.0243465085941837D-01), ( -8.9044872324475799D-01, -4.5508358712634367D-01)/
data (mpuu2(i), i =  6601,  6700) / &
( -8.6242395611104050D-01, -5.0618664534515545D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9821100336047819D-01,  5.9789570746639868D-02), (  9.9285041445986510D-01,  1.1936521481099135D-01), &
(  9.8393741344921892D-01,  1.7851377093899751D-01), (  9.7150389098625178D-01,  2.3702360599436720D-01), &
(  9.5559433413077111D-01,  2.9468537218051433D-01), (  9.3626566717027826D-01,  3.5129275608556709D-01), &
(  9.1358704794525081D-01,  4.0664321687036903D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.5851622426444285D-01,  5.1278640063356296D-01), (  8.2632106284566353D-01,  5.6319934401383409D-01), &
(  7.9116933021769020D-01,  6.1159716392646191D-01), (  7.5318679904361252D-01,  6.5780669329707864D-01), &
(  7.1250937056469232D-01,  7.0166259474016857D-01), (  6.6928258834663612D-01,  7.4300795213512161D-01), &
(  6.2366111752569475D-01,  7.8169483207105928D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.2589502747108463D-01,  8.5054948126560348D-01), (  4.7410021465055002D-01,  8.8047088905216075D-01), &
(  4.2060907444840268D-01,  9.0724197791529582D-01), (  3.6561299780477396D-01,  9.3076696107898371D-01), &
(  3.0930876031226873D-01,  9.5096166631157508D-01), (  2.5189781815421713D-01,  9.6775383709347540D-01), &
(  1.9358558729580372D-01,  9.8108339115048659D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  7.5094300847921278D-02,  9.9717643673532619D-01), (  1.5339206284987998D-02,  9.9988234745421256D-01), &
( -4.4470771854938619D-02,  9.9901068585407338D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.6339994938297334D-01,  9.8655991026477541D-01), ( -2.2209362097320326D-01,  9.7502534506699423D-01), &
( -2.7999264308027305D-01,  9.6000214573766596D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -3.9258167407295147D-01,  9.1971714629122736D-01), ( -4.4686884016237444D-01,  8.9459948563138258D-01), &
( -4.9955711254508173D-01,  8.6628095402451311D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -5.9938929840056454D-01,  8.0045766219262282D-01), ( -6.4617601298331606D-01,  7.6318841726338160D-01), &
( -6.9065071413453438D-01,  7.2318848930652768D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.7203639715038441D-01,  6.3557832048855623D-01), ( -8.0865618158817498D-01,  5.8828154822264533D-01), &
( -8.4238259964318585D-01,  5.3887990853100842D-01), ( -8.7309497841828998D-01,  4.8755016014843627D-01), &
( -9.0068342922864697D-01,  4.3447596056965554D-01), ( -9.2504924078267747D-01,  3.7984720892405138D-01), &
( -9.4610523237040356D-01,  3.2385936651785263D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.7799851493455703D-01,  2.0861185197826393D-01), ( -9.8872169196032378D-01,  1.4976453467732145D-01), &
( -9.9590722941741172D-01,  9.0381360877865302D-02), ( -9.9952941750109314D-01,  3.0674803176636421D-02), &
( -9.9957529604674922D-01, -2.9141508764193559D-02), ( -9.9604470090125197D-01, -8.8853552582524503D-02), &
( -9.8895026451030299D-01, -1.4824767898689603D-01), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.6418406395174583D-01, -2.6523403028551151D-01), ( -9.4660091308328353D-01, -3.2240767880107002D-01), &
( -9.2563083050987283D-01, -3.7842775480876545D-01), ( -9.0134884704602225D-01, -4.3309381885315146D-01), &
( -8.7384184346536686D-01, -4.8621027612448642D-01), ( -8.4320823964184566D-01, -5.3758707629564517D-01), &
( -8.0955764240405115D-01, -5.8704039352091808D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9811811290014918D-01,  6.1320736302208578D-02), (  9.9247953459870997D-01,  1.2241067519921620D-01), &
(  9.8310548743121629D-01,  1.8303988795514095D-01), (  9.7003125319454397D-01,  2.4298017990326387D-01), &
(  9.5330604035419386D-01,  3.0200594931922808D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.8192126434835505D-01,  4.7139673682599764D-01), &
(  8.5135519310526520D-01,  5.2458968267846895D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.8073722857209449D-01,  6.2485948814238634D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.9837624940897292D-01,  7.1573082528381859D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01), &
(  6.0551104140432555D-01,  7.9583690460888346D-01), (  5.5557023301960229D-01,  8.3146961230254512D-01), &
(  5.0353838372571758D-01,  8.6397285612158670D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.9399204006104810D-01,  9.1911385169005777D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.7851968938505306D-01,  9.6043051941556579D-01), (  2.1910124015686999D-01,  9.7570213003852846D-01), &
(  1.5885814333386161D-01,  9.8730141815785832D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  3.6807222941358769D-02,  9.9932238458834954D-01), ( -2.4541228522912364D-02,  9.9969881869620425D-01), &
( -8.5797312344439769D-02,  9.9631261218277800D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.0711137619221867D-01,  9.7831737071962765D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.2531029216226287D-01,  9.4560732538052139D-01), ( -3.8268343236508973D-01,  9.2387953251128674D-01), &
( -4.3861623853852777D-01,  8.9867446569395382D-01), ( -4.9289819222978393D-01,  8.7008699110871146D-01)/
data (mpuu2(i), i =  6701,  6800) / &
( -5.4532498842204613D-01,  8.3822470555483819D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.4383154288979128D-01,  7.6516726562245907D-01), ( -6.8954054473706683D-01,  7.2424708295146700D-01), &
( -7.3265427167241270D-01,  6.8060099779545324D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.1045719825259466D-01,  5.8579785745643898D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.7607009419540649D-01,  4.8218377207912289D-01), ( -9.0398929312344323D-01,  4.2755509343028242D-01), &
( -9.2850608047321548D-01,  3.7131719395183765D-01), ( -9.4952818059303656D-01,  3.1368174039889180D-01), &
( -9.6697647104485218D-01,  2.5486565960451424D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9729045667869021D-01,  7.3564563599667301D-02), &
( -9.9992470183914450D-01,  1.2271538285720007D-02), ( -9.9879545620517241D-01, -4.9067674327418168D-02), &
( -9.9390697000235606D-01, -1.1022220729388300D-01), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.7293995220556018D-01, -2.3105810828067111D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.3733901191257507D-01, -3.4841868024943418D-01), ( -9.1420975570353058D-01, -4.0524131400499008D-01), &
( -8.8763962040285416D-01, -4.6053871095823967D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.2458930278502529D-01, -5.6573181078361323D-01), ( -7.8834642762660634D-01, -6.1523159058062671D-01), &
( -7.4913639452345926D-01, -6.6241577759017178D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9802287377148624D-01,  6.2851757564161406D-02), (  9.9209931314219180D-01,  1.2545498341154623D-01), &
(  9.8225274136628937D-01,  1.8756212858252960D-01), (  9.6852209427441727D-01,  2.4892760574572015D-01), &
(  9.5096166631157508D-01,  3.0930876031226873D-01), (  9.2964089584318121D-01,  3.6846682995337232D-01), &
(  9.0464409057824624D-01,  4.2616788872679962D-01), (  8.7607009419540660D-01,  4.8218377207912272D-01), &
(  8.4403189549006641D-01,  5.3629297906596318D-01), (  8.0865618158817498D-01,  5.8828154822264522D-01), &
(  7.7008283699334801D-01,  6.3794390362184406D-01), (  7.2846439044822520D-01,  6.8508366777270036D-01), &
(  6.8396541179731551D-01,  7.2951443814699701D-01), (  6.3676186123628431D-01,  7.7106052426181371D-01), &
(  5.8704039352091808D-01,  8.0955764240405115D-01), (  5.3499761988709738D-01,  8.4485356524970701D-01), &
(  4.8083933060033396D-01,  8.7680872380914565D-01), (  4.2477968120910881D-01,  9.0529675931811882D-01), &
(  3.6704034571976724D-01,  9.3020502289221907D-01), (  3.0784964004153498D-01,  9.5143502096900834D-01), &
(  2.4744161916777321D-01,  9.6890280477642887D-01), (  1.8605515166344683D-01,  9.8253930228744124D-01), &
(  1.2393297511851219D-01,  9.9229059134825737D-01), (  6.1320736302208655D-02,  9.9811811290014918D-01), &
( -1.5339801862848657D-03,  9.9999882345170188D-01), ( -6.4382630929857521D-02,  9.9792528619859600D-01), &
( -1.2697669649688564D-01,  9.9190570043060933D-01), ( -1.8906866414980616D-01,  9.8196386910955524D-01), &
( -2.5041300657296517D-01,  9.6813910474636244D-01), ( -3.1076715274961136D-01,  9.5048607394948181D-01), &
( -3.6989244714893393D-01,  9.2907458125931586D-01), ( -4.2755509343028186D-01,  9.0398929312344345D-01), &
( -4.8352707893291880D-01,  8.7532940310411078D-01), ( -5.3758707629564551D-01,  8.4320823964184544D-01), &
( -5.8952131864106394D-01,  8.0775281792619036D-01), ( -6.3912444486377573D-01,  7.6910333764557970D-01), &
( -6.8620031168003859D-01,  7.2741262860237588D-01), ( -7.3056276922782759D-01,  6.8284554638524808D-01), &
( -7.7203639715038441D-01,  6.3557832048855623D-01), ( -8.1045719825259466D-01,  5.8579785745643898D-01), &
( -8.4567324698729895D-01,  5.3370100180715319D-01), ( -8.7754529020726135D-01,  4.7949375766015290D-01), &
( -9.0594729780726835D-01,  4.2339047414379632D-01), ( -9.3076696107898360D-01,  3.6561299780477424D-01), &
( -9.5190613680793235D-01,  3.0638979537086092D-01), ( -9.6928123535654853D-01,  2.4595505033579465D-01), &
( -9.8282355119870524D-01,  1.8454773693861970D-01), ( -9.9247953459870997D-01,  1.2241067519921635D-01), &
( -9.9821100336047819D-01,  5.9789570746640069D-02), ( -9.9999529380957619D-01, -3.0679567629661765D-03), &
( -9.9782535041111164D-01, -6.5913352797003513D-02), ( -9.9170975366909953D-01, -1.2849811079379328D-01), &
( -9.8167268619698311D-01, -1.9057475482025282D-01), ( -9.6775383709347551D-01, -2.5189781815421652D-01), &
( -9.5000824500184300D-01, -3.1222481392182488D-01), ( -9.2850608047321559D-01, -3.7131719395183749D-01), &
( -9.0333236849451193D-01, -4.2894129205532938D-01), ( -8.7458665227817622D-01, -4.8486924800079095D-01), &
( -8.4238259964318596D-01, -5.3887990853100820D-01), ( -8.0684755354379945D-01, -5.9075970185887405D-01), &
( -7.6812202852336531D-01, -6.4030348218415178D-01), ( -7.2635915508434623D-01, -6.8731534089175883D-01), &
( -6.8172407417164982D-01, -7.3160938122389252D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9792528619859600D-01,  6.4382630929857465D-02), (  9.9170975366909953D-01,  1.2849811079379317D-01), &
(  9.8137919331375456D-01,  1.9208039704989244D-01), (  9.6697647104485207D-01,  2.5486565960451457D-01), &
(  9.4856134991573027D-01,  3.1659337555616585D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01)/
data (mpuu2(i), i =  6801,  6900) / &
(  9.0001589201616028D-01,  4.3585707992225547D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  7.9953726910790501D-01,  6.0061647938386897D-01), &
(  7.5920918897838807D-01,  6.5084668499638088D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.6928258834663612D-01,  7.4300795213512161D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  5.6825895267013171D-01,  8.2284978137582621D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.5781330359887712D-01,  8.8904835585466468D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.3977688440682696D-01,  9.4050607059326830D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  2.1610679707621938D-01,  9.7636973133002114D-01), (  1.5279718525844363D-01,  9.8825756773074946D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -3.9872927587739720D-02,  9.9920475861836389D-01), ( -1.0412163387205461D-01,  9.9456457073425542D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -2.9321916269425857D-01,  9.5604525134999652D-01), ( -3.5416352542049023D-01,  9.3518350993894761D-01), &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.2719913478190139D-01,  8.4974176800085244D-01), ( -5.8081395809576475D-01,  8.1403632970594830D-01), &
( -6.3201873593980895D-01,  7.7495310659487393D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.2635915508434601D-01,  6.8731534089175894D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -8.0865618158817498D-01,  5.8828154822264533D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.7754529020726113D-01,  4.7949375766015329D-01), ( -9.0659570451491545D-01,  4.2200027079979946D-01), &
( -9.3188426558166815D-01,  3.6275572436739728D-01), ( -9.5330604035419375D-01,  3.0200594931922842D-01), &
( -9.7077214072895035D-01,  2.4000302244874133D-01), ( -9.8421009238692903D-01,  1.7700422041214892D-01), &
( -9.9356413552059530D-01,  1.1327095217756442D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9988234745421256D-01, -1.5339206284987814D-02), ( -9.9682029929116578D-01, -7.9682437971429945D-02), &
( -9.8962201746320089D-01, -1.4369503315029442D-01), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.6295326687368388D-01, -2.6966832557291526D-01), ( -9.4359345816196039D-01, -3.3110630575987626D-01), &
( -9.2031827670911059D-01, -3.9117038430225387D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.6242395611104072D-01, -5.0618664534515512D-01), ( -8.2804504525775591D-01, -5.6066157619733592D-01), &
( -7.9023022143731003D-01, -6.1281008242940971D-01), ( -7.4913639452345959D-01, -6.6241577759017145D-01), &
( -7.0493408037590510D-01, -7.0927282643886547D-01), ( -6.5780669329707886D-01, -7.5318679904361230D-01), &
( -6.0794978496777341D-01, -7.9397547755433739D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9782535041111164D-01,  6.5913352797003805D-02), (  9.9131085984611544D-01,  1.3154002870288312D-01), &
(  9.8048486177346938D-01,  1.9659459767008022D-01), (  9.6539444169768940D-01,  2.6079411791527551D-01), &
(  9.4610523237040345D-01,  3.2385936651785285D-01), (  9.2270112833387863D-01,  3.8551605384391885D-01), &
(  8.9528392103855758D-01,  4.4549601651398174D-01), (  8.6397285612158670D-01,  5.0353838372571758D-01), &
(  8.2890411477186487D-01,  5.5939071185913614D-01), (  7.9023022143731003D-01,  6.1281008242940971D-01), &
(  7.4811938045040360D-01,  6.6356415861203977D-01), (  7.0275474445722541D-01,  7.1143219574521632D-01), &
(  6.5433361783180055D-01,  7.5620600141439454D-01), (  6.0306659854034828D-01,  7.9769084094339104D-01), &
(  5.4917666218771988D-01,  8.3570628435375249D-01), (  4.9289819222978415D-01,  8.7008699110871135D-01), &
(  4.3447596056965571D-01,  9.0068342922864686D-01), (  3.7416406297145793D-01,  9.2736252565040111D-01), &
(  3.1222481392182505D-01,  9.5000824500184300D-01), (  2.4892760574572026D-01,  9.6852209427441727D-01), &
(  1.8454773693861964D-01,  9.8282355119870524D-01), (  1.1936521481099156D-01,  9.9285041445986510D-01), &
(  5.3663537652730679D-02,  9.9855907422975931D-01), ( -1.2271538285719823D-02,  9.9992470183914450D-01), &
( -7.8153241632794190D-02,  9.9694135776498216D-01), ( -1.4369503315029447D-01,  9.8962201746320089D-01), &
( -2.0861185197826332D-01,  9.7799851493455714D-01), ( -2.7262135544994887D-01,  9.6212140426904158D-01), &
( -3.3544514708453155D-01,  9.4205973977101742D-01), ( -3.9680998741671009D-01,  9.1790077562139061D-01), &
( -4.5644898239688397D-01,  8.8974958638307278D-01), ( -5.1410274419322155D-01,  8.5772861000027212D-01), &
( -5.6952051934694725D-01,  8.2197711527924144D-01), ( -6.2246127937414997D-01,  7.8265059616657573D-01), &
( -6.7269476907077275D-01,  7.3992009545951631D-01), ( -7.2000250796138165D-01,  6.9397146088965389D-01), &
( -7.6417874053611667D-01,  6.4500453681554404D-01), ( -8.0503133114296344D-01,  5.9323229503980002D-01), &
( -8.4238259964318585D-01,  5.3887990853100842D-01), ( -8.7607009419540649D-01,  4.8218377207912289D-01), &
( -9.0594729780726835D-01,  4.2339047414379632D-01), ( -9.3188426558166815D-01,  3.6275572436739728D-01)/
data (mpuu2(i), i =  6901,  7000) / &
( -9.5376818988599021D-01,  3.0054324141727368D-01), ( -9.7150389098625167D-01,  2.3702360599436759D-01), &
( -9.8501423101223984D-01,  1.7247308399679609D-01), ( -9.9424044945318790D-01,  1.0717242495680916D-01), &
( -9.9914241872481691D-01,  4.1405640977076781D-02), ( -9.9969881869620425D-01, -2.4541228522912083D-02), &
( -9.9590722941741172D-01, -9.0381360877864608D-02), ( -9.8778414164457218D-01, -1.5582839765426515D-01), &
( -9.7536488511665698D-01, -2.2059769010887326D-01), ( -9.5870347489587160D-01, -2.8440753721127188D-01), &
( -9.3787237643998989D-01, -3.4698041084592351D-01), ( -9.1296219042839832D-01, -4.0804416286497835D-01), &
( -8.8408125871263499D-01, -4.6733320874198842D-01), ( -8.5135519310526520D-01, -5.2458968267846873D-01), &
( -8.1492632905652684D-01, -5.7956455913940541D-01), ( -7.7495310659487393D-01, -6.3201873593980895D-01), &
( -7.3160938122389274D-01, -6.8172407417164960D-01), ( -6.8508366777270080D-01, -7.2846439044822486D-01), &
( -6.3557832048855600D-01, -7.7203639715038463D-01), ( -5.8330865293769829D-01, -8.1225058658520388D-01), &
( -5.2850200154222859D-01, -8.4893205521163950D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9772306664419164D-01,  6.7443919563664051D-02), (  9.9090263542778001D-01,  1.3458070850712617D-01), &
(  9.7956976568544052D-01,  2.0110463484209190D-01), (  9.6377606579543984D-01,  2.6671275747489837D-01), &
(  9.4359345816196039D-01,  3.3110630575987643D-01), (  9.1911385169005777D-01,  3.9399204006104810D-01), &
(  8.9044872324475788D-01,  4.5508358712634384D-01), (  8.5772861000027212D-01,  5.1410274419322166D-01), &
(  8.2110251499110465D-01,  5.7078074588696726D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.3681656887737002D-01,  6.7609270357531592D-01), (  6.8954054473706694D-01,  7.2424708295146689D-01), &
(  6.3912444486377573D-01,  7.6910333764557970D-01), (  5.8579785745643886D-01,  8.1045719825259477D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.7139673682599781D-01,  8.8192126434835494D-01), &
(  4.1084317105790391D-01,  9.1170603200542988D-01), (  3.4841868024943451D-01,  9.3733901191257496D-01), &
(  2.8440753721127199D-01,  9.5870347489587149D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.5279718525844341D-01,  9.8825756773074946D-01), (  8.5797312344440088D-02,  9.9631261218277800D-01), &
(  1.8406729905805042D-02,  9.9983058179582340D-01), ( -4.9067674327418008D-02,  9.9879545620517241D-01), &
( -1.1631863091190475D-01,  9.9321194923479450D-01), ( -1.8303988795514115D-01,  9.8310548743121629D-01), &
( -2.4892760574571993D-01,  9.6852209427441738D-01), ( -3.1368174039889146D-01,  9.4952818059303667D-01), &
( -3.7700741021641820D-01,  9.2621024213831138D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -4.9822766697278154D-01,  8.6704624551569287D-01), ( -5.5557023301960196D-01,  8.3146961230254546D-01), &
( -6.1038280627630948D-01,  7.9210657730021228D-01), ( -6.6241577759017178D-01,  7.4913639452345926D-01), &
( -7.1143219574521610D-01,  7.0275474445722552D-01), ( -7.5720884650648468D-01,  6.5317284295377664D-01), &
( -7.9953726910790501D-01,  6.0061647938386886D-01), ( -8.3822470555483786D-01,  5.4532498842204669D-01), &
( -8.7309497841828998D-01,  4.8755016014843627D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.3076696107898360D-01,  3.6561299780477424D-01), ( -9.5330604035419386D-01,  3.0200594931922803D-01), &
( -9.7150389098625167D-01,  2.3702360599436759D-01), ( -9.8527764238894122D-01,  1.7096188876030163D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9932238458834943D-01,  3.6807222941359276D-02), &
( -9.9952941750109314D-01, -3.0674803176636622D-02), ( -9.9518472667219693D-01, -9.8017140329560590D-02), &
( -9.8630809724459867D-01, -1.6491312048996948D-01), ( -9.7293995220556018D-01, -2.3105810828067111D-01), &
( -9.5514116830577067D-01, -2.9615088824362379D-01), ( -9.3299279883473873D-01, -3.5989503653498850D-01), &
( -9.0659570451491533D-01, -4.2200027079979963D-01), ( -8.7607009419540682D-01, -4.8218377207912233D-01), &
( -8.4155497743689844D-01, -5.4017147272989285D-01), ( -8.0320753148064494D-01, -5.9569930449243325D-01), &
( -7.6120238548426222D-01, -6.4851440102211200D-01), ( -7.1573082528381871D-01, -6.9837624940897280D-01), &
( -6.6699992230363758D-01, -7.4505778544146584D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.6066157619733581D-01, -8.2804504525775591D-01), ( -5.0353838372571813D-01, -8.6397285612158647D-01), &
( -4.4412214457042898D-01, -8.9596624975618533D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9761843513851955D-01,  6.8974327628266746D-02), (  9.9048508425645709D-01,  1.3762012158648604D-01), &
(  9.7863392442942321D-01,  2.0561041305309924D-01), (  9.6212140426904158D-01,  2.7262135544994898D-01), &
(  9.4102617505088926D-01,  3.3833376696554113D-01), (  9.1544871608826783D-01,  4.0243465085941843D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  8.1314441484925359D-01,  5.8206199034077544D-01), (  7.7106052426181382D-01,  6.3676186123628420D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.2366111752569453D-01,  7.8169483207105950D-01), (  5.6825895267013160D-01,  8.2284978137582632D-01)/
data (mpuu2(i), i =  7001,  7100) / &
(  5.1015009670676692D-01,  8.6008539042939003D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.8693100551438847D-01,  9.2210866874334518D-01), (  3.2240767880106996D-01,  9.4660091308328353D-01), &
(  2.5634868248994308D-01,  9.6658437447833301D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.2088808723577700D-01,  9.9266614244894802D-01), (  5.2131704680283539D-02,  9.9864021818026516D-01), &
( -1.6872987947281648D-02,  9.9985764100582386D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.5431297301302013D-01,  9.8802201714328353D-01), ( -2.2209362097320370D-01,  9.7502534506699412D-01), &
( -2.8881640820604937D-01,  9.5738450078897597D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -4.1782371582021227D-01,  9.0852811871630612D-01), ( -4.7949375766015268D-01,  8.7754529020726146D-01), &
( -5.3887990853100820D-01,  8.4238259964318596D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.4968130739068330D-01,  7.6020668165120231D-01), ( -7.0056879394324856D-01,  7.1358486878079341D-01), &
( -7.4811938045040360D-01,  6.6356415861203977D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.3232086776792957D-01,  5.5429412145362023D-01), ( -8.6857070597134067D-01,  4.9556526182577293D-01), &
( -9.0068342922864675D-01,  4.3447596056965598D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5190613680793223D-01,  3.0638979537086136D-01), ( -9.7077214072895035D-01,  2.4000302244874133D-01), &
( -9.8501423101223984D-01,  1.7247308399679609D-01), ( -9.9456457073425542D-01,  1.0412163387205502D-01), &
( -9.9937767038800285D-01,  3.5274238898213787D-02), ( -9.9943060455546173D-01, -3.3741171851377455D-02), &
( -9.9472312110432570D-01, -1.0259586902243631D-01), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.7113915844972520D-01, -2.3851359484431789D-01), ( -9.5237501271976588D-01, -3.0492922973540243D-01), &
( -9.2907458125931586D-01, -3.6989244714893388D-01), ( -9.0134884704602181D-01, -4.3309381885315229D-01), &
( -8.6932987134860673D-01, -4.9423230851595978D-01), ( -8.3317016470191330D-01, -5.5301670558002736D-01), &
( -7.9304196047944375D-01, -6.0916701233645310D-01), ( -7.4913639452345926D-01, -6.6241577759017178D-01), &
( -7.0166259474016868D-01, -7.1250937056469210D-01), ( -6.5084668499638099D-01, -7.5920918897838796D-01), &
( -5.9693070806219650D-01, -8.0229279553811572D-01), ( -5.4017147272989352D-01, -8.4155497743689800D-01), &
( -4.8083933060033446D-01, -8.7680872380914543D-01), ( -4.1921688836322429D-01, -9.0788611648766604D-01), &
( -3.5559766170478407D-01, -9.3463912981968067D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9751145614030345D-01,  7.0504573389613856D-02), (  9.9005821026229712D-01,  1.4065823933284921D-01), &
(  9.7767735782450993D-01,  2.1011183688046961D-01), (  9.6043051941556579D-01,  2.7851968938505306D-01), &
(  9.3840353406310806D-01,  3.4554132496398909D-01), (  9.1170603200542988D-01,  4.1084317105790391D-01), &
(  8.8047088905216075D-01,  4.7410021465054997D-01), (  8.4485356524970712D-01,  5.3499761988709715D-01), &
(  8.0503133114296366D-01,  5.9323229503979980D-01), (  7.6120238548426178D-01,  6.4851440102211244D-01), &
(  7.1358486878079375D-01,  7.0056879394324834D-01), (  6.6241577759017178D-01,  7.4913639452345926D-01), &
(  6.0794978496777363D-01,  7.9397547755433717D-01), (  5.5045797293660492D-01,  8.3486287498638001D-01), &
(  4.9022648328829138D-01,  8.7159508665595098D-01), (  4.2755509343028220D-01,  9.0398929312344334D-01), &
(  3.6275572436739723D-01,  9.3188426558166815D-01), (  2.9615088824362396D-01,  9.5514116830577067D-01), &
(  2.2807208317088579D-01,  9.7364424965081187D-01), (  1.5885814333386139D-01,  9.8730141815785843D-01), &
(  8.8853552582524684D-02,  9.9604470090125197D-01), (  1.8406729905805042D-02,  9.9983058179582340D-01), &
( -5.2131704680283192D-02,  9.9864021818026527D-01), ( -1.2241067519921617D-01,  9.9247953459870997D-01), &
( -1.9208039704989249D-01,  9.8137919331375456D-01), ( -2.6079411791527568D-01,  9.6539444169768929D-01), &
( -3.2820984357909233D-01,  9.4460483726148037D-01), ( -3.9399204006104799D-01,  9.1911385169005777D-01), &
( -4.5781330359887740D-01,  8.8904835585466446D-01), ( -5.1935599016558920D-01,  8.5455798836540076D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -6.3439328416364527D-01,  7.7301045336273710D-01), &
( -6.8731534089175916D-01,  7.2635915508434590D-01), ( -7.3681656887736979D-01,  6.7609270357531592D-01), &
( -7.8265059616657562D-01,  6.2246127937415008D-01), ( -8.2458930278502507D-01,  5.6573181078361345D-01), &
( -8.6242395611104050D-01,  5.0618664534515523D-01), ( -8.9596624975618511D-01,  4.4412214457042931D-01), &
( -9.2504924078267747D-01,  3.7984720892405138D-01), ( -9.4952818059303667D-01,  3.1368174039889141D-01), &
( -9.6928123535654842D-01,  2.4595505033579507D-01), ( -9.8421009238692903D-01,  1.7700422041214892D-01), &
( -9.9424044945318790D-01,  1.0717242495680916D-01), ( -9.9932238458834943D-01,  3.6807222941359276D-02), &
( -9.9943060455546173D-01, -3.3741171851377455D-02), ( -9.9456457073425553D-01, -1.0412163387205432D-01), &
( -9.8474850180190421D-01, -1.7398387338746391D-01), ( -9.7003125319454397D-01, -2.4298017990326382D-01), &
( -9.5048607394948181D-01, -3.1076715274961131D-01), ( -9.2621024213831127D-01, -3.7700741021641837D-01)/
data (mpuu2(i), i =  7101,  7200) / &
( -8.9732458070541832D-01, -4.4137126873171667D-01), ( -8.6397285612158659D-01, -5.0353838372571780D-01), &
( -8.2632106284566365D-01, -5.6319934401383387D-01), ( -7.8455659715557546D-01, -6.2005721176328887D-01), &
( -7.3888732446061522D-01, -6.7382900037875604D-01), ( -6.8954054473706716D-01, -7.2424708295146667D-01), &
( -6.3676186123628487D-01, -7.7106052426181326D-01), ( -5.8081395809576430D-01, -8.1403632970594852D-01), &
( -5.2197529293715450D-01, -8.5296060493036352D-01), ( -4.6053871095824067D-01, -8.8763962040285360D-01), &
( -3.9680998741671070D-01, -9.1790077562139027D-01), ( -3.3110630575987654D-01, -9.4359345816196027D-01), &
( -2.6375467897483118D-01, -9.6458979328981276D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9740212990127530D-01,  7.2034653246889332D-02), (  9.8962201746320089D-01,  1.4369503315029447D-01), &
(  9.7670008612871184D-01,  2.1460881099378676D-01), (  9.5870347489587160D-01,  2.8440753721127188D-01), &
(  9.3572568948108037D-01,  3.5272855575521073D-01), (  9.0788611648766626D-01,  4.1921688836322391D-01), &
(  8.7532940310411089D-01,  4.8352707893291874D-01), (  8.3822470555483797D-01,  5.4532498842204646D-01), &
(  7.9676481020841883D-01,  6.0428953094815596D-01), (  7.5116513190968637D-01,  6.6011434206742048D-01), &
(  7.0166259474016868D-01,  7.1250937056469232D-01), (  6.4851440102211255D-01,  7.6120238548426178D-01), &
(  5.9199669496204099D-01,  8.0594039057117628D-01), (  5.3240312787719801D-01,  8.4649093877405202D-01), &
(  4.7004333245959579D-01,  8.8264333997956268D-01), (  4.0524131400498981D-01,  9.1420975570353069D-01), &
(  3.3833376696554107D-01,  9.4102617505088926D-01), (  2.6966832557291520D-01,  9.6295326687368388D-01), &
(  1.9960175762113105D-01,  9.7987710369951764D-01), (  1.2849811079379322D-01,  9.9170975366909953D-01), &
(  5.6726821166907783D-02,  9.9838973740734016D-01), ( -1.5339206284987876D-02,  9.9988234745421256D-01), &
( -8.7325535206191879D-02,  9.9617982859569698D-01), ( -1.5885814333386128D-01,  9.8730141815785843D-01), &
( -2.2956536582051898D-01,  9.7329324605469825D-01), ( -2.9907982630804059D-01,  9.5422809510910556D-01), &
( -3.6704034571976712D-01,  9.3020502289221907D-01), ( -4.3309381885315196D-01,  9.0134884704602203D-01), &
( -4.9689704902265447D-01,  8.6780949676330332D-01), ( -5.5811853122055577D-01,  8.2976123379452327D-01), &
( -6.1644017453085365D-01,  7.8740174702903132D-01), ( -6.7155895484701844D-01,  7.4095112535495899D-01), &
( -7.2318848930652746D-01,  6.9065071413453460D-01), ( -7.7106052426181382D-01,  6.3676186123628409D-01), &
( -8.1492632905652640D-01,  5.7956455913940597D-01), ( -8.5455798836540042D-01,  5.1935599016558975D-01), &
( -8.8974958638307267D-01,  4.5644898239688414D-01), ( -9.2031827670911048D-01,  3.9117038430225404D-01), &
( -9.4610523237040334D-01,  3.2385936651785302D-01), ( -9.6697647104485207D-01,  2.5486565960451468D-01), &
( -9.8282355119870513D-01,  1.8454773693862014D-01), ( -9.9356413552059530D-01,  1.1327095217756442D-01), &
( -9.9914241872481691D-01,  4.1405640977076781D-02), ( -9.9952941750109314D-01, -3.0674803176636178D-02), &
( -9.9472312110432570D-01, -1.0259586902243631D-01), ( -9.8474850180190432D-01, -1.7398387338746346D-01), &
( -9.6965738512429245D-01, -2.4446790274782426D-01), ( -9.4952818059303679D-01, -3.1368174039889118D-01), &
( -9.2446547432526271D-01, -3.8126576922216210D-01), ( -8.9459948563138258D-01, -4.4686884016237438D-01), &
( -8.6008539042939025D-01, -5.1015009670676659D-01), ( -8.2110251499110454D-01, -5.7078074588696748D-01), &
( -7.7785340420945315D-01, -6.2844576660183260D-01), ( -7.3056276922782759D-01, -6.8284554638524797D-01), &
( -6.7947631989936519D-01, -7.3369743811466015D-01), ( -6.2485948814238645D-01, -7.8073722857209438D-01), &
( -5.6699604882510912D-01, -8.2372051122739109D-01), ( -5.0618664534515534D-01, -8.6242395611104050D-01), &
( -4.4274722756457041D-01, -8.9664647017868004D-01), ( -3.7700741021641904D-01, -9.2621024213831105D-01), &
( -3.0930876031226906D-01, -9.5096166631157497D-01), ( -2.4000302244874142D-01, -9.7077214072895035D-01), &
( -1.6945029123396829D-01, -9.8553873531217606D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9729045667869021D-01,  7.3564563599667426D-02), (  9.8917650996478101D-01,  1.4673047445536175D-01), &
(  9.7570213003852857D-01,  2.1910124015686980D-01), (  9.5694033573220882D-01,  2.9028467725446233D-01), &
(  9.3299279883473896D-01,  3.5989503653498811D-01), (  9.0398929312344334D-01,  4.2755509343028208D-01), &
(  8.7008699110871146D-01,  4.9289819222978404D-01), (  8.3146961230254524D-01,  5.5557023301960218D-01), &
(  7.8834642762660634D-01,  6.1523159058062682D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.8954054473706705D-01,  7.2424708295146689D-01), (  6.3439328416364560D-01,  7.7301045336273688D-01), &
(  5.7580819141784534D-01,  8.1758481315158371D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.4961132965460682D-01,  8.9322430119551521D-01), (  3.8268343236508984D-01,  9.2387953251128674D-01), &
(  3.1368174039889135D-01,  9.4952818059303667D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.7096188876030136D-01,  9.8527764238894122D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  2.4541228522912267D-02,  9.9969881869620425D-01), ( -4.9067674327417786D-02,  9.9879545620517241D-01)/
data (mpuu2(i), i =  7201,  7300) / &
( -1.2241067519921617D-01,  9.9247953459870997D-01), ( -1.9509032201612819D-01,  9.8078528040323043D-01), &
( -2.6671275747489831D-01,  9.6377606579543984D-01), ( -3.3688985339222016D-01,  9.4154406518302070D-01), &
( -4.0524131400498975D-01,  9.1420975570353069D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.3499761988709693D-01,  8.4485356524970723D-01), ( -5.9569930449243291D-01,  8.0320753148064516D-01), &
( -6.5317284295377653D-01,  7.5720884650648479D-01), ( -7.0710678118654746D-01,  7.0710678118654757D-01), &
( -7.5720884650648468D-01,  6.5317284295377664D-01), ( -8.0320753148064505D-01,  5.9569930449243313D-01), &
( -8.4485356524970712D-01,  5.3499761988709715D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.1420975570353069D-01,  4.0524131400498986D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.6377606579543984D-01,  2.6671275747489848D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9247953459870997D-01,  1.2241067519921679D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9969881869620425D-01, -2.4541228522912083D-02), ( -9.9518472667219693D-01, -9.8017140329560146D-02), &
( -9.8527764238894122D-01, -1.7096188876030141D-01), ( -9.7003125319454397D-01, -2.4298017990326382D-01), &
( -9.4952818059303667D-01, -3.1368174039889157D-01), ( -9.2387953251128674D-01, -3.8268343236508967D-01), &
( -8.9322430119551544D-01, -4.4961132965460626D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.1758481315158393D-01, -5.7580819141784489D-01), ( -7.7301045336273688D-01, -6.3439328416364571D-01), &
( -7.2424708295146700D-01, -6.8954054473706683D-01), ( -6.7155895484701866D-01, -7.4095112535495877D-01), &
( -6.1523159058062660D-01, -7.8834642762660645D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.9289819222978426D-01, -8.7008699110871135D-01), ( -4.2755509343028247D-01, -9.0398929312344312D-01), &
( -3.5989503653498794D-01, -9.3299279883473896D-01), ( -2.9028467725446327D-01, -9.5694033573220860D-01), &
( -2.1910124015687010D-01, -9.7570213003852846D-01), ( -1.4673047445536233D-01, -9.8917650996478090D-01), &
( -7.3564563599667357D-02, -9.9729045667869021D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9717643673532619D-01,  7.5094300847921305D-02), (  9.8872169196032378D-01,  1.4976453467732151D-01), &
(  9.7468351068851067D-01,  2.2358902922978999D-01), (  9.5514116830577067D-01,  2.9615088824362379D-01), &
(  9.3020502289221907D-01,  3.6704034571976718D-01), (  9.0001589201616028D-01,  4.3585707992225547D-01), &
(  8.6474425751946238D-01,  5.0221247404571079D-01), (  8.2458930278502529D-01,  5.6573181078361312D-01), &
(  7.7977778792301455D-01,  6.2605638840434352D-01), (  7.3056276922782759D-01,  6.8284554638524808D-01), &
(  6.7722217013718056D-01,  7.3577858916571337D-01), (  6.2005721176328921D-01,  7.8455659715557524D-01), &
(  5.5939071185913614D-01,  8.2890411477186487D-01), (  4.9556526182577254D-01,  8.6857070597134090D-01), &
(  4.2894129205532955D-01,  9.0333236849451182D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  2.8881640820604948D-01,  9.5738450078897586D-01), (  2.1610679707621960D-01,  9.7636973133002114D-01), &
(  1.4217680351944822D-01,  9.8984127845882053D-01), (  6.7443919563664106D-02,  9.9772306664419164D-01), &
( -7.6698287395311759D-03,  9.9997058643097414D-01), ( -8.2740264549375470D-02,  9.9657114579055484D-01), &
( -1.5734345561623816D-01,  9.8754394179435934D-01), ( -2.3105810828067117D-01,  9.7293995220556018D-01), &
( -3.0346794657201126D-01,  9.5284164760119872D-01), ( -3.7416406297145804D-01,  9.2736252565040100D-01), &
( -4.4274722756456980D-01,  8.9664647017868027D-01), ( -5.0883014254310710D-01,  8.6086693863776720D-01), &
( -5.7203962932475705D-01,  8.2022598256943469D-01), ( -6.3201873593980895D-01,  7.7495310659487393D-01), &
( -6.8842875278409033D-01,  7.2530397237306088D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.8928925316888576D-01,  6.1402155893103838D-01), ( -8.3317016470191319D-01,  5.5301670558002747D-01), &
( -8.7234605889439143D-01,  4.8888889691976323D-01), ( -9.0659570451491533D-01,  4.2200027079979985D-01), &
( -9.3572568948108037D-01,  3.5272855575521056D-01), ( -9.5957151308198441D-01,  2.8146493792575833D-01), &
( -9.7799851493455714D-01,  2.0861185197826349D-01), ( -9.9090263542778001D-01,  1.3458070850712628D-01), &
( -9.9821100336047819D-01,  5.9789570746640069D-02), ( -9.9988234745421256D-01, -1.5339206284988258D-02), &
( -9.9590722941741172D-01, -9.0381360877864608D-02), ( -9.8630809724459867D-01, -1.6491312048996948D-01), &
( -9.7113915844972509D-01, -2.3851359484431833D-01), ( -9.5048607394948181D-01, -3.1076715274961131D-01), &
( -9.2446547432526260D-01, -3.8126576922216249D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.5693897741782898D-01, -5.1541787801946259D-01), ( -8.1581441080673389D-01, -5.7831379641165548D-01), &
( -7.7008283699334812D-01, -6.3794390362184394D-01), ( -7.2000250796138154D-01, -6.9397146088965411D-01), &
( -6.6585623366550972D-01, -7.4608007351006378D-01), ( -6.0794978496777408D-01, -7.9397547755433684D-01), &
( -5.4661016691083464D-01, -8.3738720161566205D-01), ( -4.8218377207912261D-01, -8.7607009419540671D-01), &
( -4.1503442447608230D-01, -9.0980570810465200D-01), ( -3.4554132496398904D-01, -9.3840353406310817D-01)/
data (mpuu2(i), i =  7301,  7400) / &
( -2.7409690986870644D-01, -9.6170207652912254D-01), ( -2.0110463484209207D-01, -9.7956976568544052D-01), &
( -1.2697669649688612D-01, -9.9190570043060933D-01), ( -5.2131704680283657D-02, -9.9864021818026516D-01), &
(  2.3007681468839830D-02, -9.9973528826056168D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9706007033948296D-01,  7.6623861392031492D-02), (  9.8825756773074946D-01,  1.5279718525844344D-01), &
(  9.7364424965081198D-01,  2.2807208317088573D-01), (  9.5330604035419386D-01,  3.0200594931922808D-01), &
(  9.2736252565040111D-01,  3.7416406297145793D-01), (  8.9596624975618522D-01,  4.4412214457042920D-01), &
(  8.5930181835700847D-01,  5.1146885043797030D-01), (  8.1758481315158371D-01,  5.7580819141784534D-01), &
(  7.7106052426181382D-01,  6.3676186123628420D-01), (  7.2000250796138165D-01,  6.9397146088965389D-01), &
(  6.6471097820334502D-01,  7.4710060598018002D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.4275078486451589D-01,  8.3989379419599952D-01), (  4.7679923006332225D-01,  8.7901222642863341D-01), &
(  4.0804416286497874D-01,  9.1296219042839810D-01), (  3.3688985339222005D-01,  9.4154406518302081D-01), &
(  2.6375467897483129D-01,  9.6458979328981276D-01), (  1.8906866414980628D-01,  9.8196386910955524D-01), &
(  1.1327095217756457D-01,  9.9356413552059530D-01), (  3.6807222941358991D-02,  9.9932238458834954D-01), &
( -3.9872927587739943D-02,  9.9920475861836389D-01), ( -1.1631863091190453D-01,  9.9321194923479461D-01), &
( -1.9208039704989227D-01,  9.8137919331375456D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.3977688440682685D-01,  9.4050607059326830D-01), ( -4.1084317105790397D-01,  9.1170603200542977D-01), &
( -4.7949375766015268D-01,  8.7754529020726146D-01), ( -5.4532498842204613D-01,  8.3822470555483819D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.6699992230363736D-01,  7.4505778544146606D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.7301045336273699D-01,  6.3439328416364549D-01), &
( -8.1934752007679701D-01,  5.7329716669804209D-01), ( -8.6086693863776742D-01,  5.0883014254310688D-01), &
( -8.9732458070541821D-01,  4.4137126873171689D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5422809510910556D-01,  2.9907982630804053D-01), ( -9.7433938278557575D-01,  2.2508391135979328D-01), &
( -9.8872169196032367D-01,  1.4976453467732190D-01), ( -9.9729045667869021D-01,  7.3564563599667745D-02), &
( -9.9999529380957619D-01, -3.0679567629657324D-03), ( -9.9682029929116567D-01, -7.9682437971430389D-02), &
( -9.8778414164457218D-01, -1.5582839765426515D-01), ( -9.7293995220556029D-01, -2.3105810828067067D-01), &
( -9.5237501271976588D-01, -3.0492922973540243D-01), ( -9.2621024213831149D-01, -3.7700741021641793D-01), &
( -8.9459948563138258D-01, -4.4686884016237438D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.1581441080673411D-01, -5.7831379641165515D-01), ( -7.6910333764557970D-01, -6.3912444486377573D-01), &
( -7.1787004505573204D-01, -6.9617713149146265D-01), ( -6.6241577759017178D-01, -7.4913639452345937D-01), &
( -6.0306659854034805D-01, -7.9769084094339116D-01), ( -5.4017147272989352D-01, -8.4155497743689800D-01), &
( -4.7410021465054974D-01, -8.8047088905216087D-01), ( -4.0524131400499036D-01, -9.1420975570353047D-01), &
( -3.3399965144200983D-01, -9.4257319760144676D-01), ( -2.6079411791527590D-01, -9.6539444169768929D-01), &
( -1.8605515166344697D-01, -9.8253930228744124D-01), ( -1.1022220729388331D-01, -9.9390697000235606D-01), &
( -3.3741171851377760D-02, -9.9943060455546173D-01), (  4.2938256934940716D-02, -9.9907772775264536D-01), &
(  1.1936521481099133D-01, -9.9285041445986510D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9694135776498216D-01,  7.8153241632794232D-02), (  9.8778414164457218D-01,  1.5582839765426523D-01), &
(  9.7258436893473221D-01,  2.3255030703877524D-01), (  9.5143502096900834D-01,  3.0784964004153487D-01), &
(  9.2446547432526260D-01,  3.8126576922216238D-01), (  8.9184070939234272D-01,  4.5234958723377089D-01), &
(  8.5376030113811141D-01,  5.2066625414036716D-01), (  8.1045719825259477D-01,  5.8579785745643886D-01), &
(  7.6219629813457890D-01,  6.4734596863651206D-01), (  7.0927282643886569D-01,  7.0493408037590488D-01), &
(  6.5201053109695972D-01,  7.5820990981301517D-01), (  5.9075970185887428D-01,  8.0684755354379922D-01), &
(  5.2589502747108463D-01,  8.5054948126560348D-01), (  4.5781330359887729D-01,  8.8904835585466446D-01), &
(  3.8693100551438869D-01,  9.2210866874334507D-01), (  3.1368174039889152D-01,  9.4952818059303667D-01), &
(  2.3851359484431850D-01,  9.7113915844972509D-01), (  1.6188639378011188D-01,  9.8680940181418542D-01), &
(  8.4268887593324113D-02,  9.9644305135004263D-01), (  6.1358846491545160D-03,  9.9998117528260111D-01), &
( -7.2034653246889305D-02,  9.9740212990127530D-01), ( -1.4976453467732129D-01,  9.8872169196032378D-01), &
( -2.2657826384560978D-01,  9.7399296216795594D-01), ( -3.0200594931922808D-01,  9.5330604035419386D-01), &
( -3.7558617848921722D-01,  9.2678747430458175D-01), ( -4.4686884016237444D-01,  8.9459948563138258D-01), &
( -5.1541787801946293D-01,  8.5693897741782876D-01), ( -5.8081395809576430D-01,  8.1403632970594852D-01), &
( -6.4265703396622686D-01,  7.6615399019631292D-01), ( -7.0056879394324822D-01,  7.1358486878079375D-01)/
data (mpuu2(i), i =  7401,  7500) / &
( -7.5419497531688884D-01,  6.5665054572942938D-01), ( -8.0320753148064483D-01,  5.9569930449243347D-01), &
( -8.4730663868585843D-01,  5.3110400115125489D-01), ( -8.8622253014888053D-01,  4.6325978355186032D-01), &
( -9.1971714629122725D-01,  3.9258167407295180D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01), &
( -9.6965738512429245D-01,  2.4446790274782404D-01), ( -9.8579750916756737D-01,  1.6793829497473126D-01), &
( -9.9590722941741172D-01,  9.0381360877865302D-02), ( -9.9992470183914450D-01,  1.2271538285720007D-02), &
( -9.9782535041111164D-01, -6.5913352797003513D-02), ( -9.8962201746320089D-01, -1.4369503315029442D-01), &
( -9.7536488511665698D-01, -2.2059769010887326D-01), ( -9.5514116830577089D-01, -2.9615088824362334D-01), &
( -9.2907458125931586D-01, -3.6989244714893388D-01), ( -8.9732458070541843D-01, -4.4137126873171628D-01), &
( -8.6008539042939003D-01, -5.1015009670676692D-01), ( -8.1758481315158371D-01, -5.7580819141784534D-01), &
( -7.7008283699334812D-01, -6.3794390362184394D-01), ( -7.1787004505573171D-01, -6.9617713149146299D-01), &
( -6.6126583783999238D-01, -7.5015164580621485D-01), ( -6.0061647938386853D-01, -7.9953726910790524D-01), &
( -5.3629297906596329D-01, -8.4403189549006630D-01), ( -4.6868882203582790D-01, -8.8336333866573158D-01), &
( -3.9821756215337334D-01, -9.1729099700837802D-01), ( -3.2531029216226326D-01, -9.4560732538052117D-01), &
( -2.5041300657296539D-01, -9.6813910474636233D-01), ( -1.7398387338746377D-01, -9.8474850180190421D-01), &
( -9.6490431355253162D-02, -9.9533391214048217D-01), ( -1.8406729905805164D-02, -9.9983058179582340D-01), &
(  5.9789570746639764D-02, -9.9821100336047819D-01), (  1.3762012158648526D-01, -9.9048508425645709D-01), &
(  2.1460881099378709D-01, -9.7670008612871173D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9682029929116567D-01,  7.9682437971430126D-02), (  9.8730141815785843D-01,  1.5885814333386145D-01), &
(  9.7150389098625178D-01,  2.3702360599436720D-01), (  9.4952818059303667D-01,  3.1368174039889152D-01), &
(  9.2151403934204190D-01,  3.8834504669882625D-01), (  8.8763962040285393D-01,  4.6053871095824001D-01), &
(  8.4812034480329723D-01,  5.2980362468629461D-01), (  8.0320753148064494D-01,  5.9569930449243336D-01), &
(  7.5318679904361252D-01,  6.5780669329707864D-01), (  6.9837624940897292D-01,  7.1573082528381859D-01), &
(  6.3912444486377584D-01,  7.6910333764557959D-01), (  5.7580819141784545D-01,  8.1758481315158371D-01), &
(  5.0883014254310710D-01,  8.6086693863776720D-01), (  4.3861623853852771D-01,  8.9867446569395382D-01), &
(  3.6561299780477396D-01,  9.3076696107898371D-01), (  2.9028467725446228D-01,  9.5694033573220894D-01), &
(  2.1311031991609136D-01,  9.7702814265775439D-01), (  1.3458070850712622D-01,  9.9090263542778001D-01), &
(  5.5195244349690031D-02,  9.9847558057329477D-01), ( -2.4541228522912142D-02,  9.9969881869620425D-01), &
( -1.0412163387205461D-01,  9.9456457073425542D-01), ( -1.8303988795514073D-01,  9.8310548743121640D-01), &
( -2.6079411791527546D-01,  9.6539444169768940D-01), ( -3.3688985339221994D-01,  9.4154406518302081D-01), &
( -4.1084317105790397D-01,  9.1170603200542977D-01), ( -4.8218377207912272D-01,  8.7607009419540660D-01), &
( -5.5045797293660470D-01,  8.3486287498638012D-01), ( -6.1523159058062671D-01,  7.8834642762660634D-01), &
( -6.7609270357531581D-01,  7.3681656887737002D-01), ( -7.3265427167241270D-01,  6.8060099779545324D-01), &
( -7.8455659715557513D-01,  6.2005721176328943D-01), ( -8.3146961230254535D-01,  5.5557023301960218D-01), &
( -8.7309497841829020D-01,  4.8755016014843588D-01), ( -9.0916798309052238D-01,  4.1642956009763715D-01), &
( -9.3945922360218992D-01,  3.4266071731199443D-01), ( -9.6377606579543984D-01,  2.6671275747489848D-01), &
( -9.8196386910955524D-01,  1.8906866414980633D-01), ( -9.9390697000235606D-01,  1.1022220729388325D-01), &
( -9.9952941750109314D-01,  3.0674803176636865D-02), ( -9.9879545620517241D-01, -4.9067674327417724D-02), &
( -9.9170975366909953D-01, -1.2849811079379284D-01), ( -9.7831737071962765D-01, -2.0711137619221862D-01), &
( -9.5870347489587160D-01, -2.8440753721127188D-01), ( -9.3299279883473907D-01, -3.5989503653498767D-01), &
( -9.0134884704602203D-01, -4.3309381885315190D-01), ( -8.6397285612158681D-01, -5.0353838372571746D-01), &
( -8.2110251499110454D-01, -5.7078074588696748D-01), ( -7.7301045336273710D-01, -6.3439328416364527D-01), &
( -7.2000250796138188D-01, -6.9397146088965378D-01), ( -6.6241577759017178D-01, -7.4913639452345937D-01), &
( -6.0061647938386931D-01, -7.9953726910790479D-01), ( -5.3499761988709726D-01, -8.4485356524970712D-01), &
( -4.6597649576796585D-01, -8.8479709843093790D-01), ( -3.9399204006104821D-01, -9.1911385169005766D-01), &
( -3.1950203081601541D-01, -9.4758559101774120D-01), ( -2.4298017990326412D-01, -9.7003125319454397D-01), &
( -1.6491312048997064D-01, -9.8630809724459856D-01), ( -8.5797312344440213D-02, -9.9631261218277800D-01), &
( -6.1358846491544163D-03, -9.9998117528260111D-01), (  7.3564563599666996D-02, -9.9729045667869021D-01), &
(  1.5279718525844338D-01, -9.8825756773074946D-01), (  2.3105810828067058D-01, -9.7293995220556029D-01), &
(  3.0784964004153476D-01, -9.5143502096900845D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9669689520289606D-01,  8.1211446809592441D-02), (  9.8680940181418553D-01,  1.6188639378011183D-01)/
data (mpuu2(i), i =  7501,  7600) / &
(  9.7040283868755550D-01,  2.4149188530286933D-01), (  9.4758559101774109D-01,  3.1950203081601569D-01), &
(  9.1850839432521225D-01,  3.9540147894781635D-01), (  8.8336333866573158D-01,  4.6868882203582796D-01), &
(  8.4238259964318585D-01,  5.3887990853100842D-01), (  7.9583690460888357D-01,  6.0551104140432555D-01), &
(  7.4403374417992929D-01,  6.6814204142651845D-01), (  6.8731534089175916D-01,  7.2635915508434590D-01), &
(  6.2605638840434363D-01,  7.7977778792301433D-01), (  5.6066157619733603D-01,  8.2804504525775569D-01), &
(  4.9156291610654990D-01,  8.7084206347007886D-01), (  4.1921688836322396D-01,  9.0788611648766615D-01), &
(  3.4410142598993898D-01,  9.3893248353206449D-01), (  2.6671275747489842D-01,  9.6377606579543984D-01), &
(  1.8756212858252952D-01,  9.8225274136628937D-01), (  1.0717242495680887D-01,  9.9424044945318790D-01), &
(  2.6074717829104040D-02,  9.9965999674395922D-01), ( -5.5195244349689913D-02,  9.9847558057329477D-01), &
( -1.3610057517570628D-01,  9.9069502544266463D-01), ( -2.1610679707621927D-01,  9.7636973133002125D-01), &
( -2.9468537218051422D-01,  9.5559433413077111D-01), ( -3.7131719395183754D-01,  9.2850608047321559D-01), &
( -4.4549601651398185D-01,  8.9528392103855747D-01), ( -5.1673179901764998D-01,  8.5614732837519436D-01), &
( -5.8455394295301510D-01,  8.1135484701706395D-01), ( -6.4851440102211244D-01,  7.6120238548426189D-01), &
( -7.0819063703319540D-01,  7.0602126144933974D-01), ( -7.6318841726338116D-01,  6.4617601298331651D-01), &
( -8.1314441484925348D-01,  5.8206199034077566D-01), ( -8.5772861000027212D-01,  5.1410274419322177D-01), &
( -8.9664647017868027D-01,  4.4274722756456997D-01), ( -9.2964089584318133D-01,  3.6846682995337215D-01), &
( -9.5649391890239499D-01,  2.9175226323498943D-01), ( -9.7702814265775439D-01,  2.1311031991609142D-01), &
( -9.9110791372327689D-01,  1.3306052515713901D-01), ( -9.9864021818026516D-01,  5.2131704680283601D-02), &
( -9.9957529604674922D-01, -2.9141508764193559D-02), ( -9.9390697000235606D-01, -1.1022220729388300D-01), &
( -9.8167268619698322D-01, -1.9057475482025241D-01), ( -9.6295326687368388D-01, -2.6966832557291526D-01), &
( -9.3787237643998989D-01, -3.4698041084592351D-01), ( -9.0659570451491556D-01, -4.2200027079979924D-01), &
( -8.6932987134860673D-01, -4.9423230851595978D-01), ( -8.2632106284566365D-01, -5.6319934401383387D-01), &
( -7.7785340420945293D-01, -6.2844576660183293D-01), ( -7.2424708295146700D-01, -6.8954054473706683D-01), &
( -6.6585623366551006D-01, -7.4608007351006345D-01), ( -6.0306659854034805D-01, -7.9769084094339116D-01), &
( -5.3629297906596329D-01, -8.4403189549006630D-01), ( -4.6597649576796585D-01, -8.8479709843093790D-01), &
( -3.9258167407295147D-01, -9.1971714629122736D-01), ( -3.1659337555616612D-01, -9.4856134991573016D-01), &
( -2.3851359484431819D-01, -9.7113915844972520D-01), ( -1.5885814333386153D-01, -9.8730141815785832D-01), &
( -7.8153241632794648D-02, -9.9694135776498205D-01), (  3.0679567629661149D-03, -9.9999529380957619D-01), &
(  8.4268887593323877D-02, -9.9644305135004263D-01), (  1.6491312048996939D-01, -9.8630809724459878D-01), &
(  2.4446790274782418D-01, -9.6965738512429245D-01), (  3.2240767880106957D-01, -9.4660091308328365D-01), &
(  3.9821756215337384D-01, -9.1729099700837780D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9657114579055484D-01,  8.2740264549375692D-02), (  9.8630809724459867D-01,  1.6491312048996992D-01), &
(  9.6928123535654853D-01,  2.4595505033579459D-01), (  9.4560732538052128D-01,  3.2531029216226293D-01), &
(  9.1544871608826783D-01,  4.0243465085941843D-01), (  8.7901222642863353D-01,  4.7679923006332209D-01), &
(  8.3654772722351201D-01,  5.4789405917310019D-01), (  7.8834642762660634D-01,  6.1523159058062682D-01), &
(  7.3473887809596339D-01,  6.7835004312986147D-01), (  6.7609270357531603D-01,  7.3681656887736979D-01), &
(  6.1281008242940982D-01,  7.9023022143730992D-01), (  5.4532498842204657D-01,  8.3822470555483797D-01), &
(  4.7410021465055002D-01,  8.8047088905216075D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.2240767880106996D-01,  9.4660091308328353D-01), (  2.4298017990326398D-01,  9.7003125319454397D-01), &
(  1.6188639378011188D-01,  9.8680940181418542D-01), (  7.9682437971430126D-02,  9.9682029929116567D-01), &
( -3.0679567629657936D-03,  9.9999529380957619D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.6793829497473109D-01,  9.8579750916756748D-01), ( -2.4892760574571993D-01,  9.6852209427441738D-01), &
( -3.2820984357909233D-01,  9.4460483726148037D-01), ( -4.0524131400498975D-01,  9.1420975570353069D-01), &
( -4.7949375766015306D-01,  8.7754529020726124D-01), ( -5.5045797293660470D-01,  8.3486287498638012D-01), &
( -6.1764730793780376D-01,  7.8645521359908588D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.9210657730021217D-01,  6.1038280627630970D-01), &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.8192126434835494D-01,  4.7139673682599781D-01), &
( -9.1790077562139050D-01,  3.9680998741671025D-01), ( -9.4758559101774109D-01,  3.1950203081601580D-01), &
( -9.7077214072895024D-01,  2.4000302244874175D-01), ( -9.8730141815785843D-01,  1.5885814333386145D-01), &
( -9.9706007033948296D-01,  7.6623861392031686D-02), ( -9.9998117528260111D-01, -6.1358846491541101D-03)/
data (mpuu2(i), i =  7601,  7700) / &
( -9.9604470090125197D-01, -8.8853552582524503D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6775383709347551D-01, -2.5189781815421652D-01), ( -9.4359345816196039D-01, -3.3110630575987626D-01), &
( -9.1296219042839832D-01, -4.0804416286497835D-01), ( -8.7607009419540682D-01, -4.8218377207912233D-01), &
( -8.3317016470191330D-01, -5.5301670558002736D-01), ( -7.8455659715557546D-01, -6.2005721176328887D-01), &
( -7.3056276922782737D-01, -6.8284554638524830D-01), ( -6.7155895484701866D-01, -7.4095112535495877D-01), &
( -6.0794978496777408D-01, -7.9397547755433684D-01), ( -5.4017147272989274D-01, -8.4155497743689855D-01), &
( -4.6868882203582790D-01, -8.8336333866573158D-01), ( -3.9399204006104821D-01, -9.1911385169005766D-01), &
( -3.1659337555616612D-01, -9.4856134991573016D-01), ( -2.3702360599436767D-01, -9.7150389098625167D-01), &
( -1.5582839765426501D-01, -9.8778414164457218D-01), ( -7.3564563599667357D-02, -9.9729045667869021D-01), &
(  9.2037547820597154D-03, -9.9995764455196390D-01), (  9.1908956497132460D-02, -9.9576741446765982D-01), &
(  1.7398387338746338D-01, -9.8474850180190432D-01), (  2.5486565960451396D-01, -9.6697647104485229D-01), &
(  3.3399965144200949D-01, -9.4257319760144687D-01), (  4.1084317105790391D-01, -9.1170603200542988D-01), &
(  4.8486924800079084D-01, -8.7458665227817622D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9644305135004263D-01,  8.4268887593324071D-02), (  9.8579750916756748D-01,  1.6793829497473117D-01), &
(  9.6813910474636244D-01,  2.5041300657296522D-01), (  9.4359345816196039D-01,  3.3110630575987643D-01), &
(  9.1233518462332275D-01,  4.0944414869225759D-01), (  8.7458665227817622D-01,  4.8486924800079106D-01), &
(  8.3061640030884631D-01,  5.5684503727516010D-01), (  7.8073722857209449D-01,  6.2485948814238634D-01), &
(  7.2530397237306077D-01,  6.8842875278409044D-01), (  6.6471097820334490D-01,  7.4710060598018013D-01), &
(  5.9938929840056465D-01,  8.0045766219262271D-01), (  5.2980362468629483D-01,  8.4812034480329712D-01), &
(  4.5644898239688386D-01,  8.8974958638307289D-01), (  3.7984720892405111D-01,  9.2504924078267758D-01), &
(  3.0054324141727362D-01,  9.5376818988599021D-01), (  2.1910124015686977D-01,  9.7570213003852857D-01), &
(  1.3610057517570617D-01,  9.9069502544266463D-01), (  5.2131704680283317D-02,  9.9864021818026527D-01), &
( -3.2208025408304357D-02,  9.9948118696616695D-01), ( -1.1631863091190475D-01,  9.9321194923479450D-01), &
( -1.9960175762113094D-01,  9.7987710369951764D-01), ( -2.8146493792575772D-01,  9.5957151308198463D-01), &
( -3.6132580556845401D-01,  9.3243962926846247D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -5.1278640063356307D-01,  8.5851622426444274D-01), ( -5.8330865293769840D-01,  8.1225058658520388D-01), &
( -6.4968130739068286D-01,  7.6020668165120264D-01), ( -7.1143219574521654D-01,  7.0275474445722519D-01), &
( -7.6812202852336542D-01,  6.4030348218415156D-01), ( -8.1934752007679679D-01,  5.7329716669804254D-01), &
( -8.6474425751946216D-01,  5.0221247404571112D-01), ( -9.0398929312344334D-01,  4.2755509343028203D-01), &
( -9.3680344173592167D-01,  3.4985612979013486D-01), ( -9.6295326687368388D-01,  2.6966832557291504D-01), &
( -9.8225274136628937D-01,  1.8756212858252999D-01), ( -9.9456457073425542D-01,  1.0412163387205457D-01), &
( -9.9980116988788426D-01,  1.9940428551514438D-02), ( -9.9792528619859600D-01, -6.4382630929857007D-02), &
( -9.8895026451030299D-01, -1.4824767898689603D-01), ( -9.7293995220556018D-01, -2.3105810828067111D-01), &
( -9.5000824500184322D-01, -3.1222481392182450D-01), ( -9.2031827670911059D-01, -3.9117038430225387D-01), &
( -8.8408125871263499D-01, -4.6733320874198842D-01), ( -8.4155497743689867D-01, -5.4017147272989241D-01), &
( -7.9304196047944375D-01, -6.0916701233645310D-01), ( -7.3888732446061556D-01, -6.7382900037875570D-01), &
( -6.7947631989936486D-01, -7.3369743811466048D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.4661016691083542D-01, -8.3738720161566160D-01), ( -4.7410021465054974D-01, -8.8047088905216087D-01), &
( -3.9821756215337417D-01, -9.1729099700837768D-01), ( -3.1950203081601541D-01, -9.4758559101774120D-01), &
( -2.3851359484431819D-01, -9.7113915844972520D-01), ( -1.5582839765426587D-01, -9.8778414164457207D-01), &
( -7.2034653246889097D-02, -9.9740212990127530D-01), (  1.2271538285720144D-02, -9.9992470183914450D-01), &
(  9.6490431355251913D-02, -9.9533391214048239D-01), (  1.8002290140569971D-01, -9.8366241921173025D-01), &
(  2.6227470702391298D-01, -9.6499325285492055D-01), (  3.4266071731199371D-01, -9.3945922360219014D-01), &
(  4.2060907444840268D-01, -9.0724197791529582D-01), (  4.9556526182577187D-01, -8.6857070597134123D-01), &
(  5.6699604882510868D-01, -8.2372051122739132D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9631261218277800D-01,  8.5797312344439894D-02), (  9.8527764238894122D-01,  1.7096188876030122D-01), &
(  9.6697647104485207D-01,  2.5486565960451457D-01), (  9.4154406518302081D-01,  3.3688985339222005D-01), &
(  9.0916798309052238D-01,  4.1642956009763715D-01), (  8.7008699110871146D-01,  4.9289819222978404D-01), &
(  8.2458930278502529D-01,  5.6573181078361312D-01), (  7.7301045336273699D-01,  6.3439328416364549D-01), &
(  7.1573082528381859D-01,  6.9837624940897292D-01), (  6.5317284295377687D-01,  7.5720884650648446D-01)/
data (mpuu2(i), i =  7701,  7800) / &
(  5.8579785745643898D-01,  8.1045719825259466D-01), (  5.1410274419322177D-01,  8.5772861000027212D-01), &
(  4.3861623853852749D-01,  8.9867446569395393D-01), (  3.5989503653498828D-01,  9.3299279883473885D-01), &
(  2.7851968938505328D-01,  9.6043051941556579D-01), (  1.9509032201612830D-01,  9.8078528040323043D-01), &
(  1.1022220729388296D-01,  9.9390697000235606D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -6.1320736302208308D-02,  9.9811811290014918D-01), ( -1.4673047445536164D-01,  9.8917650996478101D-01), &
( -2.3105810828067117D-01,  9.7293995220556018D-01), ( -3.1368174039889124D-01,  9.4952818059303679D-01), &
( -3.9399204006104799D-01,  9.1911385169005777D-01), ( -4.7139673682599770D-01,  8.8192126434835505D-01), &
( -5.4532498842204657D-01,  8.3822470555483797D-01), ( -6.1523159058062704D-01,  7.8834642762660612D-01), &
( -6.8060099779545269D-01,  7.3265427167241315D-01), ( -7.4095112535495888D-01,  6.7155895484701855D-01), &
( -7.9583690460888346D-01,  6.0551104140432555D-01), ( -8.4485356524970689D-01,  5.3499761988709760D-01), &
( -8.8763962040285382D-01,  4.6053871095824023D-01), ( -9.2387953251128674D-01,  3.8268343236508984D-01), &
( -9.5330604035419386D-01,  3.0200594931922803D-01), ( -9.7570213003852857D-01,  2.1910124015686960D-01), &
( -9.9090263542778001D-01,  1.3458070850712628D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9932238458834954D-01, -3.6807222941359026D-02), ( -9.9247953459871008D-01, -1.2241067519921565D-01), &
( -9.7831737071962777D-01, -2.0711137619221817D-01), ( -9.5694033573220894D-01, -2.9028467725446216D-01), &
( -9.2850608047321581D-01, -3.7131719395183704D-01), ( -8.9322430119551532D-01, -4.4961132965460665D-01), &
( -8.5135519310526520D-01, -5.2458968267846873D-01), ( -8.0320753148064516D-01, -5.9569930449243291D-01), &
( -7.4913639452345926D-01, -6.6241577759017178D-01), ( -6.8954054473706716D-01, -7.2424708295146667D-01), &
( -6.2485948814238645D-01, -7.8073722857209438D-01), ( -5.5557023301960218D-01, -8.3146961230254524D-01), &
( -4.8218377207912339D-01, -8.7607009419540627D-01), ( -4.0524131400498953D-01, -9.1420975570353080D-01), &
( -3.2531029216226326D-01, -9.4560732538052117D-01), ( -2.4298017990326326D-01, -9.7003125319454420D-01), &
( -1.5885814333386153D-01, -9.8730141815785832D-01), ( -7.3564563599668231D-02, -9.9729045667869021D-01), &
(  1.2271538285720144D-02, -9.9992470183914450D-01), (  9.8017140329560090D-02, -9.9518472667219693D-01), &
(  1.8303988795514059D-01, -9.8310548743121640D-01), (  2.6671275747489820D-01, -9.6377606579543995D-01), &
(  3.4841868024943451D-01, -9.3733901191257496D-01), (  4.2755509343028136D-01, -9.0398929312344367D-01), &
(  5.0353838372571769D-01, -8.6397285612158670D-01), (  5.7580819141784489D-01, -8.1758481315158404D-01), &
(  6.4383154288979183D-01, -7.6516726562245863D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9617982859569698D-01,  8.7325535206192059D-02), (  9.8474850180190421D-01,  1.7398387338746382D-01), &
(  9.6579335887408368D-01,  2.5931291513288623D-01), (  9.3945922360218992D-01,  3.4266071731199438D-01), &
(  9.0594729780726846D-01,  4.2339047414379605D-01), (  8.6551362409056909D-01,  5.0088538261124071D-01), &
(  8.1846712958029866D-01,  5.7455335504771576D-01), (  7.6516726562245896D-01,  6.4383154288979139D-01), &
(  7.0602126144933985D-01,  7.0819063703319529D-01), (  6.4148101280858316D-01,  7.6713891193582029D-01), &
(  5.7203962932475727D-01,  8.2022598256943458D-01), (  4.9822766697278192D-01,  8.6704624551569265D-01), &
(  4.2060907444840251D-01,  9.0724197791529582D-01), (  3.3977688440682696D-01,  9.4050607059326830D-01), &
(  2.5634868248994308D-01,  9.6658437447833301D-01), (  1.7096188876030136D-01,  9.8527764238894122D-01), &
(  8.4268887593324113D-02,  9.9644305135004263D-01), ( -3.0679567629660156D-03,  9.9999529380957619D-01), &
( -9.0381360877864900D-02,  9.9590722941741172D-01), ( -1.7700422041214875D-01,  9.8421009238692903D-01), &
( -2.6227470702391370D-01,  9.6499325285492032D-01), ( -3.4554132496398882D-01,  9.3840353406310817D-01), &
( -4.2616788872679967D-01,  9.0464409057824624D-01), ( -5.0353838372571746D-01,  8.6397285612158681D-01), &
( -5.7706167285567966D-01,  8.1670057286682773D-01), ( -6.4617601298331639D-01,  7.6318841726338127D-01), &
( -7.1035334685706231D-01,  7.0384524052448505D-01), ( -7.6910333764557959D-01,  6.3912444486377584D-01), &
( -8.2197711527924167D-01,  5.6952051934694703D-01), ( -8.6857070597134067D-01,  4.9556526182577293D-01), &
( -9.0852811871630612D-01,  4.1782371582021244D-01), ( -9.4154406518302070D-01,  3.3688985339222027D-01), &
( -9.6736629222232851D-01,  2.5338203699557010D-01), ( -9.8579750916756737D-01,  1.6793829497473126D-01), &
( -9.9669689520289606D-01,  8.1211446809592663D-02), ( -9.9998117528260111D-01, -6.1358846491545542D-03), &
( -9.9562525638099431D-01, -9.3436335845747731D-02), ( -9.8366241921173025D-01, -1.8002290140569935D-01), &
( -9.6418406395174583D-01, -2.6523403028551151D-01), ( -9.3733901191257496D-01, -3.4841868024943456D-01), &
( -9.0333236849451204D-01, -4.2894129205532899D-01), ( -8.6242395611104050D-01, -5.0618664534515545D-01), &
( -8.1492632905652684D-01, -5.7956455913940541D-01), ( -7.6120238548426222D-01, -6.4851440102211200D-01), &
( -7.0166259474016868D-01, -7.1250937056469210D-01), ( -6.3676186123628420D-01, -7.7106052426181382D-01)/
data (mpuu2(i), i =  7801,  7900) / &
( -5.6699604882510835D-01, -8.2372051122739154D-01), ( -4.9289819222978426D-01, -8.7008699110871135D-01), &
( -4.1503442447608230D-01, -9.0980570810465200D-01), ( -3.3399965144200899D-01, -9.4257319760144698D-01), &
( -2.5041300657296539D-01, -9.6813910474636233D-01), ( -1.6491312048996978D-01, -9.8630809724459867D-01), &
( -7.8153241632794648D-02, -9.9694135776498205D-01), (  9.2037547820597154D-03, -9.9995764455196390D-01), &
(  9.6490431355252801D-02, -9.9533391214048228D-01), (  1.8303988795514059D-01, -9.8310548743121640D-01), &
(  2.6819085706340312D-01, -9.6336579978095405D-01), (  3.5129275608556737D-01, -9.3626566717027815D-01), &
(  4.3171065802505698D-01, -9.0201214390249329D-01), (  5.0883014254310621D-01, -8.6086693863776775D-01), &
(  5.8206199034077577D-01, -8.1314441484925337D-01), (  6.5084668499638065D-01, -7.5920918897838829D-01), &
(  7.1465868786276909D-01, -6.9947334464028377D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9604470090125197D-01,  8.8853552582524600D-02), (  9.8421009238692903D-01,  1.7700422041214875D-01), &
(  9.6458979328981276D-01,  2.6375467897483135D-01), (  9.3733901191257496D-01,  3.4841868024943456D-01), &
(  9.0267331823725883D-01,  4.3032648134008261D-01), (  8.6086693863776731D-01,  5.0883014254310699D-01), &
(  8.1225058658520388D-01,  5.8330865293769829D-01), (  7.5720884650648457D-01,  6.5317284295377676D-01), &
(  6.9617713149146310D-01,  7.1787004505573160D-01), (  6.2963823891492710D-01,  7.7688846567323244D-01), &
(  5.5811853122055632D-01,  8.2976123379452293D-01), (  4.8218377207912289D-01,  8.7607009419540649D-01), &
(  4.0243465085941832D-01,  9.1544871608826783D-01), (  3.1950203081601575D-01,  9.4758559101774109D-01), &
(  2.3404195858354365D-01,  9.7222649707893627D-01), (  1.4673047445536175D-01,  9.8917650996478101D-01), &
(  5.8258264500435732D-02,  9.9830154493389289D-01), ( -3.0674803176636459D-02,  9.9952941750109314D-01), &
( -1.1936521481099123D-01,  9.9285041445986510D-01), ( -2.0711137619221845D-01,  9.7831737071962765D-01), &
( -2.9321916269425879D-01,  9.5604525134999641D-01), ( -3.7700741021641798D-01,  9.2621024213831149D-01), &
( -4.5781330359887701D-01,  8.8904835585466468D-01), ( -5.3499761988709693D-01,  8.4485356524970723D-01), &
( -6.0794978496777352D-01,  7.9397547755433728D-01), ( -6.7609270357531615D-01,  7.3681656887736968D-01), &
( -7.3888732446061511D-01,  6.7382900037875615D-01), ( -7.9583690460888346D-01,  6.0551104140432555D-01), &
( -8.4649093877405202D-01,  5.3240312787719801D-01), ( -8.9044872324475766D-01,  4.5508358712634428D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.5694033573220882D-01,  2.9028467725446233D-01), &
( -9.7894817531906220D-01,  2.0410896609281684D-01), ( -9.9321194923479450D-01,  1.1631863091190471D-01), &
( -9.9961882249517864D-01,  2.7608145778966101D-02), ( -9.9811811290014918D-01, -6.1320736302208245D-02), &
( -9.8872169196032378D-01, -1.4976453467732168D-01), ( -9.7150389098625189D-01, -2.3702360599436695D-01), &
( -9.4660091308328365D-01, -3.2240767880106963D-01), ( -9.1420975570353069D-01, -4.0524131400498969D-01), &
( -8.7458665227817645D-01, -4.8486924800079056D-01), ( -8.2804504525775557D-01, -5.6066157619733625D-01), &
( -7.7495310659487393D-01, -6.3201873593980895D-01), ( -7.1573082528381904D-01, -6.9837624940897247D-01), &
( -6.5084668499638099D-01, -7.5920918897838796D-01), ( -5.8081395809576497D-01, -8.1403632970594808D-01), &
( -5.0618664534515534D-01, -8.6242395611104050D-01), ( -4.2755509343028247D-01, -9.0398929312344312D-01), &
( -3.4554132496398987D-01, -9.3840353406310784D-01), ( -2.6079411791527590D-01, -9.6539444169768929D-01), &
( -1.7398387338746377D-01, -9.8474850180190421D-01), ( -8.5797312344439339D-02, -9.9631261218277811D-01), &
(  3.0679567629661149D-03, -9.9999529380957619D-01), (  9.1908956497132460D-02, -9.9576741446765982D-01), &
(  1.8002290140569971D-01, -9.8366241921173025D-01), (  2.6671275747489820D-01, -9.6377606579543995D-01), &
(  3.5129275608556654D-01, -9.3626566717027848D-01), (  4.3309381885315185D-01, -9.0134884704602203D-01), &
(  5.1146885043796986D-01, -8.5930181835700870D-01), (  5.8579785745643798D-01, -8.1045719825259543D-01), &
(  6.5549285299961502D-01, -7.5520137689653688D-01), (  7.2000250796138165D-01, -6.9397146088965400D-01), &
(  7.7881651238147620D-01, -6.2725181549514375D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9590722941741172D-01,  9.0381360877864983D-02), (  9.8366241921173025D-01,  1.8002290140569951D-01), &
(  9.6336579978095405D-01,  2.6819085706340318D-01), (  9.3518350993894761D-01,  3.5416352542049034D-01), &
(  8.9934623697934157D-01,  4.3723717366104409D-01), (  8.5614732837519447D-01,  5.1673179901764987D-01), &
(  8.0594039057117628D-01,  5.9199669496204099D-01), (  7.4913639452345937D-01,  6.6241577759017178D-01), &
(  6.8620031168003870D-01,  7.2741262860237565D-01), (  6.1764730793780398D-01,  7.8645521359908577D-01), &
(  5.4403852673088404D-01,  8.3906023707031263D-01), (  4.6597649576796613D-01,  8.8479709843093779D-01), &
(  3.8410019501693504D-01,  9.2329141671952764D-01), (  2.9907982630804048D-01,  9.5422809510910567D-01), &
(  2.1161132736922761D-01,  9.7735390014519996D-01), (  1.2241067519921628D-01,  9.9247953459870997D-01), &
(  3.2208025408304482D-02,  9.9948118696616695D-01), ( -5.8258264500435607D-02,  9.9830154493389289D-01)/
data (mpuu2(i), i =  7901,  8000) / &
( -1.4824767898689586D-01,  9.8895026451030299D-01), ( -2.3702360599436723D-01,  9.7150389098625178D-01), &
( -3.2385936651785285D-01,  9.4610523237040345D-01), ( -4.0804416286497841D-01,  9.1296219042839821D-01), &
( -4.8888889691976306D-01,  8.7234605889439154D-01), ( -5.6573181078361323D-01,  8.2458930278502529D-01), &
( -6.3794390362184394D-01,  7.7008283699334812D-01), ( -7.0493408037590488D-01,  7.0927282643886569D-01), &
( -7.6615399019631281D-01,  6.4265703396622709D-01), ( -8.2110251499110465D-01,  5.7078074588696726D-01), &
( -8.6932987134860684D-01,  4.9423230851595956D-01), ( -9.1044129225806714D-01,  4.1363831223843461D-01), &
( -9.4410025849127255D-01,  3.2965846252858783D-01), ( -9.7003125319454397D-01,  2.4298017990326404D-01), &
( -9.8802201714328353D-01,  1.5431297301302008D-01), ( -9.9792528619859600D-01,  6.4382630929857257D-02), &
( -9.9965999674395922D-01, -2.6074717829103856D-02), ( -9.9321194923479461D-01, -1.1631863091190446D-01), &
( -9.7863392442942321D-01, -2.0561041305309916D-01), ( -9.5604525134999652D-01, -2.9321916269425830D-01), &
( -9.2563083050987283D-01, -3.7842775480876545D-01), ( -8.8763962040285393D-01, -4.6053871095824006D-01), &
( -8.4238259964318596D-01, -5.3887990853100820D-01), ( -7.9023022143731003D-01, -6.1281008242940971D-01), &
( -7.3160938122389274D-01, -6.8172407417164960D-01), ( -6.6699992230363803D-01, -7.4505778544146550D-01), &
( -5.9693070806219650D-01, -8.0229279553811572D-01), ( -5.2197529293715450D-01, -8.5296060493036352D-01), &
( -4.4274722756456963D-01, -8.9664647017868038D-01), ( -3.5989503653498794D-01, -9.3299279883473896D-01), &
( -2.7409690986870644D-01, -9.6170207652912254D-01), ( -1.8605515166344697D-01, -9.8253930228744124D-01), &
( -9.6490431355253162D-02, -9.9533391214048217D-01), ( -6.1358846491544163D-03, -9.9998117528260111D-01), &
(  8.4268887593323877D-02, -9.9644305135004263D-01), (  1.7398387338746338D-01, -9.8474850180190432D-01), &
(  2.6227470702391381D-01, -9.6499325285492032D-01), (  3.4841868024943451D-01, -9.3733901191257496D-01), &
(  4.3171065802505698D-01, -9.0201214390249329D-01), (  5.1146885043797063D-01, -8.5930181835700825D-01), &
(  5.8704039352091797D-01, -8.0955764240405126D-01), (  6.5780669329707853D-01, -7.5318679904361263D-01), &
(  7.2318848930652713D-01, -6.9065071413453494D-01), (  7.8265059616657529D-01, -6.2246127937415052D-01), &
(  8.3570628435375249D-01, -5.4917666218771977D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9576741446765982D-01,  9.1908956497132724D-02), (  9.8310548743121629D-01,  1.8303988795514095D-01), &
(  9.6212140426904158D-01,  2.7262135544994898D-01), (  9.3299279883473896D-01,  3.5989503653498811D-01), &
(  8.9596624975618522D-01,  4.4412214457042920D-01), (  8.5135519310526520D-01,  5.2458968267846895D-01), &
(  7.9953726910790501D-01,  6.0061647938386897D-01), (  7.4095112535495922D-01,  6.7155895484701833D-01), &
(  6.7609270357531603D-01,  7.3681656887736979D-01), (  6.0551104140432555D-01,  7.9583690460888346D-01), &
(  5.2980362468629483D-01,  8.4812034480329712D-01), (  4.4961132965460660D-01,  8.9322430119551532D-01), &
(  3.6561299780477374D-01,  9.3076696107898371D-01), (  2.7851968938505306D-01,  9.6043051941556579D-01), &
(  1.8906866414980628D-01,  9.8196386910955524D-01), (  9.8017140329560770D-02,  9.9518472667219682D-01), &
(  6.1358846491545160D-03,  9.9998117528260111D-01), ( -8.5797312344439769D-02,  9.9631261218277800D-01), &
( -1.7700422041214853D-01,  9.8421009238692914D-01), ( -2.6671275747489831D-01,  9.6377606579543984D-01), &
( -3.5416352542049040D-01,  9.3518350993894761D-01), ( -4.3861623853852738D-01,  8.9867446569395393D-01), &
( -5.1935599016558920D-01,  8.5455798836540076D-01), ( -5.9569930449243325D-01,  8.0320753148064494D-01), &
( -6.6699992230363736D-01,  7.4505778544146606D-01), ( -7.3265427167241293D-01,  6.8060099779545291D-01), &
( -7.9210657730021217D-01,  6.1038280627630970D-01), ( -8.4485356524970712D-01,  5.3499761988709715D-01), &
( -8.9044872324475788D-01,  4.5508358712634389D-01), ( -9.2850608047321548D-01,  3.7131719395183765D-01), &
( -9.5870347489587149D-01,  2.8440753721127204D-01), ( -9.8078528040323043D-01,  1.9509032201612858D-01), &
( -9.9456457073425542D-01,  1.0412163387205457D-01), ( -9.9992470183914450D-01,  1.2271538285720007D-02), &
( -9.9682029929116578D-01, -7.9682437971429945D-02), ( -9.8527764238894133D-01, -1.7096188876030097D-01), &
( -9.6539444169768940D-01, -2.6079411791527563D-01), ( -9.3733901191257507D-01, -3.4841868024943418D-01), &
( -9.0134884704602203D-01, -4.3309381885315190D-01), ( -8.5772861000027212D-01, -5.1410274419322155D-01), &
( -8.0684755354379945D-01, -5.9075970185887405D-01), ( -7.4913639452345926D-01, -6.6241577759017178D-01), &
( -6.8508366777270080D-01, -7.2846439044822486D-01), ( -6.1523159058062737D-01, -7.8834642762660589D-01), &
( -5.4017147272989274D-01, -8.4155497743689855D-01), ( -4.6053871095824067D-01, -8.8763962040285360D-01), &
( -3.7700741021641820D-01, -9.2621024213831138D-01), ( -2.9028467725446239D-01, -9.5694033573220882D-01), &
( -2.0110463484209207D-01, -9.7956976568544052D-01), ( -1.1022220729388331D-01, -9.9390697000235606D-01), &
( -1.8406729905805164D-02, -9.9983058179582340D-01), (  7.3564563599667884D-02, -9.9729045667869021D-01), &
(  1.6491312048996939D-01, -9.8630809724459878D-01), (  2.5486565960451396D-01, -9.6697647104485229D-01)/
data (mpuu2(i), i =  8001,  8100) / &
(  3.4266071731199454D-01, -9.3945922360218981D-01), (  4.2755509343028220D-01, -9.0398929312344334D-01), &
(  5.0883014254310621D-01, -8.6086693863776775D-01), (  5.8579785745643875D-01, -8.1045719825259488D-01), &
(  6.5780669329707853D-01, -7.5318679904361263D-01), (  7.2424708295146667D-01, -6.8954054473706716D-01), &
(  7.8455659715557502D-01, -6.2005721176328943D-01), (  8.3822470555483775D-01, -5.4532498842204680D-01), &
(  8.8479709843093790D-01, -4.6597649576796590D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9562525638099431D-01,  9.3436335845747787D-02), (  9.8253930228744124D-01,  1.8605515166344663D-01), &
(  9.6085663310767966D-01,  2.7704608030609990D-01), (  9.3076696107898371D-01,  3.6561299780477385D-01), &
(  8.9253355540276458D-01,  4.5098098904510386D-01), (  8.4649093877405213D-01,  5.3240312787719790D-01), &
(  7.9304196047944364D-01,  6.0916701233645321D-01), (  7.3265427167241282D-01,  6.8060099779545302D-01), &
(  6.6585623366550972D-01,  7.4608007351006367D-01), (  5.9323229503979991D-01,  8.0503133114296355D-01), &
(  5.1541787801946315D-01,  8.5693897741782865D-01), (  4.3309381885315201D-01,  9.0134884704602203D-01), &
(  3.4698041084592368D-01,  9.3787237643998989D-01), (  2.5783110216215893D-01,  9.6619000344541262D-01), &
(  1.6642590354046422D-01,  9.8605396334619544D-01), (  7.3564563599667454D-02,  9.9729045667869021D-01), &
( -1.9940428551514476D-02,  9.9980116988788426D-01), ( -1.1327095217756424D-01,  9.9356413552059530D-01), &
( -2.0561041305309899D-01,  9.7863392442942321D-01), ( -2.9615088824362384D-01,  9.5514116830577067D-01), &
( -3.8410019501693515D-01,  9.2329141671952764D-01), ( -4.6868882203582768D-01,  8.8336333866573169D-01), &
( -5.4917666218771954D-01,  8.3570628435375272D-01), ( -6.2485948814238623D-01,  7.8073722857209460D-01), &
( -6.9507511398000077D-01,  7.1893712237280449D-01), ( -7.5920918897838796D-01,  6.5084668499638099D-01), &
( -8.1670057286682751D-01,  5.7706167285567989D-01), ( -8.6704624551569265D-01,  4.9822766697278176D-01), &
( -9.0980570810465233D-01,  4.1503442447608146D-01), ( -9.4460483726148015D-01,  3.2820984357909272D-01), &
( -9.7113915844972509D-01,  2.3851359484431855D-01), ( -9.8917650996478101D-01,  1.4673047445536180D-01), &
( -9.9855907422975931D-01,  5.3663537652730520D-02), ( -9.9920475861836389D-01, -3.9872927587739880D-02), &
( -9.9110791372327689D-01, -1.3306052515713879D-01), ( -9.7433938278557586D-01, -2.2508391135979261D-01), &
( -9.4904588185270067D-01, -3.1513792875252228D-01), ( -9.1544871608826806D-01, -4.0243465085941793D-01), &
( -8.7384184346536686D-01, -4.8621027612448642D-01), ( -8.2458930278502529D-01, -5.6573181078361323D-01), &
( -7.6812202852336564D-01, -6.4030348218415145D-01), ( -7.0493408037590477D-01, -7.0927282643886569D-01), &
( -6.3557832048855667D-01, -7.7203639715038408D-01), ( -5.6066157619733659D-01, -8.2804504525775546D-01), &
( -4.8083933060033368D-01, -8.7680872380914587D-01), ( -3.9680998741671070D-01, -9.1790077562139027D-01), &
( -3.0930876031226823D-01, -9.5096166631157530D-01), ( -2.1910124015687010D-01, -9.7570213003852846D-01), &
( -1.2697669649688612D-01, -9.9190570043060933D-01), ( -3.3741171851377760D-02, -9.9943060455546173D-01), &
(  5.9789570746639764D-02, -9.9821100336047819D-01), (  1.5279718525844338D-01, -9.8825756773074946D-01), &
(  2.4446790274782418D-01, -9.6965738512429245D-01), (  3.3399965144200866D-01, -9.4257319760144709D-01), &
(  4.2060907444840268D-01, -9.0724197791529582D-01), (  5.0353838372571769D-01, -8.6397285612158670D-01), &
(  5.8206199034077499D-01, -8.1314441484925393D-01), (  6.5549285299961568D-01, -7.5520137689653632D-01), &
(  7.2318848930652713D-01, -6.9065071413453494D-01), (  7.8455659715557502D-01, -6.2005721176328943D-01), &
(  8.3906023707031252D-01, -5.4403852673088415D-01), (  8.8622253014888053D-01, -4.6325978355186043D-01), &
(  9.2563083050987272D-01, -3.7842775480876573D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9548075549192694D-01,  9.4963495329638992D-02), (  9.8196386910955524D-01,  1.8906866414980619D-01), &
(  9.5957151308198452D-01,  2.8146493792575794D-01), (  9.2850608047321559D-01,  3.7131719395183754D-01), &
(  8.8904835585466457D-01,  4.5781330359887723D-01), (  8.4155497743689844D-01,  5.4017147272989285D-01), &
(  7.8645521359908577D-01,  6.1764730793780387D-01), (  7.2424708295146700D-01,  6.8954054473706683D-01), &
(  6.5549285299961546D-01,  7.5520137689653644D-01), (  5.8081395809576464D-01,  8.1403632970594830D-01), &
(  5.0088538261124094D-01,  8.6551362409056898D-01), (  4.1642956009763732D-01,  9.0916798309052238D-01), &
(  3.2820984357909244D-01,  9.4460483726148026D-01), (  2.3702360599436734D-01,  9.7150389098625178D-01), &
(  1.4369503315029458D-01,  9.8962201746320078D-01), (  4.9067674327418133D-02,  9.9879545620517241D-01), &
( -4.6003182130914741D-02,  9.9894129318685687D-01), ( -1.4065823933284913D-01,  9.9005821026229712D-01), &
( -2.3404195858354335D-01,  9.7222649707893627D-01), ( -3.2531029216226287D-01,  9.4560732538052139D-01), &
( -4.1363831223843450D-01,  9.1044129225806725D-01), ( -4.9822766697278154D-01,  8.6704624551569287D-01), &
( -5.7831379641165548D-01,  8.1581441080673389D-01), ( -6.5317284295377653D-01,  7.5720884650648479D-01), &
( -7.2212819392921523D-01,  6.9175925836415786D-01), ( -7.8455659715557535D-01,  6.2005721176328898D-01)/
data (mpuu2(i), i =  8101,  8200) / &
( -8.3989379419599952D-01,  5.4275078486451589D-01), ( -8.8763962040285382D-01,  4.6053871095824023D-01), &
( -9.2736252565040111D-01,  3.7416406297145799D-01), ( -9.5870347489587149D-01,  2.8440753721127204D-01), &
( -9.8137919331375456D-01,  1.9208039704989244D-01), ( -9.9518472667219682D-01,  9.8017140329560840D-02), &
( -9.9999529380957619D-01,  3.0679567629659770D-03), ( -9.9576741446765982D-01, -9.1908956497132960D-02), &
( -9.8253930228744135D-01, -1.8605515166344624D-01), ( -9.6043051941556590D-01, -2.7851968938505289D-01), &
( -9.2964089584318121D-01, -3.6846682995337238D-01), ( -8.9044872324475799D-01, -4.5508358712634367D-01), &
( -8.4320823964184566D-01, -5.3758707629564517D-01), ( -7.8834642762660634D-01, -6.1523159058062671D-01), &
( -7.2635915508434623D-01, -6.8731534089175883D-01), ( -6.5780669329707886D-01, -7.5318679904361230D-01), &
( -5.8330865293769829D-01, -8.1225058658520388D-01), ( -5.0353838372571813D-01, -8.6397285612158647D-01), &
( -4.1921688836322429D-01, -9.0788611648766604D-01), ( -3.3110630575987654D-01, -9.4359345816196027D-01), &
( -2.4000302244874142D-01, -9.7077214072895035D-01), ( -1.4673047445536233D-01, -9.8917650996478090D-01), &
( -5.2131704680283657D-02, -9.9864021818026516D-01), (  4.2938256934940716D-02, -9.9907772775264536D-01), &
(  1.3762012158648615D-01, -9.9048508425645698D-01), (  2.3105810828067144D-01, -9.7293995220556007D-01), &
(  3.2240767880106957D-01, -9.4660091308328365D-01), (  4.1084317105790391D-01, -9.1170603200542988D-01), &
(  4.9556526182577265D-01, -8.6857070597134078D-01), (  5.7580819141784489D-01, -8.1758481315158404D-01), &
(  6.5084668499638065D-01, -7.5920918897838829D-01), (  7.2000250796138165D-01, -6.9397146088965400D-01), &
(  7.8265059616657529D-01, -6.2246127937415052D-01), (  8.3822470555483775D-01, -5.4532498842204680D-01), &
(  8.8622253014888053D-01, -4.6325978355186043D-01), (  9.2621024213831138D-01, -3.7700741021641826D-01), &
(  9.5782641302753291D-01, -2.8734745954472929D-01), (  1.0000000000000000D+00,  0.0000000000000000D+00), &
(  9.9533391214048228D-01,  9.6490431355252593D-02), (  9.8137919331375456D-01,  1.9208039704989244D-01), &
(  9.5826607140801767D-01,  2.8587783472708062D-01), (  9.2621024213831138D-01,  3.7700741021641826D-01), &
(  8.8551085613619995D-01,  4.6461868630623782D-01), (  8.3654772722351201D-01,  5.4789405917310019D-01), &
(  7.7977778792301455D-01,  6.2605638840434352D-01), (  7.1573082528381859D-01,  6.9837624940897292D-01), &
(  6.4500453681554404D-01,  7.6417874053611667D-01), (  5.6825895267013160D-01,  8.2284978137582632D-01), &
(  4.8621027612448658D-01,  8.7384184346536675D-01), (  3.9962419984564679D-01,  9.1667905992104270D-01), &
(  3.0930876031226873D-01,  9.5096166631157508D-01), (  2.1610679707621960D-01,  9.7636973133002114D-01), &
(  1.2088808723577722D-01,  9.9266614244894802D-01), (  2.4541228522912267D-02,  9.9969881869620425D-01), &
( -7.2034653246889305D-02,  9.9740212990127530D-01), ( -1.6793829497473109D-01,  9.8579750916756748D-01), &
( -2.6227470702391348D-01,  9.6499325285492044D-01), ( -3.5416352542049040D-01,  9.3518350993894761D-01), &
( -4.4274722756457024D-01,  8.9664647017868015D-01), ( -5.2719913478190106D-01,  8.4974176800085266D-01), &
( -6.0673112703452414D-01,  7.9490712632823723D-01), ( -6.8060099779545302D-01,  7.3265427167241282D-01), &
( -7.4811938045040360D-01,  6.6356415861203977D-01), ( -8.0865618158817498D-01,  5.8828154822264533D-01), &
( -8.6164646114308130D-01,  5.0750899105297098D-01), ( -9.0659570451491533D-01,  4.2200027079979985D-01), &
( -9.4308443746609361D-01,  3.3255336986604406D-01), ( -9.7077214072895024D-01,  2.4000302244874175D-01), &
( -9.8940042779138027D-01,  1.4521292465284780D-01), ( -9.9879545620517241D-01,  4.9067674327417973D-02), &
( -9.9886954991428356D-01, -4.7535484156959296D-02), ( -9.8962201746320089D-01, -1.4369503315029442D-01), &
( -9.7113915844972509D-01, -2.3851359484431833D-01), ( -9.4359345816196039D-01, -3.3110630575987626D-01), &
( -9.0724197791529593D-01, -4.2060907444840234D-01), ( -8.6242395611104072D-01, -5.0618664534515512D-01), &
( -8.0955764240405148D-01, -5.8704039352091775D-01), ( -7.4913639452345926D-01, -6.6241577759017178D-01), &
( -6.8172407417165015D-01, -7.3160938122389219D-01), ( -6.0794978496777341D-01, -7.9397547755433739D-01), &
( -5.2850200154222859D-01, -8.4893205521163950D-01), ( -4.4412214457042976D-01, -8.9596624975618488D-01), &
( -3.5559766170478407D-01, -9.3463912981968067D-01), ( -2.6375467897483207D-01, -9.6458979328981254D-01), &
( -1.6945029123396740D-01, -9.8553873531217617D-01), ( -7.3564563599667357D-02, -9.9729045667869021D-01), &
(  2.3007681468838942D-02, -9.9973528826056168D-01), (  1.1936521481099133D-01, -9.9285041445986510D-01), &
(  2.1460881099378623D-01, -9.7670008612871195D-01), (  3.0784964004153476D-01, -9.5143502096900845D-01), &
(  3.9821756215337384D-01, -9.1729099700837780D-01), (  4.8486924800079084D-01, -8.7458665227817622D-01), &
(  5.6699604882510868D-01, -8.2372051122739132D-01), (  6.4383154288979116D-01, -7.6516726562245918D-01), &
(  7.1465868786276843D-01, -6.9947334464028443D-01), (  7.7881651238147620D-01, -6.2725181549514375D-01), &
(  8.3570628435375249D-01, -5.4917666218771977D-01), (  8.8479709843093746D-01, -4.6597649576796668D-01), &
(  9.2563083050987272D-01, -3.7842775480876573D-01), (  9.5782641302753269D-01, -2.8734745954473018D-01)/
data (mpuu2(i), i =  8201,  8205) / &
(  9.8108339115048659D-01, -1.9358558729580391D-01), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00), (  0.0000000000000000D+00,  0.0000000000000000D+00), &
(  0.0000000000000000D+00,  0.0000000000000000D+00)/

end module mpfuna


